@@ -18,16 +18,16 @@
  */
 
 
-#include "accessibility/extended/accessibletablistboxtable.hxx"
-#include "accessibility/extended/AccessibleBrowseBoxTableCell.hxx"
-#include "accessibility/extended/AccessibleBrowseBoxCheckBoxCell.hxx"
+#include <extended/accessibletablistboxtable.hxx>
+#include <extended/AccessibleBrowseBoxTableCell.hxx>
+#include <extended/AccessibleBrowseBoxCheckBoxCell.hxx>
 #include <svtools/svtabbx.hxx>
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
 
-//........................................................................
+
 namespace accessibility
 {
-//........................................................................
+
 
     // class AccessibleTabListBoxTable ---------------------------------------------
 
@@ -36,9 +36,9 @@ namespace accessibility
     using namespace ::com::sun::star::lang;
     using namespace ::com::sun::star;
 
-    // -----------------------------------------------------------------------------
+
     // Ctor() and Dtor()
-    // -----------------------------------------------------------------------------
+
     AccessibleTabListBoxTable::AccessibleTabListBoxTable( const Reference< XAccessible >& rxParent, SvHeaderTabListBox& rBox ) :
 
         AccessibleBrowseBoxTable( rxParent, rBox ),
@@ -48,38 +48,38 @@ namespace accessibility
     {
         m_pTabListBox->AddEventListener( LINK( this, AccessibleTabListBoxTable, WindowEventListener ) );
     }
-    // -----------------------------------------------------------------------------
+
     AccessibleTabListBoxTable::~AccessibleTabListBoxTable()
     {
         if ( isAlive() )
         {
-            m_pTabListBox = NULL;
+            m_pTabListBox = nullptr;
 
             // increment ref count to prevent double call of Dtor
             osl_atomic_increment( &m_refCount );
             dispose();
         }
     }
-    // -----------------------------------------------------------------------------
+
     void AccessibleTabListBoxTable::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
     {
         if ( isAlive() )
         {
-            sal_uLong nEventId = rVclWindowEvent.GetId();
+            VclEventId nEventId = rVclWindowEvent.GetId();
             switch ( nEventId )
             {
-                case  VCLEVENT_OBJECT_DYING :
+                case  VclEventId::ObjectDying :
                 {
                     m_pTabListBox->RemoveEventListener( LINK( this, AccessibleTabListBoxTable, WindowEventListener ) );
-                    m_pTabListBox = NULL;
+                    m_pTabListBox = nullptr;
                     break;
                 }
 
-                case VCLEVENT_CONTROL_GETFOCUS :
-                case VCLEVENT_CONTROL_LOSEFOCUS :
+                case VclEventId::ControlGetFocus :
+                case VclEventId::ControlLoseFocus :
                 {
                     uno::Any aOldValue, aNewValue;
-                    if ( VCLEVENT_CONTROL_GETFOCUS == nEventId )
+                    if ( nEventId == VclEventId::ControlGetFocus )
                         aNewValue <<= AccessibleStateType::FOCUSED;
                     else
                         aOldValue <<= AccessibleStateType::FOCUSED;
@@ -87,7 +87,7 @@ namespace accessibility
                     break;
                 }
 
-                case VCLEVENT_LISTBOX_SELECT :
+                case VclEventId::ListboxSelect :
                 {
                     // First send an event that tells the listeners of a
                     // modified selection.  The active descendant event is
@@ -108,7 +108,7 @@ namespace accessibility
                             if ( m_pTabListBox->IsTransientChildrenDisabled() )
                             {
                                 aNewValue <<= AccessibleStateType::FOCUSED;
-                                TriState eState = STATE_DONTKNOW;
+                                TriState eState = TRISTATE_INDET;
                                 if ( m_pTabListBox->IsCellCheckBox( nRow, nCol, eState ) )
                                 {
                                     AccessibleCheckBoxCell* pCell =
@@ -131,8 +131,65 @@ namespace accessibility
                     }
                     break;
                 }
+                case VclEventId::WindowGetFocus :
+                {
+                    uno::Any aOldValue, aNewValue;
+                    aNewValue <<= AccessibleStateType::FOCUSED;
+                    commitEvent( AccessibleEventId::STATE_CHANGED, aNewValue, aOldValue );
+                    break;
 
-                case VCLEVENT_CHECKBOX_TOGGLE :
+                }
+                case VclEventId::WindowLoseFocus :
+                {
+                    uno::Any aOldValue, aNewValue;
+                    aOldValue <<= AccessibleStateType::FOCUSED;
+                    commitEvent( AccessibleEventId::STATE_CHANGED, aNewValue, aOldValue );
+                    break;
+                }
+                case VclEventId::ListboxTreeSelect:
+                    {
+                        SvTreeListEntry* pEntry = static_cast< SvTreeListEntry* >( rVclWindowEvent.GetData() );
+                        if (pEntry)
+                        {
+                            sal_Int32 nRow = m_pTabListBox->GetEntryPos( pEntry );
+                            Reference< XAccessible > xChild = m_pTabListBox->CreateAccessibleCell( nRow, m_pTabListBox->GetCurrColumn() );
+                            TriState eState = TRISTATE_INDET;
+                            if ( m_pTabListBox->IsCellCheckBox( nRow, m_pTabListBox->GetCurrColumn(), eState ) )
+                            {
+                                AccessibleCheckBoxCell* pCell = static_cast< AccessibleCheckBoxCell* >( xChild.get() );
+                                pCell->commitEvent( AccessibleEventId::SELECTION_CHANGED, Any(), Any() );
+                            }
+                            else
+                            {
+                                AccessibleBrowseBoxTableCell* pCell = static_cast< AccessibleBrowseBoxTableCell* >( xChild.get() );
+                                pCell->commitEvent( AccessibleEventId::SELECTION_CHANGED, Any(), Any() );
+                            }
+                        }
+                    }
+                    break;
+                case VclEventId::ListboxTreeFocus:
+                    {
+                        if ( m_pTabListBox && m_pTabListBox->HasFocus() )
+                        {
+                            uno::Any aOldValue, aNewValue;
+                            SvTreeListEntry* pEntry = static_cast< SvTreeListEntry* >( rVclWindowEvent.GetData() );
+                            if ( pEntry )
+                            {
+                                sal_Int32 nRow = m_pTabListBox->GetEntryPos( pEntry );
+                                m_xCurChild = m_pTabListBox->CreateAccessibleCell( nRow, m_pTabListBox->GetCurrColumn() );
+                                aNewValue <<= m_xCurChild;
+                                commitEvent( AccessibleEventId::ACTIVE_DESCENDANT_CHANGED, aNewValue ,aOldValue);
+                            }
+                            else
+                            {
+                                aNewValue <<= AccessibleStateType::FOCUSED;
+                                commitEvent( AccessibleEventId::STATE_CHANGED, aNewValue ,aOldValue);
+                            }
+                        }
+                    }
+                    break;
+
+                case VclEventId::CheckboxToggle :
                 {
                     if ( m_pTabListBox && m_pTabListBox->HasFocus() )
                     {
@@ -141,27 +198,27 @@ namespace accessibility
                         {
                             sal_Int32 nRow = m_pTabListBox->GetEntryPos( pEntry );
                             sal_uInt16 nCol = m_pTabListBox->GetCurrColumn();
-                            TriState eState = STATE_DONTKNOW;
+                            TriState eState = TRISTATE_INDET;
                             if ( m_pTabListBox->IsCellCheckBox( nRow, nCol, eState ) )
                             {
                                 Reference< XAccessible > xChild =
                                     m_pTabListBox->CreateAccessibleCell( nRow, nCol );
                                 AccessibleCheckBoxCell* pCell =
                                     static_cast< AccessibleCheckBoxCell* >( xChild.get() );
-                                pCell->SetChecked( m_pTabListBox->IsItemChecked( pEntry, nCol ) );
+                                pCell->SetChecked( SvHeaderTabListBox::IsItemChecked( pEntry, nCol ) );
                             }
                         }
                     }
                     break;
                 }
 
-                case VCLEVENT_TABLECELL_NAMECHANGED :
+                case VclEventId::TableCellNameChanged :
                 {
                     if ( m_pTabListBox->IsTransientChildrenDisabled() )
                     {
                         commitEvent( AccessibleEventId::SELECTION_CHANGED, Any(), Any() );
                         TabListBoxEventData* pData = static_cast< TabListBoxEventData* >( rVclWindowEvent.GetData() );
-                        SvTreeListEntry* pEntry = pData != NULL ? pData->m_pEntry : NULL;
+                        SvTreeListEntry* pEntry = pData != nullptr ? pData->m_pEntry : nullptr;
                         if ( pEntry )
                         {
                             sal_Int32 nRow = m_pTabListBox->GetEntryPos( pEntry );
@@ -169,16 +226,16 @@ namespace accessibility
                             Reference< XAccessible > xChild =
                                 m_pTabListBox->CreateAccessibleCell( nRow, nCol );
                             uno::Any aOldValue, aNewValue;
-                            aOldValue <<= OUString( pData->m_sOldText );
+                            aOldValue <<= pData->m_sOldText;
                             OUString sNewText( m_pTabListBox->GetCellText( nRow, nCol ) );
                             aNewValue <<= sNewText;
-                            TriState eState = STATE_DONTKNOW;
+                            TriState eState = TRISTATE_INDET;
 
                             if ( m_pTabListBox->IsCellCheckBox( nRow, nCol, eState ) )
                             {
                                 AccessibleCheckBoxCell* pCell =
                                     static_cast< AccessibleCheckBoxCell* >( xChild.get() );
-                                pCell->commitEvent( AccessibleEventId::NAME_CHANGED, aOldValue, aNewValue );
+                                pCell->commitEvent( AccessibleEventId::NAME_CHANGED, aNewValue, aOldValue );
                             }
                             else
                             {
@@ -190,35 +247,25 @@ namespace accessibility
                     }
                     break;
                 }
+                default: break;
             }
         }
     }
-    // -----------------------------------------------------------------------------
-    IMPL_LINK( AccessibleTabListBoxTable, WindowEventListener, VclSimpleEvent*, pEvent )
+
+    IMPL_LINK( AccessibleTabListBoxTable, WindowEventListener, VclWindowEvent&, rEvent, void )
     {
-        OSL_ENSURE( pEvent && pEvent->ISA( VclWindowEvent ), "Unknown WindowEvent!" );
-        if ( pEvent && pEvent->ISA( VclWindowEvent ) )
-        {
-            OSL_ENSURE( ( (VclWindowEvent*)pEvent )->GetWindow() && m_pTabListBox, "no event window" );
-            ProcessWindowEvent( *(VclWindowEvent*)pEvent );
-        }
-        return 0;
+        OSL_ENSURE( rEvent.GetWindow() && m_pTabListBox, "no event window" );
+        ProcessWindowEvent( rEvent );
     }
     // helpers --------------------------------------------------------------------
 
     void AccessibleTabListBoxTable::ensureValidIndex( sal_Int32 _nIndex ) const
-            SAL_THROW( ( IndexOutOfBoundsException ) )
     {
-        if ( ( _nIndex < 0 ) || ( _nIndex >= implGetCellCount() ) )
+        if ( ( _nIndex < 0 ) || ( _nIndex >= (implGetRowCount() * implGetColumnCount()) ) )
             throw IndexOutOfBoundsException();
     }
 
-    sal_Bool AccessibleTabListBoxTable::implIsRowSelected( sal_Int32 _nRow ) const
-    {
-        return m_pTabListBox ? m_pTabListBox->IsSelected( m_pTabListBox->GetEntry( _nRow ) ) : sal_False;
-    }
-
-    void AccessibleTabListBoxTable::implSelectRow( sal_Int32 _nRow, sal_Bool _bSelect )
+    void AccessibleTabListBoxTable::implSelectRow( sal_Int32 _nRow, bool _bSelect )
     {
         if ( m_pTabListBox )
             m_pTabListBox->Select( m_pTabListBox->GetEntry( _nRow ), _bSelect );
@@ -256,77 +303,77 @@ namespace accessibility
 
         return 0;
     }
-    // -----------------------------------------------------------------------------
+
     // XInterface & XTypeProvider
-    // -----------------------------------------------------------------------------
+
     IMPLEMENT_FORWARD_XINTERFACE2(AccessibleTabListBoxTable, AccessibleBrowseBoxTable, AccessibleTabListBoxTableImplHelper)
     IMPLEMENT_FORWARD_XTYPEPROVIDER2(AccessibleTabListBoxTable, AccessibleBrowseBoxTable, AccessibleTabListBoxTableImplHelper)
-    // -----------------------------------------------------------------------------
+
     // XServiceInfo
-    // -----------------------------------------------------------------------------
-    OUString AccessibleTabListBoxTable::getImplementationName (void) throw (RuntimeException)
+
+    OUString AccessibleTabListBoxTable::getImplementationName()
     {
         return OUString( "com.sun.star.comp.svtools.AccessibleTabListBoxTable" );
     }
-    // -----------------------------------------------------------------------------
+
     // XAccessibleSelection
-    // -----------------------------------------------------------------------------
-    void SAL_CALL AccessibleTabListBoxTable::selectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    void SAL_CALL AccessibleTabListBoxTable::selectAccessibleChild( sal_Int32 nChildIndex )
     {
         SolarMutexGuard aSolarGuard;
-        ::osl::MutexGuard aGuard( getOslMutex() );
+        ::osl::MutexGuard aGuard( getMutex() );
 
         ensureIsAlive();
         ensureValidIndex( nChildIndex );
 
-        implSelectRow( implGetRow( nChildIndex ), sal_True );
+        implSelectRow( implGetRow( nChildIndex ), true );
     }
-    // -----------------------------------------------------------------------------
-    sal_Bool SAL_CALL AccessibleTabListBoxTable::isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    sal_Bool SAL_CALL AccessibleTabListBoxTable::isAccessibleChildSelected( sal_Int32 nChildIndex )
     {
         SolarMutexGuard aSolarGuard;
-        ::osl::MutexGuard aGuard( getOslMutex() );
+        ::osl::MutexGuard aGuard( getMutex() );
 
         ensureIsAlive();
         ensureValidIndex( nChildIndex );
 
-        return implIsRowSelected( implGetRow( nChildIndex ) );
+        return m_pTabListBox && m_pTabListBox->IsSelected( m_pTabListBox->GetEntry( implGetRow( nChildIndex ) ) );
     }
-    // -----------------------------------------------------------------------------
-    void SAL_CALL AccessibleTabListBoxTable::clearAccessibleSelection(  ) throw (RuntimeException)
+
+    void SAL_CALL AccessibleTabListBoxTable::clearAccessibleSelection(  )
     {
         SolarMutexGuard aSolarGuard;
-        ::osl::MutexGuard aGuard( getOslMutex() );
+        ::osl::MutexGuard aGuard( getMutex() );
 
         ensureIsAlive();
 
         m_pTabListBox->SetNoSelection();
     }
-    // -----------------------------------------------------------------------------
-    void SAL_CALL AccessibleTabListBoxTable::selectAllAccessibleChildren(  ) throw (RuntimeException)
+
+    void SAL_CALL AccessibleTabListBoxTable::selectAllAccessibleChildren(  )
     {
         SolarMutexGuard aSolarGuard;
-        ::osl::MutexGuard aGuard( getOslMutex() );
+        ::osl::MutexGuard aGuard( getMutex() );
 
         ensureIsAlive();
 
         m_pTabListBox->SelectAll();
     }
-    // -----------------------------------------------------------------------------
-    sal_Int32 SAL_CALL AccessibleTabListBoxTable::getSelectedAccessibleChildCount(  ) throw (RuntimeException)
+
+    sal_Int32 SAL_CALL AccessibleTabListBoxTable::getSelectedAccessibleChildCount(  )
     {
         SolarMutexGuard aSolarGuard;
-        ::osl::MutexGuard aGuard( getOslMutex() );
+        ::osl::MutexGuard aGuard( getMutex() );
 
         ensureIsAlive();
 
         return implGetColumnCount() * implGetSelRowCount();
     }
-    // -----------------------------------------------------------------------------
-    Reference< XAccessible > SAL_CALL AccessibleTabListBoxTable::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    Reference< XAccessible > SAL_CALL AccessibleTabListBoxTable::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex )
     {
         SolarMutexGuard aSolarGuard;
-        ::osl::MutexGuard aGuard( getOslMutex() );
+        ::osl::MutexGuard aGuard( getMutex() );
 
         ensureIsAlive();
 
@@ -338,20 +385,20 @@ namespace accessibility
         sal_Int32 nColumn = nSelectedChildIndex / nRows;
         return getAccessibleCellAt( nRow, nColumn );
     }
-    // -----------------------------------------------------------------------------
-    void SAL_CALL AccessibleTabListBoxTable::deselectAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (IndexOutOfBoundsException, RuntimeException)
+
+    void SAL_CALL AccessibleTabListBoxTable::deselectAccessibleChild( sal_Int32 nSelectedChildIndex )
     {
         SolarMutexGuard aSolarGuard;
-        ::osl::MutexGuard aGuard( getOslMutex() );
+        ::osl::MutexGuard aGuard( getMutex() );
 
         ensureIsAlive();
         ensureValidIndex( nSelectedChildIndex );
 
-        implSelectRow( implGetRow( nSelectedChildIndex ), sal_False );
+        implSelectRow( implGetRow( nSelectedChildIndex ), false );
     }
 
-//........................................................................
+
 }// namespace accessibility
-//........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
