@@ -20,7 +20,7 @@
 #include <standard/vclxaccessibletoolboxitem.hxx>
 #include <toolkit/helper/convert.hxx>
 #include <helper/accresmgr.hxx>
-#include <helper/accessiblestrings.hrc>
+#include <strings.hrc>
 #include <com/sun/star/awt/Point.hpp>
 #include <com/sun/star/awt/Rectangle.hpp>
 #include <com/sun/star/awt/Size.hpp>
@@ -30,6 +30,7 @@
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 #include <com/sun/star/datatransfer/clipboard/XClipboard.hpp>
 #include <com/sun/star/datatransfer/clipboard/XFlushableClipboard.hpp>
+#include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
 #include <cppuhelper/supportsservice.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/toolbox.hxx>
@@ -37,11 +38,11 @@
 #include <vcl/help.hxx>
 #include <vcl/settings.hxx>
 #include <toolkit/awt/vclxwindow.hxx>
-#include <toolkit/helper/externallock.hxx>
 #include <unotools/accessiblestatesethelper.hxx>
 #include <unotools/accessiblerelationsethelper.hxx>
 #include <cppuhelper/typeprovider.hxx>
 #include <comphelper/sequence.hxx>
+#include <strings.hxx>
 
 #include <com/sun/star/accessibility/XAccessibleSelection.hpp>
 
@@ -58,9 +59,6 @@ using namespace ::comphelper;
 // Ctor() and Dtor()
 
 VCLXAccessibleToolBoxItem::VCLXAccessibleToolBoxItem( ToolBox* _pToolBox, sal_Int32 _nPos ) :
-
-    AccessibleTextHelper_BASE( new VCLExternalSolarLock() ),
-
     m_pToolBox      ( _pToolBox ),
     m_nIndexInParent( _nPos ),
     m_nRole         ( AccessibleRole::PUSH_BUTTON ),
@@ -70,14 +68,12 @@ VCLXAccessibleToolBoxItem::VCLXAccessibleToolBoxItem( ToolBox* _pToolBox, sal_In
     m_bIndeterminate( false )
 
 {
-    m_pExternalLock = static_cast< VCLExternalSolarLock* >( getExternalLock( ) );
-
     OSL_ENSURE( m_pToolBox, "invalid toolbox" );
-    m_nItemId = m_pToolBox->GetItemId( (sal_uInt16)m_nIndexInParent );
+    m_nItemId = m_pToolBox->GetItemId( m_nIndexInParent );
     m_sOldName = GetText();
     m_bIsChecked = m_pToolBox->IsItemChecked( m_nItemId );
     m_bIndeterminate = ( m_pToolBox->GetItemState( m_nItemId ) == TRISTATE_INDET );
-    ToolBoxItemType eType = m_pToolBox->GetItemType( (sal_uInt16)m_nIndexInParent );
+    ToolBoxItemType eType = m_pToolBox->GetItemType( m_nIndexInParent );
     switch ( eType )
     {
         case ToolBoxItemType::BUTTON :
@@ -117,8 +113,6 @@ VCLXAccessibleToolBoxItem::VCLXAccessibleToolBoxItem( ToolBox* _pToolBox, sal_In
 
 VCLXAccessibleToolBoxItem::~VCLXAccessibleToolBoxItem()
 {
-    delete m_pExternalLock;
-    m_pExternalLock = nullptr;
 }
 
 OUString VCLXAccessibleToolBoxItem::GetText()
@@ -215,8 +209,8 @@ void VCLXAccessibleToolBoxItem::SetChild( const Reference< XAccessible >& _xChil
 
 void VCLXAccessibleToolBoxItem::NotifyChildEvent( const Reference< XAccessible >& _xChild, bool _bShow )
 {
-    Any aOld = _bShow ? Any() : makeAny( _xChild );
-    Any aNew = _bShow ? makeAny( _xChild ) : Any();
+    Any aOld = _bShow ? Any() : Any( _xChild );
+    Any aNew = _bShow ? Any( _xChild ) : Any();
     NotifyAccessibleEvent( AccessibleEventId::CHILD, aOld, aNew );
 }
 
@@ -238,11 +232,11 @@ void VCLXAccessibleToolBoxItem::ToggleEnableState()
     NotifyAccessibleEvent( AccessibleEventId::STATE_CHANGED, aOldValue[1], aNewValue[1] );
 }
 
-awt::Rectangle VCLXAccessibleToolBoxItem::implGetBounds(  ) throw (RuntimeException)
+awt::Rectangle VCLXAccessibleToolBoxItem::implGetBounds(  )
 {
     awt::Rectangle aRect;
     if ( m_pToolBox )
-        aRect = AWTRectangle( m_pToolBox->GetItemPosRect( (sal_uInt16)m_nIndexInParent ) );
+        aRect = AWTRectangle( m_pToolBox->GetItemPosRect( m_nIndexInParent ) );
 
     return aRect;
 }
@@ -266,7 +260,7 @@ void VCLXAccessibleToolBoxItem::implGetSelection( sal_Int32& nStartIndex, sal_In
 // XInterface
 
 IMPLEMENT_FORWARD_REFCOUNT( VCLXAccessibleToolBoxItem, AccessibleTextHelper_BASE )
-Any SAL_CALL VCLXAccessibleToolBoxItem::queryInterface( const Type& _rType ) throw (RuntimeException, std::exception)
+Any SAL_CALL VCLXAccessibleToolBoxItem::queryInterface( const Type& _rType )
 {
     // #i33611# - toolbox buttons without text don't support XAccessibleText
     if ( _rType == cppu::UnoType<XAccessibleText>::get()
@@ -293,17 +287,17 @@ void SAL_CALL VCLXAccessibleToolBoxItem::disposing()
 
 // XServiceInfo
 
-OUString VCLXAccessibleToolBoxItem::getImplementationName() throw (RuntimeException, std::exception)
+OUString VCLXAccessibleToolBoxItem::getImplementationName()
 {
     return OUString( "com.sun.star.comp.toolkit.AccessibleToolBoxItem" );
 }
 
-sal_Bool VCLXAccessibleToolBoxItem::supportsService( const OUString& rServiceName ) throw (RuntimeException, std::exception)
+sal_Bool VCLXAccessibleToolBoxItem::supportsService( const OUString& rServiceName )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
-Sequence< OUString > VCLXAccessibleToolBoxItem::getSupportedServiceNames() throw (RuntimeException, std::exception)
+Sequence< OUString > VCLXAccessibleToolBoxItem::getSupportedServiceNames()
 {
     return {"com.sun.star.accessibility.AccessibleContext",
             "com.sun.star.accessibility.AccessibleComponent",
@@ -313,21 +307,21 @@ Sequence< OUString > VCLXAccessibleToolBoxItem::getSupportedServiceNames() throw
 
 // XAccessible
 
-Reference< XAccessibleContext > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleContext(  ) throw (RuntimeException, std::exception)
+Reference< XAccessibleContext > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleContext(  )
 {
     return this;
 }
 
 // XAccessibleContext
 
-sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleChildCount(  ) throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleChildCount(  )
 {
     OContextEntryGuard aGuard( this );
 
     return m_xChild.is() ? 1 : 0;
 }
 
-Reference< XAccessible > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleChild( sal_Int32 i ) throw (RuntimeException,  css::lang::IndexOutOfBoundsException, std::exception)
+Reference< XAccessible > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleChild( sal_Int32 i )
 {
     OContextEntryGuard aGuard( this );
 
@@ -338,34 +332,34 @@ Reference< XAccessible > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleChild(
     return m_xChild;
 }
 
-Reference< XAccessible > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleParent(  ) throw (RuntimeException, std::exception)
+Reference< XAccessible > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleParent(  )
 {
     OContextEntryGuard aGuard( this );
 
     return m_pToolBox->GetAccessible();
 }
 
-sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleIndexInParent(  ) throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleIndexInParent(  )
 {
     OContextEntryGuard aGuard( this );
 
     return m_nIndexInParent;
 }
 
-sal_Int16 SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleRole(  ) throw (RuntimeException, std::exception)
+sal_Int16 SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleRole(  )
 {
     OContextEntryGuard aGuard( this );
 
     return m_nRole;
 }
 
-OUString SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleDescription(  ) throw (RuntimeException, std::exception)
+OUString SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleDescription(  )
 {
     OExternalLockGuard aGuard( this );
 
-    if (m_nRole == AccessibleRole::PANEL && getAccessibleChildCount() > 0)
+    if (m_nRole == AccessibleRole::PANEL && m_xChild.is())
     {
-        return TK_RES_STRING( RID_STR_ACC_PANEL_DESCRIPTION );
+        return AccResId( RID_STR_ACC_PANEL_DESCRIPTION );
     }
     else
     {
@@ -376,7 +370,7 @@ OUString SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleDescription(  ) throw
     }
 }
 
-OUString SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleName(  ) throw (RuntimeException, std::exception)
+OUString SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleName(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -384,7 +378,7 @@ OUString SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleName(  ) throw (Runtim
     return GetText();
 }
 
-Reference< XAccessibleRelationSet > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleRelationSet(  ) throw (RuntimeException, std::exception)
+Reference< XAccessibleRelationSet > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleRelationSet(  )
 {
     OContextEntryGuard aGuard( this );
 
@@ -393,7 +387,7 @@ Reference< XAccessibleRelationSet > SAL_CALL VCLXAccessibleToolBoxItem::getAcces
     return xSet;
 }
 
-Reference< XAccessibleStateSet > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleStateSet(  ) throw (RuntimeException, std::exception)
+Reference< XAccessibleStateSet > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleStateSet(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -427,22 +421,48 @@ Reference< XAccessibleStateSet > SAL_CALL VCLXAccessibleToolBoxItem::getAccessib
 
 // XAccessibleText
 
-sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getCaretPosition() throw (RuntimeException, std::exception)
+OUString VCLXAccessibleToolBoxItem::getText()
+{
+    OExternalLockGuard aGuard( this );
+
+    return GetText();
+}
+
+sal_Int32 VCLXAccessibleToolBoxItem::getCharacterCount()
+{
+    return GetText().getLength();
+}
+
+sal_Unicode VCLXAccessibleToolBoxItem::getCharacter( sal_Int32 nIndex )
+{
+     OExternalLockGuard aGuard( this );
+
+    return OCommonAccessibleText::implGetCharacter( GetText(), nIndex );
+}
+
+OUString VCLXAccessibleToolBoxItem::getTextRange( sal_Int32 nStartIndex, sal_Int32 nEndIndex )
+{
+     OExternalLockGuard aGuard( this );
+
+    return OCommonAccessibleText::implGetTextRange( GetText(), nStartIndex, nEndIndex );
+}
+
+sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getCaretPosition()
 {
     return -1;
 }
 
-sal_Bool SAL_CALL VCLXAccessibleToolBoxItem::setCaretPosition( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+sal_Bool SAL_CALL VCLXAccessibleToolBoxItem::setCaretPosition( sal_Int32 nIndex )
 {
     OExternalLockGuard aGuard( this );
 
-    if ( !implIsValidRange( nIndex, nIndex, implGetText().getLength() ) )
+    if ( !implIsValidRange( nIndex, nIndex, GetText().getLength() ) )
         throw IndexOutOfBoundsException();
 
     return false;
 }
 
-Sequence< PropertyValue > SAL_CALL VCLXAccessibleToolBoxItem::getCharacterAttributes( sal_Int32 nIndex, const Sequence< OUString >& ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+Sequence< PropertyValue > SAL_CALL VCLXAccessibleToolBoxItem::getCharacterAttributes( sal_Int32 nIndex, const Sequence< OUString >& )
 {
     OExternalLockGuard aGuard( this );
 
@@ -454,7 +474,7 @@ Sequence< PropertyValue > SAL_CALL VCLXAccessibleToolBoxItem::getCharacterAttrib
     return Sequence< PropertyValue >();
 }
 
-awt::Rectangle SAL_CALL VCLXAccessibleToolBoxItem::getCharacterBounds( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+awt::Rectangle SAL_CALL VCLXAccessibleToolBoxItem::getCharacterBounds( sal_Int32 nIndex )
 {
     OExternalLockGuard aGuard( this );
 
@@ -466,8 +486,8 @@ awt::Rectangle SAL_CALL VCLXAccessibleToolBoxItem::getCharacterBounds( sal_Int32
     awt::Rectangle aBounds( 0, 0, 0, 0 );
     if ( m_pToolBox && m_pToolBox->GetButtonType() != ButtonType::SYMBOLONLY ) // symbol buttons have no character bounds
     {
-        Rectangle aCharRect = m_pToolBox->GetCharacterBounds( m_nItemId, nIndex );
-        Rectangle aItemRect = m_pToolBox->GetItemRect( m_nItemId );
+        tools::Rectangle aCharRect = m_pToolBox->GetCharacterBounds( m_nItemId, nIndex );
+        tools::Rectangle aItemRect = m_pToolBox->GetItemRect( m_nItemId );
         aCharRect.Move( -aItemRect.Left(), -aItemRect.Top() );
         aBounds = AWTRectangle( aCharRect );
     }
@@ -475,7 +495,7 @@ awt::Rectangle SAL_CALL VCLXAccessibleToolBoxItem::getCharacterBounds( sal_Int32
     return aBounds;
 }
 
-sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getIndexAtPoint( const awt::Point& aPoint ) throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getIndexAtPoint( const awt::Point& aPoint )
 {
     OExternalLockGuard aGuard( this );
 
@@ -483,7 +503,7 @@ sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getIndexAtPoint( const awt::Point&
     if ( m_pToolBox && m_pToolBox->GetButtonType() != ButtonType::SYMBOLONLY ) // symbol buttons have no character bounds
     {
         sal_uInt16 nItemId = 0;
-        Rectangle aItemRect = m_pToolBox->GetItemRect( m_nItemId );
+        tools::Rectangle aItemRect = m_pToolBox->GetItemRect( m_nItemId );
         Point aPnt( VCLPoint( aPoint ) );
         aPnt += aItemRect.TopLeft();
         sal_Int32 nIdx = m_pToolBox->GetIndexForPoint( aPnt, nItemId );
@@ -494,7 +514,7 @@ sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getIndexAtPoint( const awt::Point&
     return nIndex;
 }
 
-sal_Bool SAL_CALL VCLXAccessibleToolBoxItem::setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+sal_Bool SAL_CALL VCLXAccessibleToolBoxItem::setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex )
 {
     OExternalLockGuard aGuard( this );
 
@@ -504,7 +524,7 @@ sal_Bool SAL_CALL VCLXAccessibleToolBoxItem::setSelection( sal_Int32 nStartIndex
     return false;
 }
 
-sal_Bool SAL_CALL VCLXAccessibleToolBoxItem::copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+sal_Bool SAL_CALL VCLXAccessibleToolBoxItem::copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex )
 {
     OExternalLockGuard aGuard( this );
 
@@ -518,7 +538,7 @@ sal_Bool SAL_CALL VCLXAccessibleToolBoxItem::copyText( sal_Int32 nStartIndex, sa
         Reference< datatransfer::clipboard::XClipboard > xClipboard = m_pToolBox->GetClipboard();
         if ( xClipboard.is() )
         {
-            OUString sText( getTextRange( nStartIndex, nEndIndex ) );
+            OUString sText( OCommonAccessibleText::implGetTextRange( implGetText(), nStartIndex, nEndIndex ) );
 
             vcl::unohelper::TextDataObject* pDataObj = new vcl::unohelper::TextDataObject( sText );
 
@@ -538,12 +558,12 @@ sal_Bool SAL_CALL VCLXAccessibleToolBoxItem::copyText( sal_Int32 nStartIndex, sa
 
 // XAccessibleComponent
 
-Reference< XAccessible > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleAtPoint( const awt::Point& ) throw (RuntimeException, std::exception)
+Reference< XAccessible > SAL_CALL VCLXAccessibleToolBoxItem::getAccessibleAtPoint( const awt::Point& )
 {
     return Reference< XAccessible >();
 }
 
-void SAL_CALL VCLXAccessibleToolBoxItem::grabFocus(  ) throw (RuntimeException, std::exception)
+void SAL_CALL VCLXAccessibleToolBoxItem::grabFocus(  )
 {
     Reference< XAccessible > xParent(getAccessibleParent());
 
@@ -558,7 +578,7 @@ void SAL_CALL VCLXAccessibleToolBoxItem::grabFocus(  ) throw (RuntimeException,
     }
 }
 
-sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getForeground(  ) throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getForeground(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -569,7 +589,7 @@ sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getForeground(  ) throw (RuntimeEx
     return nColor;
 }
 
-sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getBackground(  ) throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getBackground(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -581,12 +601,12 @@ sal_Int32 SAL_CALL VCLXAccessibleToolBoxItem::getBackground(  ) throw (RuntimeEx
 }
 
 // XAccessibleExtendedComponent
-Reference< awt::XFont > SAL_CALL VCLXAccessibleToolBoxItem::getFont(    ) throw (RuntimeException, std::exception)
+Reference< awt::XFont > SAL_CALL VCLXAccessibleToolBoxItem::getFont(    )
 {
     return uno::Reference< awt::XFont >();
 }
 
-OUString SAL_CALL VCLXAccessibleToolBoxItem::getTitledBorderText(  ) throw (RuntimeException, std::exception)
+OUString SAL_CALL VCLXAccessibleToolBoxItem::getTitledBorderText(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -597,7 +617,7 @@ OUString SAL_CALL VCLXAccessibleToolBoxItem::getTitledBorderText(  ) throw (Runt
     return sRet;
 }
 
-OUString SAL_CALL VCLXAccessibleToolBoxItem::getToolTipText(  ) throw (RuntimeException, std::exception)
+OUString SAL_CALL VCLXAccessibleToolBoxItem::getToolTipText(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -617,17 +637,17 @@ OUString SAL_CALL VCLXAccessibleToolBoxItem::getToolTipText(  ) throw (RuntimeEx
 
 // XAccessibleAction
 
-sal_Int32 VCLXAccessibleToolBoxItem::getAccessibleActionCount( ) throw (RuntimeException, std::exception)
+sal_Int32 VCLXAccessibleToolBoxItem::getAccessibleActionCount( )
 {
     // only one action -> "Click"
     return 1;
 }
 
-sal_Bool VCLXAccessibleToolBoxItem::doAccessibleAction ( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+sal_Bool VCLXAccessibleToolBoxItem::doAccessibleAction ( sal_Int32 nIndex )
 {
     OExternalLockGuard aGuard( this );
 
-    if ( nIndex < 0 || nIndex >= getAccessibleActionCount() )
+    if ( nIndex != 0 )
         throw IndexOutOfBoundsException();
 
     if ( m_pToolBox )
@@ -636,21 +656,21 @@ sal_Bool VCLXAccessibleToolBoxItem::doAccessibleAction ( sal_Int32 nIndex ) thro
     return true;
 }
 
-OUString VCLXAccessibleToolBoxItem::getAccessibleActionDescription ( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+OUString VCLXAccessibleToolBoxItem::getAccessibleActionDescription ( sal_Int32 nIndex )
 {
     OExternalLockGuard aGuard( this );
 
-    if ( nIndex < 0 || nIndex >= getAccessibleActionCount() )
+    if ( nIndex != 0 )
         throw IndexOutOfBoundsException();
 
-    return OUString( TK_RES_STRING( RID_STR_ACC_ACTION_CLICK ) );
+    return OUString(RID_STR_ACC_ACTION_CLICK);
 }
 
-Reference< XAccessibleKeyBinding > VCLXAccessibleToolBoxItem::getAccessibleActionKeyBinding( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+Reference< XAccessibleKeyBinding > VCLXAccessibleToolBoxItem::getAccessibleActionKeyBinding( sal_Int32 nIndex )
 {
     OContextEntryGuard aGuard( this );
 
-    if ( nIndex < 0 || nIndex >= getAccessibleActionCount() )
+    if ( nIndex != 0 )
         throw IndexOutOfBoundsException();
 
     return Reference< XAccessibleKeyBinding >();
@@ -658,7 +678,7 @@ Reference< XAccessibleKeyBinding > VCLXAccessibleToolBoxItem::getAccessibleActio
 
 // XAccessibleValue
 
-Any VCLXAccessibleToolBoxItem::getCurrentValue(  ) throw (RuntimeException, std::exception)
+Any VCLXAccessibleToolBoxItem::getCurrentValue(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -671,7 +691,7 @@ Any VCLXAccessibleToolBoxItem::getCurrentValue(  ) throw (RuntimeException, std:
     return aValue;
 }
 
-sal_Bool VCLXAccessibleToolBoxItem::setCurrentValue( const Any& aNumber ) throw (RuntimeException, std::exception)
+sal_Bool VCLXAccessibleToolBoxItem::setCurrentValue( const Any& aNumber )
 {
     OExternalLockGuard aGuard( this );
 
@@ -694,14 +714,14 @@ sal_Bool VCLXAccessibleToolBoxItem::setCurrentValue( const Any& aNumber ) throw
     return bReturn;
 }
 
-Any VCLXAccessibleToolBoxItem::getMaximumValue(  ) throw (RuntimeException, std::exception)
+Any VCLXAccessibleToolBoxItem::getMaximumValue(  )
 {
-    return makeAny((sal_Int32)1);
+    return Any((sal_Int32)1);
 }
 
-Any VCLXAccessibleToolBoxItem::getMinimumValue(  ) throw (RuntimeException, std::exception)
+Any VCLXAccessibleToolBoxItem::getMinimumValue(  )
 {
-    return makeAny((sal_Int32)0);
+    return Any((sal_Int32)0);
 }
 
 
