@@ -17,27 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <tools/resmgr.hxx>
-#include <svl/solar.hrc>
-#include <vcl/svapp.hxx>
-#include <vcl/settings.hxx>
-
+#include <unotools/resmgr.hxx>
 #include <mediamisc.hxx>
 
 namespace avmedia {
 
-ResMgr* GetResMgr()
+const std::locale& GetResLocale()
 {
-    static ResMgr* pResMgr = nullptr;
-
-    if( !pResMgr )
-    {
-        pResMgr = ResMgr::CreateResMgr("avmedia", Application::GetSettings().GetUILanguageTag());
-    }
-
-    return pResMgr;
+    static std::locale loc = Translate::Create("avmedia");
+    return loc;
 }
 
-} // namespace avemdia
+} // namespace avmedia
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
