@@ -21,7 +21,7 @@
 
 #include "breakpoint.hxx"
 #include "brkdlg.hxx"
-#include "basidesh.hxx"
+#include <basidesh.hxx>
 
 #include <sfx2/dispatch.hxx>
 
@@ -121,7 +121,7 @@ void BreakPointDialog::dispose()
     ModalDialog::dispose();
 }
 
-void BreakPointDialog::SetCurrentBreakPoint( BreakPoint* pBrk )
+void BreakPointDialog::SetCurrentBreakPoint( BreakPoint const * pBrk )
 {
     OUString aStr( "# " + OUString::number(pBrk->nLine) );
     m_pComboBox->SetText( aStr );
@@ -222,7 +222,7 @@ IMPL_LINK( BreakPointDialog, ButtonHdl, Button *, pButton, void )
         {
             delete m_aModifiedBreakPointList.remove( pBrk );
             m_pComboBox->RemoveEntryAt(nEntry);
-            if ( nEntry && !( nEntry < m_pComboBox->GetEntryCount() ) )
+            if ( nEntry && nEntry >= m_pComboBox->GetEntryCount() )
                 nEntry--;
             m_pComboBox->SetText( m_pComboBox->GetEntry( nEntry ) );
             if (SfxDispatcher* pDispatcher = GetDispatcher())
@@ -233,7 +233,7 @@ IMPL_LINK( BreakPointDialog, ButtonHdl, Button *, pButton, void )
 }
 
 
-void BreakPointDialog::UpdateFields( BreakPoint* pBrk )
+void BreakPointDialog::UpdateFields( BreakPoint const * pBrk )
 {
     if ( pBrk )
     {
