@@ -17,15 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "localizationmgr.hxx"
+#include <localizationmgr.hxx>
 
-#include "basidesh.hxx"
-#include "baside3.hxx"
-#include "iderdll.hxx"
-#include "dlged.hxx"
-#include "managelang.hxx"
+#include <basidesh.hxx>
+#include <baside3.hxx>
+#include <iderdll.hxx>
+#include <dlged.hxx>
+#include <managelang.hxx>
 
 #include <com/sun/star/frame/XLayoutManager.hpp>
+#include <com/sun/star/resource/MissingResourceException.hpp>
 #include <com/sun/star/resource/XStringResourceSupplier.hpp>
 #include <sfx2/dispatch.hxx>
 
@@ -68,7 +69,6 @@ bool LocalizationMgr::isLibraryLocalized ()
 
 void LocalizationMgr::handleTranslationbar ()
 {
-    static const char aLayoutManagerName[] = "LayoutManager";
     static const char aToolBarResName[] = "private:resource/toolbar/translationbar";
 
     Reference< beans::XPropertySet > xFrameProps
@@ -76,7 +76,7 @@ void LocalizationMgr::handleTranslationbar ()
     if ( xFrameProps.is() )
     {
         Reference< css::frame::XLayoutManager > xLayoutManager;
-        uno::Any a = xFrameProps->getPropertyValue( aLayoutManagerName );
+        uno::Any a = xFrameProps->getPropertyValue( "LayoutManager" );
         a >>= xLayoutManager;
         if ( xLayoutManager.is() )
         {
@@ -96,11 +96,6 @@ void LocalizationMgr::handleTranslationbar ()
 
 // TODO: -> export from toolkit
 
-namespace
-{
-
-
-}
 
 bool isLanguageDependentProperty( const OUString& aName )
 {
@@ -137,7 +132,7 @@ void LocalizationMgr::implEnableDisableResourceForAllLibraryDialogs( HandleResou
     for( sal_Int32 i = 0 ; i < nDlgCount ; i++ )
     {
         OUString aDlgName = pDlgNames[ i ];
-        if (DialogWindow* pWin = m_pShell->FindDlgWin(m_aDocument, m_aLibName, aDlgName))
+        if (VclPtr<DialogWindow> pWin = m_pShell->FindDlgWin(m_aDocument, m_aLibName, aDlgName))
         {
             Reference< container::XNameContainer > xDialog = pWin->GetDialog();
             if( xDialog.is() )
@@ -171,10 +166,10 @@ OUString implCreatePureResourceId
       const Reference< XStringResourceManager >& xStringResourceManager )
 {
     sal_Int32 nUniqueId = xStringResourceManager->getUniqueNumericId();
-    OUString aPureIdStr = OUString::number( nUniqueId );
-    aPureIdStr += aDot;
-    aPureIdStr += aDialogName;
-    aPureIdStr += aDot;
+    OUString aPureIdStr = OUString::number( nUniqueId )
+                        + aDot
+                        + aDialogName
+                        + aDot;
     if( !aCtrlName.isEmpty() )
     {
         aPureIdStr += aCtrlName;
@@ -402,10 +397,10 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                         aIdStrings.realloc( nPropStringCount );
                         OUString* pIdStrings = aIdStrings.getArray();
 
-                        OUString aIdStrBase = aDot;
-                        aIdStrBase += aCtrlName;
-                        aIdStrBase += aDot;
-                        aIdStrBase += aPropName;
+                        OUString aIdStrBase = aDot
+                                            + aCtrlName
+                                            + aDot
+                                            + aPropName;
 
                         const Locale* pLocales = aLocaleSeq.getConstArray();
                         sal_Int32 i;
@@ -420,8 +415,8 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             }
 
                             sal_Int32 nUniqueId = xStringResourceManager->getUniqueNumericId();
-                            OUString aPureIdStr = OUString::number( nUniqueId );
-                            aPureIdStr += aIdStrBase;
+                            OUString aPureIdStr = OUString::number( nUniqueId )
+                                                + aIdStrBase;
 
                             // Set Id for all locales
                             for( sal_Int32 iLocale = 0 ; iLocale < nLocaleCount ; iLocale++ )
@@ -430,8 +425,7 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                                 xStringResourceManager->setStringForLocale( aPureIdStr, aPropStr, rLocale );
                             }
 
-                            OUString aPropIdStr = aEsc;
-                            aPropIdStr += aPureIdStr;
+                            OUString aPropIdStr = aEsc + aPureIdStr;
                             pIdStrings[i] = aPropIdStr;
                         }
                         xPropertySet->setPropertyValue( aPropName, Any(aIdStrings) );
@@ -499,10 +493,10 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                         aIdStrings.realloc( nPropStringCount );
                         OUString* pIdStrings = aIdStrings.getArray();
 
-                        OUString aIdStrBase = aDot;
-                        aIdStrBase += aCtrlName;
-                        aIdStrBase += aDot;
-                        aIdStrBase += aPropName;
+                        OUString aIdStrBase = aDot
+                                            + aCtrlName
+                                            + aDot
+                                            + aPropName;
 
                         const Locale* pLocales = aLocaleSeq.getConstArray();
                         sal_Int32 i;
@@ -512,8 +506,8 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             OUString aPureSourceIdStr = aSourceIdStr.copy( 1 );
 
                             sal_Int32 nUniqueId = xStringResourceManager->getUniqueNumericId();
-                            OUString aPureIdStr = OUString::number( nUniqueId );
-                            aPureIdStr += aIdStrBase;
+                            OUString aPureIdStr = OUString::number( nUniqueId )
+                                                + aIdStrBase;
 
                             // Set Id for all locales
                             for( sal_Int32 iLocale = 0 ; iLocale < nLocaleCount ; iLocale++ )
@@ -532,8 +526,7 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                                 {}
                             }
 
-                            OUString aPropIdStr = aEsc;
-                            aPropIdStr += aPureIdStr;
+                            OUString aPropIdStr = aEsc + aPureIdStr;
                             pIdStrings[i] = aPropIdStr;
                         }
                         xPropertySet->setPropertyValue( aPropName, Any(aIdStrings) );
@@ -545,10 +538,10 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                         aIdStrings.realloc( nPropStringCount );
                         OUString* pIdStrings = aIdStrings.getArray();
 
-                        OUString aIdStrBase = aDot;
-                        aIdStrBase += aCtrlName;
-                        aIdStrBase += aDot;
-                        aIdStrBase += aPropName;
+                        OUString aIdStrBase = aDot
+                                            + aCtrlName
+                                            + aDot
+                                            + aPropName;
 
                         const Locale& rDefaultLocale = xSourceStringResolver->getDefaultLocale();
 
@@ -560,8 +553,8 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                             OUString aPureSourceIdStr = aSourceIdStr.copy( 1 );
 
                             sal_Int32 nUniqueId = xStringResourceManager->getUniqueNumericId();
-                            OUString aPureIdStr = OUString::number( nUniqueId );
-                            aPureIdStr += aIdStrBase;
+                            OUString aPureIdStr = OUString::number( nUniqueId )
+                                                + aIdStrBase;
 
                             // Set Id for all locales
                             for( sal_Int32 iLocale = 0 ; iLocale < nLocaleCount ; iLocale++ )
@@ -582,8 +575,7 @@ sal_Int32 LocalizationMgr::implHandleControlResourceProperties
                                 xStringResourceManager->setStringForLocale( aPureIdStr, aResStr, rLocale );
                             }
 
-                            OUString aPropIdStr = aEsc;
-                            aPropIdStr += aPureIdStr;
+                            OUString aPropIdStr = aEsc + aPureIdStr;
                             pIdStrings[i] = aPropIdStr;
                         }
                         xPropertySet->setPropertyValue( aPropName, Any(aIdStrings) );
@@ -684,7 +676,7 @@ void LocalizationMgr::handleRemoveLocales( const Sequence< Locale >& aLocaleSeq
             }
             else
             {
-                // Inconsistancy, keep last locale
+                // Inconsistency, keep last locale
                 bConsistant = false;
                 bRemove = false;
             }
@@ -719,7 +711,6 @@ void LocalizationMgr::handleRemoveLocales( const Sequence< Locale >& aLocaleSeq
 
     DBG_ASSERT( bConsistant,
         "LocalizationMgr::handleRemoveLocales(): sequence contains unsupported locales" );
-    (void)bConsistant;
 }
 
 void LocalizationMgr::handleSetDefaultLocale(const Locale& rLocale)
@@ -783,7 +774,7 @@ void LocalizationMgr::handleBasicStopped()
 }
 
 
-DialogWindow* FindDialogWindowForEditor( DlgEditor* pEditor )
+DialogWindow* FindDialogWindowForEditor( DlgEditor const * pEditor )
 {
     Shell::WindowTable const& aWindowTable = GetShell()->GetWindowTable();
     for (Shell::WindowTableIt it = aWindowTable.begin(); it != aWindowTable.end(); ++it )
@@ -800,7 +791,7 @@ DialogWindow* FindDialogWindowForEditor( DlgEditor* pEditor )
 }
 
 
-void LocalizationMgr::setControlResourceIDsForNewEditorObject( DlgEditor* pEditor,
+void LocalizationMgr::setControlResourceIDsForNewEditorObject( DlgEditor const * pEditor,
     const Any& rControlAny, const OUString& aCtrlName )
 {
     // Get library for DlgEditor
@@ -830,7 +821,7 @@ void LocalizationMgr::setControlResourceIDsForNewEditorObject( DlgEditor* pEdito
         MarkDocumentModified( aDocument );
 }
 
-void LocalizationMgr::renameControlResourceIDsForEditorObject( DlgEditor* pEditor,
+void LocalizationMgr::renameControlResourceIDsForEditorObject( DlgEditor const * pEditor,
     const css::uno::Any& rControlAny, const OUString& aNewCtrlName )
 {
     // Get library for DlgEditor
@@ -858,7 +849,7 @@ void LocalizationMgr::renameControlResourceIDsForEditorObject( DlgEditor* pEdito
 }
 
 
-void LocalizationMgr::deleteControlResourceIDsForDeletedEditorObject( DlgEditor* pEditor,
+void LocalizationMgr::deleteControlResourceIDsForDeletedEditorObject( DlgEditor const * pEditor,
     const Any& rControlAny, const OUString& aCtrlName )
 {
     // Get library for DlgEditor
@@ -887,8 +878,6 @@ void LocalizationMgr::deleteControlResourceIDsForDeletedEditorObject( DlgEditor*
 void LocalizationMgr::setStringResourceAtDialog( const ScriptDocument& rDocument, const OUString& aLibName,
     const OUString& aDlgName, const Reference< container::XNameContainer >& xDialogModel )
 {
-    static const char aResourceResolverPropName[] = "ResourceResolver";
-
     // Get library
     Reference< container::XNameContainer > xDialogLib( rDocument.getLibrary( E_DIALOGS, aLibName, true ) );
     Reference< XStringResourceManager > xStringResourceManager =
@@ -910,7 +899,7 @@ void LocalizationMgr::setStringResourceAtDialog( const ScriptDocument& rDocument
         }
 
         Reference< beans::XPropertySet > xDlgPSet( xDialogModel, UNO_QUERY );
-        xDlgPSet->setPropertyValue( aResourceResolverPropName, Any(xStringResourceManager) );
+        xDlgPSet->setPropertyValue( "ResourceResolver", Any(xStringResourceManager) );
     }
 }
 
@@ -1030,7 +1019,7 @@ void LocalizationMgr::setResourceIDsForDialog( const Reference< container::XName
     }
 }
 
-void LocalizationMgr::copyResourcesForPastedEditorObject( DlgEditor* pEditor,
+void LocalizationMgr::copyResourcesForPastedEditorObject( DlgEditor const * pEditor,
     const Any& rControlAny, const OUString& aCtrlName,
     const Reference< XStringResourceResolver >& xSourceStringResolver )
 {
@@ -1065,11 +1054,10 @@ void LocalizationMgr::copyResourceForDroppedDialog( const Reference< container::
         return;
 
     // Dialog as control
-    OUString aDummyName;
     Any aDialogCtrl;
     aDialogCtrl <<= xDialogModel;
     implHandleControlResourceProperties( aDialogCtrl, aDialogName,
-        aDummyName, xStringResourceManager, xSourceStringResolver, MOVE_RESOURCES );
+        OUString(), xStringResourceManager, xSourceStringResolver, MOVE_RESOURCES );
 
     // Handle all controls
     Sequence< OUString > aNames = xDialogModel->getElementNames();
