@@ -19,11 +19,12 @@
 
 #include <sal/config.h>
 
-#include "basidesh.hrc"
+#include <strings.hrc>
+#include <bitmaps.hlst>
 
 #include "moduldlg.hxx"
-#include "localizationmgr.hxx"
-#include "basidesh.hxx"
+#include <localizationmgr.hxx>
+#include <basidesh.hxx>
 
 #include <basic/basmgr.hxx>
 #include <com/sun/star/script/XLibraryContainerPassword.hpp>
@@ -53,14 +54,7 @@ ExtTreeListBox::ExtTreeListBox(vcl::Window* pParent, WinBits nStyle)
 {
 }
 
-VCL_BUILDER_DECL_FACTORY(ExtTreeListBox)
-{
-    WinBits nWinBits = WB_TABSTOP;
-    OString sBorder = VclBuilder::extractCustomProperty(rMap);
-    if (!sBorder.isEmpty())
-       nWinBits |= WB_BORDER;
-    rRet = VclPtr<ExtTreeListBox>::Create(pParent, nWinBits);
-}
+VCL_BUILDER_FACTORY_CONSTRUCTOR(ExtTreeListBox, WB_TABSTOP)
 
 bool ExtTreeListBox::EditingEntry( SvTreeListEntry* pEntry, Selection& )
 {
@@ -92,7 +86,7 @@ bool ExtTreeListBox::EditedEntry( SvTreeListEntry* pEntry, const OUString& rNewT
 {
     if ( !IsValidSbxName(rNewText) )
     {
-        ScopedVclPtrInstance<MessageDialog>::Create(this, IDE_RESSTR(RID_STR_BADSBXNAME))->Execute();
+        ScopedVclPtrInstance<MessageDialog>(this, IDEResId(RID_STR_BADSBXNAME))->Execute();
         return false;
     }
 
@@ -121,8 +115,8 @@ bool ExtTreeListBox::EditedEntry( SvTreeListEntry* pEntry, const OUString& rNewT
     if (SfxDispatcher* pDispatcher = GetDispatcher())
     {
         SbxItem aSbxItem( SID_BASICIDE_ARG_SBX, aDocument, aLibName, rNewText, ConvertType( eType ) );
-        pDispatcher->Execute( SID_BASICIDE_SBXRENAMED,
-                                SfxCallMode::SYNCHRON, &aSbxItem, 0L );
+        pDispatcher->ExecuteList( SID_BASICIDE_SBXRENAMED,
+                            SfxCallMode::SYNCHRON, { &aSbxItem });
     }
 
     // OV-Bug?!
@@ -184,7 +178,9 @@ bool ExtTreeListBox::NotifyAcceptDrop( SvTreeListEntry* pEntry )
 
     // don't drop in the same library
     SvTreeListEntry* pSelected = FirstSelected();
-    if ( ( nDepth == 1 ) && ( pEntry == GetParent( pSelected ) ) )
+    if (!pSelected)
+        bValid = false;
+    else if ( ( nDepth == 1 ) && ( pEntry == GetParent( pSelected ) ) )
         bValid = false;
     else if ( ( nDepth == 2 ) && ( GetParent( pEntry ) == GetParent( pSelected ) ) )
         bValid = false;
@@ -310,14 +306,13 @@ void Shell::CopyDialogResources(
     }
 }
 
-TriState ExtTreeListBox::NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeListEntry* pEntry,
+TriState ExtTreeListBox::NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeListEntry const * pEntry,
                         SvTreeListEntry*& rpNewParent, sal_uLong& rNewChildPos, bool bMove )
 {
-    (void)pEntry;
-    DBG_ASSERT( pEntry, "Kein Eintrag?" );  // ASS is ok here, should not be reached
-    DBG_ASSERT( pTarget, "Kein Ziel?" );    // with NULL (right at the beginning)
+    DBG_ASSERT( pEntry, "No entry?" );   // ASS is ok here, should not be reached
+    DBG_ASSERT( pTarget, "No target?" ); // with NULL (right at the beginning)
     sal_uInt16 nDepth = GetModel()->GetDepth( pTarget );
-    DBG_ASSERT( nDepth, "Tiefe?" );
+    DBG_ASSERT( nDepth, "Depth?" );
     if ( nDepth == 1 )
     {
         // Target = Basic => put module/dialog under the Basic
@@ -354,8 +349,8 @@ TriState ExtTreeListBox::NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeLi
             if( pDispatcher )
             {
                 SbxItem aSbxItem( SID_BASICIDE_ARG_SBX, rSourceDoc, aSourceLibName, aSourceName, ConvertType( eType ) );
-                pDispatcher->Execute( SID_BASICIDE_SBXDELETED,
-                                      SfxCallMode::SYNCHRON, &aSbxItem, 0L );
+                pDispatcher->ExecuteList( SID_BASICIDE_SBXDELETED,
+                      SfxCallMode::SYNCHRON, { &aSbxItem });
             }
         }
 
@@ -446,8 +441,8 @@ TriState ExtTreeListBox::NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeLi
         if( pDispatcher )
         {
             SbxItem aSbxItem( SID_BASICIDE_ARG_SBX, rDestDoc, aDestLibName, aSourceName, ConvertType( eType ) );
-            pDispatcher->Execute( SID_BASICIDE_SBXINSERTED,
-                                  SfxCallMode::SYNCHRON, &aSbxItem, 0L );
+            pDispatcher->ExecuteList( SID_BASICIDE_SBXINSERTED,
+                                  SfxCallMode::SYNCHRON, { &aSbxItem });
         }
     }
 
@@ -456,13 +451,20 @@ TriState ExtTreeListBox::NotifyCopyingMoving( SvTreeListEntry* pTarget, SvTreeLi
 
 // OrganizeDialog
 OrganizeDialog::OrganizeDialog(vcl::Window* pParent, sal_Int16 tabId,
-    EntryDescriptor& rDesc )
+    EntryDescriptor const & rDesc )
     : TabDialog( pParent, "OrganizeDialog",
         "modules/BasicIDE/ui/organizedialog.ui" )
     , m_aCurEntry( rDesc )
 {
     get(m_pTabCtrl, "tabcontrol");
 
+    sal_uInt16 nPageCount = m_pTabCtrl->GetPageCount();
+    for (sal_uInt16 nPage = 0; nPage < nPageCount; ++nPage)
+    {
+        sal_uInt16 nPageId = m_pTabCtrl->GetPageId(nPage);
+        m_pTabCtrl->SetTabPage(nPageId, nullptr);
+    }
+
     m_pTabCtrl->SetActivatePageHdl(LINK(this, OrganizeDialog, ActivatePageHdl));
 
     if( tabId == 0 )
@@ -501,17 +503,7 @@ void OrganizeDialog::dispose()
     TabDialog::dispose();
 };
 
-short OrganizeDialog::Execute()
-{
-    vcl::Window* pPrevDlgParent = Application::GetDefDialogParent();
-    Application::SetDefDialogParent( this );
-    short nRet = TabDialog::Execute();
-    Application::SetDefDialogParent( pPrevDlgParent );
-    return nRet;
-}
-
-
-IMPL_LINK_TYPED( OrganizeDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
+IMPL_LINK( OrganizeDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
 {
     sal_uInt16 nId = pTabCtrl->GetCurPageId();
 
@@ -521,14 +513,14 @@ IMPL_LINK_TYPED( OrganizeDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
         VclPtr<TabPage> pNewTabPage;
         if (sPageName == "modules")
         {
-            VclPtrInstance<ObjectPage> pObjectPage(pTabCtrl, "ModulePage", BROWSEMODE_MODULES);
+            VclPtrInstance<ObjectPage> pObjectPage(pTabCtrl, "ModulePage", BrowseMode::Modules);
             pNewTabPage.reset(pObjectPage);
             pObjectPage->SetTabDlg(this);
             pObjectPage->SetCurrentEntry(m_aCurEntry);
         }
         else if (sPageName == "dialogs")
         {
-            VclPtrInstance<ObjectPage> pObjectPage( pTabCtrl, "DialogPage", BROWSEMODE_DIALOGS );
+            VclPtrInstance<ObjectPage> pObjectPage( pTabCtrl, "DialogPage", BrowseMode::Dialogs );
             pNewTabPage.reset(pObjectPage);
             pObjectPage->SetTabDlg(this);
             pObjectPage->SetCurrentEntry(m_aCurEntry);
@@ -541,9 +533,9 @@ IMPL_LINK_TYPED( OrganizeDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
         }
         else
         {
-            OSL_FAIL( "PageHdl: Unbekannte ID!" );
+            OSL_FAIL( "PageHdl: Unknown ID" );
         }
-        DBG_ASSERT( pNewTabPage, "Keine Page!" );
+        DBG_ASSERT( pNewTabPage, "No page" );
         pTabCtrl->SetTabPage( nId, pNewTabPage );
     }
 }
@@ -552,14 +544,13 @@ IMPL_LINK_TYPED( OrganizeDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
 // ObjectPage
 
 
-
-ObjectPage::ObjectPage(vcl::Window *pParent, const OString &rName, sal_uInt16 nMode)
+ObjectPage::ObjectPage(vcl::Window *pParent, const OString &rName, BrowseMode nMode)
     : TabPage(pParent, rName, "modules/BasicIDE/ui/" +
         OStringToOUString(rName, RTL_TEXTENCODING_UTF8).toAsciiLowerCase() +
         ".ui")
 {
     get(m_pBasicBox, "library");
-    Size aSize(m_pBasicBox->LogicToPixel(Size(130, 117), MAP_APPFONT));
+    Size aSize(m_pBasicBox->LogicToPixel(Size(130, 117), MapMode(MapUnit::MapAppFont)));
     m_pBasicBox->set_height_request(aSize.Height());
     m_pBasicBox->set_width_request(aSize.Width());
     get(m_pEditButton, "edit");
@@ -573,12 +564,12 @@ ObjectPage::ObjectPage(vcl::Window *pParent, const OString &rName, sal_uInt16 nM
     m_pDelButton->SetClickHdl( LINK( this, ObjectPage, ButtonHdl ) );
     m_pBasicBox->SetSelectHdl( LINK( this, ObjectPage, BasicBoxHighlightHdl ) );
 
-    if( nMode & BROWSEMODE_MODULES )
+    if( nMode & BrowseMode::Modules )
     {
         m_pNewModButton->SetClickHdl( LINK( this, ObjectPage, ButtonHdl ) );
         m_pNewDlgButton->Hide();
     }
-    else if ( nMode & BROWSEMODE_DIALOGS )
+    else if ( nMode & BrowseMode::Dialogs )
     {
         m_pNewDlgButton->SetClickHdl( LINK( this, ObjectPage, ButtonHdl ) );
         m_pNewModButton->Hide();
@@ -613,7 +604,7 @@ void ObjectPage::dispose()
     TabPage::dispose();
 }
 
-void ObjectPage::SetCurrentEntry (EntryDescriptor& rDesc)
+void ObjectPage::SetCurrentEntry (EntryDescriptor const & rDesc)
 {
     m_pBasicBox->SetCurrentEntry( rDesc );
 }
@@ -636,12 +627,12 @@ void ObjectPage::CheckButtons()
     OUString aLibName( aDesc.GetLibName() );
     OUString aLibSubName( aDesc.GetLibSubName() );
     bool bVBAEnabled = aDocument.isInVBAMode();
-    sal_uInt16 nMode = m_pBasicBox->GetMode();
+    BrowseMode nMode = m_pBasicBox->GetMode();
 
     sal_uInt16 nDepth = pCurEntry ? m_pBasicBox->GetModel()->GetDepth( pCurEntry ) : 0;
     if ( nDepth >= 2 )
     {
-        if( bVBAEnabled && ( nMode & BROWSEMODE_MODULES ) && ( nDepth == 2 ) )
+        if( bVBAEnabled && ( nMode & BrowseMode::Modules ) && ( nDepth == 2 ) )
             m_pEditButton->Disable();
         else
         m_pEditButton->Enable();
@@ -676,7 +667,7 @@ void ObjectPage::CheckButtons()
     // enable/disable delete button
     if ( nDepth >= 2 && !bReadOnly && eLocation != LIBRARY_LOCATION_SHARE )
     {
-        if( bVBAEnabled && ( nMode & BROWSEMODE_MODULES ) && ( ( nDepth == 2 ) || aLibSubName == IDE_RESSTR(RID_STR_DOCUMENT_OBJECTS) ) )
+        if( bVBAEnabled && ( nMode & BrowseMode::Modules ) && ( ( nDepth == 2 ) || aLibSubName == IDEResId(RID_STR_DOCUMENT_OBJECTS) ) )
             m_pDelButton->Disable();
         else
         m_pDelButton->Enable();
@@ -685,7 +676,7 @@ void ObjectPage::CheckButtons()
         m_pDelButton->Disable();
 }
 
-IMPL_LINK_TYPED( ObjectPage, BasicBoxHighlightHdl, SvTreeListBox*, pBox, void )
+IMPL_LINK( ObjectPage, BasicBoxHighlightHdl, SvTreeListBox*, pBox, void )
 {
     if ( !pBox->IsSelected( pBox->GetHdlEntry() ) )
         return;
@@ -693,7 +684,7 @@ IMPL_LINK_TYPED( ObjectPage, BasicBoxHighlightHdl, SvTreeListBox*, pBox, void )
     CheckButtons();
 }
 
-IMPL_LINK_TYPED( ObjectPage, ButtonHdl, Button *, pButton, void )
+IMPL_LINK( ObjectPage, ButtonHdl, Button *, pButton, void )
 {
     if (pButton == m_pEditButton)
     {
@@ -711,19 +702,20 @@ IMPL_LINK_TYPED( ObjectPage, ButtonHdl, Button *, pButton, void )
             {
                 OUString aModName( aDesc.GetName() );
                 // extract the module name from the string like "Sheet1 (Example1)"
-                if( aDesc.GetLibSubName() == IDE_RESSTR(RID_STR_DOCUMENT_OBJECTS) )
+                if( aDesc.GetLibSubName() == IDEResId(RID_STR_DOCUMENT_OBJECTS) )
                 {
                     sal_Int32 nIndex = 0;
                     aModName = aModName.getToken( 0, ' ', nIndex );
                 }
                 SbxItem aSbxItem( SID_BASICIDE_ARG_SBX, aDesc.GetDocument(), aDesc.GetLibName(),
                                   aModName, TreeListBox::ConvertType( aDesc.GetType() ) );
-                pDispatcher->Execute( SID_BASICIDE_SHOWSBX, SfxCallMode::SYNCHRON, &aSbxItem, 0L );
+                pDispatcher->ExecuteList(SID_BASICIDE_SHOWSBX,
+                        SfxCallMode::SYNCHRON, { &aSbxItem });
             }
         }
-        else    // Nur Lib selektiert
+        else    // only Lib selected
         {
-            DBG_ASSERT( m_pBasicBox->GetModel()->GetDepth( pCurEntry ) == 1, "Kein LibEntry?!" );
+            DBG_ASSERT( m_pBasicBox->GetModel()->GetDepth( pCurEntry ) == 1, "No LibEntry?!" );
             ScriptDocument aDocument( ScriptDocument::getApplicationScriptDocument() );
             SvTreeListEntry* pParentEntry = m_pBasicBox->GetParent( pCurEntry );
             if ( pParentEntry )
@@ -732,15 +724,16 @@ IMPL_LINK_TYPED( ObjectPage, ButtonHdl, Button *, pButton, void )
                 if (pDocumentEntry)
                     aDocument = pDocumentEntry->GetDocument();
             }
-            SfxUsrAnyItem aDocItem( SID_BASICIDE_ARG_DOCUMENT_MODEL, makeAny( aDocument.getDocumentOrNull() ) );
+            SfxUsrAnyItem aDocItem( SID_BASICIDE_ARG_DOCUMENT_MODEL, Any( aDocument.getDocumentOrNull() ) );
             OUString aLibName( m_pBasicBox->GetEntryText( pCurEntry ) );
             SfxStringItem aLibNameItem( SID_BASICIDE_ARG_LIBNAME, aLibName );
             if ( pDispatcher )
             {
-                pDispatcher->Execute( SID_BASICIDE_LIBSELECTED, SfxCallMode::ASYNCHRON, &aDocItem, &aLibNameItem, 0L );
+                pDispatcher->ExecuteList(SID_BASICIDE_LIBSELECTED,
+                    SfxCallMode::ASYNCHRON, { &aDocItem, &aLibNameItem });
             }
         }
-        EndTabDialog( 1 );
+        EndTabDialog();
     }
     else if (pButton == m_pNewModButton)
         NewModule();
@@ -806,9 +799,8 @@ void ObjectPage::NewModule()
 
     if ( GetSelection( aDocument, aLibName ) )
     {
-        OUString aModName;
         createModImpl( static_cast<vcl::Window*>( this ), aDocument,
-                    *m_pBasicBox, aLibName, aModName, true );
+                    *m_pBasicBox, aLibName, OUString(), true );
     }
 }
 
@@ -832,7 +824,7 @@ void ObjectPage::NewDialog()
 
             if ( aDocument.hasDialog( aLibName, aDlgName ) )
             {
-                ScopedVclPtrInstance<MessageDialog>::Create(this, IDE_RESSTR(RID_STR_SBXNAMEALLREADYUSED2))->Execute();
+                ScopedVclPtrInstance<MessageDialog>(this, IDEResId(RID_STR_SBXNAMEALLREADYUSED2))->Execute();
             }
             else
             {
@@ -842,8 +834,10 @@ void ObjectPage::NewDialog()
 
                 SbxItem aSbxItem( SID_BASICIDE_ARG_SBX, aDocument, aLibName, aDlgName, TYPE_DIALOG );
                 if (SfxDispatcher* pDispatcher = GetDispatcher())
-                    pDispatcher->Execute( SID_BASICIDE_SBXINSERTED,
-                                            SfxCallMode::SYNCHRON, &aSbxItem, 0L );
+                {
+                    pDispatcher->ExecuteList( SID_BASICIDE_SBXINSERTED,
+                        SfxCallMode::SYNCHRON, { &aSbxItem });
+                }
                 LibraryLocation eLocation = aDocument.getLibraryLocation( aLibName );
                 SvTreeListEntry* pRootEntry = m_pBasicBox->FindRootEntry( aDocument, eLocation );
                 if ( pRootEntry )
@@ -851,7 +845,7 @@ void ObjectPage::NewDialog()
                     if ( !m_pBasicBox->IsExpanded( pRootEntry ) )
                         m_pBasicBox->Expand( pRootEntry );
                     SvTreeListEntry* pLibEntry = m_pBasicBox->FindEntry( pRootEntry, aLibName, OBJ_TYPE_LIBRARY );
-                    DBG_ASSERT( pLibEntry, "Libeintrag nicht gefunden!" );
+                    DBG_ASSERT( pLibEntry, "LibEntry not found!" );
                     if ( pLibEntry )
                     {
                         if ( !m_pBasicBox->IsExpanded( pLibEntry ) )
@@ -861,10 +855,10 @@ void ObjectPage::NewDialog()
                         {
                             pEntry = m_pBasicBox->AddEntry(
                                 aDlgName,
-                                Image( IDEResId( RID_IMG_DIALOG ) ),
+                                Image(BitmapEx(RID_BMP_DIALOG)),
                                 pLibEntry, false,
                                 o3tl::make_unique<Entry>(OBJ_TYPE_DIALOG));
-                            DBG_ASSERT( pEntry, "InsertEntry fehlgeschlagen!" );
+                            DBG_ASSERT( pEntry, "Insert entry failed!" );
                         }
                         m_pBasicBox->SetCurEntry( pEntry );
                         m_pBasicBox->Select( m_pBasicBox->GetCurEntry() );        // OV-Bug?!
@@ -878,7 +872,7 @@ void ObjectPage::NewDialog()
 void ObjectPage::DeleteCurrent()
 {
     SvTreeListEntry* pCurEntry = m_pBasicBox->GetCurEntry();
-    DBG_ASSERT( pCurEntry, "Kein aktueller Eintrag!" );
+    DBG_ASSERT( pCurEntry, "No current entry!" );
     EntryDescriptor aDesc( m_pBasicBox->GetEntryDescriptor( pCurEntry ) );
     ScriptDocument aDocument( aDesc.GetDocument() );
     DBG_ASSERT( aDocument.isAlive(), "ObjectPage::DeleteCurrent: no document!" );
@@ -897,8 +891,8 @@ void ObjectPage::DeleteCurrent()
         if (SfxDispatcher* pDispatcher = GetDispatcher())
         {
             SbxItem aSbxItem( SID_BASICIDE_ARG_SBX, aDocument, aLibName, aName, TreeListBox::ConvertType( eType ) );
-            pDispatcher->Execute( SID_BASICIDE_SBXDELETED,
-                                  SfxCallMode::SYNCHRON, &aSbxItem, 0L );
+            pDispatcher->ExecuteList( SID_BASICIDE_SBXDELETED,
+                                  SfxCallMode::SYNCHRON, { &aSbxItem });
         }
 
         try
@@ -920,12 +914,11 @@ void ObjectPage::DeleteCurrent()
 }
 
 
-
-void ObjectPage::EndTabDialog( sal_uInt16 nRet )
+void ObjectPage::EndTabDialog()
 {
-    DBG_ASSERT( pTabDlg, "TabDlg nicht gesetzt!" );
+    DBG_ASSERT( pTabDlg, "TabDlg not set!" );
     if ( pTabDlg )
-        pTabDlg->EndDialog( nRet );
+        pTabDlg->EndDialog( 1 );
 }
 
 LibDialog::LibDialog( vcl::Window* pParent )
@@ -956,8 +949,7 @@ void LibDialog::dispose()
 
 void LibDialog::SetStorageName( const OUString& rName )
 {
-    OUString aName( IDE_RESSTR(RID_STR_FILENAME) );
-    aName += rName;
+    OUString aName = IDEResId(RID_STR_FILENAME) + rName;
     m_pStorageFrame->set_label(aName);
 }
 
@@ -1000,8 +992,10 @@ SbModule* createModImpl( vcl::Window* pWin, const ScriptDocument& rDocument,
                     pModule = pBasic->FindModule( aModName );
                 SbxItem aSbxItem( SID_BASICIDE_ARG_SBX, rDocument, aLibName, aModName, TYPE_MODULE );
             if (SfxDispatcher* pDispatcher = GetDispatcher())
-                pDispatcher->Execute( SID_BASICIDE_SBXINSERTED,
-                                      SfxCallMode::SYNCHRON, &aSbxItem, 0L );
+            {
+                pDispatcher->ExecuteList( SID_BASICIDE_SBXINSERTED,
+                      SfxCallMode::SYNCHRON, { &aSbxItem });
+            }
             LibraryLocation eLocation = rDocument.getLibraryLocation( aLibName );
             SvTreeListEntry* pRootEntry = rBasicBox.FindRootEntry( rDocument, eLocation );
             if ( pRootEntry )
@@ -1009,7 +1003,7 @@ SbModule* createModImpl( vcl::Window* pWin, const ScriptDocument& rDocument,
                 if ( !rBasicBox.IsExpanded( pRootEntry ) )
                     rBasicBox.Expand( pRootEntry );
                 SvTreeListEntry* pLibEntry = rBasicBox.FindEntry( pRootEntry, aLibName, OBJ_TYPE_LIBRARY );
-                DBG_ASSERT( pLibEntry, "Libeintrag nicht gefunden!" );
+                DBG_ASSERT( pLibEntry, "LibEntry not found!" );
                 if ( pLibEntry )
                 {
                     if ( !rBasicBox.IsExpanded( pLibEntry ) )
@@ -1018,7 +1012,7 @@ SbModule* createModImpl( vcl::Window* pWin, const ScriptDocument& rDocument,
                     if( pBasic && rDocument.isInVBAMode() )
                     {
                         // add the new module in the "Modules" entry
-                        SvTreeListEntry* pLibSubEntry = rBasicBox.FindEntry( pLibEntry, IDE_RESSTR(RID_STR_NORMAL_MODULES) , OBJ_TYPE_NORMAL_MODULES );
+                        SvTreeListEntry* pLibSubEntry = rBasicBox.FindEntry( pLibEntry, IDEResId(RID_STR_NORMAL_MODULES) , OBJ_TYPE_NORMAL_MODULES );
                         if( pLibSubEntry )
                         {
                             if( !rBasicBox.IsExpanded( pLibSubEntry ) )
@@ -1032,10 +1026,10 @@ SbModule* createModImpl( vcl::Window* pWin, const ScriptDocument& rDocument,
                     {
                         pEntry = rBasicBox.AddEntry(
                             aModName,
-                            Image( IDEResId( RID_IMG_MODULE ) ),
+                            Image(BitmapEx(RID_BMP_MODULE)),
                             pSubRootEntry, false,
                             o3tl::make_unique<Entry>(OBJ_TYPE_MODULE));
-                        DBG_ASSERT( pEntry, "InsertEntry fehlgeschlagen!" );
+                        DBG_ASSERT( pEntry, "Insert entry failed!" );
                     }
                     rBasicBox.SetCurEntry( pEntry );
                     rBasicBox.Select( rBasicBox.GetCurEntry() );        // OV-Bug?!
@@ -1044,7 +1038,7 @@ SbModule* createModImpl( vcl::Window* pWin, const ScriptDocument& rDocument,
         }
         catch (const container::ElementExistException& )
         {
-            ScopedVclPtrInstance<MessageDialog>::Create(pWin, IDE_RESSTR(RID_STR_SBXNAMEALLREADYUSED2))->Execute();
+            ScopedVclPtrInstance<MessageDialog>(pWin, IDEResId(RID_STR_SBXNAMEALLREADYUSED2))->Execute();
         }
         catch (const container::NoSuchElementException& )
         {
