@@ -17,16 +17,20 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "dlged.hxx"
-#include "dlgeddef.hxx"
-#include "dlgedlist.hxx"
-#include "dlgedobj.hxx"
-#include "dlgedpage.hxx"
-#include "dlgedview.hxx"
-#include "iderid.hxx"
-#include "localizationmgr.hxx"
+#include <sal/config.h>
 
-#include "dlgresid.hrc"
+#include <cassert>
+
+#include <dlged.hxx>
+#include <dlgeddef.hxx>
+#include <dlgedlist.hxx>
+#include <dlgedobj.hxx>
+#include <dlgedpage.hxx>
+#include <dlgedview.hxx>
+#include <iderid.hxx>
+#include <localizationmgr.hxx>
+#include <strings.hxx>
+#include <strings.hrc>
 
 #include <com/sun/star/beans/NamedValue.hpp>
 #include <com/sun/star/form/binding/XBindableValue.hpp>
@@ -79,13 +83,7 @@ DlgEdObj::DlgEdObj(const OUString& rModelName,
 DlgEdObj::~DlgEdObj()
 {
     if ( isListening() )
-        EndListening();
-}
-
-void DlgEdObj::SetPage(SdrPage* _pNewPage)
-{
-    // now set the page
-    SdrUnoObj::SetPage(_pNewPage);
+        EndListening(true);
 }
 
 namespace
@@ -129,7 +127,7 @@ bool DlgEdObj::TransformSdrToControlCoordinates(
     DlgEdForm* pForm = nullptr;
     if ( !lcl_getDlgEdForm( this, pForm ) )
         return false;
-    Rectangle aFormRect = pForm->GetSnapRect();
+    tools::Rectangle aFormRect = pForm->GetSnapRect();
     Size aFormPos( aFormRect.Left(), aFormRect.Top() );
 
     // convert 100th_mm to pixel
@@ -137,9 +135,9 @@ bool DlgEdObj::TransformSdrToControlCoordinates(
     DBG_ASSERT( pDevice, "DlgEdObj::TransformSdrToControlCoordinates: missing default device!" );
     if ( !pDevice )
         return false;
-    aPos = pDevice->LogicToPixel( aPos, MapMode( MAP_100TH_MM ) );
-    aSize = pDevice->LogicToPixel( aSize, MapMode( MAP_100TH_MM ) );
-    aFormPos = pDevice->LogicToPixel( aFormPos, MapMode( MAP_100TH_MM ) );
+    aPos = pDevice->LogicToPixel( aPos, MapMode( MapUnit::Map100thMM ) );
+    aSize = pDevice->LogicToPixel( aSize, MapMode( MapUnit::Map100thMM ) );
+    aFormPos = pDevice->LogicToPixel( aFormPos, MapMode( MapUnit::Map100thMM ) );
 
     // subtract form position
     aPos.Width() -= aFormPos.Width();
@@ -160,8 +158,8 @@ bool DlgEdObj::TransformSdrToControlCoordinates(
     }
 
     // convert pixel to logic units
-    aPos = pDevice->PixelToLogic( aPos, MAP_APPFONT );
-    aSize = pDevice->PixelToLogic( aSize, MAP_APPFONT );
+    aPos = pDevice->PixelToLogic(aPos, MapMode(MapUnit::MapAppFont));
+    aSize = pDevice->PixelToLogic(aSize, MapMode(MapUnit::MapAppFont));
 
     // set out parameters
     nXOut = aPos.Width();
@@ -185,8 +183,8 @@ bool DlgEdObj::TransformSdrToFormCoordinates(
     DBG_ASSERT( pDevice, "DlgEdObj::TransformSdrToFormCoordinates: missing default device!" );
     if ( !pDevice )
         return false;
-    aPos = pDevice->LogicToPixel( aPos, MapMode( MAP_100TH_MM ) );
-    aSize = pDevice->LogicToPixel( aSize, MapMode( MAP_100TH_MM ) );
+    aPos = pDevice->LogicToPixel( aPos, MapMode( MapUnit::Map100thMM ) );
+    aSize = pDevice->LogicToPixel( aSize, MapMode( MapUnit::Map100thMM ) );
 
     // take window borders into account
     DlgEdForm* pForm = nullptr;
@@ -207,8 +205,8 @@ bool DlgEdObj::TransformSdrToFormCoordinates(
         aSize.Height() -= aDeviceInfo.TopInset + aDeviceInfo.BottomInset;
     }
     // convert pixel to logic units
-    aPos = pDevice->PixelToLogic( aPos, MAP_APPFONT );
-    aSize = pDevice->PixelToLogic( aSize, MAP_APPFONT );
+    aPos = pDevice->PixelToLogic(aPos, MapMode(MapUnit::MapAppFont));
+    aSize = pDevice->PixelToLogic(aSize, MapMode(MapUnit::MapAppFont));
 
     // set out parameters
     nXOut = aPos.Width();
@@ -248,9 +246,9 @@ bool DlgEdObj::TransformControlToSdrCoordinates(
     DBG_ASSERT( pDevice, "DlgEdObj::TransformControlToSdrCoordinates: missing default device!" );
     if ( !pDevice )
         return false;
-    aPos = pDevice->LogicToPixel( aPos, MAP_APPFONT );
-    aSize = pDevice->LogicToPixel( aSize, MAP_APPFONT );
-    aFormPos = pDevice->LogicToPixel( aFormPos, MAP_APPFONT );
+    aPos = pDevice->LogicToPixel(aPos, MapMode(MapUnit::MapAppFont));
+    aSize = pDevice->LogicToPixel(aSize, MapMode(MapUnit::MapAppFont));
+    aFormPos = pDevice->LogicToPixel(aFormPos, MapMode(MapUnit::MapAppFont));
 
     // add form position
     aPos.Width() += aFormPos.Width();
@@ -267,8 +265,8 @@ bool DlgEdObj::TransformControlToSdrCoordinates(
     }
 
     // convert pixel to 100th_mm
-    aPos = pDevice->PixelToLogic( aPos, MapMode( MAP_100TH_MM ) );
-    aSize = pDevice->PixelToLogic( aSize, MapMode( MAP_100TH_MM ) );
+    aPos = pDevice->PixelToLogic( aPos, MapMode( MapUnit::Map100thMM ) );
+    aSize = pDevice->PixelToLogic( aSize, MapMode( MapUnit::Map100thMM ) );
 
     // set out parameters
     nXOut = aPos.Width();
@@ -298,8 +296,8 @@ bool DlgEdObj::TransformFormToSdrCoordinates(
     if ( !lcl_getDlgEdForm( this, pForm ) )
         return false;
 
-    aPos = pDevice->LogicToPixel( aPos, MAP_APPFONT );
-    aSize = pDevice->LogicToPixel( aSize, MAP_APPFONT );
+    aPos = pDevice->LogicToPixel(aPos, MapMode(MapUnit::MapAppFont));
+    aSize = pDevice->LogicToPixel(aSize, MapMode(MapUnit::MapAppFont));
 
     // take window borders into account
     Reference< beans::XPropertySet > xPSetForm( pForm->GetUnoControlModel(), UNO_QUERY );
@@ -316,8 +314,8 @@ bool DlgEdObj::TransformFormToSdrCoordinates(
     }
 
     // convert pixel to 100th_mm
-    aPos = pDevice->PixelToLogic( aPos, MapMode( MAP_100TH_MM ) );
-    aSize = pDevice->PixelToLogic( aSize, MapMode( MAP_100TH_MM ) );
+    aPos = pDevice->PixelToLogic( aPos, MapMode( MapUnit::Map100thMM ) );
+    aSize = pDevice->PixelToLogic( aSize, MapMode( MapUnit::Map100thMM ) );
 
     // set out parameters
     nXOut = aPos.Width();
@@ -347,7 +345,7 @@ void DlgEdObj::SetRectFromProps()
             // set rectangle position and size
             Point aPoint( nXOut, nYOut );
             Size aSize( nWidthOut, nHeightOut );
-            SetSnapRect( Rectangle( aPoint, aSize ) );
+            SetSnapRect( tools::Rectangle( aPoint, aSize ) );
         }
     }
 }
@@ -355,7 +353,7 @@ void DlgEdObj::SetRectFromProps()
 void DlgEdObj::SetPropsFromRect()
 {
     // get control position and size from rectangle
-    Rectangle aRect_ = GetSnapRect();
+    tools::Rectangle aRect_ = GetSnapRect();
     sal_Int32 nXIn = aRect_.Left();
     sal_Int32 nYIn = aRect_.Top();
     sal_Int32 nWidthIn = aRect_.GetWidth();
@@ -369,15 +367,10 @@ void DlgEdObj::SetPropsFromRect()
         Reference< beans::XPropertySet > xPSet( GetUnoControlModel(), UNO_QUERY );
         if ( xPSet.is() )
         {
-            Any aValue;
-            aValue <<= nXOut;
-            xPSet->setPropertyValue( DLGED_PROP_POSITIONX, aValue );
-            aValue <<= nYOut;
-            xPSet->setPropertyValue( DLGED_PROP_POSITIONY, aValue );
-            aValue <<= nWidthOut;
-            xPSet->setPropertyValue( DLGED_PROP_WIDTH, aValue );
-            aValue <<= nHeightOut;
-            xPSet->setPropertyValue( DLGED_PROP_HEIGHT, aValue );
+            xPSet->setPropertyValue( DLGED_PROP_POSITIONX, Any(nXOut) );
+            xPSet->setPropertyValue( DLGED_PROP_POSITIONY, Any(nYOut) );
+            xPSet->setPropertyValue( DLGED_PROP_WIDTH, Any(nWidthOut) );
+            xPSet->setPropertyValue( DLGED_PROP_HEIGHT, Any(nHeightOut) );
         }
     }
 }
@@ -387,13 +380,11 @@ void DlgEdObj::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
     DBG_ASSERT( pDlgEdForm, "DlgEdObj::PositionAndSizeChange: no form!" );
     DlgEdPage& rPage = pDlgEdForm->GetDlgEditor().GetPage();
     {
-        sal_Int32 nPageXIn = 0;
-        sal_Int32 nPageYIn = 0;
         Size aPageSize = rPage.GetSize();
         sal_Int32 nPageWidthIn = aPageSize.Width();
         sal_Int32 nPageHeightIn = aPageSize.Height();
         sal_Int32 nPageX, nPageY, nPageWidth, nPageHeight;
-        if ( TransformSdrToControlCoordinates( nPageXIn, nPageYIn, nPageWidthIn, nPageHeightIn, nPageX, nPageY, nPageWidth, nPageHeight ) )
+        if ( TransformSdrToControlCoordinates( 0/*nPageXIn*/, 0/*nPageYIn*/, nPageWidthIn, nPageHeightIn, nPageX, nPageY, nPageWidth, nPageHeight ) )
         {
             Reference< beans::XPropertySet > xPSet( GetUnoControlModel(), UNO_QUERY );
             if ( xPSet.is() )
@@ -439,10 +430,8 @@ void DlgEdObj::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
 
                 if ( nNewValue != nValue )
                 {
-                    Any aNewValue;
-                    aNewValue <<= nNewValue;
                     EndListening( false );
-                    xPSet->setPropertyValue( evt.PropertyName, aNewValue );
+                    xPSet->setPropertyValue( evt.PropertyName, Any(nNewValue) );
                     StartListening();
                 }
             }
@@ -452,7 +441,7 @@ void DlgEdObj::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
     SetRectFromProps();
 }
 
-void SAL_CALL DlgEdObj::NameChange( const  css::beans::PropertyChangeEvent& evt ) throw (css::container::NoSuchElementException, css::uno::RuntimeException)
+void SAL_CALL DlgEdObj::NameChange( const  css::beans::PropertyChangeEvent& evt )
 {
     // get old name
     OUString aOldName;
@@ -462,7 +451,7 @@ void SAL_CALL DlgEdObj::NameChange( const  css::beans::PropertyChangeEvent& evt
     OUString aNewName;
     evt.NewValue >>= aNewName;
 
-    if ( !aNewName.equals(aOldName) )
+    if ( aNewName != aOldName )
     {
         Reference< container::XNameAccess > xNameAcc((GetDlgEdForm()->GetUnoControlModel()), UNO_QUERY);
         if ( xNameAcc.is() && xNameAcc->hasByName(aOldName) )
@@ -489,9 +478,7 @@ void SAL_CALL DlgEdObj::NameChange( const  css::beans::PropertyChangeEvent& evt
                 // set old name property
                 EndListening(false);
                 Reference< beans::XPropertySet >  xPSet(GetUnoControlModel(), UNO_QUERY);
-                Any aName;
-                aName <<= aOldName;
-                xPSet->setPropertyValue( DLGED_PROP_NAME, aName );
+                xPSet->setPropertyValue( DLGED_PROP_NAME, Any(aOldName) );
                 StartListening();
             }
         }
@@ -516,8 +503,8 @@ void DlgEdObj::UpdateStep()
     sal_Int32 nStep = GetStep();
 
     SdrLayerAdmin& rLayerAdmin = GetModel()->GetLayerAdmin();
-    SdrLayerID nHiddenLayerId   = rLayerAdmin.GetLayerID( "HiddenLayer", false );
-    SdrLayerID nControlLayerId   = rLayerAdmin.GetLayerID( rLayerAdmin.GetControlLayerName(), false );
+    SdrLayerID nHiddenLayerId   = rLayerAdmin.GetLayerID( "HiddenLayer" );
+    SdrLayerID nControlLayerId   = rLayerAdmin.GetLayerID( rLayerAdmin.GetControlLayerName() );
 
     if( nCurStep )
     {
@@ -536,14 +523,14 @@ void DlgEdObj::UpdateStep()
     }
 }
 
-void DlgEdObj::TabIndexChange( const beans::PropertyChangeEvent& evt ) throw (RuntimeException)
+void DlgEdObj::TabIndexChange( const beans::PropertyChangeEvent& evt )
 {
     DlgEdForm* pForm = GetDlgEdForm();
     if ( pForm )
     {
         // stop listening with all children
-        ::std::vector<DlgEdObj*> aChildList = pForm->GetChildren();
-        ::std::vector<DlgEdObj*>::iterator aIter;
+        std::vector<DlgEdObj*> aChildList = pForm->GetChildren();
+        std::vector<DlgEdObj*>::iterator aIter;
         for ( aIter = aChildList.begin() ; aIter != aChildList.end() ; ++aIter )
         {
             (*aIter)->EndListening( false );
@@ -556,11 +543,10 @@ void DlgEdObj::TabIndexChange( const beans::PropertyChangeEvent& evt ) throw (Ru
             Sequence< OUString > aNames = xNameAcc->getElementNames();
             const OUString* pNames = aNames.getConstArray();
             sal_Int32 nCtrls = aNames.getLength();
-            sal_Int16 i;
 
             // create a map of tab indices and control names, sorted by tab index
             IndexToNameMap aIndexToNameMap;
-            for ( i = 0; i < nCtrls; ++i )
+            for ( sal_Int32 i = 0; i < nCtrls; ++i )
             {
                 // get control name
                 OUString aName( pNames[i] );
@@ -576,12 +562,12 @@ void DlgEdObj::TabIndexChange( const beans::PropertyChangeEvent& evt ) throw (Ru
                     xPSet->getPropertyValue( DLGED_PROP_TABINDEX ) >>= nTabIndex;
 
                 // insert into map
-                aIndexToNameMap.insert( IndexToNameMap::value_type( nTabIndex, aName ) );
+                aIndexToNameMap.emplace( nTabIndex, aName );
             }
 
             // create a helper list of control names, sorted by tab index
-            ::std::vector< OUString > aNameList( aIndexToNameMap.size() );
-            ::std::transform(
+            std::vector< OUString > aNameList( aIndexToNameMap.size() );
+            std::transform(
                     aIndexToNameMap.begin(), aIndexToNameMap.end(),
                     aNameList.begin(),
                     ::o3tl::select2nd< IndexToNameMap::value_type >( )
@@ -603,16 +589,20 @@ void DlgEdObj::TabIndexChange( const beans::PropertyChangeEvent& evt ) throw (Ru
             aNameList.insert( aNameList.begin() + nNewTabIndex , aCtrlName );
 
             // set new tab indices
-            for ( i = 0; i < nCtrls; ++i )
+            for ( sal_Int32 i = 0; i < nCtrls; ++i )
             {
                 Any aCtrl = xNameAcc->getByName( aNameList[i] );
                 Reference< beans::XPropertySet > xPSet;
                    aCtrl >>= xPSet;
                 if ( xPSet.is() )
                 {
-                    Any aTabIndex;
-                    aTabIndex <<= (sal_Int16) i;
-                    xPSet->setPropertyValue( DLGED_PROP_TABINDEX, aTabIndex );
+                    assert(i >= SAL_MIN_INT16);
+                    if (i > SAL_MAX_INT16)
+                    {
+                        SAL_WARN("basctl", "tab " << i << " > SAL_MAX_INT16");
+                        continue;
+                    }
+                    xPSet->setPropertyValue( DLGED_PROP_TABINDEX, Any((sal_Int16) i) );
                 }
             }
 
@@ -644,105 +634,103 @@ bool DlgEdObj::supportsService( OUString const & serviceName ) const
 
 OUString DlgEdObj::GetDefaultName() const
 {
-    sal_uInt16 nResId = 0;
+    OUString sResId;
     OUString aDefaultName;
     if ( supportsService( "com.sun.star.awt.UnoControlDialogModel" ) )
     {
-        nResId = RID_STR_CLASS_DIALOG;
+        sResId = RID_STR_CLASS_DIALOG;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlButtonModel" ) )
     {
-        nResId = RID_STR_CLASS_BUTTON;
+        sResId = RID_STR_CLASS_BUTTON;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlRadioButtonModel" ) )
     {
-        nResId = RID_STR_CLASS_RADIOBUTTON;
+        sResId = RID_STR_CLASS_RADIOBUTTON;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlCheckBoxModel" ) )
     {
-        nResId = RID_STR_CLASS_CHECKBOX;
+        sResId = RID_STR_CLASS_CHECKBOX;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlListBoxModel" ) )
     {
-        nResId = RID_STR_CLASS_LISTBOX;
+        sResId = RID_STR_CLASS_LISTBOX;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlComboBoxModel" ) )
     {
-        nResId = RID_STR_CLASS_COMBOBOX;
+        sResId = RID_STR_CLASS_COMBOBOX;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlGroupBoxModel" ) )
     {
-        nResId = RID_STR_CLASS_GROUPBOX;
+        sResId = RID_STR_CLASS_GROUPBOX;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlEditModel" ) )
     {
-        nResId = RID_STR_CLASS_EDIT;
+        sResId = RID_STR_CLASS_EDIT;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlFixedTextModel" ) )
     {
-        nResId = RID_STR_CLASS_FIXEDTEXT;
+        sResId = RID_STR_CLASS_FIXEDTEXT;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlImageControlModel" ) )
     {
-        nResId = RID_STR_CLASS_IMAGECONTROL;
+        sResId = RID_STR_CLASS_IMAGECONTROL;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlProgressBarModel" ) )
     {
-        nResId = RID_STR_CLASS_PROGRESSBAR;
+        sResId = RID_STR_CLASS_PROGRESSBAR;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlScrollBarModel" ) )
     {
-        nResId = RID_STR_CLASS_SCROLLBAR;
+        sResId = RID_STR_CLASS_SCROLLBAR;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlFixedLineModel" ) )
     {
-        nResId = RID_STR_CLASS_FIXEDLINE;
+        sResId = RID_STR_CLASS_FIXEDLINE;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlDateFieldModel" ) )
     {
-        nResId = RID_STR_CLASS_DATEFIELD;
+        sResId = RID_STR_CLASS_DATEFIELD;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlTimeFieldModel" ) )
     {
-        nResId = RID_STR_CLASS_TIMEFIELD;
+        sResId = RID_STR_CLASS_TIMEFIELD;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlNumericFieldModel" ) )
     {
-        nResId = RID_STR_CLASS_NUMERICFIELD;
+        sResId = RID_STR_CLASS_NUMERICFIELD;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlCurrencyFieldModel" ) )
     {
-        nResId = RID_STR_CLASS_CURRENCYFIELD;
+        sResId = RID_STR_CLASS_CURRENCYFIELD;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlFormattedFieldModel" ) )
     {
-        nResId = RID_STR_CLASS_FORMATTEDFIELD;
+        sResId = RID_STR_CLASS_FORMATTEDFIELD;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlPatternFieldModel" ) )
     {
-        nResId = RID_STR_CLASS_PATTERNFIELD;
+        sResId = RID_STR_CLASS_PATTERNFIELD;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlFileControlModel" ) )
     {
-        nResId = RID_STR_CLASS_FILECONTROL;
+        sResId = RID_STR_CLASS_FILECONTROL;
     }
     else if ( supportsService( "com.sun.star.awt.tree.TreeControlModel" ) )
     {
-        nResId = RID_STR_CLASS_TREECONTROL;
+        sResId = RID_STR_CLASS_TREECONTROL;
     }
     else if ( supportsService( "com.sun.star.awt.UnoControlSpinButtonModel" ) )
     {
-        nResId = RID_STR_CLASS_SPINCONTROL;
+        sResId = RID_STR_CLASS_SPINCONTROL;
     }
     else
     {
-        nResId = RID_STR_CLASS_CONTROL;
+        sResId = RID_STR_CLASS_CONTROL;
     }
 
-    if (nResId)
-    {
-        aDefaultName = IDE_RESSTR(nResId);
-    }
+    if (!sResId.isEmpty())
+        aDefaultName = sResId;
 
     return aDefaultName;
 }
@@ -766,9 +754,9 @@ OUString DlgEdObj::GetUniqueName() const
     return aUniqueName;
 }
 
-sal_uInt32 DlgEdObj::GetObjInventor()   const
+SdrInventor DlgEdObj::GetObjInventor()   const
 {
-    return DlgInventor;
+    return SdrInventor::BasicDialog;
 }
 
 sal_uInt16 DlgEdObj::GetObjIdentifier() const
@@ -885,15 +873,11 @@ void DlgEdObj::clonedFrom(const DlgEdObj* _pSource)
         {
             // set tabindex
                Sequence< OUString > aNames = xCont->getElementNames();
-            Any aTabIndex;
-            aTabIndex <<= (sal_Int16) aNames.getLength();
-            xPSet->setPropertyValue( DLGED_PROP_TABINDEX, aTabIndex );
+            xPSet->setPropertyValue( DLGED_PROP_TABINDEX, Any((sal_Int16) aNames.getLength()) );
 
             // insert control model in dialog model
             Reference< awt::XControlModel > xCtrl( xPSet , UNO_QUERY );
-            Any aCtrl;
-            aCtrl <<= xCtrl;
-            xCont->insertByName( aOUniqueName , aCtrl );
+            xCont->insertByName( aOUniqueName, Any(xCtrl) );
 
             pDlgEdForm->UpdateTabOrderAndGroups();
         }
@@ -918,7 +902,7 @@ SdrObject* DlgEdObj::getFullDragClone() const
     // no need to really add the clone for dragging, it's a temporary
     // object
     SdrObject* pObj = new SdrUnoObj(OUString());
-    *pObj = *(static_cast<const SdrUnoObj*>(this));
+    *pObj = *static_cast<const SdrUnoObj*>(this);
 
     return pObj;
 }
@@ -984,9 +968,7 @@ void DlgEdObj::SetDefaults()
             OUString aOUniqueName( GetUniqueName() );
 
             // set name property
-            Any aUniqueName;
-            aUniqueName <<= aOUniqueName;
-            xPSet->setPropertyValue( DLGED_PROP_NAME, aUniqueName );
+            xPSet->setPropertyValue( DLGED_PROP_NAME, Any(aOUniqueName) );
 
             // set labels
             if ( supportsService( "com.sun.star.awt.UnoControlButtonModel" ) ||
@@ -995,7 +977,7 @@ void DlgEdObj::SetDefaults()
                 supportsService( "com.sun.star.awt.UnoControlGroupBoxModel" ) ||
                 supportsService( "com.sun.star.awt.UnoControlFixedTextModel" ) )
             {
-                xPSet->setPropertyValue( DLGED_PROP_LABEL, aUniqueName );
+                xPSet->setPropertyValue( DLGED_PROP_LABEL, Any(aOUniqueName) );
             }
 
             // set number formats supplier for formatted field
@@ -1004,9 +986,7 @@ void DlgEdObj::SetDefaults()
                 Reference< util::XNumberFormatsSupplier > xSupplier = GetDlgEdForm()->GetDlgEditor().GetNumberFormatsSupplier();
                 if ( xSupplier.is() )
                 {
-                    Any aSupplier;
-                    aSupplier <<= xSupplier;
-                    xPSet->setPropertyValue( DLGED_PROP_FORMATSSUPPLIER, aSupplier );
+                    xPSet->setPropertyValue( DLGED_PROP_FORMATSSUPPLIER, Any(xSupplier) );
                 }
             }
 
@@ -1120,7 +1100,7 @@ void DlgEdObj::EndListening(bool bRemoveListener)
     }
 }
 
-void SAL_CALL DlgEdObj::_propertyChange( const  css::beans::PropertyChangeEvent& evt ) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL DlgEdObj::_propertyChange( const  css::beans::PropertyChangeEvent& evt )
 {
     if (isListening())
     {
@@ -1158,7 +1138,7 @@ void SAL_CALL DlgEdObj::_propertyChange( const  css::beans::PropertyChangeEvent&
                 catch (container::NoSuchElementException const& e)
                 {
                     throw lang::WrappedTargetRuntimeException("", nullptr,
-                            uno::makeAny(e));
+                            uno::Any(e));
                 }
             }
         }
@@ -1176,7 +1156,7 @@ void SAL_CALL DlgEdObj::_propertyChange( const  css::beans::PropertyChangeEvent&
     }
 }
 
-void SAL_CALL DlgEdObj::_elementInserted(const css::container::ContainerEvent& ) throw(css::uno::RuntimeException)
+void SAL_CALL DlgEdObj::_elementInserted()
 {
     if (isListening())
     {
@@ -1185,7 +1165,7 @@ void SAL_CALL DlgEdObj::_elementInserted(const css::container::ContainerEvent& )
     }
 }
 
-void SAL_CALL DlgEdObj::_elementReplaced(const css::container::ContainerEvent& ) throw(css::uno::RuntimeException)
+void SAL_CALL DlgEdObj::_elementReplaced()
 {
     if (isListening())
     {
@@ -1194,7 +1174,7 @@ void SAL_CALL DlgEdObj::_elementReplaced(const css::container::ContainerEvent& )
     }
 }
 
-void SAL_CALL DlgEdObj::_elementRemoved(const css::container::ContainerEvent& ) throw(css::uno::RuntimeException)
+void SAL_CALL DlgEdObj::_elementRemoved()
 {
     if (isListening())
     {
@@ -1245,7 +1225,7 @@ void DlgEdForm::SetRectFromProps()
             // set rectangle position and size
             Point aPoint( nXOut, nYOut );
             Size aSize( nWidthOut, nHeightOut );
-            SetSnapRect( Rectangle( aPoint, aSize ) );
+            SetSnapRect( tools::Rectangle( aPoint, aSize ) );
         }
     }
 }
@@ -1253,7 +1233,7 @@ void DlgEdForm::SetRectFromProps()
 void DlgEdForm::SetPropsFromRect()
 {
     // get form position and size from rectangle
-    Rectangle aRect_ = GetSnapRect();
+    tools::Rectangle aRect_ = GetSnapRect();
     sal_Int32 nXIn = aRect_.Left();
     sal_Int32 nYIn = aRect_.Top();
     sal_Int32 nWidthIn = aRect_.GetWidth();
@@ -1267,15 +1247,10 @@ void DlgEdForm::SetPropsFromRect()
         Reference< beans::XPropertySet > xPSet( GetUnoControlModel(), UNO_QUERY );
         if ( xPSet.is() )
         {
-            Any aValue;
-            aValue <<= nXOut;
-            xPSet->setPropertyValue( DLGED_PROP_POSITIONX, aValue );
-            aValue <<= nYOut;
-            xPSet->setPropertyValue( DLGED_PROP_POSITIONY, aValue );
-            aValue <<= nWidthOut;
-            xPSet->setPropertyValue( DLGED_PROP_WIDTH, aValue );
-            aValue <<= nHeightOut;
-            xPSet->setPropertyValue( DLGED_PROP_HEIGHT, aValue );
+            xPSet->setPropertyValue( DLGED_PROP_POSITIONX, Any(nXOut) );
+            xPSet->setPropertyValue( DLGED_PROP_POSITIONY, Any(nYOut) );
+            xPSet->setPropertyValue( DLGED_PROP_WIDTH, Any(nWidthOut) );
+            xPSet->setPropertyValue( DLGED_PROP_HEIGHT, Any(nHeightOut) );
         }
     }
 }
@@ -1287,7 +1262,7 @@ void DlgEdForm::AddChild( DlgEdObj* pDlgEdObj )
 
 void DlgEdForm::RemoveChild( DlgEdObj* pDlgEdObj )
 {
-    pChildren.erase( ::std::find( pChildren.begin() , pChildren.end() , pDlgEdObj ) );
+    pChildren.erase( std::remove( pChildren.begin() , pChildren.end() , pDlgEdObj ) );
 }
 
 void DlgEdForm::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
@@ -1333,10 +1308,8 @@ void DlgEdForm::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
 
             if ( nNewValue != nValue )
             {
-                Any aNewValue;
-                aNewValue <<= nNewValue;
                 EndListening( false );
-                xPSetForm->setPropertyValue( evt.PropertyName, aNewValue );
+                xPSetForm->setPropertyValue( evt.PropertyName, Any(nNewValue) );
                 StartListening();
             }
         }
@@ -1375,10 +1348,8 @@ void DlgEdForm::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
                     }
                     if ( nNewX != nX )
                     {
-                        Any aValue;
-                        aValue <<= nNewX;
                         EndListening( false );
-                        xPSet->setPropertyValue( DLGED_PROP_POSITIONX, aValue );
+                        xPSet->setPropertyValue( DLGED_PROP_POSITIONX, Any(nNewX) );
                         StartListening();
                     }
 
@@ -1391,10 +1362,8 @@ void DlgEdForm::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
                     }
                     if ( nNewY != nY )
                     {
-                        Any aValue;
-                        aValue <<= nNewY;
                         EndListening( false );
-                        xPSet->setPropertyValue( DLGED_PROP_POSITIONY, aValue );
+                        xPSet->setPropertyValue( DLGED_PROP_POSITIONY, Any(nNewY) );
                         StartListening();
                     }
                 }
@@ -1425,7 +1394,7 @@ void DlgEdForm::UpdateStep()
 void DlgEdForm::UpdateTabIndices()
 {
     // stop listening with all children
-    ::std::vector<DlgEdObj*>::iterator aIter;
+    std::vector<DlgEdObj*>::iterator aIter;
     for ( aIter = pChildren.begin() ; aIter != pChildren.end() ; ++aIter )
     {
         (*aIter)->EndListening( false );
@@ -1455,7 +1424,7 @@ void DlgEdForm::UpdateTabIndices()
                 xPSet->getPropertyValue( DLGED_PROP_TABINDEX ) >>= nTabIndex;
 
             // insert into map
-            aIndexToNameMap.insert( IndexToNameMap::value_type( nTabIndex, aName ) );
+            aIndexToNameMap.emplace( nTabIndex, aName );
         }
 
         // set new tab indices
@@ -1467,9 +1436,8 @@ void DlgEdForm::UpdateTabIndices()
                aCtrl >>= xPSet;
             if ( xPSet.is() )
             {
-                Any aTabIndex;
-                aTabIndex <<= (sal_Int16) nNewTabIndex++;
-                xPSet->setPropertyValue( DLGED_PROP_TABINDEX, aTabIndex );
+                xPSet->setPropertyValue( DLGED_PROP_TABINDEX, Any(nNewTabIndex) );
+                nNewTabIndex++;
             }
         }
 
@@ -1516,7 +1484,7 @@ void DlgEdForm::UpdateGroups()
     if ( xTabModel.is() )
     {
         // create a global list of controls that belong to the dialog
-        ::std::vector<DlgEdObj*> aChildList = GetChildren();
+        std::vector<DlgEdObj*> aChildList = GetChildren();
         sal_uInt32 nSize = aChildList.size();
         Sequence< Reference< awt::XControl > > aSeqControls( nSize );
         for ( sal_uInt32 i = 0; i < nSize; ++i )
@@ -1583,7 +1551,7 @@ void DlgEdForm::NbcMove( const Size& rSize )
     StartListening();
 
     // set geometry properties of all children
-    ::std::vector<DlgEdObj*>::iterator aIter;
+    std::vector<DlgEdObj*>::iterator aIter;
     for ( aIter = pChildren.begin() ; aIter != pChildren.end() ; ++aIter )
     {
         (*aIter)->EndListening(false);
@@ -1605,7 +1573,7 @@ void DlgEdForm::NbcResize(const Point& rRef, const Fraction& xFract, const Fract
     StartListening();
 
     // set geometry properties of all children
-    ::std::vector<DlgEdObj*>::iterator aIter;
+    std::vector<DlgEdObj*>::iterator aIter;
     for ( aIter = pChildren.begin() ; aIter != pChildren.end() ; ++aIter )
     {
         (*aIter)->EndListening(false);
@@ -1672,9 +1640,8 @@ awt::DeviceInfo DlgEdForm::getDeviceInfo() const
 
     return aDeviceInfo;
 }
-bool DlgEdObj::MakeDataAware( const Reference< frame::XModel >& xModel )
+void DlgEdObj::MakeDataAware( const Reference< frame::XModel >& xModel )
 {
-    bool bRes = false;
     // Need to flesh this out, currently we will only support data-aware controls for calc
     // and only handle a subset of functionality e.g. linked-cell and cell range data source. Of course later
     // we need to disambiguate for writer ( and others ? ) and also support the generic form (db) bindings
@@ -1707,10 +1674,7 @@ bool DlgEdObj::MakeDataAware( const Reference< frame::XModel >& xModel )
             Reference< form::binding::XListEntrySource > xSource( xFac->createInstanceWithArguments( "com.sun.star.table.CellRangeListSource", aArgs ), UNO_QUERY );
             xListEntrySink->setListEntrySource( xSource );
         }
-        if ( xListEntrySink.is() || xBindable.is() )
-            bRes = true;
     }
-    return bRes;
 }
 } // namespace basctl
 
