@@ -33,7 +33,7 @@
 
 namespace basegfx
 {
-    namespace tools
+    namespace utils
     {
         B2DPolyPolygon createAreaGeometryForLineStartEnd(
             const B2DPolygon& rCandidate,
@@ -46,8 +46,8 @@ namespace basegfx
             double fShift)
         {
             B2DPolyPolygon aRetval;
-            OSL_ENSURE(rCandidate.count() > 1L, "createAreaGeometryForLineStartEnd: Line polygon has too less points (!)");
-            OSL_ENSURE(rArrow.count() > 0L, "createAreaGeometryForLineStartEnd: Empty arrow tools::PolyPolygon (!)");
+            OSL_ENSURE(rCandidate.count() > 1, "createAreaGeometryForLineStartEnd: Line polygon has too less points (!)");
+            OSL_ENSURE(rArrow.count() > 0, "createAreaGeometryForLineStartEnd: Empty arrow utils::PolyPolygon (!)");
             OSL_ENSURE(fWidth > 0.0, "createAreaGeometryForLineStartEnd: Width too small (!)");
             OSL_ENSURE(fDockingPosition >= 0.0 && fDockingPosition <= 1.0,
                 "createAreaGeometryForLineStartEnd: fDockingPosition out of range [0.0 .. 1.0] (!)");
@@ -75,7 +75,7 @@ namespace basegfx
                 const B2DRange aArrowSize(getRange(rArrow));
 
                 // build ArrowTransform; center in X, align with axis in Y
-                B2DHomMatrix aArrowTransform(basegfx::tools::createTranslateB2DHomMatrix(
+                B2DHomMatrix aArrowTransform(basegfx::utils::createTranslateB2DHomMatrix(
                     -aArrowSize.getCenter().getX(), -aArrowSize.getMinimum().getY()));
 
                 // scale to target size
@@ -98,9 +98,9 @@ namespace basegfx
 
                 // get the polygon vector we want to plant this arrow on
                 const double fConsumedLength(fArrowYLength * (1.0 - fDockingPosition) - fShift);
-                const B2DVector aHead(rCandidate.getB2DPoint((bStart) ? 0L : rCandidate.count() - 1L));
+                const B2DVector aHead(rCandidate.getB2DPoint(bStart ? 0 : rCandidate.count() - 1));
                 const B2DVector aTail(getPositionAbsolute(rCandidate,
-                    (bStart) ? fConsumedLength : fCandidateLength - fConsumedLength, fCandidateLength));
+                    bStart ? fConsumedLength : fCandidateLength - fConsumedLength, fCandidateLength));
 
                 // from that vector, take the needed rotation and add rotate for arrow to transformation
                 const B2DVector aTargetDirection(aHead - aTail);
@@ -125,7 +125,7 @@ namespace basegfx
 
             return aRetval;
         }
-    } // end of namespace tools
+    } // end of namespace utils
 } // end of namespace basegfx
 
 namespace basegfx
@@ -245,7 +245,7 @@ namespace basegfx
                     {
                         // before splitting recursively with internal simple criteria, use
                         // ExtremumPosFinder to remove those
-                        ::std::vector< double > aExtremumPositions;
+                        std::vector< double > aExtremumPositions;
 
                         aExtremumPositions.reserve(4);
                         aEdge.getAllExtremumPositions(aExtremumPositions);
@@ -257,7 +257,7 @@ namespace basegfx
                             if(nCount > 1)
                             {
                                 // create order from left to right
-                                ::std::sort(aExtremumPositions.begin(), aExtremumPositions.end());
+                                std::sort(aExtremumPositions.begin(), aExtremumPositions.end());
                             }
 
                             for(sal_uInt32 b(0); b < nCount;)
@@ -359,21 +359,21 @@ namespace basegfx
                 const B2DVector aPerpendStartA(aNormalizedPerpendicularA * -fHalfLineWidth);
                 const B2DVector aPerpendEndA(aNormalizedPerpendicularB * -fHalfLineWidth);
                 double fCutA(0.0);
-                const CutFlagValue aCutA(tools::findCut(
+                const CutFlagValue aCutA(utils::findCut(
                     rEdge.getStartPoint(), aPerpendStartA,
                     rEdge.getEndPoint(), aPerpendEndA,
                     CutFlagValue::ALL, &fCutA));
-                const bool bCutA(CutFlagValue::NONE != aCutA);
+                const bool bCutA(aCutA != CutFlagValue::NONE);
 
                 // create lower displacement vectors and check if they cut
                 const B2DVector aPerpendStartB(aNormalizedPerpendicularA * fHalfLineWidth);
                 const B2DVector aPerpendEndB(aNormalizedPerpendicularB * fHalfLineWidth);
                 double fCutB(0.0);
-                const CutFlagValue aCutB(tools::findCut(
+                const CutFlagValue aCutB(utils::findCut(
                     rEdge.getEndPoint(), aPerpendEndB,
                     rEdge.getStartPoint(), aPerpendStartB,
                     CutFlagValue::ALL, &fCutB));
-                const bool bCutB(CutFlagValue::NONE != aCutB);
+                const bool bCutB(aCutB != CutFlagValue::NONE);
 
                 // check if cut happens
                 const bool bCut(bCutA || bCutB);
@@ -384,10 +384,10 @@ namespace basegfx
                 {
                     if(bStartRound)
                     {
-                        basegfx::B2DPolygon aStartPolygon(tools::createHalfUnitCircle());
+                        basegfx::B2DPolygon aStartPolygon(utils::createHalfUnitCircle());
 
                         aStartPolygon.transform(
-                            tools::createScaleShearXRotateTranslateB2DHomMatrix(
+                            utils::createScaleShearXRotateTranslateB2DHomMatrix(
                                 fHalfLineWidth, fHalfLineWidth,
                                 0.0,
                                 atan2(aTangentA.getY(), aTangentA.getX()) + F_PI2,
@@ -447,10 +447,10 @@ namespace basegfx
                 {
                     if(bEndRound)
                     {
-                        basegfx::B2DPolygon aEndPolygon(tools::createHalfUnitCircle());
+                        basegfx::B2DPolygon aEndPolygon(utils::createHalfUnitCircle());
 
                         aEndPolygon.transform(
-                            tools::createScaleShearXRotateTranslateB2DHomMatrix(
+                            utils::createScaleShearXRotateTranslateB2DHomMatrix(
                                 fHalfLineWidth, fHalfLineWidth,
                                 0.0,
                                 atan2(aTangentB.getY(), aTangentB.getX()) - F_PI2,
@@ -521,8 +521,8 @@ namespace basegfx
                     // Solve by using tooling.
                     // Remark: This nearly never happens due to curve preparations to extreme points
                     // and maximum angle turning, but I constructed a test case and checked that it is
-                    // working propery.
-                    const B2DPolyPolygon aTemp(tools::solveCrossovers(aBezierPolygon));
+                    // working properly.
+                    const B2DPolyPolygon aTemp(utils::solveCrossovers(aBezierPolygon));
                     const sal_uInt32 nTempCount(aTemp.count());
 
                     if(nTempCount)
@@ -589,11 +589,11 @@ namespace basegfx
                 // create left vertical
                 if(bStartRound)
                 {
-                    aEdgePolygon = tools::createHalfUnitCircle();
+                    aEdgePolygon = utils::createHalfUnitCircle();
                     fAngle = atan2(aTangent.getY(), aTangent.getX());
                     bAngle = true;
                     aEdgePolygon.transform(
-                        tools::createScaleShearXRotateTranslateB2DHomMatrix(
+                        utils::createScaleShearXRotateTranslateB2DHomMatrix(
                             fHalfLineWidth, fHalfLineWidth,
                             0.0,
                             fAngle + F_PI2,
@@ -623,7 +623,7 @@ namespace basegfx
                 // create right vertical
                 if(bEndRound)
                 {
-                    basegfx::B2DPolygon aEndPolygon(tools::createHalfUnitCircle());
+                    basegfx::B2DPolygon aEndPolygon(utils::createHalfUnitCircle());
 
                     if(!bAngle)
                     {
@@ -631,7 +631,7 @@ namespace basegfx
                     }
 
                     aEndPolygon.transform(
-                        tools::createScaleShearXRotateTranslateB2DHomMatrix(
+                        utils::createScaleShearXRotateTranslateB2DHomMatrix(
                             fHalfLineWidth, fHalfLineWidth,
                             0.0,
                             fAngle - F_PI2,
@@ -679,7 +679,7 @@ namespace basegfx
             double fMiterMinimumAngle)
         {
             OSL_ENSURE(fHalfLineWidth > 0.0, "createAreaGeometryForJoin: LineWidth too small (!)");
-            OSL_ENSURE(B2DLineJoin::NONE != eJoin, "createAreaGeometryForJoin: B2DLineJoin::NONE not allowed (!)");
+            OSL_ENSURE(eJoin != B2DLineJoin::NONE, "createAreaGeometryForJoin: B2DLineJoin::NONE not allowed (!)");
 
             // LineJoin from tangent rPerpendPrev to tangent rPerpendEdge in rPoint
             B2DPolygon aEdgePolygon;
@@ -688,7 +688,7 @@ namespace basegfx
 
             // test if for Miter, the angle is too small and the fallback
             // to bevel needs to be used
-            if(B2DLineJoin::Miter == eJoin)
+            if(eJoin == B2DLineJoin::Miter)
             {
                 const double fAngle(fabs(rPerpendPrev.angle(rPerpendEdge)));
 
@@ -713,9 +713,9 @@ namespace basegfx
                     // is not needed since the same fCut will be found on the first edge.
                     // If it exists, insert it to complete the mitered fill polygon.
                     double fCutPos(0.0);
-                    tools::findCut(aStartPoint, rTangentPrev, aEndPoint, rTangentEdge, CutFlagValue::ALL, &fCutPos);
+                    utils::findCut(aStartPoint, rTangentPrev, aEndPoint, rTangentEdge, CutFlagValue::ALL, &fCutPos);
 
-                    if(0.0 != fCutPos)
+                    if(fCutPos != 0.0)
                     {
                         const B2DPoint aCutPoint(aStartPoint + (rTangentPrev * fCutPos));
                         aEdgePolygon.append(aCutPoint);
@@ -740,7 +740,7 @@ namespace basegfx
                         fAngleEnd += F_2PI;
                     }
 
-                    const B2DPolygon aBow(tools::createPolygonFromEllipseSegment(rPoint, fHalfLineWidth, fHalfLineWidth, fAngleStart, fAngleEnd));
+                    const B2DPolygon aBow(utils::createPolygonFromEllipseSegment(rPoint, fHalfLineWidth, fHalfLineWidth, fAngleStart, fAngleEnd));
 
                     if(aBow.count() > 1)
                     {
@@ -757,7 +757,7 @@ namespace basegfx
                     }
                     else
                     {
-                        // wanted fall-through to default
+                        SAL_FALLTHROUGH; // wanted fall-through to default
                     }
                 }
                 default: // B2DLineJoin::Bevel
@@ -777,7 +777,7 @@ namespace basegfx
         }
     } // end of anonymus namespace
 
-    namespace tools
+    namespace utils
     {
         B2DPolyPolygon createAreaGeometry(
             const B2DPolygon& rCandidate,
@@ -828,14 +828,14 @@ namespace basegfx
                 B2DPolyPolygon aRetval;
                 const bool bIsClosed(aCandidate.isClosed());
                 const sal_uInt32 nEdgeCount(bIsClosed ? nPointCount : nPointCount - 1);
-                const bool bLineCap(!bIsClosed && css::drawing::LineCap_BUTT != eCap);
+                const bool bLineCap(!bIsClosed && eCap != css::drawing::LineCap_BUTT);
 
                 if(nEdgeCount)
                 {
                     B2DCubicBezier aEdge;
                     B2DCubicBezier aPrev;
 
-                    const bool bEventuallyCreateLineJoin(B2DLineJoin::NONE != eJoin);
+                    const bool bEventuallyCreateLineJoin(eJoin != B2DLineJoin::NONE);
                     // prepare edge
                     aEdge.setStartPoint(aCandidate.getB2DPoint(0));
 
@@ -858,15 +858,15 @@ namespace basegfx
                         aEdge.setEndPoint(aCandidate.getB2DPoint(nNextIndex));
 
                         // check and create linejoin
-                        if(bEventuallyCreateLineJoin && (bIsClosed || 0 != a))
+                        if(bEventuallyCreateLineJoin && (bIsClosed || a != 0))
                         {
                             B2DVector aTangentPrev(aPrev.getTangent(1.0)); aTangentPrev.normalize();
                             B2DVector aTangentEdge(aEdge.getTangent(0.0)); aTangentEdge.normalize();
                             B2VectorOrientation aOrientation(getOrientation(aTangentPrev, aTangentEdge));
 
-                            if(B2VectorOrientation::Neutral == aOrientation)
+                            if(aOrientation == B2VectorOrientation::Neutral)
                             {
-                                   // they are parallell or empty; if they are both not zero and point
+                                   // they are parallel or empty; if they are both not zero and point
                                    // in opposite direction, a half-circle is needed
                                    if(!aTangentPrev.equalZero() && !aTangentEdge.equalZero())
                                    {
@@ -881,7 +881,7 @@ namespace basegfx
                                 }
                             }
 
-                            if(B2VectorOrientation::Positive == aOrientation)
+                            if(aOrientation == B2VectorOrientation::Positive)
                             {
                                 const B2DVector aPerpendPrev(getPerpendicular(aTangentPrev) * -fHalfLineWidth);
                                 const B2DVector aPerpendEdge(getPerpendicular(aTangentEdge) * -fHalfLineWidth);
@@ -897,7 +897,7 @@ namespace basegfx
                                         eJoin,
                                         fMiterMinimumAngle));
                             }
-                            else if(B2VectorOrientation::Negative == aOrientation)
+                            else if(aOrientation == B2VectorOrientation::Negative)
                             {
                                 const B2DVector aPerpendPrev(getPerpendicular(aTangentPrev) * fHalfLineWidth);
                                 const B2DVector aPerpendEdge(getPerpendicular(aTangentEdge) * fHalfLineWidth);
@@ -926,10 +926,10 @@ namespace basegfx
                                 createAreaGeometryForEdge(
                                     aEdge,
                                     fHalfLineWidth,
-                                    bFirst && css::drawing::LineCap_ROUND == eCap,
-                                    bLast && css::drawing::LineCap_ROUND == eCap,
-                                    bFirst && css::drawing::LineCap_SQUARE == eCap,
-                                    bLast && css::drawing::LineCap_SQUARE == eCap));
+                                    bFirst && eCap == css::drawing::LineCap_ROUND,
+                                    bLast && eCap == css::drawing::LineCap_ROUND,
+                                    bFirst && eCap == css::drawing::LineCap_SQUARE,
+                                    bLast && eCap == css::drawing::LineCap_SQUARE));
                         }
                         else
                         {
@@ -955,6 +955,14 @@ namespace basegfx
                         }
                     }
                 }
+                else
+                {
+                    // point count, but no edge count -> single point
+                    aRetval.append(
+                        createPolygonFromCircle(
+                            aCandidate.getB2DPoint(0),
+                            fHalfLineWidth));
+                }
 
                 return aRetval;
             }
@@ -963,7 +971,7 @@ namespace basegfx
                 return B2DPolyPolygon(rCandidate);
             }
         }
-    } // end of namespace tools
+    } // end of namespace utils
 } // end of namespace basegfx
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
