@@ -31,16 +31,16 @@
 
 namespace basegfx
 {
-    namespace tools
+    namespace utils
     {
         // B3DPolygon tools
         void checkClosed(B3DPolygon& rCandidate)
         {
-            while(rCandidate.count() > 1L
-                && rCandidate.getB3DPoint(0L).equal(rCandidate.getB3DPoint(rCandidate.count() - 1L)))
+            while(rCandidate.count() > 1
+                && rCandidate.getB3DPoint(0).equal(rCandidate.getB3DPoint(rCandidate.count() - 1)))
             {
                 rCandidate.setClosed(true);
-                rCandidate.remove(rCandidate.count() - 1L);
+                rCandidate.remove(rCandidate.count() - 1);
             }
         }
 
@@ -48,13 +48,13 @@ namespace basegfx
         {
             OSL_ENSURE(nIndex < rCandidate.count(), "getIndexOfPredecessor: Access to polygon out of range (!)");
 
-            if(nIndex + 1L < rCandidate.count())
+            if(nIndex + 1 < rCandidate.count())
             {
-                return nIndex + 1L;
+                return nIndex + 1;
             }
             else
             {
-                return 0L;
+                return 0;
             }
         }
 
@@ -63,7 +63,7 @@ namespace basegfx
             B3DRange aRetval;
             const sal_uInt32 nPointCount(rCandidate.count());
 
-            for(sal_uInt32 a(0L); a < nPointCount; a++)
+            for(sal_uInt32 a(0); a < nPointCount; a++)
             {
                 const B3DPoint aTestPoint(rCandidate.getB3DPoint(a));
                 aRetval.expand(aTestPoint);
@@ -77,11 +77,11 @@ namespace basegfx
             double fRetval(0.0);
             const sal_uInt32 nPointCount(rCandidate.count());
 
-            if(nPointCount > 1L)
+            if(nPointCount > 1)
             {
-                const sal_uInt32 nLoopCount(rCandidate.isClosed() ? nPointCount : nPointCount - 1L);
+                const sal_uInt32 nLoopCount(rCandidate.isClosed() ? nPointCount : nPointCount - 1);
 
-                for(sal_uInt32 a(0L); a < nLoopCount; a++)
+                for(sal_uInt32 a(0); a < nLoopCount; a++)
                 {
                     const sal_uInt32 nNextIndex(getIndexOfSuccessor(a, rCandidate));
                     const B3DPoint aCurrentPoint(rCandidate.getB3DPoint(a));
@@ -94,17 +94,17 @@ namespace basegfx
             return fRetval;
         }
 
-        void applyLineDashing(const B3DPolygon& rCandidate, const ::std::vector<double>& rDotDashArray, B3DPolyPolygon* pLineTarget, B3DPolyPolygon* pGapTarget, double fDotDashLength)
+        void applyLineDashing(const B3DPolygon& rCandidate, const std::vector<double>& rDotDashArray, B3DPolyPolygon* pLineTarget, double fDotDashLength)
         {
             const sal_uInt32 nPointCount(rCandidate.count());
             const sal_uInt32 nDotDashCount(rDotDashArray.size());
 
             if(fTools::lessOrEqual(fDotDashLength, 0.0))
             {
-                fDotDashLength = ::std::accumulate(rDotDashArray.begin(), rDotDashArray.end(), 0.0);
+                fDotDashLength = std::accumulate(rDotDashArray.begin(), rDotDashArray.end(), 0.0);
             }
 
-            if(fTools::more(fDotDashLength, 0.0) && (pLineTarget || pGapTarget) && nPointCount)
+            if(fTools::more(fDotDashLength, 0.0) && pLineTarget && nPointCount)
             {
                 // clear targets
                 if(pLineTarget)
@@ -112,11 +112,6 @@ namespace basegfx
                     pLineTarget->clear();
                 }
 
-                if(pGapTarget)
-                {
-                    pGapTarget->clear();
-                }
-
                 // prepare current edge's start
                 B3DPoint aCurrentPoint(rCandidate.getB3DPoint(0));
                 const sal_uInt32 nEdgeCount(rCandidate.isClosed() ? nPointCount : nPointCount - 1);
@@ -142,9 +137,8 @@ namespace basegfx
                         {
                             // new split is inside edge, create and append snippet [fLastDotDashMovingLength, fDotDashMovingLength]
                             const bool bHandleLine(bIsLine && pLineTarget);
-                            const bool bHandleGap(!bIsLine && pGapTarget);
 
-                            if(bHandleLine || bHandleGap)
+                            if(bHandleLine)
                             {
                                 if(!aSnippet.count())
                                 {
@@ -157,10 +151,6 @@ namespace basegfx
                                 {
                                     pLineTarget->append(aSnippet);
                                 }
-                                else
-                                {
-                                    pGapTarget->append(aSnippet);
-                                }
 
                                 aSnippet.clear();
                             }
@@ -173,9 +163,8 @@ namespace basegfx
 
                         // append snippet [fLastDotDashMovingLength, fEdgeLength]
                         const bool bHandleLine(bIsLine && pLineTarget);
-                        const bool bHandleGap(!bIsLine && pGapTarget);
 
-                        if(bHandleLine || bHandleGap)
+                        if(bHandleLine)
                         {
                             if(!aSnippet.count())
                             {
@@ -200,10 +189,6 @@ namespace basegfx
                     {
                         pLineTarget->append(aSnippet);
                     }
-                    else if(!bIsLine && pGapTarget)
-                    {
-                        pGapTarget->append(aSnippet);
-                    }
                 }
 
                 // check if start and end polygon may be merged
@@ -228,28 +213,6 @@ namespace basegfx
                         }
                     }
                 }
-
-                if(pGapTarget)
-                {
-                    const sal_uInt32 nCount(pGapTarget->count());
-
-                    if(nCount > 1)
-                    {
-                        // these polygons were created above, there exists none with less than two points,
-                        // thus dircet point access below is allowed
-                        const B3DPolygon aFirst(pGapTarget->getB3DPolygon(0));
-                        B3DPolygon aLast(pGapTarget->getB3DPolygon(nCount - 1));
-
-                        if(aFirst.getB3DPoint(0).equal(aLast.getB3DPoint(aLast.count() - 1)))
-                        {
-                            // start of first and end of last are the same -> merge them
-                            aLast.append(aFirst);
-                            aLast.removeDoublePoints();
-                            pGapTarget->setB3DPolygon(0, aLast);
-                            pGapTarget->remove(nCount - 1);
-                        }
-                    }
-                }
             }
             else
             {
@@ -258,11 +221,6 @@ namespace basegfx
                 {
                     pLineTarget->append(rCandidate);
                 }
-
-                if(pGapTarget)
-                {
-                    pGapTarget->append(rCandidate);
-                }
             }
         }
 
@@ -270,7 +228,7 @@ namespace basegfx
         {
             B3DPolygon aRetval(rCandidate);
 
-            for(sal_uInt32 a(0L); a < aRetval.count(); a++)
+            for(sal_uInt32 a(0); a < aRetval.count(); a++)
             {
                 B3DVector aVector(aRetval.getB3DPoint(a) - rCenter);
                 aVector.normalize();
@@ -286,7 +244,7 @@ namespace basegfx
 
             if(aRetval.areNormalsUsed())
             {
-                for(sal_uInt32 a(0L); a < aRetval.count(); a++)
+                for(sal_uInt32 a(0); a < aRetval.count(); a++)
                 {
                     aRetval.setNormal(a, -aRetval.getNormal(a));
                 }
@@ -309,7 +267,7 @@ namespace basegfx
                 const bool bHeightSet(!fTools::equalZero(fHeight));
                 const double fOne(1.0);
 
-                for(sal_uInt32 a(0L); a < aRetval.count(); a++)
+                for(sal_uInt32 a(0); a < aRetval.count(); a++)
                 {
                     const B3DPoint aPoint(aRetval.getB3DPoint(a));
                     B2DPoint aTextureCoordinate(aRetval.getTextureCoordinate(a));
@@ -364,7 +322,7 @@ namespace basegfx
                 const B3DPoint aPlaneCenter(aPlaneRange.getCenter() - rCenter);
                 const double fXCenter(fOne - ((atan2(aPlaneCenter.getZ(), aPlaneCenter.getX()) + F_PI) / F_2PI));
 
-                for(a = 0L; a < nPointCount; a++)
+                for(a = 0; a < nPointCount; a++)
                 {
                     const B3DVector aVector(aRetval.getB3DPoint(a) - rCenter);
                     const double fY(fOne - ((atan2(aVector.getY(), aVector.getXZLength()) + F_PI2) / F_PI));
@@ -386,7 +344,7 @@ namespace basegfx
                     else if(fTools::equal(fY, fOne))
                     {
                         // point is a south polar point, no useful X-coordinate can be created. Set
-                        // Y-coordinte, though
+                        // Y-coordinate, though
                         if(bChangeY)
                         {
                             aTexCoor.setY(fOne);
@@ -429,15 +387,15 @@ namespace basegfx
                 {
                     // correct X-texture coordinates if polar points are contained. Those
                     // coordinates cannot be correct, so use prev or next X-coordinate
-                    for(a = 0L; a < nPointCount; a++)
+                    for(a = 0; a < nPointCount; a++)
                     {
                         B2DPoint aTexCoor(aRetval.getTextureCoordinate(a));
 
                         if(fTools::equalZero(aTexCoor.getY()) || fTools::equal(aTexCoor.getY(), fOne))
                         {
                             // get prev, next TexCoor and test for pole
-                            const B2DPoint aPrevTexCoor(aRetval.getTextureCoordinate(a ? a - 1L : nPointCount - 1L));
-                            const B2DPoint aNextTexCoor(aRetval.getTextureCoordinate((a + 1L) % nPointCount));
+                            const B2DPoint aPrevTexCoor(aRetval.getTextureCoordinate(a ? a - 1 : nPointCount - 1));
+                            const B2DPoint aNextTexCoor(aRetval.getTextureCoordinate((a + 1) % nPointCount));
                             const bool bPrevPole(fTools::equalZero(aPrevTexCoor.getY()) || fTools::equal(aPrevTexCoor.getY(), fOne));
                             const bool bNextPole(fTools::equalZero(aNextTexCoor.getY()) || fTools::equal(aNextTexCoor.getY(), fOne));
 
@@ -676,20 +634,20 @@ namespace basegfx
             }
         }
 
-        bool isPointOnPolygon(const B3DPolygon& rCandidate, const B3DPoint& rPoint, bool bWithPoints)
+        bool isPointOnPolygon(const B3DPolygon& rCandidate, const B3DPoint& rPoint)
         {
             const sal_uInt32 nPointCount(rCandidate.count());
 
-            if(nPointCount > 1L)
+            if(nPointCount > 1)
             {
-                const sal_uInt32 nLoopCount(rCandidate.isClosed() ? nPointCount : nPointCount - 1L);
+                const sal_uInt32 nLoopCount(rCandidate.isClosed() ? nPointCount : nPointCount - 1);
                 B3DPoint aCurrentPoint(rCandidate.getB3DPoint(0));
 
                 for(sal_uInt32 a(0); a < nLoopCount; a++)
                 {
                     const B3DPoint aNextPoint(rCandidate.getB3DPoint((a + 1) % nPointCount));
 
-                    if(isPointOnLine(aCurrentPoint, aNextPoint, rPoint, bWithPoints))
+                    if(isPointOnLine(aCurrentPoint, aNextPoint, rPoint, true/*bWithPoints*/))
                     {
                         return true;
                     }
@@ -697,7 +655,7 @@ namespace basegfx
                     aCurrentPoint = aNextPoint;
                 }
             }
-            else if(nPointCount && bWithPoints)
+            else if(nPointCount)
             {
                 return rPoint.equal(rCandidate.getB3DPoint(0));
             }
@@ -786,7 +744,7 @@ namespace basegfx
             }
         }
 
-    } // end of namespace tools
+    } // end of namespace utils
 } // end of namespace basegfx
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
