@@ -19,19 +19,18 @@
 
 #include <basic/basicmanagerrepository.hxx>
 #include <basic/basmgr.hxx>
-#include "scriptcont.hxx"
-#include "dlgcont.hxx"
+#include <scriptcont.hxx>
+#include <dlgcont.hxx>
 #include <basic/sbuno.hxx>
-#include "sbintern.hxx"
+#include <sbintern.hxx>
 
-#include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/document/XStorageBasedDocument.hpp>
 #include <com/sun/star/document/XEmbeddedScripts.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
 #include <svtools/ehdl.hxx>
 #include <svtools/sfxecode.hxx>
 #include <unotools/pathoptions.hxx>
-#include <svl/smplhint.hxx>
+#include <svl/hint.hxx>
 #include <vcl/svapp.hxx>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
@@ -50,8 +49,6 @@
 
 namespace basic
 {
-
-
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::uno::XComponentContext;
     using ::com::sun::star::frame::XModel;
@@ -60,18 +57,15 @@ namespace basic
     using ::com::sun::star::uno::UNO_QUERY;
     using ::com::sun::star::embed::XStorage;
     using ::com::sun::star::script::XPersistentLibraryContainer;
-    using ::com::sun::star::uno::Any;
-    using ::com::sun::star::lang::XMultiServiceFactory;
     using ::com::sun::star::uno::UNO_QUERY_THROW;
-    using ::com::sun::star::beans::XPropertySet;
     using ::com::sun::star::uno::Exception;
     using ::com::sun::star::document::XStorageBasedDocument;
     using ::com::sun::star::lang::XComponent;
     using ::com::sun::star::document::XEmbeddedScripts;
 
-    typedef ::std::map< Reference< XInterface >, BasicManager*, ::comphelper::OInterfaceCompare< XInterface > > BasicManagerStore;
+    typedef std::map< Reference< XInterface >, BasicManager*, ::comphelper::OInterfaceCompare< XInterface > > BasicManagerStore;
 
-    typedef ::std::vector< BasicManagerCreationListener* >  CreationListeners;
+    typedef std::vector< BasicManagerCreationListener* >  CreationListeners;
 
     class ImplRepository : public ::utl::OEventListenerAdapter, public SfxListener
     {
@@ -87,8 +81,9 @@ namespace basic
         static ImplRepository& Instance();
 
         BasicManager*   getDocumentBasicManager( const Reference< XModel >& _rxDocumentModel );
-        BasicManager*   getApplicationBasicManager( bool _bCreate );
-        void            setApplicationBasicManager( BasicManager* _pBasicManager );
+        BasicManager*   getOrCreateApplicationBasicManager();
+        static BasicManager* getApplicationBasicManager();
+        static void          setApplicationBasicManager( BasicManager* _pBasicManager );
         void    registerCreationListener( BasicManagerCreationListener& _rListener );
         void    revokeCreationListener( BasicManagerCreationListener& _rListener );
 
@@ -108,6 +103,17 @@ namespace basic
         BasicManager*&
                 impl_getLocationForModel( const Reference< XModel >& _rxDocumentModel );
 
+        /** tests if there is a location set at which the BasicManager for the given model
+            is stored.
+
+            @param _rxDocumentModel
+                the model whose BasicManager's location is to be retrieved. Must not be <NULL/>.
+
+            @precond
+                our mutex is locked
+        */
+        bool impl_hasLocationForModel( const Reference< XModel >& _rxDocumentModel ) const;
+
         /** creates a new BasicManager instance for the given model
 
             @param _out_rpBasicManager
@@ -117,7 +123,7 @@ namespace basic
             @param _rxDocumentModel
                 the model whose BasicManager will be created. Must not be <NULL/>.
         */
-        void impl_createManagerForModel(
+        bool impl_createManagerForModel(
                     BasicManager*& _out_rpBasicManager,
                     const Reference< XModel >& _rxDocumentModel );
 
@@ -183,7 +189,7 @@ namespace basic
 
         /** removes the Model/BasicManager pair given by iterator from our store
         */
-        void impl_removeFromRepository( BasicManagerStore::iterator _pos );
+        void impl_removeFromRepository( const BasicManagerStore::iterator& _pos );
 
     private:
         StarBASIC* impl_getDefaultAppBasicLibrary();
@@ -211,7 +217,6 @@ namespace basic
             create( CreateImplRepository(), ::osl::GetGlobalMutex() );
     }
 
-
     BasicManager* ImplRepository::getDocumentBasicManager( const Reference< XModel >& _rxDocumentModel )
     {
         SolarMutexGuard g;
@@ -225,30 +230,35 @@ namespace basic
             without creating another instance.
          */
         BasicManager*& pBasicManager = impl_getLocationForModel( _rxDocumentModel );
-        if ( pBasicManager == nullptr )
-            impl_createManagerForModel( pBasicManager, _rxDocumentModel );
-
-        return pBasicManager;
+        if (pBasicManager != nullptr)
+            return pBasicManager;
+        if (impl_createManagerForModel(pBasicManager, _rxDocumentModel))
+            return pBasicManager;
+        return nullptr;
     }
 
-
-    BasicManager* ImplRepository::getApplicationBasicManager( bool _bCreate )
+    BasicManager* ImplRepository::getOrCreateApplicationBasicManager()
     {
         SolarMutexGuard g;
 
         BasicManager* pAppManager = GetSbData()->pAppBasMgr;
-        if ( ( pAppManager == nullptr ) && _bCreate )
+        if (pAppManager == nullptr)
             pAppManager = impl_createApplicationBasicManager();
-
         return pAppManager;
     }
 
+    BasicManager* ImplRepository::getApplicationBasicManager()
+    {
+        SolarMutexGuard g;
+
+        return GetSbData()->pAppBasMgr;
+    }
 
     void ImplRepository::setApplicationBasicManager( BasicManager* _pBasicManager )
     {
         SolarMutexGuard g;
 
-        BasicManager* pPreviousManager = getApplicationBasicManager( false );
+        BasicManager* pPreviousManager = getApplicationBasicManager();
         delete pPreviousManager;
 
         GetSbData()->pAppBasMgr = _pBasicManager;
@@ -259,7 +269,7 @@ namespace basic
     {
         SolarMutexGuard g;
 
-        OSL_PRECOND( getApplicationBasicManager( false ) == nullptr, "ImplRepository::impl_createApplicationBasicManager: there already is one!" );
+        OSL_PRECOND(getApplicationBasicManager() == nullptr, "ImplRepository::impl_createApplicationBasicManager: there already is one!");
 
         // Determine Directory
         SvtPathOptions aPathCFG;
@@ -303,7 +313,7 @@ namespace basic
 
         // StarDesktop
         Reference< XComponentContext > xContext = ::comphelper::getProcessComponentContext();
-        pBasicManager->SetGlobalUNOConstant( "StarDesktop", makeAny( Desktop::create(xContext)));
+        pBasicManager->SetGlobalUNOConstant( "StarDesktop", css::uno::Any( Desktop::create(xContext)));
 
         // (BasicLibraries and DialogLibraries have automatically been added in SetLibraryContainerInfo)
 
@@ -327,7 +337,7 @@ namespace basic
     {
         SolarMutexGuard g;
 
-        CreationListeners::iterator pos = ::std::find( m_aCreationListeners.begin(), m_aCreationListeners.end(), &_rListener );
+        CreationListeners::iterator pos = std::find( m_aCreationListeners.begin(), m_aCreationListeners.end(), &_rListener );
         if ( pos != m_aCreationListeners.end() )
             m_aCreationListeners.erase( pos );
         else {
@@ -350,14 +360,13 @@ namespace basic
 
     StarBASIC* ImplRepository::impl_getDefaultAppBasicLibrary()
     {
-        BasicManager* pAppManager = getApplicationBasicManager( true );
+        BasicManager* pAppManager = getOrCreateApplicationBasicManager();
 
         StarBASIC* pAppBasic = pAppManager ? pAppManager->GetLib(0) : nullptr;
         DBG_ASSERT( pAppBasic != nullptr, "impl_getApplicationBasic: unable to determine the default application's Basic library!" );
         return pAppBasic;
     }
 
-
     BasicManager*& ImplRepository::impl_getLocationForModel( const Reference< XModel >& _rxDocumentModel )
     {
         Reference< XInterface > xNormalized( _rxDocumentModel, UNO_QUERY );
@@ -367,6 +376,13 @@ namespace basic
         return location;
     }
 
+    bool ImplRepository::impl_hasLocationForModel( const Reference< XModel >& _rxDocumentModel ) const
+    {
+        Reference< XInterface > xNormalized( _rxDocumentModel, UNO_QUERY );
+        DBG_ASSERT( _rxDocumentModel.is(), "ImplRepository::impl_getLocationForModel: invalid model!" );
+
+        return m_aStore.find(xNormalized) != m_aStore.end();
+    }
 
     void ImplRepository::impl_initDocLibraryContainers_nothrow( const Reference< XPersistentLibraryContainer >& _rxBasicLibraries, const Reference< XPersistentLibraryContainer >& _rxDialogLibraries )
     {
@@ -393,8 +409,7 @@ namespace basic
         }
     }
 
-
-    void ImplRepository::impl_createManagerForModel( BasicManager*& _out_rpBasicManager, const Reference< XModel >& _rxDocumentModel )
+    bool ImplRepository::impl_createManagerForModel( BasicManager*& _out_rpBasicManager, const Reference< XModel >& _rxDocumentModel )
     {
         StarBASIC* pAppBasic = impl_getDefaultAppBasicLibrary();
 
@@ -403,13 +418,13 @@ namespace basic
         if ( !impl_getDocumentStorage_nothrow( _rxDocumentModel, xStorage ) )
         {
             // the document is not able to provide the storage it is based on.
-            return;
+            return false;
         }
         Reference< XPersistentLibraryContainer > xBasicLibs;
         Reference< XPersistentLibraryContainer > xDialogLibs;
         if ( !impl_getDocumentLibraryContainers_nothrow( _rxDocumentModel, xBasicLibs, xDialogLibs ) )
             // the document does not have BasicLibraries and DialogLibraries
-            return;
+            return false;
 
         if ( xStorage.is() )
         {
@@ -427,10 +442,10 @@ namespace basic
             {
                 // handle errors
                 std::vector<BasicError>& aErrors = _out_rpBasicManager->GetErrors();
-                for(std::vector<BasicError>::const_iterator i = aErrors.begin(); i != aErrors.end(); ++i)
+                for(const auto& rError : aErrors)
                 {
                     // show message to user
-                    if ( ERRCODE_BUTTON_CANCEL == ErrorHandler::HandleError( i->GetErrorId() ) )
+                    if ( ErrorHandler::HandleError( rError.GetErrorId() ) == DialogMask::ButtonsCancel )
                     {
                         // user wants to break loading of BASIC-manager
                         delete _out_rpBasicManager;
@@ -463,27 +478,34 @@ namespace basic
         _out_rpBasicManager->GetLib(0)->SetParent( pAppBasic );
 
         // global properties in the document's Basic
-        _out_rpBasicManager->SetGlobalUNOConstant( "ThisComponent", makeAny( _rxDocumentModel ) );
+        _out_rpBasicManager->SetGlobalUNOConstant( "ThisComponent", css::uno::Any( _rxDocumentModel ) );
 
         // notify
         impl_notifyCreationListeners( _rxDocumentModel, *_out_rpBasicManager );
 
         // register as listener for this model being disposed/closed
         OSL_ENSURE( _rxDocumentModel.is(), "ImplRepository::impl_createManagerForModel: the document must be an XComponent!" );
+        assert(impl_hasLocationForModel(_rxDocumentModel));
         startComponentListening( _rxDocumentModel );
 
-        // register as listener for the BasicManager being destroyed
-        StartListening( *_out_rpBasicManager );
+        bool bOk = false;
+        // startComponentListening may fail in a disposed _rxDocumentModel, in which case _out_rpBasicManager will be removed
+        // from the map and destroyed
+        if (impl_hasLocationForModel(_rxDocumentModel))
+        {
+            bOk = true;
+            // register as listener for the BasicManager being destroyed
+            StartListening( *_out_rpBasicManager );
+        }
 
         // #i104876: Library container must not be modified just after
         // creation. This happens as side effect when creating default
         // "Standard" libraries and needs to be corrected here
-        xBasicLibs->setModified( sal_False );
-        xDialogLibs->setModified( sal_False );
-
+        xBasicLibs->setModified( false );
+        xDialogLibs->setModified( false );
+        return bOk;
     }
 
-
     bool ImplRepository::impl_getDocumentStorage_nothrow( const Reference< XModel >& _rxDocument, Reference< XStorage >& _out_rStorage )
     {
         _out_rStorage.clear();
@@ -520,7 +542,7 @@ namespace basic
     }
 
 
-    void ImplRepository::impl_removeFromRepository( BasicManagerStore::iterator _pos )
+    void ImplRepository::impl_removeFromRepository( const BasicManagerStore::iterator& _pos )
     {
         OSL_PRECOND( _pos != m_aStore.end(), "ImplRepository::impl_removeFromRepository: invalid position!" );
 
@@ -559,8 +581,7 @@ namespace basic
 
     void ImplRepository::Notify( SfxBroadcaster& _rBC, const SfxHint& _rHint )
     {
-        const SfxSimpleHint* pSimpleHint = dynamic_cast< const SfxSimpleHint* >( &_rHint );
-        if ( !pSimpleHint || ( pSimpleHint->GetId() != SFX_HINT_DYING ) )
+        if ( _rHint.GetId() != SfxHintId::Dying )
             // not interested in
             return;
 
@@ -584,37 +605,31 @@ namespace basic
         }
     }
 
-
     BasicManager* BasicManagerRepository::getDocumentBasicManager( const Reference< XModel >& _rxDocumentModel )
     {
         return ImplRepository::Instance().getDocumentBasicManager( _rxDocumentModel );
     }
 
-
-    BasicManager* BasicManagerRepository::getApplicationBasicManager( bool _bCreate )
+    BasicManager* BasicManagerRepository::getApplicationBasicManager()
     {
-        return ImplRepository::Instance().getApplicationBasicManager( _bCreate );
+        return ImplRepository::Instance().getOrCreateApplicationBasicManager();
     }
 
-
     void BasicManagerRepository::resetApplicationBasicManager()
     {
-        return ImplRepository::Instance().setApplicationBasicManager( nullptr );
+        ImplRepository::setApplicationBasicManager( nullptr );
     }
 
-
     void BasicManagerRepository::registerCreationListener( BasicManagerCreationListener& _rListener )
     {
         ImplRepository::Instance().registerCreationListener( _rListener );
     }
 
-
     void BasicManagerRepository::revokeCreationListener( BasicManagerCreationListener& _rListener )
     {
         ImplRepository::Instance().revokeCreationListener( _rListener );
     }
 
-
 } // namespace basic
 
 
