@@ -24,8 +24,11 @@
 #include <tools/color.hxx>
 #include <i18nlangtag/lang.h>
 #include <basic/sbx.hxx>
+#include <basic/sberrors.hxx>
 #include "sbxconv.hxx"
-#include "math.h"
+#include <runtime.hxx>
+#include <sbintern.hxx>
+#include <math.h>
 #include <comphelper/processfactory.hxx>
 #include <memory>
 
@@ -38,7 +41,7 @@ double ImpGetDate( const SbxValues* p )
     switch( +p->eType )
     {
     case SbxNULL:
-        SbxBase::SetError( ERRCODE_SBX_CONVERSION );
+        SbxBase::SetError( ERRCODE_BASIC_CONVERSION );
         SAL_FALLTHROUGH;
     case SbxEMPTY:
         nRes = 0;
@@ -100,8 +103,16 @@ double ImpGetDate( const SbxValues* p )
         else
         {
             LanguageType eLangType = Application::GetSettings().GetLanguageTag().getLanguageType();
-
-            std::unique_ptr<SvNumberFormatter> pFormatter(new SvNumberFormatter( comphelper::getProcessComponentContext(), eLangType ));
+            std::shared_ptr<SvNumberFormatter> pFormatter;
+            if (GetSbData()->pInst)
+            {
+                pFormatter = GetSbData()->pInst->GetNumberFormatter();
+            }
+            else
+            {
+                sal_uInt32 nDummy;
+                pFormatter = SbiInstance::PrepareNumberFormatter( nDummy, nDummy, nDummy );
+            }
 
             sal_uInt32 nIndex;
             sal_Int32 nCheckPos = 0;
@@ -143,7 +154,7 @@ double ImpGetDate( const SbxValues* p )
 
             if ( !bSuccess )
             {
-                SbxBase::SetError( ERRCODE_SBX_CONVERSION ); nRes = 0;
+                SbxBase::SetError( ERRCODE_BASIC_CONVERSION ); nRes = 0;
             }
         }
         break;
@@ -155,7 +166,7 @@ double ImpGetDate( const SbxValues* p )
         }
         else
         {
-            SbxBase::SetError( ERRCODE_SBX_NO_OBJECT ); nRes = 0;
+            SbxBase::SetError( ERRCODE_BASIC_NO_OBJECT ); nRes = 0;
         }
         break;
     case SbxBYREF | SbxCHAR:
@@ -195,7 +206,7 @@ double ImpGetDate( const SbxValues* p )
         nRes = ImpSalUInt64ToDouble( *p->puInt64 );
         break;
     default:
-        SbxBase::SetError( ERRCODE_SBX_CONVERSION ); nRes = 0;
+        SbxBase::SetError( ERRCODE_BASIC_CONVERSION ); nRes = 0;
         break;
     }
     return nRes;
@@ -250,7 +261,7 @@ start:
         pDec = ImpCreateDecimal( p );
         if( !pDec->setDouble( n ) )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW );
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW );
         }
         break;
     direct:
@@ -268,7 +279,16 @@ start:
             Color* pColor;
 
             LanguageType eLangType = Application::GetSettings().GetLanguageTag().getLanguageType();
-            std::unique_ptr<SvNumberFormatter> pFormatter(new SvNumberFormatter( comphelper::getProcessComponentContext(), eLangType ));
+            std::shared_ptr<SvNumberFormatter> pFormatter;
+            if (GetSbData()->pInst)
+            {
+                pFormatter = GetSbData()->pInst->GetNumberFormatter();
+            }
+            else
+            {
+                sal_uInt32 nDummy;
+                pFormatter = SbiInstance::PrepareNumberFormatter( nDummy, nDummy, nDummy );
+            }
 
             sal_uInt32 nIndex;
             sal_Int32 nCheckPos = 0;
@@ -285,20 +305,20 @@ start:
                 {
                     switch( eDate )
                     {
-                    case DateOrder::MDY: aStr = "MM.TT.JJJJ"; break;
-                    case DateOrder::DMY: aStr = "TT.MM.JJJJ"; break;
-                    case DateOrder::YMD: aStr = "JJJJ.MM.TT"; break;
-                    default:               aStr = "MM.TT.JJJJ";
+                        default:
+                        case DateOrder::MDY: aStr = "MM/DD/YYYY"; break;
+                        case DateOrder::DMY: aStr = "DD/MM/YYYY"; break;
+                        case DateOrder::YMD: aStr = "YYYY/MM/DD"; break;
                     }
                 }
                 else
                 {
                     switch( eDate )
                     {
-                    case DateOrder::MDY: aStr = "MM.TT.JJJJ HH:MM:SS"; break;
-                    case DateOrder::DMY: aStr = "TT.MM.JJJJ HH:MM:SS"; break;
-                    case DateOrder::YMD: aStr = "JJJJ.MM.TT HH:MM:SS"; break;
-                    default:              aStr = "MM.TT.JJJJ HH:MM:SS";
+                        default:
+                        case DateOrder::MDY: aStr = "MM/DD/YYYY HH:MM:SS"; break;
+                        case DateOrder::DMY: aStr = "DD/MM/YYYY HH:MM:SS"; break;
+                        case DateOrder::YMD: aStr = "YYYY/MM/DD HH:MM:SS"; break;
                     }
                 }
             }
@@ -310,7 +330,7 @@ start:
                                             nCheckPos,
                                             nType,
                                             nIndex,
-                                            LANGUAGE_GERMAN,
+                                            LANGUAGE_ENGLISH_US,
                                             eLangType );
             pFormatter->GetOutputString( n, nIndex, *p->pOUString, &pColor );
             break;
@@ -323,28 +343,28 @@ start:
         }
         else
         {
-            SbxBase::SetError( ERRCODE_SBX_NO_OBJECT );
+            SbxBase::SetError( ERRCODE_BASIC_NO_OBJECT );
         }
         break;
     case SbxBYREF | SbxCHAR:
         if( n > SbxMAXCHAR )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMAXCHAR;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMAXCHAR;
         }
         else if( n < SbxMINCHAR )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMINCHAR;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMINCHAR;
         }
         *p->pChar = (sal_Unicode) n;
         break;
     case SbxBYREF | SbxBYTE:
         if( n > SbxMAXBYTE )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMAXBYTE;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMAXBYTE;
         }
         else if( n < 0 )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = 0;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = 0;
         }
         *p->pByte = (sal_uInt8) n;
         break;
@@ -352,11 +372,11 @@ start:
     case SbxBYREF | SbxBOOL:
         if( n > SbxMAXINT )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMAXINT;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMAXINT;
         }
         else if( n < SbxMININT )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMININT;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMININT;
         }
         *p->pInteger = (sal_Int16) n;
         break;
@@ -364,44 +384,44 @@ start:
     case SbxBYREF | SbxUSHORT:
         if( n > SbxMAXUINT )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMAXUINT;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMAXUINT;
         }
         else if( n < 0 )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = 0;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = 0;
         }
         *p->pUShort = (sal_uInt16) n;
         break;
     case SbxBYREF | SbxLONG:
         if( n > SbxMAXLNG )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMAXLNG;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMAXLNG;
         }
         else if( n < SbxMINLNG )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMINLNG;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMINLNG;
         }
         *p->pLong = (sal_Int32) n;
         break;
     case SbxBYREF | SbxULONG:
         if( n > SbxMAXULNG )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMAXULNG;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMAXULNG;
         }
         else if( n < 0 )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = 0;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = 0;
         }
         *p->pULong = (sal_uInt32) n;
         break;
     case SbxBYREF | SbxSINGLE:
         if( n > SbxMAXSNG )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMAXSNG;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMAXSNG;
         }
         else if( n < SbxMINSNG )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMINSNG;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMINSNG;
         }
         *p->pSingle = (float) n;
         break;
@@ -418,16 +438,16 @@ start:
     case SbxBYREF | SbxCURRENCY:
         if( n > SbxMAXCURR )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMAXCURR;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMAXCURR;
         }
         else if( n < SbxMINCURR )
         {
-            SbxBase::SetError( ERRCODE_SBX_OVERFLOW ); n = SbxMINCURR;
+            SbxBase::SetError( ERRCODE_BASIC_MATH_OVERFLOW ); n = SbxMINCURR;
         }
         *p->pnInt64 = ImpDoubleToCurrency( n );
         break;
     default:
-        SbxBase::SetError( ERRCODE_SBX_CONVERSION );
+        SbxBase::SetError( ERRCODE_BASIC_CONVERSION );
         break;
     }
 }
