@@ -20,44 +20,25 @@
 #if defined _MSC_VER
 #pragma warning(push, 1)
 #endif
+#if !defined WIN32_LEAN_AND_MEAN
+# define WIN32_LEAN_AND_MEAN
+#endif
 #include <windows.h>
 #if defined _MSC_VER
 #pragma warning(pop)
 #endif
 
-#define JAWT_GetAWT hidden_JAWT_GetAWT
-#include "jawt.h"
-#undef JAWT_GetAWT
-
 #if defined _MSC_VER
 #pragma warning(push, 1)
 #endif
-/* When cross-compiling to Windows we don't have any Windows JDK
- * available. Copying this short snippet from win32/jawt_md.h can
- * surely not be against its license. The intent is to enable
- * interoperation with real Oracle Java after all. We leave out the
- * informative comments that might have "artistic merit" and be more
- * copyrightable. Use this also for native Windows compilation for
- * simplicity.
- */
-typedef struct jawt_Win32DrawingSurfaceInfo {
-    union {
-        HWND hwnd;
-        HBITMAP hbitmap;
-        void* pbits;
-    };
-    HDC hdc;
-    HPALETTE hpalette;
-} JAWT_Win32DrawingSurfaceInfo;
-
-JNIIMPORT unsigned char JNICALL JAWT_GetAWT(JNIEnv *, JAWT *);
+#include <jawt_md.h>
 #if defined _MSC_VER
 #pragma warning(pop)
 #endif
 
 #define SYSTEM_WIN32   1
 
-#define OLD_PROC_KEY "oldwindowproc"
+#define OLD_PROC_KEY L"oldwindowproc"
 
 static LRESULT APIENTRY OpenOfficeWndProc( HWND , UINT , WPARAM , LPARAM );
 
@@ -90,7 +71,7 @@ JNIEXPORT jint JNICALL Java_com_sun_star_comp_beans_LocalOfficeWindow_getNativeW
 {
     (void) env; // unused
     (void) obj_this; // unused
-    return (SYSTEM_WIN32);
+    return SYSTEM_WIN32;
 }
 
 
@@ -150,13 +131,13 @@ JNIEXPORT jlong JNICALL Java_com_sun_star_comp_beans_LocalOfficeWindow_getNative
        and calls on such construct produce
        a stack overflow.
      */
-    if (GetProp( hWnd, OLD_PROC_KEY )==0)
+    if (GetPropW( hWnd, OLD_PROC_KEY )==NULL)
     {
-        hFuncPtr = SetWindowLongPtr( hWnd, GWLP_WNDPROC, (LONG_PTR)OpenOfficeWndProc );
-        SetProp( hWnd, OLD_PROC_KEY, (HANDLE)hFuncPtr );
+        hFuncPtr = SetWindowLongPtrW( hWnd, GWLP_WNDPROC, (LONG_PTR)OpenOfficeWndProc );
+        SetPropW( hWnd, OLD_PROC_KEY, (HANDLE)hFuncPtr );
     }
 
-    return ((jlong)hWnd);
+    return (jlong)hWnd;
 }
 
 
@@ -201,7 +182,7 @@ static LRESULT APIENTRY OpenOfficeWndProc(
 #pragma warning(push)
 #pragma warning(disable: 4152) /* function/data pointer conversion: */
 #endif
-    return CallWindowProc(GetProp(hWnd, OLD_PROC_KEY),
+    return CallWindowProcW(GetPropW(hWnd, OLD_PROC_KEY),
                           hWnd, uMsg, wParam, lParam);
 #if defined _MSC_VER
 #pragma warning(pop)
