@@ -38,7 +38,6 @@ using namespace com::sun::star::uno;
 #ifdef BRDEBUG
 #include <rtl/strbuf.hxx>
 #include <rtl/ustrbuf.hxx>
-#include <osl/mutex.hxx>
 using namespace ::std;
 using namespace ::osl;
 using namespace ::rtl;
@@ -52,8 +51,6 @@ using namespace ::rtl;
 #include <unistd.h>
 #endif
 
-using namespace ::com::sun::star::uno;
-
 namespace CPPU_CURRENT_NAMESPACE
 {
   bool is_complex_struct(const typelib_TypeDescription * type)
