@@ -21,10 +21,10 @@
 #include <sal/log.hxx>
 #include <typelib/typedescription.hxx>
 #include <uno/data.h>
-#include "bridges/cpp_uno/shared/bridge.hxx"
-#include "bridges/cpp_uno/shared/cppinterfaceproxy.hxx"
-#include "bridges/cpp_uno/shared/types.hxx"
-#include "bridges/cpp_uno/shared/vtablefactory.hxx"
+#include "bridge.hxx"
+#include "cppinterfaceproxy.hxx"
+#include "types.hxx"
+#include "vtablefactory.hxx"
 #include "share.hxx"
 #include <sal/alloca.h>
 
@@ -354,7 +354,6 @@ static typelib_TypeClass cpp_mediate(
 }
 
 
-
 /**
  * is called on incoming vtable calls
  * (called by asm snippets)
@@ -374,7 +373,7 @@ static void cpp_vtable_call()
 //  fprintf(stderr,"cpp_mediate nFunctionIndex=%x\n",nFunctionIndex);
 //  fflush(stderr);
 
-    sal_Bool bComplex = nFunctionIndex & 0x80000000 ? sal_True : sal_False;
+    sal_Bool bComplex = (nFunctionIndex & 0x80000000) ? sal_True : sal_False;
     typelib_TypeClass aType =
         cpp_mediate( nFunctionIndex, vTableOffset, pCallStack+17, (sal_Int64*)&nRegReturn );
 
@@ -425,7 +424,7 @@ static void cpp_vtable_call()
     if( bComplex )
     {
         __asm__( "add %i7, 4, %i7\n\t" );
-        // after call to complex return valued funcion there is an unimp instruction
+        // after call to complex return valued function there is an unimp instruction
     }
 
 }
@@ -484,7 +483,7 @@ bridges::cpp_uno::shared::VtableFactory::mapBlockToVtable(void * block)
     return static_cast< Slot * >(block) + 2;
 }
 
-sal_Size bridges::cpp_uno::shared::VtableFactory::getBlockSize(
+std::size_t bridges::cpp_uno::shared::VtableFactory::getBlockSize(
     sal_Int32 slotCount)
 {
     return (slotCount + 2) * sizeof (Slot) + slotCount * codeSnippetSize;
