@@ -25,10 +25,10 @@
 #include <uno/data.h>
 #include <typelib/typedescription.hxx>
 
-#include "bridge.hxx"
-#include "cppinterfaceproxy.hxx"
-#include "types.hxx"
-#include "vtablefactory.hxx"
+#include <bridge.hxx>
+#include <cppinterfaceproxy.hxx>
+#include <types.hxx>
+#include <vtablefactory.hxx>
 
 #include "mscx.hxx"
 
@@ -207,7 +207,7 @@ static inline typelib_TypeClass cpp2uno_call(
         }
         if ( pReturnTD )
         {
-            typelib_TypeClass eRet = (typelib_TypeClass)pReturnTD->eTypeClass;
+            typelib_TypeClass eRet = pReturnTD->eTypeClass;
             TYPELIB_DANGER_RELEASE( pReturnTD );
             return eRet;
         }
