@@ -236,21 +236,24 @@ void
 
 #pragma warning( disable : 4237 )
 #include <sal/config.h>
+
+#include <memory>
+
 #include <malloc.h>
 #include <new.h>
 #include <typeinfo.h>
 #include <signal.h>
 
-#include "rtl/alloc.h"
-#include "rtl/strbuf.hxx"
-#include "rtl/ustrbuf.hxx"
+#include <rtl/alloc.h>
+#include <rtl/strbuf.hxx>
+#include <rtl/ustrbuf.hxx>
 #include <sal/log.hxx>
 #include <osl/mutex.hxx>
 
-#include "com/sun/star/uno/Any.hxx"
+#include <com/sun/star/uno/Any.hxx>
 #include <unordered_map>
 #include "mscx.hxx"
-#include "bridges/cpp_uno/shared/except.hxx"
+#include <except.hxx>
 
 #pragma pack(push, 8)
 
@@ -303,33 +306,31 @@ static inline OUString toRTTIname(
 
 //RTTI simulation
 
-typedef std::unordered_map< OUString, void *, OUStringHash, equal_to< OUString > > t_string2PtrMap;
-class __type_info_descriptor;
+typedef std::unordered_map< OUString, void * > t_string2PtrMap;
+class type_info_descriptor;
 
 class RTTInfos
 {
     Mutex               _aMutex;
     t_string2PtrMap     _allRTTI;
 
-    static OUString toRawName( OUString const & rUNOname ) throw ();
 public:
     type_info * getRTTI( OUString const & rUNOname ) throw ();
     int getRTTI_len(OUString const & rUNOname) throw ();
-    __type_info_descriptor * insert_new_type_info_descriptor(OUString const & rUNOname);
+    type_info_descriptor * insert_new_type_info_descriptor(OUString const & rUNOname);
 
     RTTInfos() throw ();
-    ~RTTInfos() throw ();
 };
-class __type_info
+class type_info_
 {
     friend type_info * RTTInfos::getRTTI( OUString const & ) throw ();
     friend int mscx_filterCppException(
         LPEXCEPTION_POINTERS, uno_Any *, uno_Mapping * );
 
 public:
-    virtual ~__type_info() throw ();
+    virtual ~type_info_() throw ();
 
-    inline __type_info( void * m_data, const char * m_d_name ) throw ()
+    type_info_( void * m_data, const char * m_d_name ) throw ()
         : _m_data( m_data )
         { ::strcpy( _m_d_name, m_d_name ); } // #100211# - checked
 
@@ -338,28 +339,28 @@ private:
     char _m_d_name[1];
 };
 
-__type_info::~__type_info() throw ()
+type_info_::~type_info_() throw ()
 {
     (void)_m_data;
 }
 
-class __type_info_descriptor
+class type_info_descriptor
 {
 private:
     int type_info_size;
-    __type_info info;
+    type_info_ info;
 
 public:
 
-    inline __type_info_descriptor(void * m_data, const char * m_d_name) throw ()
+    type_info_descriptor(void * m_data, const char * m_d_name) throw ()
         : info(m_data, m_d_name)
     {
-        type_info_size = sizeof(__type_info) + strlen(m_d_name);
+        type_info_size = sizeof(type_info_) + strlen(m_d_name);
     }
 
     type_info * get_type_info()
     {
-        return (type_info *)&info;
+        return reinterpret_cast<type_info *>(&info);
     }
     int get_type_info_size()
     {
@@ -367,12 +368,12 @@ public:
     }
 };
 
-__type_info_descriptor * RTTInfos::insert_new_type_info_descriptor(OUString const & rUNOname) {
+type_info_descriptor * RTTInfos::insert_new_type_info_descriptor(OUString const & rUNOname) {
 
     // insert new type_info
     OString aRawName(OUStringToOString(toRTTIname(rUNOname), RTL_TEXTENCODING_ASCII_US));
-    __type_info_descriptor * pRTTI = new(::rtl_allocateMemory(sizeof(__type_info_descriptor) + aRawName.getLength()))
-        __type_info_descriptor(NULL, aRawName.getStr());
+    type_info_descriptor * pRTTI = new(::rtl_allocateMemory(sizeof(type_info_descriptor) + aRawName.getLength()))
+        type_info_descriptor(nullptr, aRawName.getStr());
 
     // put into map
     pair< t_string2PtrMap::iterator, bool > insertion(
@@ -384,7 +385,7 @@ __type_info_descriptor * RTTInfos::insert_new_type_info_descriptor(OUString cons
 type_info * RTTInfos::getRTTI( OUString const & rUNOname ) throw ()
 {
     // a must be
-    static_assert(sizeof(__type_info) == sizeof(type_info), "### type info structure size differ!");
+    static_assert(sizeof(type_info_) == sizeof(type_info), "### type info structure size differ!");
 
     MutexGuard aGuard( _aMutex );
     t_string2PtrMap::const_iterator const iFind( _allRTTI.find( rUNOname ) );
@@ -392,13 +393,13 @@ type_info * RTTInfos::getRTTI( OUString const & rUNOname ) throw ()
     // check if type is already available
     if (iFind == _allRTTI.end())
     {
-        // Wrap new __type_info in __type_info_descriptor to preserve length info
-        __type_info_descriptor * pRTTI = insert_new_type_info_descriptor(rUNOname);
+        // Wrap new type_info_ in type_info_descriptor to preserve length info
+        type_info_descriptor * pRTTI = insert_new_type_info_descriptor(rUNOname);
         return pRTTI->get_type_info();
     }
     else
     {
-        return ((__type_info_descriptor *)iFind->second)->get_type_info();
+        return static_cast<type_info_descriptor *>(iFind->second)->get_type_info();
     }
 }
 
@@ -407,17 +408,17 @@ int RTTInfos::getRTTI_len(OUString const & rUNOname) throw ()
     MutexGuard aGuard(_aMutex);
     t_string2PtrMap::const_iterator const iFind(_allRTTI.find(rUNOname));
 
-    // Wrap new __type_info in __type_info_descriptor to preserve length info
+    // Wrap new type_info_ in type_info_descriptor to preserve length info
     // check if type is already available
     if (iFind == _allRTTI.end())
     {
-        // Wrap new __type_info in __type_info_descriptor to preserve length info
-        __type_info_descriptor * pRTTI = insert_new_type_info_descriptor(rUNOname);
+        // Wrap new type_info_ in type_info_descriptor to preserve length info
+        type_info_descriptor * pRTTI = insert_new_type_info_descriptor(rUNOname);
         return pRTTI->get_type_info_size();
     }
     else
     {
-        return ((__type_info_descriptor *)iFind->second)->get_type_info_size();
+        return static_cast<type_info_descriptor *>(iFind->second)->get_type_info_size();
     }
 }
 
@@ -425,20 +426,6 @@ RTTInfos::RTTInfos() throw ()
 {
 }
 
-RTTInfos::~RTTInfos() throw ()
-{
-    SAL_INFO("bridges", "> freeing generated RTTI infos... <");
-
-    MutexGuard aGuard( _aMutex );
-    for ( t_string2PtrMap::const_iterator iPos( _allRTTI.begin() );
-          iPos != _allRTTI.end(); ++iPos )
-    {
-        __type_info * pType = (__type_info *)iPos->second;
-        pType->~__type_info(); // obsolete, but good style...
-        ::rtl_freeMemory( pType );
-    }
-}
-
 void * __cdecl copyConstruct(
     void * pExcThis,
     void * pSource,
@@ -466,11 +453,11 @@ void GenerateConstructorTrampoline(
 
     // mov r8, pTD
     *p++ = 0x49; *p++ = 0xB8;
-    *((void **)p) = pTD; p += 8;
+    *reinterpret_cast<void **>(p) = pTD; p += 8;
 
     // mov r11, copyConstruct
     *p++ = 0x49; *p++ = 0xBB;
-    *((void **)p) = reinterpret_cast<void *>(&copyConstruct); p += 8;
+    *reinterpret_cast<void **>(p) = reinterpret_cast<void *>(&copyConstruct); p += 8;
 
     // jmp r11
     *p++ = 0x41; *p++ = 0xFF; *p++ = 0xE3;
@@ -486,11 +473,11 @@ void GenerateDestructorTrampoline(
 
     // mov rdx, pTD
     *p++ = 0x48; *p++ = 0xBA;
-    *((void **)p) = pTD; p += 8;
+    *reinterpret_cast<void **>(p) = pTD; p += 8;
 
     // mov r11, destruct
     *p++ = 0x49; *p++ = 0xBB;
-    *((void **)p) = reinterpret_cast<void *>(&destruct); p += 8;
+    *reinterpret_cast<void **>(p) = reinterpret_cast<void *>(&destruct); p += 8;
 
     // jmp r11
     *p++ = 0x41; *p++ = 0xFF; *p++ = 0xE3;
@@ -507,10 +494,10 @@ struct ExceptionType
     sal_Int32   _n1, _n2, _n3;  // thiscast
     sal_Int32   _n4;            // object_size
     sal_uInt32  _pCopyCtor;     // copyctor
-    __type_info   type_info;
+    type_info_   type_info;
 
 
-    inline ExceptionType(
+    ExceptionType(
         unsigned char * pCode,
         sal_uInt64 pCodeBase,
         typelib_TypeDescription * pTD ) throw ()
@@ -519,7 +506,7 @@ struct ExceptionType
         , _n2( -1 )
         , _n3( 0 )
         , _n4( pTD->nSize)
-        , type_info(NULL, "")
+        , type_info(nullptr, "")
         {
             // As _n0 is always initialized to zero, that means the
             // hasvirtbase flag (see the ONTL catchabletype struct) is
@@ -535,9 +522,6 @@ struct ExceptionType
             _pCopyCtor = static_cast<sal_uInt32>(
                 reinterpret_cast<sal_uInt64>(pCode) - pCodeBase);
         }
-    inline ~ExceptionType() throw ()
-        {
-        }
 };
 
 struct RaiseInfo;
@@ -553,7 +537,6 @@ public:
     static DWORD allocationGranularity;
 
     ExceptionInfos() throw ();
-    ~ExceptionInfos() throw ();
 };
 
 DWORD ExceptionInfos::allocationGranularity = 0;
@@ -572,9 +555,7 @@ struct RaiseInfo
     unsigned char *        _code;
     sal_uInt64         _codeBase;
 
-    RaiseInfo( typelib_TypeDescription * pTD ) throw ();
-
-    ~RaiseInfo() throw ();
+    explicit RaiseInfo(typelib_TypeDescription * pTD) throw ();
 };
 
 /* Rewrite of 32-Bit-Code to work under 64 Bit:
@@ -600,7 +581,7 @@ RaiseInfo::RaiseInfo(typelib_TypeDescription * pTD)throw ()
     int codeSize = codeSnippetSize;
     // Info count
     int nLen = 0;
-    for (pCompTD = (typelib_CompoundTypeDescription*)pTD;
+    for (pCompTD = reinterpret_cast<typelib_CompoundTypeDescription*>(pTD);
         pCompTD; pCompTD = pCompTD->pBaseTypeDescription)
     {
         ++nLen;
@@ -613,14 +594,13 @@ RaiseInfo::RaiseInfo(typelib_TypeDescription * pTD)throw ()
     // 2.Pass: Get the total needed memory for class ExceptionType
     // (with embedded type_info) and keep the sizes for each instance
     // is stored in allocated int array
-    int *exceptionTypeSizeArray = new int[nLen];
+    auto exceptionTypeSizeArray = std::unique_ptr<int[]>(new int[nLen]);
 
     nLen = 0;
-    for (pCompTD = (typelib_CompoundTypeDescription*)pTD;
+    for (pCompTD = reinterpret_cast<typelib_CompoundTypeDescription*>(pTD);
         pCompTD; pCompTD = pCompTD->pBaseTypeDescription)
     {
-        typelib_TypeDescription * pTD = (typelib_TypeDescription *)pCompTD;
-        int typeInfoLen = mscx_getRTTI_len(pTD->pTypeName);
+        int typeInfoLen = mscx_getRTTI_len(pCompTD->aBase.pTypeName);
         // Mem has to be on 4-byte Boundary
         if (typeInfoLen % 4 != 0)
         {
@@ -642,11 +622,11 @@ RaiseInfo::RaiseInfo(typelib_TypeDescription * pTD)throw ()
     // 32 bit offsets
     const int totalSize = codeSize + typeInfoArraySize + excTypeAddLen;
     unsigned char * pCode = _code =
-        (unsigned char *)::rtl_allocateMemory(totalSize);
+        static_cast<unsigned char *>(::rtl_allocateMemory(totalSize));
     int pCodeOffset = 0;
 
     // New base of types array, starts after Trampoline D-Tor / C-Tors
-    DWORD * types = (DWORD *)(pCode + codeSize);
+    DWORD * types = reinterpret_cast<DWORD *>(pCode + codeSize);
 
     // New base of ExceptionType array, starts after types array
     unsigned char *etMem = pCode + codeSize + typeInfoArraySize;
@@ -665,7 +645,7 @@ RaiseInfo::RaiseInfo(typelib_TypeDescription * pTD)throw ()
 
     // Fill pCode with D-Tor code
     GenerateDestructorTrampoline(pCode, pTD);
-    _pDtor = (sal_Int32)((sal_uInt64)pCode - _codeBase);
+    _pDtor = (sal_Int32)(reinterpret_cast<sal_uInt64>(pCode) - _codeBase);
     pCodeOffset += codeSnippetSize;
 
     // Info count accompanied by type info ptrs: type, base type, base base type, ...
@@ -676,12 +656,12 @@ RaiseInfo::RaiseInfo(typelib_TypeDescription * pTD)throw ()
     types[0] = nLen;
 
     int nPos = 1;
-    for (pCompTD = (typelib_CompoundTypeDescription*)pTD;
+    for (pCompTD = reinterpret_cast<typelib_CompoundTypeDescription*>(pTD);
         pCompTD; pCompTD = pCompTD->pBaseTypeDescription)
     {
         // Create instance in mem block with placement new
         ExceptionType * et = new(etMem + etMemOffset)ExceptionType(
-            pCode + pCodeOffset, _codeBase, (typelib_TypeDescription *)pCompTD);
+            pCode + pCodeOffset, _codeBase, reinterpret_cast<typelib_TypeDescription *>(pCompTD));
 
         // Next trampoline entry offset
         pCodeOffset += codeSnippetSize;
@@ -694,45 +674,15 @@ RaiseInfo::RaiseInfo(typelib_TypeDescription * pTD)throw ()
     }
     // Final check: end of address calculation must be end of mem
     assert(etMem + etMemOffset == pCode + totalSize);
-
-    // remove array
-    delete[] exceptionTypeSizeArray;
-}
-
-RaiseInfo::~RaiseInfo() throw ()
-{
-    sal_uInt32 * pTypes = (sal_uInt32 *)(_codeBase + _types) + 1;
-
-    // Because of placement new we have to call D.-tor, not delete!
-    for ( int nTypes = *(sal_uInt32 *)(_codeBase + _types); nTypes--; )
-    {
-        ExceptionType *et = (ExceptionType *)(_codeBase + pTypes[nTypes]);
-        et->~ExceptionType();
-    }
-    // free our single block
-    ::rtl_freeMemory( _code );
-    ::typelib_typedescription_release( _pTD );
 }
 
 ExceptionInfos::ExceptionInfos() throw ()
 {
 }
 
-ExceptionInfos::~ExceptionInfos() throw ()
-{
-    SAL_INFO("bridges", "> freeing exception infos... <");
-
-    MutexGuard aGuard( _aMutex );
-    for ( t_string2PtrMap::const_iterator iPos( _allRaiseInfos.begin() );
-          iPos != _allRaiseInfos.end(); ++iPos )
-    {
-        delete (RaiseInfo *)iPos->second;
-    }
-}
-
 RaiseInfo * ExceptionInfos::getRaiseInfo( typelib_TypeDescription * pTD ) throw ()
 {
-    static ExceptionInfos * s_pInfos = 0;
+    static ExceptionInfos * s_pInfos = nullptr;
     if (! s_pInfos)
     {
         MutexGuard aGuard( Mutex::getGlobalMutex() );
@@ -742,12 +692,7 @@ RaiseInfo * ExceptionInfos::getRaiseInfo( typelib_TypeDescription * pTD ) throw
             GetSystemInfo( &systemInfo );
             allocationGranularity = systemInfo.dwAllocationGranularity;
 
-#ifdef LEAK_STATIC_DATA
             s_pInfos = new ExceptionInfos();
-#else
-            static ExceptionInfos s_allExceptionInfos;
-            s_pInfos = &s_allExceptionInfos;
-#endif
         }
     }
 
@@ -767,13 +712,13 @@ RaiseInfo * ExceptionInfos::getRaiseInfo( typelib_TypeDescription * pTD ) throw
 
         // Put into map
         pair< t_string2PtrMap::iterator, bool > insertion(
-            s_pInfos->_allRaiseInfos.insert( t_string2PtrMap::value_type( rTypeName, (void *)pRaiseInfo ) ) );
+            s_pInfos->_allRaiseInfos.insert( t_string2PtrMap::value_type( rTypeName, static_cast<void *>(pRaiseInfo) ) ) );
         assert(insertion.second && "### raise info insertion failed?!");
     }
     else
     {
         // Reuse existing info
-        pRaiseInfo = (RaiseInfo *)iFind->second;
+        pRaiseInfo = static_cast<RaiseInfo *>(iFind->second);
     }
 
     return pRaiseInfo;
@@ -782,18 +727,13 @@ RaiseInfo * ExceptionInfos::getRaiseInfo( typelib_TypeDescription * pTD ) throw
 type_info * mscx_getRTTI(
     OUString const & rUNOname )
 {
-    static RTTInfos * s_pRTTIs = 0;
+    static RTTInfos * s_pRTTIs = nullptr;
     if (! s_pRTTIs)
     {
         MutexGuard aGuard( Mutex::getGlobalMutex() );
         if (! s_pRTTIs)
         {
-#ifdef LEAK_STATIC_DATA
             s_pRTTIs = new RTTInfos();
-#else
-            static RTTInfos s_aRTTIs;
-            s_pRTTIs = &s_aRTTIs;
-#endif
         }
     }
     return s_pRTTIs->getRTTI( rUNOname );
@@ -801,18 +741,13 @@ type_info * mscx_getRTTI(
 int mscx_getRTTI_len(
     OUString const & rUNOname)
 {
-    static RTTInfos * s_pRTTIs = 0;
+    static RTTInfos * s_pRTTIs = nullptr;
     if (!s_pRTTIs)
     {
         MutexGuard aGuard(Mutex::getGlobalMutex());
         if (!s_pRTTIs)
         {
-#ifdef LEAK_STATIC_DATA
             s_pRTTIs = new RTTInfos();
-#else
-            static RTTInfos s_aRTTIs;
-            s_pRTTIs = &s_aRTTIs;
-#endif
         }
     }
     return s_pRTTIs->getRTTI_len(rUNOname);
@@ -828,7 +763,7 @@ void mscx_raiseException(
     // ExceptionInfos::getRaiseInfo()
 
     // construct cpp exception object
-    typelib_TypeDescription * pTD = NULL;
+    typelib_TypeDescription * pTD = nullptr;
     TYPELIB_DANGER_GET( &pTD, pUnoExc->pType );
 
     void * pCppExc = alloca( pTD->nSize );
@@ -836,12 +771,12 @@ void mscx_raiseException(
 
     ULONG_PTR arFilterArgs[4];
     arFilterArgs[0] = MSVC_magic_number;
-    arFilterArgs[1] = (ULONG_PTR)pCppExc;
-    arFilterArgs[2] = (ULONG_PTR)ExceptionInfos::getRaiseInfo( pTD );
-    arFilterArgs[3] = ((RaiseInfo *)arFilterArgs[2])->_codeBase;
+    arFilterArgs[1] = reinterpret_cast<ULONG_PTR>(pCppExc);
+    arFilterArgs[2] = reinterpret_cast<ULONG_PTR>(ExceptionInfos::getRaiseInfo( pTD ));
+    arFilterArgs[3] = reinterpret_cast<RaiseInfo *>(arFilterArgs[2])->_codeBase;
 
     // Destruct uno exception
-    ::uno_any_destruct( pUnoExc, 0 );
+    ::uno_any_destruct( pUnoExc, nullptr );
     TYPELIB_DANGER_RELEASE( pTD );
 
     // last point to release anything not affected by stack unwinding
@@ -853,13 +788,13 @@ int mscx_filterCppException(
     uno_Any * pUnoExc,
     uno_Mapping * pCpp2Uno )
 {
-    if (pPointers == 0)
+    if (pPointers == nullptr)
         return EXCEPTION_CONTINUE_SEARCH;
 
     EXCEPTION_RECORD * pRecord = pPointers->ExceptionRecord;
 
     // Handle only C++ exceptions:
-    if (pRecord == 0 || pRecord->ExceptionCode != MSVC_ExceptionCode)
+    if (pRecord == nullptr || pRecord->ExceptionCode != MSVC_ExceptionCode)
         return EXCEPTION_CONTINUE_SEARCH;
 
     bool rethrow = __CxxDetectRethrow( &pRecord );
@@ -867,25 +802,11 @@ int mscx_filterCppException(
 
     if (rethrow && pRecord == pPointers->ExceptionRecord)
     {
-        pRecord = *reinterpret_cast< EXCEPTION_RECORD ** >(
-#if _MSC_VER >= 1900 // VC 2015 (and later?)
-            __current_exception()
-#else
-            // Hack to get msvcrt internal _curexception field
-            reinterpret_cast< char * >( __pxcptinfoptrs() ) +
-            // As long as we don't demand MSVCR source as build prerequisite,
-            // we have to code those offsets here.
-            //
-            // MSVS9/crt/src/mtdll.h:
-            // offsetof (_tiddata, _curexception) -
-            // offsetof (_tiddata, _tpxcptinfoptrs):
-            0x48
-#endif
-            );
+        pRecord = *reinterpret_cast< EXCEPTION_RECORD ** >(__current_exception());
     }
 
     // Rethrow: handle only C++ exceptions:
-    if (pRecord == 0 || pRecord->ExceptionCode != MSVC_ExceptionCode)
+    if (pRecord == nullptr || pRecord->ExceptionCode != MSVC_ExceptionCode)
         return EXCEPTION_CONTINUE_SEARCH;
 
     if (pRecord->NumberParameters == 4 &&
@@ -916,15 +837,15 @@ int mscx_filterCppException(
             {
                 OUString aRTTIname(
                     OStringToOUString(
-                        (reinterpret_cast<__type_info *>(base + et->_pTypeInfo)
+                        (reinterpret_cast<type_info_ *>(base + et->_pTypeInfo)
                          ->_m_d_name),
                         RTL_TEXTENCODING_ASCII_US));
                 OUString aUNOname( toUNOname( aRTTIname ) );
 
-                typelib_TypeDescription * pExcTD = 0;
+                typelib_TypeDescription * pExcTD = nullptr;
                 typelib_typedescription_getByName(
                     &pExcTD, aUNOname.pData );
-                if (pExcTD == NULL)
+                if (pExcTD == nullptr)
                 {
                     OUStringBuffer buf;
                     buf.append(
@@ -943,7 +864,7 @@ int mscx_filterCppException(
                 {
                     // construct uno exception any
                     uno_any_constructAndConvert(
-                        pUnoExc, (void *) pRecord->ExceptionInformation[1],
+                        pUnoExc, reinterpret_cast<void *>(pRecord->ExceptionInformation[1]),
                         pExcTD, pCpp2Uno );
                     typelib_typedescription_release( pExcTD );
                 }
