@@ -7,12 +7,14 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
+#include <sal/config.h>
+
+#include <com/sun/star/rendering/PanoseWeight.hpp>
+#include <com/sun/star/rendering/XSpriteCanvas.hpp>
+
 #include "ogl_canvasfont.hxx"
 #include "ogl_textlayout.hxx"
 
-#include <com/sun/star/rendering/XSpriteCanvas.hpp>
-#include <com/sun/star/rendering/PanoseWeight.hpp>
-
 
 using namespace ::com::sun::star;
 
@@ -27,47 +29,36 @@ namespace oglcanvas
     {
     }
 
-    void SAL_CALL CanvasFont::disposing()
-    {
-        ::osl::MutexGuard aGuard( m_aMutex );
-    }
-
     uno::Reference< rendering::XTextLayout > SAL_CALL CanvasFont::createTextLayout( const rendering::StringContext& aText,
                                                                                     sal_Int8                        nDirection,
-                                                                                    sal_Int64                       nRandomSeed ) throw (uno::RuntimeException, std::exception)
+                                                                                    sal_Int64                       nRandomSeed )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
         return new TextLayout( aText, nDirection, nRandomSeed, ImplRef( this ) );
     }
 
-    uno::Sequence< double > SAL_CALL CanvasFont::getAvailableSizes(  ) throw (uno::RuntimeException, std::exception)
+    uno::Sequence< double > SAL_CALL CanvasFont::getAvailableSizes(  )
     {
-        ::osl::MutexGuard aGuard( m_aMutex );
-
         // TODO
         return uno::Sequence< double >();
     }
 
-    uno::Sequence< beans::PropertyValue > SAL_CALL CanvasFont::getExtraFontProperties(  ) throw (uno::RuntimeException, std::exception)
+    uno::Sequence< beans::PropertyValue > SAL_CALL CanvasFont::getExtraFontProperties(  )
     {
-        ::osl::MutexGuard aGuard( m_aMutex );
-
         // TODO
         return uno::Sequence< beans::PropertyValue >();
     }
 
-    rendering::FontRequest SAL_CALL CanvasFont::getFontRequest(  ) throw (uno::RuntimeException, std::exception)
+    rendering::FontRequest SAL_CALL CanvasFont::getFontRequest(  )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
         return maFontRequest;
     }
 
-    rendering::FontMetrics SAL_CALL CanvasFont::getFontMetrics(  ) throw (uno::RuntimeException, std::exception)
+    rendering::FontMetrics SAL_CALL CanvasFont::getFontMetrics(  )
     {
-        ::osl::MutexGuard aGuard( m_aMutex );
-
         // TODO
         return rendering::FontMetrics();
     }
