@@ -9,13 +9,12 @@
 
 #include <sal/config.h>
 
-#include <basegfx/tools/canvastools.hxx>
-#include <basegfx/tools/unopolypolygon.hxx>
+#include <basegfx/utils/canvastools.hxx>
+#include <basegfx/utils/unopolypolygon.hxx>
 #include <com/sun/star/lang/NoSupportException.hpp>
 #include <com/sun/star/rendering/XColorSpace.hpp>
 #include <com/sun/star/rendering/XIntegerBitmapColorSpace.hpp>
 #include <com/sun/star/uno/Reference.hxx>
-#include <osl/mutex.hxx>
 #include <rtl/instance.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <vcl/canvastools.hxx>
@@ -53,7 +52,7 @@ static void initContext()
     glShadeModel(GL_FLAT);
 }
 
-static void initTransformation(const ::Size& rSize, bool bMirror=false)
+static void initTransformation(const ::Size& rSize)
 {
     // use whole window
     glViewport( 0,0,
@@ -63,9 +62,9 @@ static void initTransformation(const ::Size& rSize, bool bMirror=false)
     // model coordinate system is already in device pixel
     glMatrixMode(GL_MODELVIEW);
     glLoadIdentity();
-    glTranslated(-1.0, (bMirror ? -1.0 : 1.0), 0.0);
+    glTranslated(-1.0, 1.0, 0.0);
     glScaled( 2.0  / rSize.Width(),
-              (bMirror ? 2.0 : -2.0) / rSize.Height(),
+              -2.0 / rSize.Height(),
               1.0 );
 
     // clear to black
@@ -160,7 +159,7 @@ namespace oglcanvas
         // Map a one-by-one millimeter box to pixel
         SystemChildWindow* pChildWindow = mxContext->getChildWindow();
         const MapMode aOldMapMode( pChildWindow->GetMapMode() );
-        pChildWindow->SetMapMode( MapMode(MAP_MM) );
+        pChildWindow->SetMapMode( MapMode(MapUnit::MapMM) );
         const Size aPixelSize( pChildWindow->LogicToPixel(Size(1,1)) );
         pChildWindow->SetMapMode( aOldMapMode );
 
@@ -175,7 +174,7 @@ namespace oglcanvas
         // Map the pixel dimensions of the output window to millimeter
         SystemChildWindow* pChildWindow = mxContext->getChildWindow();
         const MapMode aOldMapMode( pChildWindow->GetMapMode() );
-        pChildWindow->SetMapMode( MapMode(MAP_MM) );
+        pChildWindow->SetMapMode( MapMode(MapUnit::MapMM) );
         const Size aLogSize( pChildWindow->PixelToLogic(pChildWindow->GetOutputSizePixel()) );
         pChildWindow->SetMapMode( aOldMapMode );
 
@@ -271,7 +270,7 @@ namespace oglcanvas
         };
     }
 
-    bool SpriteDeviceHelper::showBuffer( bool bIsVisible, bool /*bUpdateAll*/ )
+    bool SpriteDeviceHelper::showBuffer( bool bIsVisible, SAL_UNUSED_PARAMETER bool /*bUpdateAll*/ )
     {
         // hidden or disposed?
         if( !bIsVisible || !mxContext->isInitialized() || !mpSpriteCanvas )
@@ -348,13 +347,13 @@ namespace oglcanvas
 
     uno::Any SpriteDeviceHelper::isAccelerated() const
     {
-        return css::uno::makeAny(false);
+        return css::uno::Any(false);
     }
 
     uno::Any SpriteDeviceHelper::getDeviceHandle() const
     {
         const SystemChildWindow* pChildWindow = mxContext->getChildWindow();
-        return uno::makeAny( reinterpret_cast< sal_Int64 >(pChildWindow) );
+        return uno::Any( reinterpret_cast< sal_Int64 >(pChildWindow) );
     }
 
     uno::Any SpriteDeviceHelper::getSurfaceHandle() const
@@ -382,7 +381,7 @@ namespace oglcanvas
 
     void SpriteDeviceHelper::dumpScreenContent() const
     {
-        SAL_INFO("canvas.ogl", BOOST_CURRENT_FUNCTION );
+        SAL_INFO("canvas.ogl", OSL_THIS_FUNC );
     }
 
     void SpriteDeviceHelper::show( const ::rtl::Reference< CanvasCustomSprite >& xSprite )
@@ -551,7 +550,7 @@ namespace oglcanvas
                         mnDepthId, mnTextureId, false);
             }
 
-            virtual ~BufferContextImpl()
+            virtual ~BufferContextImpl() override
             {
                 glDeleteTextures(1, &mnTextureId);
                 glDeleteRenderbuffers(1, &mnDepthId);
