@@ -22,14 +22,14 @@
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <basegfx/numeric/ftools.hxx>
 #include <basegfx/point/b2dpoint.hxx>
-#include <basegfx/tools/canvastools.hxx>
+#include <basegfx/utils/canvastools.hxx>
 #include <canvas/canvastools.hxx>
 #include <com/sun/star/util/Endianness.hpp>
 #include <rtl/math.hxx>
 #include <tools/diagnose_ex.h>
 #include <tools/poly.hxx>
 #include <vcl/bitmapex.hxx>
-#include <vcl/bmpacc.hxx>
+#include <vcl/bitmapaccess.hxx>
 #include <vcl/canvastools.hxx>
 #include <vcl/window.hxx>
 
@@ -152,13 +152,13 @@ namespace vclcanvas
         sal_Int8* pRes = aRes.getArray();
 
         int nCurrPos(0);
-        for( int y=rect.Y1;
+        for( long y=rect.Y1;
              y<aBmpSize.Height() && y<rect.Y2;
              ++y )
         {
             if( pAlphaReadAccess.get() != nullptr )
             {
-                for( int x=rect.X1;
+                for( long x=rect.X1;
                      x<aBmpSize.Width() && x<rect.X2;
                      ++x )
                 {
@@ -170,7 +170,7 @@ namespace vclcanvas
             }
             else
             {
-                for( int x=rect.X1;
+                for( long x=rect.X1;
                      x<aBmpSize.Width() && x<rect.X2;
                      ++x )
                 {
@@ -218,8 +218,8 @@ namespace vclcanvas
 
             if( pAlphaWriteAccess.get() )
             {
-                DBG_ASSERT( pAlphaWriteAccess->GetScanlineFormat() == BMP_FORMAT_8BIT_PAL ||
-                            pAlphaWriteAccess->GetScanlineFormat() == BMP_FORMAT_8BIT_TC_MASK,
+                DBG_ASSERT( pAlphaWriteAccess->GetScanlineFormat() == ScanlineFormat::N8BitPal ||
+                            pAlphaWriteAccess->GetScanlineFormat() == ScanlineFormat::N8BitTcMask,
                             "non-8bit alpha not supported!" );
             }
 
@@ -230,8 +230,8 @@ namespace vclcanvas
             const Size aBmpSize( aBitmap.GetSizePixel() );
 
             // for the time being, always read as BGRA
-            int x, y, nCurrPos(0);
-            for( y=rect.Y1;
+            int nCurrPos(0);
+            for( long y=rect.Y1;
                  y<aBmpSize.Height() && y<rect.Y2;
                  ++y )
             {
@@ -239,12 +239,12 @@ namespace vclcanvas
                 {
                     switch( pWriteAccess->GetScanlineFormat() )
                     {
-                        case BMP_FORMAT_8BIT_PAL:
+                        case ScanlineFormat::N8BitPal:
                         {
                             Scanline pScan  = pWriteAccess->GetScanline( y );
                             Scanline pAScan = pAlphaWriteAccess->GetScanline( y );
 
-                            for( x=rect.X1;
+                            for( long x=rect.X1;
                                  x<aBmpSize.Width() && x<rect.X2;
                                  ++x )
                             {
@@ -262,12 +262,12 @@ namespace vclcanvas
                         }
                         break;
 
-                        case BMP_FORMAT_24BIT_TC_BGR:
+                        case ScanlineFormat::N24BitTcBgr:
                         {
                             Scanline pScan  = pWriteAccess->GetScanline( y );
                             Scanline pAScan = pAlphaWriteAccess->GetScanline( y );
 
-                            for( x=rect.X1;
+                            for( long x=rect.X1;
                                  x<aBmpSize.Width() && x<rect.X2;
                                  ++x )
                             {
@@ -284,12 +284,12 @@ namespace vclcanvas
                         }
                         break;
 
-                        case BMP_FORMAT_24BIT_TC_RGB:
+                        case ScanlineFormat::N24BitTcRgb:
                         {
                             Scanline pScan  = pWriteAccess->GetScanline( y );
                             Scanline pAScan = pAlphaWriteAccess->GetScanline( y );
 
-                            for( x=rect.X1;
+                            for( long x=rect.X1;
                                  x<aBmpSize.Width() && x<rect.X2;
                                  ++x )
                             {
@@ -308,7 +308,7 @@ namespace vclcanvas
 
                         default:
                         {
-                            for( x=rect.X1;
+                            for( long x=rect.X1;
                                  x<aBmpSize.Width() && x<rect.X2;
                                  ++x )
                             {
@@ -333,11 +333,11 @@ namespace vclcanvas
                     // canvashelper.cxx, unify!
                     switch( pWriteAccess->GetScanlineFormat() )
                     {
-                        case BMP_FORMAT_8BIT_PAL:
+                        case ScanlineFormat::N8BitPal:
                         {
                             Scanline pScan = pWriteAccess->GetScanline( y );
 
-                            for( x=rect.X1;
+                            for( long x=rect.X1;
                                  x<aBmpSize.Width() && x<rect.X2;
                                  ++x )
                             {
@@ -351,11 +351,11 @@ namespace vclcanvas
                         }
                         break;
 
-                        case BMP_FORMAT_24BIT_TC_BGR:
+                        case ScanlineFormat::N24BitTcBgr:
                         {
                             Scanline pScan = pWriteAccess->GetScanline( y );
 
-                            for( x=rect.X1;
+                            for( long x=rect.X1;
                                  x<aBmpSize.Width() && x<rect.X2;
                                  ++x )
                             {
@@ -368,11 +368,11 @@ namespace vclcanvas
                         }
                         break;
 
-                        case BMP_FORMAT_24BIT_TC_RGB:
+                        case ScanlineFormat::N24BitTcRgb:
                         {
                             Scanline pScan = pWriteAccess->GetScanline( y );
 
-                            for( x=rect.X1;
+                            for( long x=rect.X1;
                                  x<aBmpSize.Width() && x<rect.X2;
                                  ++x )
                             {
@@ -387,7 +387,7 @@ namespace vclcanvas
 
                         default:
                         {
-                            for( x=rect.X1;
+                            for( long x=rect.X1;
                                  x<aBmpSize.Width() && x<rect.X2;
                                  ++x )
                             {
@@ -533,11 +533,11 @@ namespace vclcanvas
         if( !mpOutDev.get() )
             return rendering::IntegerBitmapLayout(); // we're disposed
 
-        rendering::IntegerBitmapLayout xBitmapLayout( ::canvas::tools::getStdMemoryLayout(getSize()) );
+        rendering::IntegerBitmapLayout aBitmapLayout( ::canvas::tools::getStdMemoryLayout(getSize()) );
         if ( !hasAlpha() )
-            xBitmapLayout.ColorSpace = canvas::tools::getStdColorSpaceWithoutAlpha();
+            aBitmapLayout.ColorSpace = canvas::tools::getStdColorSpaceWithoutAlpha();
 
-        return xBitmapLayout;
+        return aBitmapLayout;
     }
 
     BitmapEx CanvasBitmapHelper::getBitmap() const
