@@ -18,30 +18,25 @@
  */
 
 #include "AreaWrapper.hxx"
-#include "macros.hxx"
-#include "ContainerHelper.hxx"
 #include "Chart2ModelContact.hxx"
-#include "WrappedDirectStateProperty.hxx"
-#include <comphelper/InlineContainer.hxx>
+#include <WrappedDirectStateProperty.hxx>
 #include <com/sun/star/drawing/FillStyle.hpp>
 #include <cppuhelper/supportsservice.hxx>
 
-#include "LinePropertiesHelper.hxx"
-#include "FillProperties.hxx"
-#include "UserDefinedProperties.hxx"
+#include <LinePropertiesHelper.hxx>
+#include <FillProperties.hxx>
+#include <UserDefinedProperties.hxx>
 
 #include <algorithm>
 
 using namespace ::com::sun::star;
 using ::com::sun::star::beans::Property;
 using ::osl::MutexGuard;
-using ::com::sun::star::uno::Any;
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::Sequence;
 
 namespace
 {
-static const char lcl_aServiceName[] = "com.sun.star.comp.chart.Area";
 
 struct StaticAreaWrapperPropertyArray_Initializer
 {
@@ -54,12 +49,12 @@ struct StaticAreaWrapperPropertyArray_Initializer
 private:
     static Sequence< Property > lcl_GetPropertySequence()
     {
-        ::std::vector< ::com::sun::star::beans::Property > aProperties;
+        std::vector< css::beans::Property > aProperties;
         ::chart::LinePropertiesHelper::AddPropertiesToVector( aProperties );
         ::chart::FillProperties::AddPropertiesToVector( aProperties );
         ::chart::UserDefinedProperties::AddPropertiesToVector( aProperties );
 
-        ::std::sort( aProperties.begin(), aProperties.end(),
+        std::sort( aProperties.begin(), aProperties.end(),
                      ::chart::PropertyNameLess() );
 
         return comphelper::containerToSequence( aProperties );
@@ -77,9 +72,9 @@ namespace chart
 namespace wrapper
 {
 
-AreaWrapper::AreaWrapper( std::shared_ptr< Chart2ModelContact > spChart2ModelContact ) :
-        m_spChart2ModelContact( spChart2ModelContact ),
-        m_aEventListenerContainer( m_aMutex )
+AreaWrapper::AreaWrapper(const std::shared_ptr<Chart2ModelContact>& spChart2ModelContact)
+    : m_spChart2ModelContact(spChart2ModelContact)
+    , m_aEventListenerContainer(m_aMutex)
 {
 }
 
@@ -88,40 +83,33 @@ AreaWrapper::~AreaWrapper()
 
 // ____ XShape ____
 awt::Point SAL_CALL AreaWrapper::getPosition()
-    throw (uno::RuntimeException, std::exception)
 {
     return awt::Point(0,0);
 }
 
 void SAL_CALL AreaWrapper::setPosition( const awt::Point& /*aPosition*/ )
-    throw (uno::RuntimeException, std::exception)
 {
     OSL_FAIL( "trying to set position of chart area" );
 }
 
 awt::Size SAL_CALL AreaWrapper::getSize()
-    throw (uno::RuntimeException, std::exception)
 {
     return m_spChart2ModelContact->GetPageSize();
 }
 
 void SAL_CALL AreaWrapper::setSize( const awt::Size& /*aSize*/ )
-    throw (beans::PropertyVetoException,
-           uno::RuntimeException, std::exception)
 {
     OSL_FAIL( "trying to set size of chart area" );
 }
 
 // ____ XShapeDescriptor (base of XShape) ____
 OUString SAL_CALL AreaWrapper::getShapeType()
-    throw (uno::RuntimeException, std::exception)
 {
     return OUString( "com.sun.star.chart.ChartArea" );
 }
 
 // ____ XComponent ____
 void SAL_CALL AreaWrapper::dispose()
-    throw (uno::RuntimeException, std::exception)
 {
     Reference< uno::XInterface > xSource( static_cast< ::cppu::OWeakObject* >( this ) );
     m_aEventListenerContainer.disposeAndClear( lang::EventObject( xSource ) );
@@ -132,14 +120,12 @@ void SAL_CALL AreaWrapper::dispose()
 
 void SAL_CALL AreaWrapper::addEventListener(
     const Reference< lang::XEventListener >& xListener )
-    throw (uno::RuntimeException, std::exception)
 {
     m_aEventListenerContainer.addInterface( xListener );
 }
 
 void SAL_CALL AreaWrapper::removeEventListener(
     const Reference< lang::XEventListener >& aListener )
-    throw (uno::RuntimeException, std::exception)
 {
     m_aEventListenerContainer.removeInterface( aListener );
 }
@@ -161,46 +147,30 @@ const Sequence< beans::Property >& AreaWrapper::getPropertySequence()
 
 const std::vector< WrappedProperty* > AreaWrapper::createWrappedProperties()
 {
-    ::std::vector< ::chart::WrappedProperty* > aWrappedProperties;
+    std::vector< ::chart::WrappedProperty* > aWrappedProperties;
 
     aWrappedProperties.push_back( new WrappedDirectStateProperty("LineStyle","LineStyle") );
 
     return aWrappedProperties;
 }
 
-Sequence< OUString > AreaWrapper::getSupportedServiceNames_Static()
-{
-    Sequence< OUString > aServices( 4 );
-    aServices[ 0 ] = "com.sun.star.xml.UserDefinedAttributesSupplier";
-    aServices[ 1 ] = "com.sun.star.beans.PropertySet";
-    aServices[ 2 ] = "com.sun.star.drawing.FillProperties";
-    aServices[ 3 ] = "com.sun.star.drawing.LineProperties";
-
-    return aServices;
-}
-
-// implement XServiceInfo methods basing upon getSupportedServiceNames_Static
 OUString SAL_CALL AreaWrapper::getImplementationName()
-    throw( css::uno::RuntimeException, std::exception )
 {
-    return getImplementationName_Static();
-}
-
-OUString AreaWrapper::getImplementationName_Static()
-{
-    return OUString(lcl_aServiceName);
+    return OUString("com.sun.star.comp.chart.Area");
 }
 
 sal_Bool SAL_CALL AreaWrapper::supportsService( const OUString& rServiceName )
-    throw( css::uno::RuntimeException, std::exception )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 css::uno::Sequence< OUString > SAL_CALL AreaWrapper::getSupportedServiceNames()
-    throw( css::uno::RuntimeException, std::exception )
 {
-    return getSupportedServiceNames_Static();
+    return {
+        "com.sun.star.xml.UserDefinedAttributesSupplier",
+        "com.sun.star.beans.PropertySet",
+        "com.sun.star.drawing.FillProperties",
+        "com.sun.star.drawing.LineProperties" };
 }
 
 } //  namespace wrapper
