@@ -18,31 +18,30 @@
  */
 
 #include "AxisWrapper.hxx"
-#include "AxisHelper.hxx"
-#include "TitleHelper.hxx"
+#include <AxisHelper.hxx>
+#include <TitleHelper.hxx>
 #include "Chart2ModelContact.hxx"
-#include "ContainerHelper.hxx"
-#include "macros.hxx"
-#include "WrappedDirectStateProperty.hxx"
+#include <WrappedDirectStateProperty.hxx>
 #include "GridWrapper.hxx"
 #include "TitleWrapper.hxx"
-#include "DisposeHelper.hxx"
+#include <DisposeHelper.hxx>
+#include <unonames.hxx>
 
-#include <comphelper/InlineContainer.hxx>
+#include <cppuhelper/supportsservice.hxx>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/chart/ChartAxisArrangeOrderType.hpp>
 #include <com/sun/star/chart/ChartAxisPosition.hpp>
 #include <com/sun/star/chart/ChartAxisLabelPosition.hpp>
 #include <com/sun/star/chart/ChartAxisMarkPosition.hpp>
 
-#include "CharacterProperties.hxx"
-#include "LinePropertiesHelper.hxx"
-#include "UserDefinedProperties.hxx"
+#include <CharacterProperties.hxx>
+#include <LinePropertiesHelper.hxx>
+#include <UserDefinedProperties.hxx>
 #include "WrappedCharacterHeightProperty.hxx"
 #include "WrappedTextRotationProperty.hxx"
 #include "WrappedGapwidthProperty.hxx"
 #include "WrappedScaleProperty.hxx"
-#include "WrappedDefaultProperty.hxx"
+#include <WrappedDefaultProperty.hxx>
 #include "WrappedNumberFormatProperty.hxx"
 #include "WrappedScaleTextProperties.hxx"
 
@@ -52,17 +51,14 @@
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::chart2;
-using namespace ::chart::ContainerHelper;
 
 using ::com::sun::star::beans::Property;
-using ::osl::MutexGuard;
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::Sequence;
 using ::com::sun::star::uno::Any;
 
 namespace
 {
-static const OUString lcl_aServiceName( "com.sun.star.comp.chart.Axis" );
 
 enum
 {
@@ -98,244 +94,236 @@ enum
     PROP_AXIS_CAN_OVERLAP,
     PROP_AXIS_STACKEDTEXT,
     PROP_AXIS_OVERLAP,
-    PROP_AXIS_GAP_WIDTH
+    PROP_AXIS_GAP_WIDTH,
+    PROP_AXIS_DISPLAY_UNITS,
+    PROP_AXIS_BUILTINUNIT,
+    PROP_AXIS_TRY_STAGGERING_FIRST
 };
 
 void lcl_AddPropertiesToVector(
-    ::std::vector< Property > & rOutProperties )
+    std::vector< Property > & rOutProperties )
 {
     //Properties for scaling:
-    rOutProperties.push_back(
-        Property( "Max",
+    rOutProperties.emplace_back( "Max",
                   PROP_AXIS_MAX,
-                  ::getCppuType( reinterpret_cast< const double * >(0)),
+                  cppu::UnoType<double>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEVOID ));
+                  | beans::PropertyAttribute::MAYBEVOID );
 
-    rOutProperties.push_back(
-        Property( "Min",
+    rOutProperties.emplace_back( "Min",
                   PROP_AXIS_MIN,
-                  ::getCppuType( reinterpret_cast< const double * >(0)),
+                  cppu::UnoType<double>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEVOID ));
+                  | beans::PropertyAttribute::MAYBEVOID );
 
-    rOutProperties.push_back(
-        Property( "StepMain",
+    rOutProperties.emplace_back( "StepMain",
                   PROP_AXIS_STEPMAIN,
-                  ::getCppuType( reinterpret_cast< const double * >(0)),
+                  cppu::UnoType<double>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEVOID ));
+                  | beans::PropertyAttribute::MAYBEVOID );
 
-    rOutProperties.push_back(
-        Property( "StepHelpCount",
+    rOutProperties.emplace_back( "StepHelpCount",
                   PROP_AXIS_STEPHELP_COUNT,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEVOID ));
+                  | beans::PropertyAttribute::MAYBEVOID );
 
     //deprecated property use 'StepHelpCount' instead
-    rOutProperties.push_back(
-        Property( "StepHelp",
+    rOutProperties.emplace_back( "StepHelp",
                   PROP_AXIS_STEPHELP,
-                  ::getCppuType( reinterpret_cast< const double * >(0)),
+                  cppu::UnoType<double>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEVOID ));
+                  | beans::PropertyAttribute::MAYBEVOID );
 
-    rOutProperties.push_back(
-        Property( "AutoMax",
+    rOutProperties.emplace_back( "AutoMax",
                   PROP_AXIS_AUTO_MAX,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "AutoMin",
+    rOutProperties.emplace_back( "AutoMin",
                   PROP_AXIS_AUTO_MIN,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "AutoStepMain",
+    rOutProperties.emplace_back( "AutoStepMain",
                   PROP_AXIS_AUTO_STEPMAIN,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "AutoStepHelp",
+    rOutProperties.emplace_back( "AutoStepHelp",
                   PROP_AXIS_AUTO_STEPHELP,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "AxisType",
+    rOutProperties.emplace_back( "AxisType",
                   PROP_AXIS_TYPE,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)), //type com::sun::star::chart::ChartAxisType
+                  cppu::UnoType<sal_Int32>::get(), //type css::chart::ChartAxisType
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "TimeIncrement",
+    rOutProperties.emplace_back( "TimeIncrement",
                   PROP_AXIS_TIME_INCREMENT,
-                  ::getCppuType( reinterpret_cast< const ::com::sun::star::chart::TimeIncrement * >(0)),
+                  cppu::UnoType<css::chart::TimeIncrement>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEVOID ));
+                  beans::PropertyAttribute::MAYBEVOID );
 
-    rOutProperties.push_back(
-        Property( "ExplicitTimeIncrement",
+    rOutProperties.emplace_back( "ExplicitTimeIncrement",
                   PROP_AXIS_EXPLICIT_TIME_INCREMENT,
-                  ::getCppuType( reinterpret_cast< const ::com::sun::star::chart::TimeIncrement * >(0)),
+                  cppu::UnoType<css::chart::TimeIncrement>::get(),
                   beans::PropertyAttribute::READONLY |
-                  beans::PropertyAttribute::MAYBEVOID ));
+                  beans::PropertyAttribute::MAYBEVOID );
 
-    rOutProperties.push_back(
-        Property( "Logarithmic",
+    rOutProperties.emplace_back( "Logarithmic",
                   PROP_AXIS_LOGARITHMIC,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "ReverseDirection",
+    rOutProperties.emplace_back( "ReverseDirection",
                   PROP_AXIS_REVERSEDIRECTION,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
     //todo: this property is missing in the API
-    rOutProperties.push_back(
-        Property( "Visible",
+    rOutProperties.emplace_back( "Visible",
                   PROP_AXIS_VISIBLE,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "CrossoverPosition",
+    rOutProperties.emplace_back( "CrossoverPosition",
                   PROP_AXIS_CROSSOVER_POSITION,
-                  ::getCppuType( reinterpret_cast< const ::com::sun::star::chart::ChartAxisPosition * >(0)),
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  cppu::UnoType<css::chart::ChartAxisPosition>::get(),
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "CrossoverValue",
+    rOutProperties.emplace_back( "CrossoverValue",
                   PROP_AXIS_CROSSOVER_VALUE,
-                  ::getCppuType( reinterpret_cast< const double * >(0)),
-                  beans::PropertyAttribute::MAYBEVOID ));
+                  cppu::UnoType<double>::get(),
+                  beans::PropertyAttribute::MAYBEVOID );
 
-    rOutProperties.push_back(
-        Property( "Origin",
+    rOutProperties.emplace_back( "Origin",
                   PROP_AXIS_ORIGIN,
-                  ::getCppuType( reinterpret_cast< const double * >(0)),
+                  cppu::UnoType<double>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEVOID ));
+                  | beans::PropertyAttribute::MAYBEVOID );
 
-    rOutProperties.push_back(
-        Property( "AutoOrigin",
+    rOutProperties.emplace_back( "AutoOrigin",
                   PROP_AXIS_AUTO_ORIGIN,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
     //Properties for interval marks:
-    rOutProperties.push_back(
-        Property( "Marks",
+    rOutProperties.emplace_back( "Marks",
                   PROP_AXIS_MARKS,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "HelpMarks",
+    rOutProperties.emplace_back( "HelpMarks",
                   PROP_AXIS_HELPMARKS,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "MarkPosition",
+    rOutProperties.emplace_back( "MarkPosition",
                   PROP_AXIS_MARK_POSITION,
-                  ::getCppuType( reinterpret_cast< const ::com::sun::star::chart::ChartAxisMarkPosition * >(0)),
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  cppu::UnoType<css::chart::ChartAxisMarkPosition>::get(),
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
     //Properties for labels:
-    rOutProperties.push_back(
-        Property( "DisplayLabels",
+    rOutProperties.emplace_back( "DisplayLabels",
                   PROP_AXIS_DISPLAY_LABELS,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "NumberFormat",
+    rOutProperties.emplace_back( CHART_UNONAME_NUMFMT,
                   PROP_AXIS_NUMBERFORMAT,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "LinkNumberFormatToSource",
+    rOutProperties.emplace_back( CHART_UNONAME_LINK_TO_SRC_NUMFMT,
                   PROP_AXIS_LINK_NUMBERFORMAT_TO_SOURCE,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "LabelPosition",
+    rOutProperties.emplace_back( "LabelPosition",
                   PROP_AXIS_LABEL_POSITION,
-                  ::getCppuType( reinterpret_cast< const ::com::sun::star::chart::ChartAxisLabelPosition * >(0)),
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  cppu::UnoType<css::chart::ChartAxisLabelPosition>::get(),
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "TextRotation",
+    rOutProperties.emplace_back( "TextRotation",
                   PROP_AXIS_TEXT_ROTATION,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "ArrangeOrder",
+    rOutProperties.emplace_back( "ArrangeOrder",
                   PROP_AXIS_ARRANGE_ORDER,
-                  ::getCppuType( reinterpret_cast< const ::com::sun::star::chart::ChartAxisArrangeOrderType * >(0)),
+                  cppu::UnoType<css::chart::ChartAxisArrangeOrderType>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "TextBreak",
+    rOutProperties.emplace_back( "TextBreak",
                   PROP_AXIS_TEXTBREAK,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "TextCanOverlap",
+    rOutProperties.emplace_back( "TextCanOverlap",
                   PROP_AXIS_CAN_OVERLAP,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "StackedText",
+    rOutProperties.emplace_back( "StackedText",
                   PROP_AXIS_STACKEDTEXT,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // Properties related to bar charts:
-    rOutProperties.push_back(
-        Property( "Overlap",
+    rOutProperties.emplace_back( "Overlap",
                   PROP_AXIS_OVERLAP,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "GapWidth",
+    rOutProperties.emplace_back( "GapWidth",
                   PROP_AXIS_GAP_WIDTH,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
+
+    //Properties for display units:
+    rOutProperties.emplace_back( "DisplayUnits",
+                  PROP_AXIS_DISPLAY_UNITS,
+                  cppu::UnoType<bool>::get(),
+                  beans::PropertyAttribute::BOUND
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+
+    //Properties for labels:
+    rOutProperties.emplace_back( "BuiltInUnit",
+                  PROP_AXIS_BUILTINUNIT,
+                  cppu::UnoType<OUString>::get(),
+                  beans::PropertyAttribute::BOUND
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+
+    // Compatibility option: starting from LibreOffice 5.1 the rotated
+    // layout is preferred to staggering for axis labels.
+    rOutProperties.emplace_back( "TryStaggeringFirst",
+                  PROP_AXIS_TRY_STAGGERING_FIRST,
+                  cppu::UnoType<bool>::get(),
+                  beans::PropertyAttribute::BOUND
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 }
 
 struct StaticAxisWrapperPropertyArray_Initializer
@@ -347,19 +335,19 @@ struct StaticAxisWrapperPropertyArray_Initializer
     }
 
 private:
-    Sequence< Property > lcl_GetPropertySequence()
+    static Sequence< Property > lcl_GetPropertySequence()
     {
-        ::std::vector< ::com::sun::star::beans::Property > aProperties;
+        std::vector< css::beans::Property > aProperties;
         lcl_AddPropertiesToVector( aProperties );
         ::chart::CharacterProperties::AddPropertiesToVector( aProperties );
         ::chart::LinePropertiesHelper::AddPropertiesToVector( aProperties );
         ::chart::UserDefinedProperties::AddPropertiesToVector( aProperties );
         ::chart::wrapper::WrappedScaleTextProperties::addProperties( aProperties );
 
-        ::std::sort( aProperties.begin(), aProperties.end(),
+        std::sort( aProperties.begin(), aProperties.end(),
                      ::chart::PropertyNameLess() );
 
-        return ::chart::ContainerHelper::ContainerToSequence( aProperties );
+        return comphelper::containerToSequence( aProperties );
     }
 };
 
@@ -375,7 +363,7 @@ namespace wrapper
 {
 
 AxisWrapper::AxisWrapper(
-    tAxisType eType, ::boost::shared_ptr< Chart2ModelContact > spChart2ModelContact ) :
+    tAxisType eType, const std::shared_ptr<Chart2ModelContact>& spChart2ModelContact) :
         m_spChart2ModelContact( spChart2ModelContact ),
         m_aEventListenerContainer( m_aMutex ),
         m_eType( eType )
@@ -387,7 +375,7 @@ AxisWrapper::~AxisWrapper()
 }
 
 // ____ chart::XAxis ____
-Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getAxisTitle() throw (uno::RuntimeException)
+Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getAxisTitle()
 {
     if( !m_xAxisTitle.is() )
     {
@@ -410,13 +398,13 @@ Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getAxisTitle() throw (uno
                 eTitleType = TitleHelper::SECONDARY_Y_AXIS_TITLE;
                 break;
             default:
-                return 0;
+                return nullptr;
         }
         m_xAxisTitle = new TitleWrapper( eTitleType, m_spChart2ModelContact );
     }
     return m_xAxisTitle;
 }
-Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getMajorGrid() throw (uno::RuntimeException)
+Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getMajorGrid()
 {
     if( !m_xMajorGrid.is() )
     {
@@ -433,13 +421,13 @@ Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getMajorGrid() throw (uno
                 eGridType = GridWrapper::Z_MAJOR_GRID;
                 break;
             default:
-                return 0;
+                return nullptr;
         }
         m_xMajorGrid = new GridWrapper( eGridType, m_spChart2ModelContact );
     }
     return m_xMajorGrid;
 }
-Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getMinorGrid() throw (uno::RuntimeException)
+Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getMinorGrid()
 {
     if( !m_xMinorGrid.is() )
     {
@@ -456,7 +444,7 @@ Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getMinorGrid() throw (uno
                 eGridType = GridWrapper::Z_MINOR_GRID;
                 break;
             default:
-                return 0;
+                return nullptr;
         }
         m_xMinorGrid = new GridWrapper( eGridType, m_spChart2ModelContact );
     }
@@ -465,42 +453,35 @@ Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getMinorGrid() throw (uno
 
 // ____ XShape ____
 awt::Point SAL_CALL AxisWrapper::getPosition()
-    throw (uno::RuntimeException)
 {
-    awt::Point aResult( m_spChart2ModelContact->GetAxisPosition( this->getAxis() ) );
+    awt::Point aResult( m_spChart2ModelContact->GetAxisPosition( getAxis() ) );
     return aResult;
 }
 
 void SAL_CALL AxisWrapper::setPosition( const awt::Point& /*aPosition*/ )
-    throw (uno::RuntimeException)
 {
     OSL_FAIL( "trying to set position of Axis" );
 }
 
 awt::Size SAL_CALL AxisWrapper::getSize()
-    throw (uno::RuntimeException)
 {
-    awt::Size aSize( m_spChart2ModelContact->GetAxisSize( this->getAxis() ) );
+    awt::Size aSize( m_spChart2ModelContact->GetAxisSize( getAxis() ) );
     return aSize;
 }
 
 void SAL_CALL AxisWrapper::setSize( const awt::Size& /*aSize*/ )
-    throw (beans::PropertyVetoException,
-           uno::RuntimeException)
 {
     OSL_FAIL( "trying to set size of Axis" );
 }
 
 // ____ XShapeDescriptor (base of XShape) ____
 OUString SAL_CALL AxisWrapper::getShapeType()
-    throw (uno::RuntimeException)
 {
     return OUString("com.sun.star.chart.ChartAxis");
 }
 
 // ____ XNumberFormatsSupplier ____
 uno::Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getNumberFormatSettings()
-    throw (uno::RuntimeException)
 {
     Reference< util::XNumberFormatsSupplier > xNumSuppl( m_spChart2ModelContact->getChartModel(), uno::UNO_QUERY );
     if( xNumSuppl.is() )
@@ -510,7 +491,6 @@ uno::Reference< beans::XPropertySet > SAL_CALL AxisWrapper::getNumberFormatSetti
 }
 
 uno::Reference< util::XNumberFormats > SAL_CALL AxisWrapper::getNumberFormats()
-    throw (uno::RuntimeException)
 {
     Reference< util::XNumberFormatsSupplier > xNumSuppl( m_spChart2ModelContact->getChartModel(), uno::UNO_QUERY );
     if( xNumSuppl.is() )
@@ -519,26 +499,25 @@ uno::Reference< util::XNumberFormats > SAL_CALL AxisWrapper::getNumberFormats()
     return uno::Reference< util::XNumberFormats >();
 }
 
-void AxisWrapper::getDimensionAndMainAxisBool( tAxisType eType, sal_Int32& rnDimensionIndex, sal_Bool& rbMainAxis )
+void AxisWrapper::getDimensionAndMainAxisBool( tAxisType eType, sal_Int32& rnDimensionIndex, bool& rbMainAxis )
 {
     switch( eType )
     {
         case X_AXIS:
-            rnDimensionIndex = 0; rbMainAxis = sal_True; break;
+            rnDimensionIndex = 0; rbMainAxis = true; break;
         case Y_AXIS:
-            rnDimensionIndex = 1; rbMainAxis = sal_True; break;
+            rnDimensionIndex = 1; rbMainAxis = true; break;
         case Z_AXIS:
-            rnDimensionIndex = 2; rbMainAxis = sal_True; break;
+            rnDimensionIndex = 2; rbMainAxis = true; break;
         case SECOND_X_AXIS:
-            rnDimensionIndex = 0; rbMainAxis = sal_False; break;
+            rnDimensionIndex = 0; rbMainAxis = false; break;
         case SECOND_Y_AXIS:
-            rnDimensionIndex = 1; rbMainAxis = sal_False; break;
+            rnDimensionIndex = 1; rbMainAxis = false; break;
     }
 }
 
 // ____ XComponent ____
 void SAL_CALL AxisWrapper::dispose()
-    throw (uno::RuntimeException)
 {
     Reference< uno::XInterface > xSource( static_cast< ::cppu::OWeakObject* >( this ) );
     m_aEventListenerContainer.disposeAndClear( lang::EventObject( xSource ) );
@@ -552,14 +531,12 @@ void SAL_CALL AxisWrapper::dispose()
 
 void SAL_CALL AxisWrapper::addEventListener(
     const Reference< lang::XEventListener >& xListener )
-    throw (uno::RuntimeException)
 {
     m_aEventListenerContainer.addInterface( xListener );
 }
 
 void SAL_CALL AxisWrapper::removeEventListener(
     const Reference< lang::XEventListener >& aListener )
-    throw (uno::RuntimeException)
 {
     m_aEventListenerContainer.removeInterface( aListener );
 }
@@ -567,18 +544,18 @@ void SAL_CALL AxisWrapper::removeEventListener(
 //ReferenceSizePropertyProvider
 void AxisWrapper::updateReferenceSize()
 {
-    Reference< beans::XPropertySet > xProp( this->getAxis(), uno::UNO_QUERY );
+    Reference< beans::XPropertySet > xProp( getAxis(), uno::UNO_QUERY );
     if( xProp.is() )
     {
         if( xProp->getPropertyValue("ReferencePageSize").hasValue() )
-            xProp->setPropertyValue("ReferencePageSize", uno::makeAny(
+            xProp->setPropertyValue("ReferencePageSize", uno::Any(
             m_spChart2ModelContact->GetPageSize() ));
     }
 }
 Any AxisWrapper::getReferenceSize()
 {
     Any aRet;
-    Reference< beans::XPropertySet > xProp( this->getAxis(), uno::UNO_QUERY );
+    Reference< beans::XPropertySet > xProp( getAxis(), uno::UNO_QUERY );
     if( xProp.is() )
         aRet = xProp->getPropertyValue("ReferencePageSize");
     return aRet;
@@ -594,7 +571,7 @@ Reference< chart2::XAxis > AxisWrapper::getAxis()
     try
     {
         sal_Int32 nDimensionIndex = 0;
-        sal_Bool  bMainAxis = sal_True;
+        bool  bMainAxis = true;
         AxisWrapper::getDimensionAndMainAxisBool( m_eType, nDimensionIndex, bMainAxis );
 
         Reference< XDiagram > xDiagram( m_spChart2ModelContact->getChart2Diagram() );
@@ -604,12 +581,12 @@ Reference< chart2::XAxis > AxisWrapper::getAxis()
             xAxis = AxisHelper::createAxis( nDimensionIndex, bMainAxis, xDiagram, m_spChart2ModelContact->m_xContext );
             Reference< beans::XPropertySet > xProp( xAxis, uno::UNO_QUERY );
             if( xProp.is() )
-                xProp->setPropertyValue("Show", uno::makeAny( sal_False ) );
+                xProp->setPropertyValue("Show", uno::Any( false ) );
         }
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
     return xAxis;
 }
@@ -617,7 +594,7 @@ Reference< chart2::XAxis > AxisWrapper::getAxis()
 // WrappedPropertySet
 Reference< beans::XPropertySet > AxisWrapper::getInnerPropertySet()
 {
-    return Reference< beans::XPropertySet >( this->getAxis(), uno::UNO_QUERY );
+    return Reference< beans::XPropertySet >( getAxis(), uno::UNO_QUERY );
 }
 
 const Sequence< beans::Property >& AxisWrapper::getPropertySequence()
@@ -627,7 +604,7 @@ const Sequence< beans::Property >& AxisWrapper::getPropertySequence()
 
 const std::vector< WrappedProperty* > AxisWrapper::createWrappedProperties()
 {
-    ::std::vector< ::chart::WrappedProperty* > aWrappedProperties;
+    std::vector< ::chart::WrappedProperty* > aWrappedProperties;
 
     aWrappedProperties.push_back( new WrappedTextRotationProperty() );
     aWrappedProperties.push_back( new WrappedProperty("Marks","MajorTickmarks") );
@@ -636,16 +613,17 @@ const std::vector< WrappedProperty* > AxisWrapper::createWrappedProperties()
     aWrappedProperties.push_back( new WrappedProperty("ArrangeOrder","ArrangeOrder") );
     aWrappedProperties.push_back( new WrappedProperty("Visible","Show") );
     aWrappedProperties.push_back( new WrappedDirectStateProperty("DisplayLabels","DisplayLabels") );
+    aWrappedProperties.push_back( new WrappedDirectStateProperty("TryStaggeringFirst","TryStaggeringFirst") );
     aWrappedProperties.push_back( new WrappedDirectStateProperty("TextBreak","TextBreak") );
     aWrappedProperties.push_back( new WrappedNumberFormatProperty(m_spChart2ModelContact) );
-    aWrappedProperties.push_back( new WrappedLinkNumberFormatProperty(m_spChart2ModelContact) );
+    aWrappedProperties.push_back( new WrappedLinkNumberFormatProperty );
     aWrappedProperties.push_back( new WrappedProperty("StackedText","StackCharacters") );
     aWrappedProperties.push_back( new WrappedDirectStateProperty("CrossoverPosition","CrossoverPosition") );
     {
         WrappedGapwidthProperty* pWrappedGapwidthProperty( new WrappedGapwidthProperty( m_spChart2ModelContact ) );
         WrappedBarOverlapProperty* pWrappedBarOverlapProperty( new WrappedBarOverlapProperty( m_spChart2ModelContact ) );
         sal_Int32 nDimensionIndex = 0;
-        sal_Bool  bMainAxis = sal_True;
+        bool  bMainAxis = true;
         sal_Int32 nAxisIndex = 0;
         AxisWrapper::getDimensionAndMainAxisBool( m_eType, nDimensionIndex, bMainAxis );
         if( !bMainAxis )
@@ -664,18 +642,24 @@ const std::vector< WrappedProperty* > AxisWrapper::createWrappedProperties()
     return aWrappedProperties;
 }
 
-Sequence< OUString > AxisWrapper::getSupportedServiceNames_Static()
+OUString SAL_CALL AxisWrapper::getImplementationName()
 {
-    Sequence< OUString > aServices( 3 );
-    aServices[ 0 ] = "com.sun.star.chart.ChartAxis";
-    aServices[ 1 ] = "com.sun.star.xml.UserDefinedAttributesSupplier";
-    aServices[ 2 ] = "com.sun.star.style.CharacterProperties";
-
-    return aServices;
+    return OUString("com.sun.star.comp.chart.Axis");
 }
 
-// implement XServiceInfo methods basing upon getSupportedServiceNames_Static
-APPHELPER_XSERVICEINFO_IMPL( AxisWrapper, lcl_aServiceName );
+sal_Bool SAL_CALL AxisWrapper::supportsService( const OUString& rServiceName )
+{
+    return cppu::supportsService(this, rServiceName);
+}
+
+css::uno::Sequence< OUString > SAL_CALL AxisWrapper::getSupportedServiceNames()
+{
+    return {
+        "com.sun.star.chart.ChartAxis",
+        "com.sun.star.xml.UserDefinedAttributesSupplier",
+        "com.sun.star.style.CharacterProperties"
+    };
+}
 
 } //  namespace wrapper
 } //  namespace chart
