@@ -18,15 +18,13 @@
  */
 
 #include "ChartDataWrapper.hxx"
-#include "macros.hxx"
-#include "DiagramHelper.hxx"
-#include "DataSourceHelper.hxx"
-#include "servicenames_charttypes.hxx"
-#include "ContainerHelper.hxx"
-#include "CommonFunctors.hxx"
-#include "ChartModelHelper.hxx"
-#include "DataSeriesHelper.hxx"
-#include "ControllerLockGuard.hxx"
+#include <DiagramHelper.hxx>
+#include <DataSourceHelper.hxx>
+#include <servicenames_charttypes.hxx>
+#include <CommonFunctors.hxx>
+#include <ChartModelHelper.hxx>
+#include <DataSeriesHelper.hxx>
+#include <ControllerLockGuard.hxx>
 #include "Chart2ModelContact.hxx"
 #include <cppuhelper/supportsservice.hxx>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
@@ -42,9 +40,8 @@
 #include <com/sun/star/chart/ChartDataRowSource.hpp>
 #include <com/sun/star/chart/XChartDocument.hpp>
 
-#include "CharacterProperties.hxx"
-#include "LineProperties.hxx"
-#include "FillProperties.hxx"
+#include <CharacterProperties.hxx>
+#include <FillProperties.hxx>
 
 #include <map>
 #include <algorithm>
@@ -53,7 +50,6 @@
 using namespace ::com::sun::star;
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::Sequence;
-using ::osl::MutexGuard;
 using ::com::sun::star::chart2::XAnyDescriptionAccess;
 using ::com::sun::star::chart::XComplexDescriptionAccess;
 using ::com::sun::star::chart::XChartData;
@@ -62,7 +58,6 @@ using ::com::sun::star::chart::XDateCategories;
 
 namespace
 {
-static const char lcl_aServiceName[] = "com.sun.star.comp.chart.ChartData";
 
 uno::Sequence< uno::Sequence< double > > lcl_getNANInsteadDBL_MIN( const uno::Sequence< uno::Sequence< double > >& rData )
 {
@@ -386,16 +381,16 @@ struct lcl_DateCategoriesOperator : public lcl_Operator
     const Sequence< double >& m_rDates;
 };
 
-ChartDataWrapper::ChartDataWrapper( std::shared_ptr< Chart2ModelContact > spChart2ModelContact ) :
-        m_spChart2ModelContact( spChart2ModelContact ),
-        m_aEventListenerContainer( m_aMutex )
+ChartDataWrapper::ChartDataWrapper(const std::shared_ptr<Chart2ModelContact>& spChart2ModelContact)
+    : m_spChart2ModelContact(spChart2ModelContact)
+    , m_aEventListenerContainer(m_aMutex)
 {
     osl_atomic_increment( &m_refCount );
     initDataAccess();
     osl_atomic_decrement( &m_refCount );
 }
 
-ChartDataWrapper::ChartDataWrapper( std::shared_ptr< Chart2ModelContact > spChart2ModelContact,
+ChartDataWrapper::ChartDataWrapper( const std::shared_ptr<Chart2ModelContact>& spChart2ModelContact,
                                     const Reference< XChartData >& xNewData ) :
         m_spChart2ModelContact( spChart2ModelContact ),
         m_aEventListenerContainer( m_aMutex )
@@ -417,7 +412,6 @@ ChartDataWrapper::~ChartDataWrapper()
 
 // ____ XChartDataArray (read)____
 Sequence< Sequence< double > > SAL_CALL ChartDataWrapper::getData()
-    throw (uno::RuntimeException, std::exception)
 {
     initDataAccess();
     if( m_xDataAccess.is() )
@@ -425,7 +419,6 @@ Sequence< Sequence< double > > SAL_CALL ChartDataWrapper::getData()
     return Sequence< Sequence< double > >();
 }
 Sequence< OUString > SAL_CALL ChartDataWrapper::getRowDescriptions()
-    throw (uno::RuntimeException, std::exception)
 {
     initDataAccess();
     if( m_xDataAccess.is() )
@@ -433,7 +426,6 @@ Sequence< OUString > SAL_CALL ChartDataWrapper::getRowDescriptions()
     return Sequence< OUString >();
 }
 Sequence< OUString > SAL_CALL ChartDataWrapper::getColumnDescriptions()
-    throw (uno::RuntimeException, std::exception)
 {
     initDataAccess();
     if( m_xDataAccess.is() )
@@ -442,14 +434,14 @@ Sequence< OUString > SAL_CALL ChartDataWrapper::getColumnDescriptions()
 }
 
 // ____ XComplexDescriptionAccess (read) ____
-Sequence< Sequence< OUString > > SAL_CALL ChartDataWrapper::getComplexRowDescriptions() throw (uno::RuntimeException, std::exception)
+Sequence< Sequence< OUString > > SAL_CALL ChartDataWrapper::getComplexRowDescriptions()
 {
     initDataAccess();
     if( m_xDataAccess.is() )
         return m_xDataAccess->getComplexRowDescriptions();
     return Sequence< Sequence< OUString > >();
 }
-Sequence< Sequence< OUString > > SAL_CALL ChartDataWrapper::getComplexColumnDescriptions() throw (uno::RuntimeException, std::exception)
+Sequence< Sequence< OUString > > SAL_CALL ChartDataWrapper::getComplexColumnDescriptions()
 {
     initDataAccess();
     if( m_xDataAccess.is() )
@@ -458,14 +450,14 @@ Sequence< Sequence< OUString > > SAL_CALL ChartDataWrapper::getComplexColumnDesc
 }
 
 // ____ XAnyDescriptionAccess (read) ____
-Sequence< Sequence< uno::Any > > SAL_CALL ChartDataWrapper::getAnyRowDescriptions() throw (uno::RuntimeException, std::exception)
+Sequence< Sequence< uno::Any > > SAL_CALL ChartDataWrapper::getAnyRowDescriptions()
 {
     initDataAccess();
     if( m_xDataAccess.is() )
         return m_xDataAccess->getAnyRowDescriptions();
     return Sequence< Sequence< uno::Any > >();
 }
-Sequence< Sequence< uno::Any > > SAL_CALL ChartDataWrapper::getAnyColumnDescriptions() throw (uno::RuntimeException, std::exception)
+Sequence< Sequence< uno::Any > > SAL_CALL ChartDataWrapper::getAnyColumnDescriptions()
 {
     initDataAccess();
     if( m_xDataAccess.is() )
@@ -474,7 +466,7 @@ Sequence< Sequence< uno::Any > > SAL_CALL ChartDataWrapper::getAnyColumnDescript
 }
 
 // ____ XDateCategories (read) ____
-Sequence< double > SAL_CALL ChartDataWrapper::getDateCategories() throw (uno::RuntimeException, std::exception)
+Sequence< double > SAL_CALL ChartDataWrapper::getDateCategories()
 {
     initDataAccess();
     Reference< XDateCategories > xDateCategories( m_xDataAccess, uno::UNO_QUERY );
@@ -485,50 +477,47 @@ Sequence< double > SAL_CALL ChartDataWrapper::getDateCategories() throw (uno::Ru
 
 // ____ XChartDataArray (write)____
 void SAL_CALL ChartDataWrapper::setData( const Sequence< Sequence< double > >& rData )
-    throw (uno::RuntimeException, std::exception)
 {
     lcl_DataOperator aOperator( rData );
     applyData( aOperator );
 }
 void SAL_CALL ChartDataWrapper::setRowDescriptions( const Sequence< OUString >& rRowDescriptions )
-    throw (uno::RuntimeException, std::exception)
 {
     lcl_RowDescriptionsOperator aOperator( rRowDescriptions, m_spChart2ModelContact->getChart2Document() );
     applyData( aOperator );
 }
 void SAL_CALL ChartDataWrapper::setColumnDescriptions( const Sequence< OUString >& rColumnDescriptions )
-    throw (uno::RuntimeException, std::exception)
 {
     lcl_ColumnDescriptionsOperator aOperator( rColumnDescriptions, m_spChart2ModelContact->getChart2Document() );
     applyData( aOperator );
 }
 
 // ____ XComplexDescriptionAccess (write) ____
-void SAL_CALL ChartDataWrapper::setComplexRowDescriptions( const Sequence< Sequence< OUString > >& rRowDescriptions ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ChartDataWrapper::setComplexRowDescriptions( const Sequence< Sequence< OUString > >& rRowDescriptions )
 {
     lcl_ComplexRowDescriptionsOperator aOperator( rRowDescriptions, m_spChart2ModelContact->getChart2Document() );
     applyData( aOperator );
 }
-void SAL_CALL ChartDataWrapper::setComplexColumnDescriptions( const Sequence< Sequence< OUString > >& rColumnDescriptions ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ChartDataWrapper::setComplexColumnDescriptions( const Sequence< Sequence< OUString > >& rColumnDescriptions )
 {
     lcl_ComplexColumnDescriptionsOperator aOperator( rColumnDescriptions, m_spChart2ModelContact->getChart2Document() );
     applyData( aOperator );
 }
 
 // ____ XAnyDescriptionAccess (write) ____
-void SAL_CALL ChartDataWrapper::setAnyRowDescriptions( const Sequence< Sequence< uno::Any > >& rRowDescriptions ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ChartDataWrapper::setAnyRowDescriptions( const Sequence< Sequence< uno::Any > >& rRowDescriptions )
 {
     lcl_AnyRowDescriptionsOperator aOperator( rRowDescriptions );
     applyData( aOperator );
 }
-void SAL_CALL ChartDataWrapper::setAnyColumnDescriptions( const Sequence< Sequence< uno::Any > >& rColumnDescriptions ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ChartDataWrapper::setAnyColumnDescriptions( const Sequence< Sequence< uno::Any > >& rColumnDescriptions )
 {
     lcl_AnyColumnDescriptionsOperator aOperator( rColumnDescriptions );
     applyData( aOperator );
 }
 
 // ____ XDateCategories (write) ____
-void SAL_CALL ChartDataWrapper::setDateCategories( const Sequence< double >& rDates ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ChartDataWrapper::setDateCategories( const Sequence< double >& rDates )
 {
     Reference< chart2::XChartDocument > xChartDoc( m_spChart2ModelContact->getChart2Document() );
     ControllerLockGuardUNO aCtrlLockGuard( uno::Reference< frame::XModel >( xChartDoc, uno::UNO_QUERY ));
@@ -539,38 +528,31 @@ void SAL_CALL ChartDataWrapper::setDateCategories( const Sequence< double >& rDa
 
 // ____ XChartData (base of XChartDataArray) ____
 void SAL_CALL ChartDataWrapper::addChartDataChangeEventListener(
-    const uno::Reference<
-        ::com::sun::star::chart::XChartDataChangeEventListener >& aListener )
-    throw (uno::RuntimeException, std::exception)
+    const uno::Reference< css::chart::XChartDataChangeEventListener >& aListener )
 {
     m_aEventListenerContainer.addInterface( aListener );
 }
 
 void SAL_CALL ChartDataWrapper::removeChartDataChangeEventListener(
-    const uno::Reference<
-        ::com::sun::star::chart::XChartDataChangeEventListener >& aListener )
-    throw (uno::RuntimeException, std::exception)
+    const uno::Reference< css::chart::XChartDataChangeEventListener >& aListener )
 {
     m_aEventListenerContainer.removeInterface( aListener );
 }
 
 double SAL_CALL ChartDataWrapper::getNotANumber()
-    throw (uno::RuntimeException, std::exception)
 {
     return DBL_MIN;
 }
 
 sal_Bool SAL_CALL ChartDataWrapper::isNotANumber( double nNumber )
-    throw (uno::RuntimeException, std::exception)
 {
-    return DBL_MIN == nNumber
+    return nNumber == DBL_MIN
         || ::rtl::math::isNan( nNumber )
         || ::rtl::math::isInf( nNumber );
 }
 
 // ____ XComponent ____
 void SAL_CALL ChartDataWrapper::dispose()
-    throw (uno::RuntimeException, std::exception)
 {
     m_aEventListenerContainer.disposeAndClear( lang::EventObject( static_cast< ::cppu::OWeakObject* >( this )));
     m_xDataAccess=nullptr;
@@ -578,26 +560,22 @@ void SAL_CALL ChartDataWrapper::dispose()
 
 void SAL_CALL ChartDataWrapper::addEventListener(
     const uno::Reference< lang::XEventListener > & xListener )
-    throw (uno::RuntimeException, std::exception)
 {
     m_aEventListenerContainer.addInterface( xListener );
 }
 
 void SAL_CALL ChartDataWrapper::removeEventListener(
     const uno::Reference< lang::XEventListener >& aListener )
-    throw (uno::RuntimeException, std::exception)
 {
     m_aEventListenerContainer.removeInterface( aListener );
 }
 
 // ____ XEventListener ____
 void SAL_CALL ChartDataWrapper::disposing( const lang::EventObject& /* Source */ )
-    throw (uno::RuntimeException, std::exception)
 {
 }
 
-void ChartDataWrapper::fireChartDataChangeEvent(
-    ::com::sun::star::chart::ChartDataChangeEvent& aEvent )
+void ChartDataWrapper::fireChartDataChangeEvent( css::chart::ChartDataChangeEvent& aEvent )
 {
     if( ! m_aEventListenerContainer.getLength() )
         return;
@@ -607,16 +585,7 @@ void ChartDataWrapper::fireChartDataChangeEvent(
     if( xSrc.is() )
         aEvent.Source = xSrc;
 
-    ::cppu::OInterfaceIteratorHelper aIter( m_aEventListenerContainer );
-
-    while( aIter.hasMoreElements() )
-    {
-        uno::Reference<
-            ::com::sun::star::chart::XChartDataChangeEventListener > xListener(
-                aIter.next(), uno::UNO_QUERY );
-        if( xListener.is() )
-            xListener->chartDataChanged( aEvent );
-    }
+    m_aEventListenerContainer.notifyEach( &css::chart::XChartDataChangeEventListener::chartDataChanged, aEvent );
 }
 
 void ChartDataWrapper::switchToInternalDataProvider()
@@ -654,7 +623,7 @@ void ChartDataWrapper::applyData( lcl_Operator& rDataOperator )
     bool bStacked = false;
     bool bPercent = false;
     bool bDeep = false;
-    uno::Reference< ::com::sun::star::chart::XChartDocument > xOldDoc( xChartDoc, uno::UNO_QUERY );
+    uno::Reference< css::chart::XChartDocument > xOldDoc( xChartDoc, uno::UNO_QUERY );
     OSL_ASSERT( xOldDoc.is());
     uno::Reference< beans::XPropertySet > xDiaProp( xOldDoc->getDiagram(), uno::UNO_QUERY );
     if( xDiaProp.is())
@@ -701,53 +670,38 @@ void ChartDataWrapper::applyData( lcl_Operator& rDataOperator )
     //correct stacking mode
     if( bStacked || bPercent || bDeep )
     {
-        StackMode eStackMode = StackMode_Y_STACKED;
+        StackMode eStackMode = StackMode::YStacked;
         if( bDeep )
-            eStackMode = StackMode_Z_STACKED;
+            eStackMode = StackMode::ZStacked;
         else if( bPercent )
-            eStackMode = StackMode_Y_STACKED_PERCENT;
+            eStackMode = StackMode::YStackedPercent;
         DiagramHelper::setStackMode( xDia, eStackMode );
     }
 
     // notify listeners
-    ::com::sun::star::chart::ChartDataChangeEvent aEvent(
+    css::chart::ChartDataChangeEvent aEvent(
         static_cast< ::cppu::OWeakObject* >( this ),
-        ::com::sun::star::chart::ChartDataChangeType_ALL, 0, 0, 0, 0 );
+        css::chart::ChartDataChangeType_ALL, 0, 0, 0, 0 );
     fireChartDataChangeEvent( aEvent );
     // \-- locked controllers
 }
 
-uno::Sequence< OUString > ChartDataWrapper::getSupportedServiceNames_Static()
-{
-    uno::Sequence< OUString > aServices( 2 );
-    aServices[ 0 ] = "com.sun.star.chart.ChartDataArray";
-    aServices[ 1 ] = "com.sun.star.chart.ChartData";
-
-    return aServices;
-}
-
-// implement XServiceInfo methods basing upon getSupportedServiceNames_Static
 OUString SAL_CALL ChartDataWrapper::getImplementationName()
-    throw( css::uno::RuntimeException, std::exception )
 {
-    return getImplementationName_Static();
-}
-
-OUString ChartDataWrapper::getImplementationName_Static()
-{
-    return OUString(lcl_aServiceName);
+    return OUString("com.sun.star.comp.chart.ChartData");
 }
 
 sal_Bool SAL_CALL ChartDataWrapper::supportsService( const OUString& rServiceName )
-    throw( css::uno::RuntimeException, std::exception )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 css::uno::Sequence< OUString > SAL_CALL ChartDataWrapper::getSupportedServiceNames()
-    throw( css::uno::RuntimeException, std::exception )
 {
-    return getSupportedServiceNames_Static();
+    return {
+        "com.sun.star.chart.ChartDataArray",
+        "com.sun.star.chart.ChartData"
+    };
 }
 
 } //  namespace wrapper
