@@ -18,11 +18,8 @@
  */
 
 #include "LegendWrapper.hxx"
-#include "macros.hxx"
 #include "Chart2ModelContact.hxx"
-#include "LegendHelper.hxx"
-#include "ContainerHelper.hxx"
-#include <comphelper/InlineContainer.hxx>
+#include <LegendHelper.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/chart2/XTitled.hpp>
@@ -32,13 +29,13 @@
 #include <com/sun/star/chart2/RelativePosition.hpp>
 #include <com/sun/star/drawing/FillStyle.hpp>
 
-#include "CharacterProperties.hxx"
-#include "LinePropertiesHelper.hxx"
-#include "FillProperties.hxx"
-#include "UserDefinedProperties.hxx"
+#include <CharacterProperties.hxx>
+#include <LinePropertiesHelper.hxx>
+#include <FillProperties.hxx>
+#include <UserDefinedProperties.hxx>
 #include "WrappedCharacterHeightProperty.hxx"
-#include "PositionAndSizeHelper.hxx"
-#include "WrappedDirectStateProperty.hxx"
+#include <PositionAndSizeHelper.hxx>
+#include <WrappedDirectStateProperty.hxx>
 #include "WrappedAutomaticPositionProperties.hxx"
 #include "WrappedScaleTextProperties.hxx"
 
@@ -58,12 +55,9 @@ class WrappedLegendAlignmentProperty : public WrappedProperty
 {
 public:
     WrappedLegendAlignmentProperty();
-    virtual ~WrappedLegendAlignmentProperty();
 
-    virtual void setPropertyValue( const Any& rOuterValue, const Reference< beans::XPropertySet >& xInnerPropertySet ) const
-                                    throw (beans::UnknownPropertyException, beans::PropertyVetoException, lang::IllegalArgumentException, lang::WrappedTargetException, uno::RuntimeException) override;
-    virtual Any getPropertyValue( const Reference< beans::XPropertySet >& xInnerPropertySet ) const
-                                    throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) override;
+    virtual void setPropertyValue( const Any& rOuterValue, const Reference< beans::XPropertySet >& xInnerPropertySet ) const override;
+    virtual Any getPropertyValue( const Reference< beans::XPropertySet >& xInnerPropertySet ) const override;
 
 protected:
     virtual Any convertInnerToOuterValue( const Any& rInnerValue ) const override;
@@ -74,12 +68,8 @@ WrappedLegendAlignmentProperty::WrappedLegendAlignmentProperty()
     : ::chart::WrappedProperty( "Alignment", "AnchorPosition" )
 {
 }
-WrappedLegendAlignmentProperty::~WrappedLegendAlignmentProperty()
-{
-}
 
 Any WrappedLegendAlignmentProperty::getPropertyValue( const Reference< beans::XPropertySet >& xInnerPropertySet ) const
-                        throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException)
 {
     Any aRet;
     if( xInnerPropertySet.is() )
@@ -88,57 +78,56 @@ Any WrappedLegendAlignmentProperty::getPropertyValue( const Reference< beans::XP
         xInnerPropertySet->getPropertyValue( "Show" ) >>= bShowLegend;
         if(!bShowLegend)
         {
-            aRet = uno::makeAny( ::com::sun::star::chart::ChartLegendPosition_NONE );
+            aRet <<= css::chart::ChartLegendPosition_NONE;
         }
         else
         {
             aRet = xInnerPropertySet->getPropertyValue( m_aInnerName );
-            aRet = this->convertInnerToOuterValue( aRet );
+            aRet = convertInnerToOuterValue( aRet );
         }
     }
     return aRet;
 }
 
 void WrappedLegendAlignmentProperty::setPropertyValue( const Any& rOuterValue, const Reference< beans::XPropertySet >& xInnerPropertySet ) const
-                throw (beans::UnknownPropertyException, beans::PropertyVetoException, lang::IllegalArgumentException, lang::WrappedTargetException, uno::RuntimeException)
 {
     if(xInnerPropertySet.is())
     {
         bool bNewShowLegend = true;
         bool bOldShowLegend = true;
         {
-            ::com::sun::star::chart::ChartLegendPosition eOuterPos(::com::sun::star::chart::ChartLegendPosition_NONE);
-            if( (rOuterValue >>= eOuterPos)  && eOuterPos == ::com::sun::star::chart::ChartLegendPosition_NONE )
+            css::chart::ChartLegendPosition eOuterPos(css::chart::ChartLegendPosition_NONE);
+            if( (rOuterValue >>= eOuterPos)  && eOuterPos == css::chart::ChartLegendPosition_NONE )
                 bNewShowLegend = false;
             xInnerPropertySet->getPropertyValue( "Show" ) >>= bOldShowLegend;
         }
         if(bNewShowLegend!=bOldShowLegend)
         {
-            xInnerPropertySet->setPropertyValue( "Show", uno::makeAny(bNewShowLegend) );
+            xInnerPropertySet->setPropertyValue( "Show", uno::Any(bNewShowLegend) );
         }
         if(!bNewShowLegend)
             return;
 
         //set corresponding LegendPosition
-        Any aInnerValue = this->convertOuterToInnerValue( rOuterValue );
+        Any aInnerValue = convertOuterToInnerValue( rOuterValue );
         xInnerPropertySet->setPropertyValue( m_aInnerName, aInnerValue );
 
         //correct LegendExpansion
         chart2::LegendPosition eNewInnerPos(chart2::LegendPosition_LINE_END);
         if( aInnerValue >>= eNewInnerPos )
         {
-            ::com::sun::star::chart::ChartLegendExpansion eNewExpansion =
+            css::chart::ChartLegendExpansion eNewExpansion =
                 ( eNewInnerPos == chart2::LegendPosition_LINE_END ||
                   eNewInnerPos == chart2::LegendPosition_LINE_START )
-                ? ::com::sun::star::chart::ChartLegendExpansion_HIGH
-                : ::com::sun::star::chart::ChartLegendExpansion_WIDE;
+                ? css::chart::ChartLegendExpansion_HIGH
+                : css::chart::ChartLegendExpansion_WIDE;
 
-            ::com::sun::star::chart::ChartLegendExpansion eOldExpansion( ::com::sun::star::chart::ChartLegendExpansion_HIGH );
+            css::chart::ChartLegendExpansion eOldExpansion( css::chart::ChartLegendExpansion_HIGH );
             bool bExpansionWasSet(
                 xInnerPropertySet->getPropertyValue( "Expansion" ) >>= eOldExpansion );
 
             if( !bExpansionWasSet || (eOldExpansion != eNewExpansion))
-                xInnerPropertySet->setPropertyValue( "Expansion", uno::makeAny( eNewExpansion ));
+                xInnerPropertySet->setPropertyValue( "Expansion", uno::Any( eNewExpansion ));
         }
 
         //correct RelativePosition
@@ -152,7 +141,7 @@ void WrappedLegendAlignmentProperty::setPropertyValue( const Any& rOuterValue, c
 
 Any WrappedLegendAlignmentProperty::convertInnerToOuterValue( const Any& rInnerValue ) const
 {
-    ::com::sun::star::chart::ChartLegendPosition ePos = ::com::sun::star::chart::ChartLegendPosition_NONE;
+    css::chart::ChartLegendPosition ePos = css::chart::ChartLegendPosition_NONE;
 
     chart2::LegendPosition eNewPos;
     if( rInnerValue >>= eNewPos )
@@ -160,44 +149,44 @@ Any WrappedLegendAlignmentProperty::convertInnerToOuterValue( const Any& rInnerV
         switch( eNewPos )
         {
             case chart2::LegendPosition_LINE_START:
-                ePos = ::com::sun::star::chart::ChartLegendPosition_LEFT;
+                ePos = css::chart::ChartLegendPosition_LEFT;
                 break;
             case chart2::LegendPosition_LINE_END:
-                ePos = ::com::sun::star::chart::ChartLegendPosition_RIGHT;
+                ePos = css::chart::ChartLegendPosition_RIGHT;
                 break;
             case chart2::LegendPosition_PAGE_START:
-                ePos = ::com::sun::star::chart::ChartLegendPosition_TOP;
+                ePos = css::chart::ChartLegendPosition_TOP;
                 break;
             case chart2::LegendPosition_PAGE_END:
-                ePos = ::com::sun::star::chart::ChartLegendPosition_BOTTOM;
+                ePos = css::chart::ChartLegendPosition_BOTTOM;
                 break;
 
             default:
-                ePos = ::com::sun::star::chart::ChartLegendPosition_NONE;
+                ePos = css::chart::ChartLegendPosition_NONE;
                 break;
         }
     }
-    return uno::makeAny( ePos );
+    return uno::Any( ePos );
 }
 Any WrappedLegendAlignmentProperty::convertOuterToInnerValue( const Any& rOuterValue ) const
 {
     chart2::LegendPosition eNewPos = chart2::LegendPosition_LINE_END;
 
-    ::com::sun::star::chart::ChartLegendPosition ePos;
+    css::chart::ChartLegendPosition ePos;
     if( rOuterValue >>= ePos )
     {
         switch( ePos )
         {
-            case ::com::sun::star::chart::ChartLegendPosition_LEFT:
+            case css::chart::ChartLegendPosition_LEFT:
                 eNewPos = chart2::LegendPosition_LINE_START;
                 break;
-            case ::com::sun::star::chart::ChartLegendPosition_RIGHT:
+            case css::chart::ChartLegendPosition_RIGHT:
                 eNewPos = chart2::LegendPosition_LINE_END;
                 break;
-            case ::com::sun::star::chart::ChartLegendPosition_TOP:
+            case css::chart::ChartLegendPosition_TOP:
                 eNewPos = chart2::LegendPosition_PAGE_START;
                 break;
-            case ::com::sun::star::chart::ChartLegendPosition_BOTTOM:
+            case css::chart::ChartLegendPosition_BOTTOM:
                 eNewPos = chart2::LegendPosition_PAGE_END;
                 break;
             default: // NONE
@@ -205,13 +194,12 @@ Any WrappedLegendAlignmentProperty::convertOuterToInnerValue( const Any& rOuterV
         }
     }
 
-    return uno::makeAny( eNewPos );
+    return uno::Any( eNewPos );
 }
 }
 
 namespace
 {
-static const char lcl_aServiceName[] = "com.sun.star.comp.chart.Legend";
 
 enum
 {
@@ -220,21 +208,19 @@ enum
 };
 
 void lcl_AddPropertiesToVector(
-    ::std::vector< Property > & rOutProperties )
+    std::vector< Property > & rOutProperties )
 {
-    rOutProperties.push_back(
-        Property( "Alignment",
+    rOutProperties.emplace_back( "Alignment",
                   PROP_LEGEND_ALIGNMENT,
-                  cppu::UnoType<com::sun::star::chart::ChartLegendPosition>::get(),
+                  cppu::UnoType<css::chart::ChartLegendPosition>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 
-    rOutProperties.push_back(
-        Property( "Expansion",
+    rOutProperties.emplace_back( "Expansion",
                   PROP_LEGEND_EXPANSION,
-                  cppu::UnoType<com::sun::star::chart::ChartLegendExpansion>::get(),
+                  cppu::UnoType<css::chart::ChartLegendExpansion>::get(),
                   //#i111967# no PropertyChangeEvent is fired on change so far
-                  beans::PropertyAttribute::MAYBEDEFAULT ));
+                  beans::PropertyAttribute::MAYBEDEFAULT );
 }
 
 struct StaticLegendWrapperPropertyArray_Initializer
@@ -248,7 +234,7 @@ struct StaticLegendWrapperPropertyArray_Initializer
 private:
     static Sequence< Property > lcl_GetPropertySequence()
     {
-        ::std::vector< ::com::sun::star::beans::Property > aProperties;
+        std::vector< css::beans::Property > aProperties;
         lcl_AddPropertiesToVector( aProperties );
         ::chart::CharacterProperties::AddPropertiesToVector( aProperties );
         ::chart::LinePropertiesHelper::AddPropertiesToVector( aProperties );
@@ -257,7 +243,7 @@ private:
         ::chart::wrapper::WrappedAutomaticPositionProperties::addProperties( aProperties );
         ::chart::wrapper::WrappedScaleTextProperties::addProperties( aProperties );
 
-        ::std::sort( aProperties.begin(), aProperties.end(),
+        std::sort( aProperties.begin(), aProperties.end(),
                      ::chart::PropertyNameLess() );
 
         return comphelper::containerToSequence( aProperties );
@@ -275,9 +261,9 @@ namespace chart
 namespace wrapper
 {
 
-LegendWrapper::LegendWrapper( std::shared_ptr< Chart2ModelContact > spChart2ModelContact ) :
-        m_spChart2ModelContact( spChart2ModelContact ),
-        m_aEventListenerContainer( m_aMutex )
+LegendWrapper::LegendWrapper(const std::shared_ptr<Chart2ModelContact>& spChart2ModelContact)
+    : m_spChart2ModelContact(spChart2ModelContact)
+    , m_aEventListenerContainer(m_aMutex)
 {
 }
 
@@ -287,15 +273,13 @@ LegendWrapper::~LegendWrapper()
 
 // ____ XShape ____
 awt::Point SAL_CALL LegendWrapper::getPosition()
-    throw (uno::RuntimeException, std::exception)
 {
     return m_spChart2ModelContact->GetLegendPosition();
 }
 
 void SAL_CALL LegendWrapper::setPosition( const awt::Point& aPosition )
-    throw (uno::RuntimeException, std::exception)
 {
-    Reference< beans::XPropertySet > xProp( this->getInnerPropertySet() );
+    Reference< beans::XPropertySet > xProp( getInnerPropertySet() );
     if( xProp.is() )
     {
         awt::Size aPageSize( m_spChart2ModelContact->GetPageSize() );
@@ -304,27 +288,24 @@ void SAL_CALL LegendWrapper::setPosition( const awt::Point& aPosition )
         aRelativePosition.Anchor = drawing::Alignment_TOP_LEFT;
         aRelativePosition.Primary = aPageSize.Width == 0 ? 0 : double(aPosition.X)/double(aPageSize.Width);
         aRelativePosition.Secondary = aPageSize.Height == 0 ? 0 : double(aPosition.Y)/double(aPageSize.Height);
-        xProp->setPropertyValue( "RelativePosition", uno::makeAny(aRelativePosition) );
+        xProp->setPropertyValue( "RelativePosition", uno::Any(aRelativePosition) );
     }
 }
 
 awt::Size SAL_CALL LegendWrapper::getSize()
-    throw (uno::RuntimeException, std::exception)
 {
     return m_spChart2ModelContact->GetLegendSize();
 }
 
 void SAL_CALL LegendWrapper::setSize( const awt::Size& aSize )
-    throw (beans::PropertyVetoException,
-           uno::RuntimeException, std::exception)
 {
-    Reference< beans::XPropertySet > xProp( this->getInnerPropertySet() );
+    Reference< beans::XPropertySet > xProp( getInnerPropertySet() );
     if( xProp.is() )
     {
         awt::Size aPageSize( m_spChart2ModelContact->GetPageSize() );
         awt::Rectangle aPageRectangle( 0,0,aPageSize.Width,aPageSize.Height);
 
-        awt::Point aPos( this->getPosition() );
+        awt::Point aPos( getPosition() );
         awt::Rectangle aNewPositionAndSize(aPos.X,aPos.Y,aSize.Width,aSize.Height);
 
         PositionAndSizeHelper::moveObject( OBJECTTYPE_LEGEND
@@ -334,14 +315,12 @@ void SAL_CALL LegendWrapper::setSize( const awt::Size& aSize )
 
 // ____ XShapeDescriptor (base of XShape) ____
 OUString SAL_CALL LegendWrapper::getShapeType()
-    throw (uno::RuntimeException, std::exception)
 {
     return OUString( "com.sun.star.chart.ChartLegend" );
 }
 
 // ____ XComponent ____
 void SAL_CALL LegendWrapper::dispose()
-    throw (uno::RuntimeException, std::exception)
 {
     Reference< uno::XInterface > xSource( static_cast< ::cppu::OWeakObject* >( this ) );
     m_aEventListenerContainer.disposeAndClear( lang::EventObject( xSource ) );
@@ -352,14 +331,12 @@ void SAL_CALL LegendWrapper::dispose()
 
 void SAL_CALL LegendWrapper::addEventListener(
     const Reference< lang::XEventListener >& xListener )
-    throw (uno::RuntimeException, std::exception)
 {
     m_aEventListenerContainer.addInterface( xListener );
 }
 
 void SAL_CALL LegendWrapper::removeEventListener(
     const Reference< lang::XEventListener >& aListener )
-    throw (uno::RuntimeException, std::exception)
 {
     m_aEventListenerContainer.removeInterface( aListener );
 }
@@ -367,18 +344,18 @@ void SAL_CALL LegendWrapper::removeEventListener(
 //ReferenceSizePropertyProvider
 void LegendWrapper::updateReferenceSize()
 {
-    Reference< beans::XPropertySet > xProp( this->getInnerPropertySet(), uno::UNO_QUERY );
+    Reference< beans::XPropertySet > xProp( getInnerPropertySet(), uno::UNO_QUERY );
     if( xProp.is() )
     {
         if( xProp->getPropertyValue( "ReferencePageSize" ).hasValue() )
-            xProp->setPropertyValue( "ReferencePageSize", uno::makeAny(
+            xProp->setPropertyValue( "ReferencePageSize", uno::Any(
                 m_spChart2ModelContact->GetPageSize() ));
     }
 }
 Any LegendWrapper::getReferenceSize()
 {
     Any aRet;
-    Reference< beans::XPropertySet > xProp( this->getInnerPropertySet(), uno::UNO_QUERY );
+    Reference< beans::XPropertySet > xProp( getInnerPropertySet(), uno::UNO_QUERY );
     if( xProp.is() )
         aRet = xProp->getPropertyValue( "ReferencePageSize" );
 
@@ -407,7 +384,7 @@ const Sequence< beans::Property >& LegendWrapper::getPropertySequence()
 
 const std::vector< WrappedProperty* > LegendWrapper::createWrappedProperties()
 {
-    ::std::vector< ::chart::WrappedProperty* > aWrappedProperties;
+    std::vector< ::chart::WrappedProperty* > aWrappedProperties;
 
     aWrappedProperties.push_back( new WrappedLegendAlignmentProperty() );
     aWrappedProperties.push_back( new WrappedProperty( "Expansion", "Expansion"));
@@ -421,39 +398,24 @@ const std::vector< WrappedProperty* > LegendWrapper::createWrappedProperties()
     return aWrappedProperties;
 }
 
-Sequence< OUString > LegendWrapper::getSupportedServiceNames_Static()
-{
-    Sequence< OUString > aServices( 4 );
-    aServices[ 0 ] = "com.sun.star.chart.ChartLegend";
-    aServices[ 1 ] = "com.sun.star.drawing.Shape";
-    aServices[ 2 ] = "com.sun.star.xml.UserDefinedAttributesSupplier";
-    aServices[ 3 ] = "com.sun.star.style.CharacterProperties";
-
-    return aServices;
-}
-
-// implement XServiceInfo methods basing upon getSupportedServiceNames_Static
 OUString SAL_CALL LegendWrapper::getImplementationName()
-    throw( css::uno::RuntimeException, std::exception )
 {
-    return getImplementationName_Static();
-}
-
-OUString LegendWrapper::getImplementationName_Static()
-{
-    return OUString(lcl_aServiceName);
+    return OUString("com.sun.star.comp.chart.Legend");
 }
 
 sal_Bool SAL_CALL LegendWrapper::supportsService( const OUString& rServiceName )
-    throw( css::uno::RuntimeException, std::exception )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 css::uno::Sequence< OUString > SAL_CALL LegendWrapper::getSupportedServiceNames()
-    throw( css::uno::RuntimeException, std::exception )
 {
-    return getSupportedServiceNames_Static();
+    return {
+        "com.sun.star.chart.ChartLegend",
+        "com.sun.star.drawing.Shape",
+        "com.sun.star.xml.UserDefinedAttributesSupplier",
+        "com.sun.star.style.CharacterProperties"
+    };
 }
 
 } //  namespace wrapper
