@@ -18,18 +18,16 @@
  */
 
 #include "TitleWrapper.hxx"
-#include "macros.hxx"
-#include "ContainerHelper.hxx"
-#include "ControllerLockGuard.hxx"
+#include <ControllerLockGuard.hxx>
 
-#include <comphelper/InlineContainer.hxx>
+#include <cppuhelper/supportsservice.hxx>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/chart2/RelativePosition.hpp>
 
-#include "CharacterProperties.hxx"
-#include "LinePropertiesHelper.hxx"
-#include "FillProperties.hxx"
-#include "UserDefinedProperties.hxx"
+#include <CharacterProperties.hxx>
+#include <LinePropertiesHelper.hxx>
+#include <FillProperties.hxx>
+#include <UserDefinedProperties.hxx>
 #include "WrappedCharacterHeightProperty.hxx"
 #include "WrappedTextRotationProperty.hxx"
 #include "WrappedAutomaticPositionProperties.hxx"
@@ -50,15 +48,11 @@ namespace chart
 class WrappedTitleStringProperty : public WrappedProperty
 {
 public:
-    WrappedTitleStringProperty( const Reference< uno::XComponentContext >& xContext );
-    virtual ~WrappedTitleStringProperty();
+    explicit WrappedTitleStringProperty( const Reference< uno::XComponentContext >& xContext );
 
-    virtual void setPropertyValue( const Any& rOuterValue, const Reference< beans::XPropertySet >& xInnerPropertySet ) const
-                                    throw (beans::UnknownPropertyException, beans::PropertyVetoException, lang::IllegalArgumentException, lang::WrappedTargetException, uno::RuntimeException) SAL_OVERRIDE;
-    virtual Any getPropertyValue( const Reference< beans::XPropertySet >& xInnerPropertySet ) const
-                                    throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) SAL_OVERRIDE;
-    virtual Any getPropertyDefault( const Reference< beans::XPropertyState >& xInnerPropertyState ) const
-                        throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException) SAL_OVERRIDE;
+    virtual void setPropertyValue( const Any& rOuterValue, const Reference< beans::XPropertySet >& xInnerPropertySet ) const override;
+    virtual Any getPropertyValue( const Reference< beans::XPropertySet >& xInnerPropertySet ) const override;
+    virtual Any getPropertyDefault( const Reference< beans::XPropertyState >& xInnerPropertyState ) const override;
 
 protected:
     Reference< uno::XComponentContext > m_xContext;
@@ -69,12 +63,8 @@ WrappedTitleStringProperty::WrappedTitleStringProperty( const Reference< uno::XC
     , m_xContext( xContext )
 {
 }
-WrappedTitleStringProperty::~WrappedTitleStringProperty()
-{
-}
 
 void WrappedTitleStringProperty::setPropertyValue( const Any& rOuterValue, const Reference< beans::XPropertySet >& xInnerPropertySet ) const
-                throw (beans::UnknownPropertyException, beans::PropertyVetoException, lang::IllegalArgumentException, lang::WrappedTargetException, uno::RuntimeException)
 {
     Reference< chart2::XTitle > xTitle(xInnerPropertySet,uno::UNO_QUERY);
     if(xTitle.is())
@@ -85,7 +75,6 @@ void WrappedTitleStringProperty::setPropertyValue( const Any& rOuterValue, const
     }
 }
 Any WrappedTitleStringProperty::getPropertyValue( const Reference< beans::XPropertySet >& xInnerPropertySet ) const
-                        throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException)
 {
     Any aRet( getPropertyDefault( Reference< beans::XPropertyState >( xInnerPropertySet, uno::UNO_QUERY ) ) );
     Reference< chart2::XTitle > xTitle(xInnerPropertySet,uno::UNO_QUERY);
@@ -103,31 +92,25 @@ Any WrappedTitleStringProperty::getPropertyValue( const Reference< beans::XPrope
     return aRet;
 }
 Any WrappedTitleStringProperty::getPropertyDefault( const Reference< beans::XPropertyState >& /*xInnerPropertyState*/ ) const
-                        throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException)
 {
-    return uno::makeAny( OUString() );//default title is a empty String
+    return uno::Any( OUString() );//default title is a empty String
 }
 
 class WrappedStackedTextProperty : public WrappedProperty
 {
 public:
     WrappedStackedTextProperty();
-    virtual ~WrappedStackedTextProperty();
 };
 
 WrappedStackedTextProperty::WrappedStackedTextProperty()
     : ::chart::WrappedProperty( "StackedText", "StackCharacters" )
 {
 }
-WrappedStackedTextProperty::~WrappedStackedTextProperty()
-{
-}
 
 }// end namespace chart
 
 namespace
 {
-static const char lcl_aServiceName[] = "com.sun.star.comp.chart.Title";
 
 enum
 {
@@ -137,27 +120,24 @@ enum
 };
 
 void lcl_AddPropertiesToVector(
-    ::std::vector< Property > & rOutProperties )
+    std::vector< Property > & rOutProperties )
 {
-    rOutProperties.push_back(
-        Property( "String",
+    rOutProperties.emplace_back( "String",
                   PROP_TITLE_STRING,
                   cppu::UnoType<OUString>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEVOID ));
+                  | beans::PropertyAttribute::MAYBEVOID );
 
-    rOutProperties.push_back(
-        Property( "TextRotation",
+    rOutProperties.emplace_back( "TextRotation",
                   PROP_TITLE_TEXT_ROTATION,
                   cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "StackedText",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "StackedText",
                   PROP_TITLE_TEXT_STACKED,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 }
 
 struct StaticTitleWrapperPropertyArray_Initializer
@@ -169,9 +149,9 @@ struct StaticTitleWrapperPropertyArray_Initializer
     }
 
 private:
-    Sequence< Property > lcl_GetPropertySequence()
+    static Sequence< Property > lcl_GetPropertySequence()
     {
-        ::std::vector< beans::Property > aProperties;
+        std::vector< beans::Property > aProperties;
         lcl_AddPropertiesToVector( aProperties );
         ::chart::CharacterProperties::AddPropertiesToVector( aProperties );
         ::chart::LinePropertiesHelper::AddPropertiesToVector( aProperties );
@@ -180,10 +160,10 @@ private:
         ::chart::wrapper::WrappedAutomaticPositionProperties::addProperties( aProperties );
         ::chart::wrapper::WrappedScaleTextProperties::addProperties( aProperties );
 
-        ::std::sort( aProperties.begin(), aProperties.end(),
+        std::sort( aProperties.begin(), aProperties.end(),
                      ::chart::PropertyNameLess() );
 
-        return ::chart::ContainerHelper::ContainerToSequence( aProperties );
+        return comphelper::containerToSequence( aProperties );
     }
 };
 
@@ -199,13 +179,13 @@ namespace wrapper
 {
 
 TitleWrapper::TitleWrapper( ::chart::TitleHelper::eTitleType eTitleType,
-    ::boost::shared_ptr< Chart2ModelContact > spChart2ModelContact ) :
+    const std::shared_ptr<Chart2ModelContact>& spChart2ModelContact ) :
         m_spChart2ModelContact( spChart2ModelContact ),
         m_aEventListenerContainer( m_aMutex ),
         m_eTitleType(eTitleType)
 {
     ControllerLockGuardUNO aCtrlLockGuard( Reference< frame::XModel >( m_spChart2ModelContact->getChart2Document(), uno::UNO_QUERY ));
-    if( !getTitleObject().is() ) //#i83831# create an empty title at the model, thus references to properties can be mapped mapped correctly
+    if( !getTitleObject().is() ) //#i83831# create an empty title at the model, thus references to properties can be mapped correctly
         TitleHelper::createTitle( m_eTitleType, OUString(), m_spChart2ModelContact->getChartModel(), m_spChart2ModelContact->m_xContext );
 }
 
@@ -215,15 +195,13 @@ TitleWrapper::~TitleWrapper()
 
 // ____ XShape ____
 awt::Point SAL_CALL TitleWrapper::getPosition()
-    throw (uno::RuntimeException, std::exception)
 {
-    return m_spChart2ModelContact->GetTitlePosition( this->getTitleObject() );
+    return m_spChart2ModelContact->GetTitlePosition( getTitleObject() );
 }
 
 void SAL_CALL TitleWrapper::setPosition( const awt::Point& aPosition )
-    throw (uno::RuntimeException, std::exception)
 {
-    Reference< beans::XPropertySet > xPropertySet( this->getInnerPropertySet() );
+    Reference< beans::XPropertySet > xPropertySet( getInnerPropertySet() );
     if(xPropertySet.is())
     {
         awt::Size aPageSize( m_spChart2ModelContact->GetPageSize() );
@@ -232,33 +210,28 @@ void SAL_CALL TitleWrapper::setPosition( const awt::Point& aPosition )
         aRelativePosition.Anchor = drawing::Alignment_TOP_LEFT;
         aRelativePosition.Primary = double(aPosition.X)/double(aPageSize.Width);
         aRelativePosition.Secondary = double(aPosition.Y)/double(aPageSize.Height);
-        xPropertySet->setPropertyValue( "RelativePosition", uno::makeAny(aRelativePosition) );
+        xPropertySet->setPropertyValue( "RelativePosition", uno::Any(aRelativePosition) );
     }
 }
 
 awt::Size SAL_CALL TitleWrapper::getSize()
-    throw (uno::RuntimeException, std::exception)
 {
-    return m_spChart2ModelContact->GetTitleSize( this->getTitleObject() );
+    return m_spChart2ModelContact->GetTitleSize( getTitleObject() );
 }
 
 void SAL_CALL TitleWrapper::setSize( const awt::Size& /*aSize*/ )
-    throw (beans::PropertyVetoException,
-           uno::RuntimeException, std::exception)
 {
     OSL_FAIL( "trying to set size of title" );
 }
 
 // ____ XShapeDescriptor (base of XShape) ____
 OUString SAL_CALL TitleWrapper::getShapeType()
-    throw (uno::RuntimeException, std::exception)
 {
     return OUString( "com.sun.star.chart.ChartTitle" );
 }
 
 // ____ XComponent ____
 void SAL_CALL TitleWrapper::dispose()
-    throw (uno::RuntimeException, std::exception)
 {
     Reference< uno::XInterface > xSource( static_cast< ::cppu::OWeakObject* >( this ) );
     m_aEventListenerContainer.disposeAndClear( lang::EventObject( xSource ) );
@@ -269,14 +242,12 @@ void SAL_CALL TitleWrapper::dispose()
 
 void SAL_CALL TitleWrapper::addEventListener(
     const Reference< lang::XEventListener >& xListener )
-    throw (uno::RuntimeException, std::exception)
 {
     m_aEventListenerContainer.addInterface( xListener );
 }
 
 void SAL_CALL TitleWrapper::removeEventListener(
     const Reference< lang::XEventListener >& aListener )
-    throw (uno::RuntimeException, std::exception)
 {
     m_aEventListenerContainer.removeInterface( aListener );
 }
@@ -285,7 +256,7 @@ Reference< beans::XPropertySet > TitleWrapper::getFirstCharacterPropertySet()
 {
     Reference< beans::XPropertySet > xProp;
 
-    Reference< chart2::XTitle > xTitle( this->getTitleObject() );
+    Reference< chart2::XTitle > xTitle( getTitleObject() );
     if( xTitle.is())
     {
         Sequence< Reference< chart2::XFormattedString > > aStrings( xTitle->getText());
@@ -319,12 +290,12 @@ void TitleWrapper::getFastCharacterPropertyValue( sal_Int32 nHandle, Any& rValue
 }
 
 void TitleWrapper::setFastCharacterPropertyValue(
-    sal_Int32 nHandle, const Any& rValue ) throw (uno::Exception)
+    sal_Int32 nHandle, const Any& rValue )
 {
     OSL_ASSERT( FAST_PROPERTY_ID_START_CHAR_PROP <= nHandle &&
                 nHandle < CharacterProperties::FAST_PROPERTY_ID_END_CHAR_PROP );
 
-    Reference< chart2::XTitle > xTitle( this->getTitleObject() );
+    Reference< chart2::XTitle > xTitle( getTitleObject() );
     if( xTitle.is())
     {
         Sequence< Reference< chart2::XFormattedString > > aStrings( xTitle->getText());
@@ -346,7 +317,6 @@ void TitleWrapper::setFastCharacterPropertyValue(
 // WrappedPropertySet
 
 void SAL_CALL TitleWrapper::setPropertyValue( const OUString& rPropertyName, const Any& rValue )
-                                    throw (beans::UnknownPropertyException, beans::PropertyVetoException, lang::IllegalArgumentException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     sal_Int32 nHandle = getInfoHelper().getHandleByName( rPropertyName );
     if( CharacterProperties::IsCharacterPropertyHandle( nHandle ) )
@@ -358,7 +328,6 @@ void SAL_CALL TitleWrapper::setPropertyValue( const OUString& rPropertyName, con
 }
 
 Any SAL_CALL TitleWrapper::getPropertyValue( const OUString& rPropertyName )
-                                    throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     Any aRet;
     sal_Int32 nHandle = getInfoHelper().getHandleByName( rPropertyName );
@@ -370,7 +339,6 @@ Any SAL_CALL TitleWrapper::getPropertyValue( const OUString& rPropertyName )
 }
 
 beans::PropertyState SAL_CALL TitleWrapper::getPropertyState( const OUString& rPropertyName )
-                                    throw (beans::UnknownPropertyException, uno::RuntimeException, std::exception)
 {
     beans::PropertyState aState( beans::PropertyState_DIRECT_VALUE );
 
@@ -393,7 +361,6 @@ beans::PropertyState SAL_CALL TitleWrapper::getPropertyState( const OUString& rP
     return aState;
 }
 void SAL_CALL TitleWrapper::setPropertyToDefault( const OUString& rPropertyName )
-                                    throw (beans::UnknownPropertyException, uno::RuntimeException, std::exception)
 {
     sal_Int32 nHandle = getInfoHelper().getHandleByName( rPropertyName );
     if( CharacterProperties::IsCharacterPropertyHandle( nHandle ) )
@@ -405,7 +372,6 @@ void SAL_CALL TitleWrapper::setPropertyToDefault( const OUString& rPropertyName
         WrappedPropertySet::setPropertyToDefault( rPropertyName );
 }
 Any SAL_CALL TitleWrapper::getPropertyDefault( const OUString& rPropertyName )
-                                    throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     Any aRet;
 
@@ -429,7 +395,6 @@ Any SAL_CALL TitleWrapper::getPropertyDefault( const OUString& rPropertyName )
 }
 
 void SAL_CALL TitleWrapper::addPropertyChangeListener( const OUString& rPropertyName, const Reference< beans::XPropertyChangeListener >& xListener )
-                                    throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     sal_Int32 nHandle = getInfoHelper().getHandleByName( rPropertyName );
     if( CharacterProperties::IsCharacterPropertyHandle( nHandle ) )
@@ -442,7 +407,6 @@ void SAL_CALL TitleWrapper::addPropertyChangeListener( const OUString& rProperty
         WrappedPropertySet::addPropertyChangeListener( rPropertyName, xListener );
 }
 void SAL_CALL TitleWrapper::removePropertyChangeListener( const OUString& rPropertyName, const Reference< beans::XPropertyChangeListener >& xListener )
-                                    throw (beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     sal_Int32 nHandle = getInfoHelper().getHandleByName( rPropertyName );
     if( CharacterProperties::IsCharacterPropertyHandle( nHandle ) )
@@ -458,18 +422,18 @@ void SAL_CALL TitleWrapper::removePropertyChangeListener( const OUString& rPrope
 //ReferenceSizePropertyProvider
 void TitleWrapper::updateReferenceSize()
 {
-    Reference< beans::XPropertySet > xProp( this->getTitleObject(), uno::UNO_QUERY );
+    Reference< beans::XPropertySet > xProp( getTitleObject(), uno::UNO_QUERY );
     if( xProp.is() )
     {
         if( xProp->getPropertyValue( "ReferencePageSize" ).hasValue() )
-            xProp->setPropertyValue( "ReferencePageSize", uno::makeAny(
+            xProp->setPropertyValue( "ReferencePageSize", uno::Any(
                             m_spChart2ModelContact->GetPageSize() ));
     }
 }
 Any TitleWrapper::getReferenceSize()
 {
     Any aRet;
-    Reference< beans::XPropertySet > xProp( this->getTitleObject(), uno::UNO_QUERY );
+    Reference< beans::XPropertySet > xProp( getTitleObject(), uno::UNO_QUERY );
     if( xProp.is() )
         aRet = xProp->getPropertyValue( "ReferencePageSize" );
 
@@ -489,7 +453,7 @@ Reference< chart2::XTitle > TitleWrapper::getTitleObject()
 
 Reference< beans::XPropertySet > TitleWrapper::getInnerPropertySet()
 {
-    return Reference< beans::XPropertySet >( this->getTitleObject(), uno::UNO_QUERY );
+    return Reference< beans::XPropertySet >( getTitleObject(), uno::UNO_QUERY );
 }
 
 const Sequence< beans::Property >& TitleWrapper::getPropertySequence()
@@ -499,7 +463,7 @@ const Sequence< beans::Property >& TitleWrapper::getPropertySequence()
 
 const std::vector< WrappedProperty* > TitleWrapper::createWrappedProperties()
 {
-    ::std::vector< ::chart::WrappedProperty* > aWrappedProperties;
+    std::vector< ::chart::WrappedProperty* > aWrappedProperties;
 
     aWrappedProperties.push_back( new WrappedTitleStringProperty( m_spChart2ModelContact->m_xContext ) );
     aWrappedProperties.push_back( new WrappedTextRotationProperty( true ) );
@@ -511,19 +475,25 @@ const std::vector< WrappedProperty* > TitleWrapper::createWrappedProperties()
     return aWrappedProperties;
 }
 
-Sequence< OUString > TitleWrapper::getSupportedServiceNames_Static()
+OUString SAL_CALL TitleWrapper::getImplementationName()
 {
-    Sequence< OUString > aServices( 4 );
-    aServices[ 0 ] = "com.sun.star.chart.ChartTitle";
-    aServices[ 1 ] = "com.sun.star.drawing.Shape";
-    aServices[ 2 ] = "com.sun.star.xml.UserDefinedAttributesSupplier";
-    aServices[ 3 ] = "com.sun.star.style.CharacterProperties";
-
-    return aServices;
+    return OUString("com.sun.star.comp.chart.Title");
 }
 
-// implement XServiceInfo methods basing upon getSupportedServiceNames_Static
-APPHELPER_XSERVICEINFO_IMPL( TitleWrapper, OUString(lcl_aServiceName) );
+sal_Bool SAL_CALL TitleWrapper::supportsService( const OUString& rServiceName )
+{
+    return cppu::supportsService(this, rServiceName);
+}
+
+css::uno::Sequence< OUString > SAL_CALL TitleWrapper::getSupportedServiceNames()
+{
+    return {
+        "com.sun.star.chart.ChartTitle",
+        "com.sun.star.drawing.Shape",
+        "com.sun.star.xml.UserDefinedAttributesSupplier",
+         "com.sun.star.style.CharacterProperties"
+    };
+}
 
 } //  namespace wrapper
 } //  namespace chart
