@@ -17,13 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "dlg_DataSource.hxx"
-#include "Strings.hrc"
-#include "ResId.hxx"
+#include <dlg_DataSource.hxx>
+#include <strings.hrc>
+#include <ResId.hxx>
 #include "ChartTypeTemplateProvider.hxx"
-#include "DiagramHelper.hxx"
+#include <DiagramHelper.hxx>
 #include "DialogModel.hxx"
-#include "HelpIds.hrc"
+#include <helpids.h>
 
 #include "tp_RangeChooser.hxx"
 #include "tp_DataSource.hxx"
@@ -36,7 +36,6 @@ using namespace ::com::sun::star::chart2;
 using namespace ::chart;
 
 using ::com::sun::star::uno::Reference;
-using ::com::sun::star::uno::Sequence;
 
 namespace chart
 {
@@ -44,12 +43,11 @@ namespace chart
 class DocumentChartTypeTemplateProvider : public ChartTypeTemplateProvider
 {
 public:
-    DocumentChartTypeTemplateProvider(
+    explicit DocumentChartTypeTemplateProvider(
         const Reference< chart2::XChartDocument > & xDoc );
-    virtual ~DocumentChartTypeTemplateProvider();
 
     // ____ ChartTypeTemplateProvider ____
-    virtual Reference< chart2::XChartTypeTemplate > getCurrentTemplate() const SAL_OVERRIDE;
+    virtual Reference< chart2::XChartTypeTemplate > getCurrentTemplate() const override;
 
 private:
     Reference< chart2::XChartTypeTemplate > m_xTemplate;
@@ -73,9 +71,6 @@ DocumentChartTypeTemplateProvider::DocumentChartTypeTemplateProvider(
     }
 }
 
-DocumentChartTypeTemplateProvider::~DocumentChartTypeTemplateProvider()
-{}
-
 Reference< chart2::XChartTypeTemplate > DocumentChartTypeTemplateProvider::getCurrentTemplate() const
 {
     return m_xTemplate;
@@ -84,9 +79,9 @@ Reference< chart2::XChartTypeTemplate > DocumentChartTypeTemplateProvider::getCu
 class DataSourceTabControl : public TabControl
 {
 public:
-    DataSourceTabControl(vcl::Window* pParent);
+    explicit DataSourceTabControl(vcl::Window* pParent);
 
-    virtual bool DeactivatePage() SAL_OVERRIDE;
+    virtual bool DeactivatePage() override;
 
     void DisableTabToggling();
     void EnableTabToggling();
@@ -129,13 +124,11 @@ DataSourceDialog::DataSourceDialog(vcl::Window * pParent,
     const Reference< uno::XComponentContext > & xContext)
     : TabDialog(pParent, "DataRangeDialog",
         "modules/schart/ui/datarangedialog.ui")
-    , m_xChartDocument(xChartDocument)
-    , m_xContext(xContext)
     , m_apDocTemplateProvider(new DocumentChartTypeTemplateProvider(xChartDocument))
     , m_apDialogModel(new DialogModel(xChartDocument, xContext))
     , m_pTabControl(VclPtr<DataSourceTabControl>::Create(get_content_area()))
-    , m_pRangeChooserTabPage(0)
-    , m_pDataSourceTabPage(0)
+    , m_pRangeChooserTabPage(nullptr)
+    , m_pDataSourceTabPage(nullptr)
     , m_bRangeChooserTabIsValid(true)
     , m_bDataSourceTabIsValid(true)
 {
@@ -148,8 +141,8 @@ DataSourceDialog::DataSourceDialog(vcl::Window * pParent,
     m_pDataSourceTabPage = VclPtr<DataSourceTabPage>::Create( m_pTabControl, *(m_apDialogModel.get()),
                                     m_apDocTemplateProvider.get(), this, true /* bHideDescription */ );
 
-    m_pTabControl->InsertPage( TP_RANGECHOOSER, SCH_RESSTR(STR_PAGE_DATA_RANGE) );
-    m_pTabControl->InsertPage( TP_DATA_SOURCE,  SCH_RESSTR(STR_OBJECT_DATASERIES_PLURAL) );
+    m_pTabControl->InsertPage( TP_RANGECHOOSER, SchResId(STR_PAGE_DATA_RANGE) );
+    m_pTabControl->InsertPage( TP_DATA_SOURCE,  SchResId(STR_OBJECT_DATASERIES_PLURAL) );
 
     m_pTabControl->SetTabPage( TP_DATA_SOURCE,  m_pDataSourceTabPage );
     m_pTabControl->SetTabPage( TP_RANGECHOOSER, m_pRangeChooserTabPage );
@@ -217,7 +210,7 @@ void DataSourceDialog::setValidPage( TabPage * pTabPage )
 
     if( m_bRangeChooserTabIsValid && m_bDataSourceTabIsValid )
     {
-        m_pBtnOK->Enable( true );
+        m_pBtnOK->Enable();
         OSL_ASSERT( m_pTabControl );
         m_pTabControl->EnableTabToggling();
     }
