@@ -17,12 +17,12 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "res_ErrorBar.hxx"
-#include "ResId.hxx"
-#include "Bitmaps.hrc"
-#include "RangeSelectionHelper.hxx"
-#include "TabPageNotifiable.hxx"
-#include "macros.hxx"
+#include <res_ErrorBar.hxx>
+#include <ResId.hxx>
+#include <bitmaps.hlst>
+#include <RangeSelectionHelper.hxx>
+#include <TabPageNotifiable.hxx>
+#include <helpids.h>
 
 #include <rtl/math.hxx>
 #include <vcl/dialog.hxx>
@@ -52,22 +52,22 @@ sal_uInt16 lcl_getLbEntryPosByErrorKind( SvxChartKindError eErrorKind )
     switch( eErrorKind )
     {
         // for these cases select the default in the list box
-        case CHERROR_NONE:
-        case CHERROR_PERCENT:
-        case CHERROR_CONST:
-        case CHERROR_RANGE:
+        case SvxChartKindError::NONE:
+        case SvxChartKindError::Percent:
+        case SvxChartKindError::Const:
+        case SvxChartKindError::Range:
             nResult = CHART_LB_FUNCTION_STD_DEV;
             break;
-        case CHERROR_VARIANT:
+        case SvxChartKindError::Variant:
             nResult = CHART_LB_FUNCTION_VARIANCE;
             break;
-        case CHERROR_SIGMA:
+        case SvxChartKindError::Sigma:
             nResult = CHART_LB_FUNCTION_STD_DEV;
             break;
-        case CHERROR_BIGERROR:
+        case SvxChartKindError::BigError:
             nResult = CHART_LB_FUNCTION_ERROR_MARGIN;
             break;
-        case CHERROR_STDERROR:
+        case SvxChartKindError::StdError:
             nResult = CHART_LB_FUNCTION_STD_ERROR;
             break;
     }
@@ -81,12 +81,10 @@ namespace chart
 ErrorBarResources::ErrorBarResources( VclBuilderContainer* pParent, Dialog * pParentDialog,
                                       const SfxItemSet& rInAttrs, bool bNoneAvailable,
                                       tErrorBarType eType /* = ERROR_BAR_Y */ ) :
-        m_eErrorKind( CHERROR_NONE ),
-        m_eIndicate( CHINDICATE_BOTH ),
+        m_eErrorKind( SvxChartKindError::NONE ),
+        m_eIndicate( SvxChartIndicate::Both ),
         m_bErrorKindUnique( true ),
         m_bIndicatorUnique( true ),
-        m_bPlusUnique( true ),
-        m_bMinusUnique( true ),
         m_bRangePosUnique( true ),
         m_bRangeNegUnique( true ),
         m_bNoneAvailable( bNoneAvailable ),
@@ -186,7 +184,7 @@ void ErrorBarResources::SetChartDocumentForRangeChoosing(
             }
             catch( const uno::Exception& e )
             {
-                ASSERT_EXCEPTION( e );
+                SAL_WARN("chart2", "Exception caught. " << e );
             }
         }
     }
@@ -197,6 +195,7 @@ void ErrorBarResources::SetChartDocumentForRangeChoosing(
     if( m_bHasInternalDataProvider )
     {
         m_pRbRange->SetText(m_pUIStringRbRange->GetText());
+        m_pRbRange->SetHelpId( HID_SCH_ERROR_BARS_FROM_DATA );
     }
 
     if( m_pRbRange->IsChecked())
@@ -233,7 +232,7 @@ void ErrorBarResources::UpdateControlStates()
 
     // range buttons
     m_pRbRange->Enable( !m_bHasInternalDataProvider || m_bEnableDataTableDialog );
-    bool bShowRange = ( m_pRbRange->IsChecked());
+    bool bShowRange = m_pRbRange->IsChecked();
     bool bCanChooseRange =
         ( bShowRange &&
           m_apRangeSelectionHelper.get() &&
@@ -254,13 +253,13 @@ void ErrorBarResources::UpdateControlStates()
     // unit for metric fields
     bool bIsErrorMargin(
         ( m_pRbFunction->IsChecked()) &&
-        ( m_pLbFunction->GetSelectEntryPos() == CHART_LB_FUNCTION_ERROR_MARGIN ));
+        ( m_pLbFunction->GetSelectedEntryPos() == CHART_LB_FUNCTION_ERROR_MARGIN ));
     bool bIsPercentage( m_pRbPercent->IsChecked() || bIsErrorMargin );
-    OUString aCustomUnit;
+    FieldUnit eFieldUnit = FUNIT_NONE;
 
     if( bIsPercentage )
     {
-        aCustomUnit = " %";
+        eFieldUnit = FUNIT_PERCENT;
         m_pMfPositive->SetDecimalDigits( 1 );
         m_pMfPositive->SetSpinSize( 10 );
         m_pMfNegative->SetDecimalDigits( 1 );
@@ -280,8 +279,8 @@ void ErrorBarResources::UpdateControlStates()
     m_pMfPositive->SetValue( nPlusValue );
     m_pMfNegative->SetValue( nMinusValue );
 
-    m_pMfPositive->SetCustomUnitText( aCustomUnit );
-    m_pMfNegative->SetCustomUnitText( aCustomUnit );
+    m_pMfPositive->SetUnit(eFieldUnit);
+    m_pMfNegative->SetUnit(eFieldUnit);
 
     // positive and negative value fields
     bool bPosEnabled = ( m_pRbPositive->IsChecked() || m_pRbBoth->IsChecked());
@@ -308,7 +307,7 @@ void ErrorBarResources::UpdateControlStates()
     }
 
     // all functions except error margin take no arguments
-    if( m_pRbFunction->IsChecked() &&  ( m_pLbFunction->GetSelectEntryPos() != CHART_LB_FUNCTION_ERROR_MARGIN ))
+    if( m_pRbFunction->IsChecked() &&  ( m_pLbFunction->GetSelectedEntryPos() != CHART_LB_FUNCTION_ERROR_MARGIN ))
     {
         bPosEnabled = false;
         bNegEnabled = false;
@@ -340,38 +339,38 @@ void ErrorBarResources::UpdateControlStates()
     }
 }
 
-IMPL_LINK_NOARG_TYPED( ErrorBarResources, CategoryChosen2, ListBox&, void )
+IMPL_LINK_NOARG( ErrorBarResources, CategoryChosen2, ListBox&, void )
 {
    CategoryChosen(nullptr);
 }
 
-IMPL_LINK_NOARG_TYPED( ErrorBarResources, CategoryChosen, Button*, void )
+IMPL_LINK_NOARG( ErrorBarResources, CategoryChosen, Button*, void )
 {
     m_bErrorKindUnique = true;
     SvxChartKindError eOldError = m_eErrorKind;
 
     if( m_pRbNone->IsChecked())
-        m_eErrorKind = CHERROR_NONE;
+        m_eErrorKind = SvxChartKindError::NONE;
     else if( m_pRbConst->IsChecked())
-        m_eErrorKind = CHERROR_CONST;
+        m_eErrorKind = SvxChartKindError::Const;
     else if( m_pRbPercent->IsChecked())
-        m_eErrorKind = CHERROR_PERCENT;
+        m_eErrorKind = SvxChartKindError::Percent;
     else if( m_pRbRange->IsChecked())
-        m_eErrorKind = CHERROR_RANGE;
+        m_eErrorKind = SvxChartKindError::Range;
     else if( m_pRbFunction->IsChecked())
     {
-        if( m_pLbFunction->GetSelectEntryCount() == 1 )
+        if( m_pLbFunction->GetSelectedEntryCount() == 1 )
         {
-            switch( m_pLbFunction->GetSelectEntryPos())
+            switch( m_pLbFunction->GetSelectedEntryPos())
             {
                 case CHART_LB_FUNCTION_STD_ERROR:
-                    m_eErrorKind = CHERROR_STDERROR; break;
+                    m_eErrorKind = SvxChartKindError::StdError; break;
                 case CHART_LB_FUNCTION_STD_DEV:
-                    m_eErrorKind = CHERROR_SIGMA; break;
+                    m_eErrorKind = SvxChartKindError::Sigma; break;
                 case CHART_LB_FUNCTION_VARIANCE:
-                    m_eErrorKind = CHERROR_VARIANT; break;
+                    m_eErrorKind = SvxChartKindError::Variant; break;
                 case CHART_LB_FUNCTION_ERROR_MARGIN:
-                    m_eErrorKind = CHERROR_BIGERROR; break;
+                    m_eErrorKind = SvxChartKindError::BigError; break;
                 default:
                     m_bErrorKindUnique = false;
             }
@@ -386,16 +385,16 @@ IMPL_LINK_NOARG_TYPED( ErrorBarResources, CategoryChosen, Button*, void )
     }
 
     // changed to range
-    if( m_eErrorKind == CHERROR_RANGE &&
-        eOldError != CHERROR_RANGE )
+    if( m_eErrorKind == SvxChartKindError::Range &&
+        eOldError != SvxChartKindError::Range )
     {
         m_pCbSyncPosNeg->Check(
             (!m_pEdRangePositive->GetText().isEmpty()) &&
             m_pEdRangePositive->GetText() == m_pEdRangeNegative->GetText());
     }
     // changed from range
-    else if( m_eErrorKind != CHERROR_RANGE &&
-        eOldError == CHERROR_RANGE )
+    else if( m_eErrorKind != SvxChartKindError::Range &&
+        eOldError == SvxChartKindError::Range )
     {
         m_pCbSyncPosNeg->Check( m_pMfPositive->GetValue() == m_pMfNegative->GetValue());
     }
@@ -403,13 +402,13 @@ IMPL_LINK_NOARG_TYPED( ErrorBarResources, CategoryChosen, Button*, void )
     UpdateControlStates();
 }
 
-IMPL_LINK_NOARG_TYPED(ErrorBarResources, SynchronizePosAndNeg, CheckBox&, void)
+IMPL_LINK_NOARG(ErrorBarResources, SynchronizePosAndNeg, CheckBox&, void)
 {
     UpdateControlStates();
     PosValueChanged( *m_pMfPositive );
 }
 
-IMPL_LINK_NOARG_TYPED(ErrorBarResources, PosValueChanged, Edit&, void)
+IMPL_LINK_NOARG(ErrorBarResources, PosValueChanged, Edit&, void)
 {
     if( m_pCbSyncPosNeg->IsChecked())
     {
@@ -423,22 +422,22 @@ IMPL_LINK_NOARG_TYPED(ErrorBarResources, PosValueChanged, Edit&, void)
     }
 }
 
-IMPL_LINK_NOARG_TYPED(ErrorBarResources, IndicatorChanged, Button*, void)
+IMPL_LINK_NOARG(ErrorBarResources, IndicatorChanged, Button*, void)
 {
     m_bIndicatorUnique = true;
     if( m_pRbBoth->IsChecked())
-        m_eIndicate = CHINDICATE_BOTH;
+        m_eIndicate = SvxChartIndicate::Both;
     else if( m_pRbPositive->IsChecked())
-        m_eIndicate = CHINDICATE_UP;
+        m_eIndicate = SvxChartIndicate::Up;
     else if( m_pRbNegative->IsChecked())
-        m_eIndicate = CHINDICATE_DOWN;
+        m_eIndicate = SvxChartIndicate::Down;
     else
         m_bIndicatorUnique = false;
 
     UpdateControlStates();
 }
 
-IMPL_LINK_TYPED( ErrorBarResources, ChooseRange, Button*, pButton, void )
+IMPL_LINK( ErrorBarResources, ChooseRange, Button*, pButton, void )
 {
     OSL_ASSERT( m_apRangeSelectionHelper.get());
     if( ! m_apRangeSelectionHelper.get())
@@ -470,7 +469,7 @@ IMPL_LINK_TYPED( ErrorBarResources, ChooseRange, Button*, pButton, void )
         m_pCurrentRangeChoosingField = nullptr;
 }
 
-IMPL_LINK_TYPED( ErrorBarResources, RangeChanged, Edit&, rEdit, void )
+IMPL_LINK( ErrorBarResources, RangeChanged, Edit&, rEdit, void )
 {
     if( &rEdit == m_pEdRangePositive )
     {
@@ -490,7 +489,7 @@ void ErrorBarResources::Reset(const SfxItemSet& rInAttrs)
     const SfxPoolItem *pPoolItem = nullptr;
 
     // category
-    m_eErrorKind = CHERROR_NONE;
+    m_eErrorKind = SvxChartKindError::NONE;
     SfxItemState aState = rInAttrs.GetItemState( SCHATTR_STAT_KIND_ERROR, true, &pPoolItem );
     m_bErrorKindUnique = ( aState != SfxItemState::DONTCARE );
 
@@ -503,22 +502,22 @@ void ErrorBarResources::Reset(const SfxItemSet& rInAttrs)
     {
         switch( m_eErrorKind )
         {
-            case CHERROR_NONE:
+            case SvxChartKindError::NONE:
                 m_pRbNone->Check();
                 break;
-            case CHERROR_PERCENT:
+            case SvxChartKindError::Percent:
                 m_pRbPercent->Check();
                 break;
-            case CHERROR_CONST:
+            case SvxChartKindError::Const:
                 m_pRbConst->Check();
                 break;
-            case CHERROR_STDERROR:
-            case CHERROR_VARIANT:
-            case CHERROR_SIGMA:
-            case CHERROR_BIGERROR:
+            case SvxChartKindError::StdError:
+            case SvxChartKindError::Variant:
+            case SvxChartKindError::Sigma:
+            case SvxChartKindError::BigError:
                 m_pRbFunction->Check();
                 break;
-            case CHERROR_RANGE:
+            case SvxChartKindError::Range:
                 m_pRbRange->Check();
                 break;
         }
@@ -533,19 +532,17 @@ void ErrorBarResources::Reset(const SfxItemSet& rInAttrs)
 
     // parameters
     aState = rInAttrs.GetItemState( SCHATTR_STAT_CONSTPLUS, true, &pPoolItem );
-    m_bPlusUnique = ( aState != SfxItemState::DONTCARE );
     if( aState == SfxItemState::SET )
     {
         m_fPlusValue = static_cast<const SvxDoubleItem*>(pPoolItem)->GetValue();
     }
 
     aState = rInAttrs.GetItemState( SCHATTR_STAT_CONSTMINUS, true, &pPoolItem );
-    m_bMinusUnique = ( aState != SfxItemState::DONTCARE );
     if( aState == SfxItemState::SET )
     {
         m_fMinusValue = static_cast<const SvxDoubleItem*>(pPoolItem)->GetValue();
 
-        if( m_eErrorKind != CHERROR_RANGE &&
+        if( m_eErrorKind != SvxChartKindError::Range &&
             m_fPlusValue == m_fMinusValue )
             m_pCbSyncPosNeg->Check();
     }
@@ -560,15 +557,15 @@ void ErrorBarResources::Reset(const SfxItemSet& rInAttrs)
     {
         switch( m_eIndicate )
         {
-            case CHINDICATE_NONE :
+            case SvxChartIndicate::NONE :
                 // no longer used, use both as default
-                m_eIndicate = CHINDICATE_BOTH;
-                // fall-through intended to BOTH
-            case CHINDICATE_BOTH :
+                m_eIndicate = SvxChartIndicate::Both;
+                SAL_FALLTHROUGH; // to BOTH
+            case SvxChartIndicate::Both :
                 m_pRbBoth->Check(); break;
-            case CHINDICATE_UP :
+            case SvxChartIndicate::Up :
                 m_pRbPositive->Check(); break;
-            case CHINDICATE_DOWN :
+            case SvxChartIndicate::Down :
                 m_pRbNegative->Check(); break;
         }
     }
@@ -584,7 +581,7 @@ void ErrorBarResources::Reset(const SfxItemSet& rInAttrs)
     m_bRangePosUnique = ( aState != SfxItemState::DONTCARE );
     if( aState == SfxItemState::SET )
     {
-        OUString sRangePositive = (static_cast< const SfxStringItem * >( pPoolItem ))->GetValue();
+        OUString sRangePositive = static_cast< const SfxStringItem * >( pPoolItem )->GetValue();
         m_pEdRangePositive->SetText( sRangePositive );
     }
 
@@ -592,9 +589,9 @@ void ErrorBarResources::Reset(const SfxItemSet& rInAttrs)
     m_bRangeNegUnique = ( aState != SfxItemState::DONTCARE );
     if( aState == SfxItemState::SET )
     {
-        OUString sRangeNegative = (static_cast< const SfxStringItem * >( pPoolItem ))->GetValue();
+        OUString sRangeNegative = static_cast< const SfxStringItem * >( pPoolItem )->GetValue();
         m_pEdRangeNegative->SetText( sRangeNegative );
-        if( m_eErrorKind == CHERROR_RANGE &&
+        if( m_eErrorKind == SvxChartKindError::Range &&
             !sRangeNegative.isEmpty() &&
             sRangeNegative == m_pEdRangePositive->GetText() )
             m_pCbSyncPosNeg->Check();
@@ -612,7 +609,7 @@ bool ErrorBarResources::FillItemSet(SfxItemSet& rOutAttrs) const
 
     if( m_bErrorKindUnique )
     {
-        if( m_eErrorKind == CHERROR_RANGE )
+        if( m_eErrorKind == SvxChartKindError::Range )
         {
             OUString aPosRange;
             OUString aNegRange;
@@ -637,9 +634,9 @@ bool ErrorBarResources::FillItemSet(SfxItemSet& rOutAttrs) const
             if( m_bRangeNegUnique )
                 rOutAttrs.Put( SfxStringItem( SCHATTR_STAT_RANGE_NEG, aNegRange ));
         }
-        else if( m_eErrorKind == CHERROR_CONST ||
-                 m_eErrorKind == CHERROR_PERCENT ||
-                 m_eErrorKind == CHERROR_BIGERROR )
+        else if( m_eErrorKind == SvxChartKindError::Const ||
+                 m_eErrorKind == SvxChartKindError::Percent ||
+                 m_eErrorKind == SvxChartKindError::BigError )
         {
             double fPosValue = static_cast< double >( m_pMfPositive->GetValue()) /
                 pow( 10.0, m_pMfPositive->GetDecimalDigits());
@@ -665,15 +662,15 @@ void ErrorBarResources::FillValueSets()
 {
     if( m_eErrorBarType == ERROR_BAR_Y )
     {
-        m_pFiNegative->SetImage( Image( SchResId( BMP_INDICATE_DOWN       ) ) );
-        m_pFiPositive->SetImage( Image( SchResId( BMP_INDICATE_UP         ) ) );
-        m_pFiBoth->SetImage(     Image( SchResId( BMP_INDICATE_BOTH_VERTI ) ) );
+        m_pFiNegative->SetImage(Image(BitmapEx(BMP_INDICATE_DOWN)));
+        m_pFiPositive->SetImage(Image(BitmapEx(BMP_INDICATE_UP)));
+        m_pFiBoth->SetImage(Image(BitmapEx(BMP_INDICATE_BOTH_VERTI)));
     }
     else if( m_eErrorBarType == ERROR_BAR_X )
     {
-        m_pFiNegative->SetImage( Image( SchResId( BMP_INDICATE_LEFT      ) ) );
-        m_pFiPositive->SetImage( Image( SchResId( BMP_INDICATE_RIGHT     ) ) );
-        m_pFiBoth->SetImage(     Image( SchResId( BMP_INDICATE_BOTH_HORI ) ) );
+        m_pFiNegative->SetImage(Image(BitmapEx(BMP_INDICATE_LEFT)));
+        m_pFiPositive->SetImage(Image(BitmapEx(BMP_INDICATE_RIGHT)));
+        m_pFiBoth->SetImage(Image(BitmapEx(BMP_INDICATE_BOTH_HORI)));
     }
 }
 
@@ -719,7 +716,7 @@ void ErrorBarResources::disposingRangeSelection()
         m_apRangeSelectionHelper->stopRangeListening( false );
 }
 
-bool ErrorBarResources::isRangeFieldContentValid( Edit & rEdit )
+void ErrorBarResources::isRangeFieldContentValid( Edit & rEdit )
 {
     OUString aRange( rEdit.GetText());
     bool bIsValid = ( aRange.isEmpty() ) ||
@@ -736,8 +733,6 @@ bool ErrorBarResources::isRangeFieldContentValid( Edit & rEdit )
         rEdit.SetControlBackground( RANGE_SELECTION_INVALID_RANGE_BACKGROUND_COLOR );
         rEdit.SetControlForeground( RANGE_SELECTION_INVALID_RANGE_FOREGROUND_COLOR );
     }
-
-    return bIsValid;
 }
 
 } //namespace chart
