@@ -18,16 +18,15 @@
  */
 
 #include "tp_DataSource.hxx"
-#include "Strings.hrc"
-#include "ResId.hxx"
-#include "chartview/ChartSfxItemIds.hxx"
-#include "macros.hxx"
+#include <strings.hrc>
+#include <ResId.hxx>
+#include <chartview/ChartSfxItemIds.hxx>
 #include "ChartTypeTemplateProvider.hxx"
-#include "RangeSelectionHelper.hxx"
-#include "DataSeriesHelper.hxx"
+#include <RangeSelectionHelper.hxx>
+#include <DataSeriesHelper.hxx>
 #include "tp_DataSourceControls.hxx"
-#include "ControllerLockGuard.hxx"
-#include "DataSourceHelper.hxx"
+#include <ControllerLockGuard.hxx>
+#include <DataSourceHelper.hxx>
 #include <com/sun/star/sheet/XRangeSelection.hpp>
 #include <com/sun/star/table/XCellRange.hpp>
 #include <com/sun/star/chart2/XChartType.hpp>
@@ -58,10 +57,10 @@ OUString lcl_GetRoleLBEntry(
 {
     OUStringBuffer aEntry( rRole );
     aEntry.append( "\t" );
-    aEntry.append( OUString(
-        ::chart::DialogModel::ConvertRoleFromInternalToUI( rRole )) );
+    aEntry.append(
+        ::chart::DialogModel::ConvertRoleFromInternalToUI( rRole ) );
     aEntry.append( "\t" );
-    aEntry.append(OUString( rRange ));
+    aEntry.append( rRange );
 
     OUString sFoo = aEntry.makeStringAndClear();
     return sFoo;
@@ -102,8 +101,7 @@ OUString lcl_GetSelectedRole( const SvTabListBox & rRoleListBox, bool bUITransla
     OUString aResult;
     SvTreeListEntry * pEntry = rRoleListBox.FirstSelected();
     if( pEntry )
-        aResult = OUString( SvTabListBox::GetEntryText( pEntry,
-                                                       bUITranslated ? 1 : 0 ));
+        aResult = SvTabListBox::GetEntryText( pEntry, bUITranslated ? 1 : 0 );
     return aResult;
 }
 
@@ -112,11 +110,11 @@ OUString lcl_GetSelectedRolesRange( const SvTabListBox & rRoleListBox )
     OUString aResult;
     SvTreeListEntry * pEntry = rRoleListBox.FirstSelected();
     if( pEntry )
-        aResult = OUString( SvTabListBox::GetEntryText( pEntry, 2 ));
+        aResult = SvTabListBox::GetEntryText( pEntry, 2 );
     return aResult;
 }
 
-OUString lcl_GetSequenceNameForLabel( ::chart::SeriesEntry * pEntry )
+OUString lcl_GetSequenceNameForLabel( ::chart::SeriesEntry const * pEntry )
 {
     OUString aResult( "values-y" );
     if( pEntry &&
@@ -219,8 +217,8 @@ DataSourceTabPage::DataSourceTabPage(
 
     m_pFT_CAPTION->Show(!bHideDescription);
 
-    m_aFixedTextRange = OUString( m_pFT_RANGE->GetText() );
-    this->SetText( SCH_RESSTR( STR_OBJECT_DATASERIES_PLURAL ) );
+    m_aFixedTextRange = m_pFT_RANGE->GetText();
+    SetText( SchResId( STR_OBJECT_DATASERIES_PLURAL ) );
 
     // set handlers
     m_pLB_SERIES->SetSelectHdl( LINK( this, DataSourceTabPage, SeriesSelectionChangedHdl ));
@@ -242,19 +240,19 @@ DataSourceTabPage::DataSourceTabPage(
     m_pEDT_CATEGORIES->SetUpdateDataHdl( LINK( this, DataSourceTabPage, RangeUpdateDataHdl ));
 
     // #i75179# enable setting the background to a different color
-    m_pEDT_RANGE->SetStyle( m_pEDT_RANGE->GetStyle() | WB_FORCECTRLBACKGROUND );
-    m_pEDT_CATEGORIES->SetStyle( m_pEDT_CATEGORIES->GetStyle() | WB_FORCECTRLBACKGROUND );
+    m_pEDT_RANGE->SetForceControlBackground(true);
+    m_pEDT_CATEGORIES->SetForceControlBackground(true);
 
     // set symbol font for arrows
     // note: StarSymbol is substituted to OpenSymbol for OOo
     vcl::Font aSymbolFont( m_pBTN_UP->GetFont());
-    aSymbolFont.SetName( "StarSymbol" );
+    aSymbolFont.SetFamilyName( "StarSymbol" );
     m_pBTN_UP->SetControlFont( aSymbolFont );
     m_pBTN_DOWN->SetControlFont( aSymbolFont );
 
     // set button text
-    sal_Unicode cBlackUpPointingTriangle( 0x25b2 );
-    sal_Unicode cBlackDownPointingTriangle( 0x25bc );
+    sal_Unicode const cBlackUpPointingTriangle( 0x25b2 );
+    sal_Unicode const cBlackDownPointingTriangle( 0x25bc );
     m_pBTN_UP->SetText( OUString( cBlackUpPointingTriangle ));
     m_pBTN_DOWN->SetText( OUString( cBlackDownPointingTriangle ));
 
@@ -268,9 +266,6 @@ DataSourceTabPage::DataSourceTabPage(
     if( m_pLB_SERIES->First())
         m_pLB_SERIES->Select( m_pLB_SERIES->First());
     m_pLB_SERIES->GrabFocus();
-
-    m_pBTN_UP->SetAccessibleName(SCH_RESSTR(STR_BUTTON_UP));
-    m_pBTN_DOWN->SetAccessibleName(SCH_RESSTR(STR_BUTTON_DOWN));
 }
 
 DataSourceTabPage::~DataSourceTabPage()
@@ -407,11 +402,11 @@ void DataSourceTabPage::fillSeriesListBox()
     SvTreeListEntry * pSelectedEntry = nullptr;
     m_pLB_SERIES->Clear();
 
-    ::std::vector< DialogModel::tSeriesWithChartTypeByName > aSeries(
+    std::vector< DialogModel::tSeriesWithChartTypeByName > aSeries(
         m_rDialogModel.getAllDataSeriesWithLabel() );
 
     sal_Int32 nUnnamedSeriesIndex = 1;
-    for( ::std::vector< DialogModel::tSeriesWithChartTypeByName >::const_iterator aIt = aSeries.begin();
+    for( std::vector< DialogModel::tSeriesWithChartTypeByName >::const_iterator aIt = aSeries.begin();
          aIt != aSeries.end(); ++aIt )
     {
         OUString aLabel( (*aIt).first );
@@ -419,18 +414,18 @@ void DataSourceTabPage::fillSeriesListBox()
         {
             if( nUnnamedSeriesIndex > 1 )
             {
-                OUString aResString(::chart::SchResId( STR_DATA_UNNAMED_SERIES_WITH_INDEX ).toString());
+                OUString aResString(::chart::SchResId( STR_DATA_UNNAMED_SERIES_WITH_INDEX ));
 
                 // replace index of unnamed series
                 const OUString aReplacementStr( "%NUMBER" );
                 sal_Int32 nIndex = aResString.indexOf( aReplacementStr );
                 if( nIndex != -1 )
-                    aLabel = OUString( aResString.replaceAt(
+                    aLabel = aResString.replaceAt(
                                          nIndex, aReplacementStr.getLength(),
-                                         OUString::number(nUnnamedSeriesIndex)));
+                                         OUString::number(nUnnamedSeriesIndex));
             }
             if( aLabel.isEmpty() )
-                aLabel = ::chart::SchResId( STR_DATA_UNNAMED_SERIES ).toString();
+                aLabel = ::chart::SchResId( STR_DATA_UNNAMED_SERIES );
 
             ++nUnnamedSeriesIndex;
         }
@@ -533,7 +528,7 @@ void DataSourceTabPage::updateControlState()
     isValid();
 }
 
-IMPL_LINK_NOARG_TYPED(DataSourceTabPage, SeriesSelectionChangedHdl, SvTreeListBox*, void)
+IMPL_LINK_NOARG(DataSourceTabPage, SeriesSelectionChangedHdl, SvTreeListBox*, void)
 {
     m_rDialogModel.startControllerLockTimer();
     if( m_pLB_SERIES->FirstSelected())
@@ -544,7 +539,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, SeriesSelectionChangedHdl, SvTreeListBo
     updateControlState();
 }
 
-IMPL_LINK_NOARG_TYPED(DataSourceTabPage, RoleSelectionChangedHdl, SvTreeListBox*, void)
+IMPL_LINK_NOARG(DataSourceTabPage, RoleSelectionChangedHdl, SvTreeListBox*, void)
 {
     m_rDialogModel.startControllerLockTimer();
     SvTreeListEntry * pEntry = m_pLB_ROLE->FirstSelected();
@@ -568,7 +563,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, RoleSelectionChangedHdl, SvTreeListBox*
     }
 }
 
-IMPL_LINK_NOARG_TYPED(DataSourceTabPage, MainRangeButtonClickedHdl, Button*, void)
+IMPL_LINK_NOARG(DataSourceTabPage, MainRangeButtonClickedHdl, Button*, void)
 {
     OSL_ASSERT( m_pCurrentRangeChoosingField == nullptr );
     m_pCurrentRangeChoosingField = m_pEDT_RANGE;
@@ -583,7 +578,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, MainRangeButtonClickedHdl, Button*, voi
 
     if( bHasSelectedEntry && (m_pLB_ROLE->FirstSelected() != nullptr))
     {
-        OUString aUIStr(SCH_RESSTR(STR_DATA_SELECT_RANGE_FOR_SERIES));
+        OUString aUIStr(SchResId(STR_DATA_SELECT_RANGE_FOR_SERIES));
 
         // replace role
         OUString aReplacement( "%VALUETYPE" );
@@ -599,7 +594,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, MainRangeButtonClickedHdl, Button*, voi
         if( nIndex != -1 )
         {
             aUIStr = aUIStr.replaceAt( nIndex, aReplacement.getLength(),
-                                       OUString( m_pLB_SERIES->GetEntryText( pEntry )));
+                                       m_pLB_SERIES->GetEntryText( pEntry ));
         }
 
         lcl_enableRangeChoosing( true, m_pParentDialog );
@@ -609,7 +604,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, MainRangeButtonClickedHdl, Button*, voi
         m_pCurrentRangeChoosingField = nullptr;
 }
 
-IMPL_LINK_NOARG_TYPED(DataSourceTabPage, CategoriesRangeButtonClickedHdl, Button*, void)
+IMPL_LINK_NOARG(DataSourceTabPage, CategoriesRangeButtonClickedHdl, Button*, void)
 {
     OSL_ASSERT( m_pCurrentRangeChoosingField == nullptr );
     m_pCurrentRangeChoosingField = m_pEDT_CATEGORIES;
@@ -617,13 +612,13 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, CategoriesRangeButtonClickedHdl, Button
         ! updateModelFromControl( m_pCurrentRangeChoosingField ))
         return;
 
-    OUString aStr( SCH_RESSTR( m_pFT_CATEGORIES->IsVisible() ? STR_DATA_SELECT_RANGE_FOR_CATEGORIES : STR_DATA_SELECT_RANGE_FOR_DATALABELS ));
+    OUString aStr( SchResId( m_pFT_CATEGORIES->IsVisible() ? STR_DATA_SELECT_RANGE_FOR_CATEGORIES : STR_DATA_SELECT_RANGE_FOR_DATALABELS ));
     lcl_enableRangeChoosing( true, m_pParentDialog );
     m_rDialogModel.getRangeSelectionHelper()->chooseRange(
         m_rDialogModel.getCategoriesRange(), aStr, *this );
 }
 
-IMPL_LINK_NOARG_TYPED(DataSourceTabPage, AddButtonClickedHdl, Button*, void)
+IMPL_LINK_NOARG(DataSourceTabPage, AddButtonClickedHdl, Button*, void)
 {
     m_rDialogModel.startControllerLockTimer();
     SeriesEntry * pEntry = dynamic_cast< SeriesEntry * >( m_pLB_SERIES->FirstSelected());
@@ -639,7 +634,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, AddButtonClickedHdl, Button*, void)
     }
     else
     {
-        ::std::vector< Reference< XDataSeriesContainer > > aCntVec(
+        std::vector< Reference< XDataSeriesContainer > > aCntVec(
             m_rDialogModel.getAllDataSeriesContainers());
         if( ! aCntVec.empty())
             xChartTypeForNewSeries.set( aCntVec.front(), uno::UNO_QUERY );
@@ -661,7 +656,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, AddButtonClickedHdl, Button*, void)
     SeriesSelectionChangedHdl( nullptr );
 }
 
-IMPL_LINK_NOARG_TYPED(DataSourceTabPage, RemoveButtonClickedHdl, Button*, void)
+IMPL_LINK_NOARG(DataSourceTabPage, RemoveButtonClickedHdl, Button*, void)
 {
     m_rDialogModel.startControllerLockTimer();
     SeriesEntry * pEntry = dynamic_cast< SeriesEntry * >( m_pLB_SERIES->FirstSelected());
@@ -703,7 +698,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, RemoveButtonClickedHdl, Button*, void)
     }
 }
 
-IMPL_LINK_NOARG_TYPED(DataSourceTabPage, UpButtonClickedHdl, Button*, void)
+IMPL_LINK_NOARG(DataSourceTabPage, UpButtonClickedHdl, Button*, void)
 {
     m_rDialogModel.startControllerLockTimer();
     SeriesEntry * pEntry = dynamic_cast< SeriesEntry * >( m_pLB_SERIES->FirstSelected());
@@ -718,7 +713,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, UpButtonClickedHdl, Button*, void)
     }
 }
 
-IMPL_LINK_NOARG_TYPED(DataSourceTabPage, DownButtonClickedHdl, Button*, void)
+IMPL_LINK_NOARG(DataSourceTabPage, DownButtonClickedHdl, Button*, void)
 {
     m_rDialogModel.startControllerLockTimer();
     SeriesEntry * pEntry = dynamic_cast< SeriesEntry * >( m_pLB_SERIES->FirstSelected());
@@ -733,7 +728,7 @@ IMPL_LINK_NOARG_TYPED(DataSourceTabPage, DownButtonClickedHdl, Button*, void)
     }
 }
 
-IMPL_LINK_TYPED( DataSourceTabPage, RangeModifiedHdl, Edit&, rEdit, void )
+IMPL_LINK( DataSourceTabPage, RangeModifiedHdl, Edit&, rEdit, void )
 {
     // note: isValid sets the color of the edit field
     if( isRangeFieldContentValid( rEdit ))
@@ -751,7 +746,7 @@ IMPL_LINK_TYPED( DataSourceTabPage, RangeModifiedHdl, Edit&, rEdit, void )
     isValid();
 }
 
-IMPL_LINK_TYPED( DataSourceTabPage, RangeUpdateDataHdl, Edit&, rEdit, void )
+IMPL_LINK( DataSourceTabPage, RangeUpdateDataHdl, Edit&, rEdit, void )
 {
     // note: isValid sets the color of the edit field
     if( isRangeFieldContentValid( rEdit ))
@@ -837,7 +832,7 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
                 // create or change categories
                 if( !xLabeledSeq.is())
                 {
-                    xLabeledSeq.set( DataSourceHelper::createLabeledDataSequence( Reference< uno::XComponentContext >(nullptr)));
+                    xLabeledSeq.set( DataSourceHelper::createLabeledDataSequence() );
                     m_rDialogModel.setCategories( xLabeledSeq );
                 }
                 try
@@ -847,7 +842,7 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
                 catch( const uno::Exception & ex )
                 {
                     // should work as validation should have happened before
-                    ASSERT_EXCEPTION( ex );
+                    SAL_WARN("chart2", "Exception caught. " << ex );
                 }
             }
             else if( xLabeledSeq.is())
@@ -892,7 +887,7 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
                             if( ! xLabeledSeq.is())
                             {
                                 // no corresponding labeled data sequence for label found
-                                xLabeledSeq.set( DataSourceHelper::createLabeledDataSequence( Reference< uno::XComponentContext >(nullptr)));
+                                xLabeledSeq.set( DataSourceHelper::createLabeledDataSequence() );
                                 lcl_addLSequenceToDataSource( xLabeledSeq, xSource );
                             }
                         }
@@ -908,7 +903,7 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
                                 catch( const uno::Exception & ex )
                                 {
                                     // should work as validation should have happened before
-                                    ASSERT_EXCEPTION( ex );
+                                    SAL_WARN("chart2", "Exception caught. " << ex );
                                 }
                                 if( xNewSeq.is())
                                 {
@@ -917,7 +912,7 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
                                     // "$Sheet1.$A$1"
                                     aRange = xNewSeq->getSourceRangeRepresentation();
                                     Reference< beans::XPropertySet > xProp( xNewSeq, uno::UNO_QUERY_THROW );
-                                    xProp->setPropertyValue( "Role" , uno::makeAny( lcl_aLabelRole ));
+                                    xProp->setPropertyValue( "Role" , uno::Any( lcl_aLabelRole ));
                                     xLabeledSeq->setLabel( xNewSeq );
                                 }
                             }
@@ -939,7 +934,7 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
                             catch( const uno::Exception & ex )
                             {
                                 // should work as validation should have happened before
-                                ASSERT_EXCEPTION( ex );
+                                SAL_WARN("chart2", "Exception caught. " << ex );
                             }
                             if( xNewSeq.is())
                             {
@@ -949,14 +944,14 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
                                 aRange = xNewSeq->getSourceRangeRepresentation();
 
                                 Reference< beans::XPropertySet > xProp( xNewSeq, uno::UNO_QUERY_THROW );
-                                xProp->setPropertyValue( "Role" , uno::makeAny( aSelectedRole ));
+                                xProp->setPropertyValue( "Role" , uno::Any( aSelectedRole ));
                                 if( !xLabeledSeq.is())
                                 {
                                     if( aSelectedRole == aSequenceNameForLabel )
                                         xLabeledSeq.set( lcl_findLSequenceWithOnlyLabel( xSource ));
                                     if( ! xLabeledSeq.is())
                                     {
-                                        xLabeledSeq.set( DataSourceHelper::createLabeledDataSequence( Reference< uno::XComponentContext >(nullptr)));
+                                        xLabeledSeq.set( DataSourceHelper::createLabeledDataSequence() );
                                         lcl_addLSequenceToDataSource( xLabeledSeq, xSource );
                                     }
                                 }
@@ -971,7 +966,7 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
             catch( const uno::Exception & ex )
             {
                 bResult = false;
-                ASSERT_EXCEPTION( ex );
+                SAL_WARN("chart2", "Exception caught. " << ex );
             }
         }
     }
@@ -984,7 +979,7 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
         {
             Reference< util::XModifiable > xModifiable( m_rDialogModel.getChartModel(), uno::UNO_QUERY );
             if( xModifiable.is() )
-                xModifiable->setModified( sal_True );
+                xModifiable->setModified( true );
             const DialogModelTimeBasedInfo& rInfo = m_rDialogModel.getTimeBasedInfo();
             if(rInfo.bTimeBased)
             {
@@ -993,7 +988,7 @@ bool DataSourceTabPage::updateModelFromControl( Edit * pField )
         }
         catch( const uno::Exception & ex )
         {
-            ASSERT_EXCEPTION( ex );
+            SAL_WARN("chart2", "Exception caught. " << ex );
         }
     }
 
