@@ -17,44 +17,43 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <sal/config.h>
 
 #include <set>
 
-#include "ChartController.hxx"
-#include "servicenames.hxx"
-#include "ResId.hxx"
-#include "dlg_DataSource.hxx"
-#include "ChartModelHelper.hxx"
+#include <ChartController.hxx>
+#include <servicenames.hxx>
+#include <ResId.hxx>
+#include <dlg_DataSource.hxx>
+#include <ChartModelHelper.hxx>
 #include "ControllerCommandDispatch.hxx"
-#include "Strings.hrc"
-#include "chartview/ExplicitValueProvider.hxx"
-#include "ChartViewHelper.hxx"
+#include <strings.hrc>
+#include <chartview/ExplicitValueProvider.hxx>
+#include <ChartViewHelper.hxx>
 
-#include "ChartWindow.hxx"
-#include "chartview/DrawModelWrapper.hxx"
-#include "DrawViewWrapper.hxx"
-#include "ObjectIdentifier.hxx"
-#include "DiagramHelper.hxx"
-#include "ControllerLockGuard.hxx"
+#include <ChartWindow.hxx>
+#include <chartview/DrawModelWrapper.hxx>
+#include <DrawViewWrapper.hxx>
+#include <ObjectIdentifier.hxx>
+#include <DiagramHelper.hxx>
+#include <ControllerLockGuard.hxx>
 #include "UndoGuard.hxx"
 #include "ChartDropTargetHelper.hxx"
 
-#include "macros.hxx"
-#include "dlg_CreationWizard.hxx"
-#include "dlg_ChartType.hxx"
-#include "AccessibleChartView.hxx"
+#include <dlg_CreationWizard.hxx>
+#include <dlg_ChartType.hxx>
+#include <AccessibleChartView.hxx>
 #include "DrawCommandDispatch.hxx"
 #include "ShapeController.hxx"
 #include "UndoActions.hxx"
-#include "ViewElementListProvider.hxx"
+#include <ViewElementListProvider.hxx>
 
 #include <cppuhelper/supportsservice.hxx>
 
 #include <com/sun/star/awt/PosSize.hpp>
 #include <com/sun/star/chart2/XChartDocument.hpp>
 #include <com/sun/star/chart2/data/XDataReceiver.hpp>
-#include <com/sun/star/frame/XLoadable.hpp>
 #include <com/sun/star/frame/XController2.hpp>
 #include <com/sun/star/util/XCloneable.hpp>
 #include <com/sun/star/embed/XEmbeddedClient.hpp>
@@ -66,6 +65,7 @@
 #include <com/sun/star/ui/XSidebar.hpp>
 #include <com/sun/star/chart2/XChartTypeContainer.hpp>
 #include <com/sun/star/chart2/XCoordinateSystemContainer.hpp>
+#include <com/sun/star/drawing/XShape.hpp>
 
 #include <svx/sidebar/SelectionChangeHandler.hxx>
 #include <vcl/msgbox.hxx>
@@ -105,7 +105,6 @@ ChartController::ChartController(uno::Reference<uno::XComponentContext> const &
     m_xFrame( nullptr ),
     m_aModelMutex(),
     m_aModel( nullptr, m_aModelMutex ),
-    m_pChartWindow( nullptr ),
     m_xViewWindow(),
     m_xChartView(),
     m_pDrawModelWrapper(),
@@ -113,16 +112,17 @@ ChartController::ChartController(uno::Reference<uno::XComponentContext> const &
     m_eDragMode(SdrDragMode::Move),
     m_bWaitingForDoubleClick(false),
     m_bWaitingForMouseUp(false),
+    m_bFieldButtonDown(false),
     m_bConnectingToView(false),
     m_bDisposed(false),
     m_xUndoManager( nullptr ),
-    m_aDispatchContainer( m_xCC, this ),
+    m_aDispatchContainer( m_xCC ),
     m_eDrawMode( CHARTDRAW_SELECT ),
     mpSelectionChangeHandler(new svx::sidebar::SelectionChangeHandler(
             [this]() { return this->GetContextName(); },
-                this, vcl::EnumContext::Context_Cell))
+                this, vcl::EnumContext::Context::Cell))
 {
-    m_aDoubleClickTimer.SetTimeoutHdl( LINK( this, ChartController, DoubleClickWaitingHdl ) );
+    m_aDoubleClickTimer.SetInvokeHandler( LINK( this, ChartController, DoubleClickWaitingHdl ) );
 }
 
 ChartController::~ChartController()
@@ -187,7 +187,7 @@ void ChartController::TheModel::tryTermination()
             try
             {
                 //@todo ? are we allowed to use sal_True here if we have the explicit ownership?
-                //I think yes, because there might be other closelistners later in the list which might be interested still
+                //I think yes, because there might be other CloseListeners later in the list which might be interested still
                 //but make sure that we do not throw the CloseVetoException here ourselves
                 //so stop listening before trying to terminate or check the source of queryclosing event
                 m_xCloseable->close(true);
@@ -214,62 +214,42 @@ void ChartController::TheModel::tryTermination()
     }
     catch(const uno::Exception& ex)
     {
-        (void)(ex); // no warning in non-debug builds
-        OSL_FAIL( OString( OString("Termination of model failed: ")
-            + OUStringToOString( ex.Message, RTL_TEXTENCODING_ASCII_US ) ).getStr() );
+        SAL_WARN( "chart2", "Termination of model failed: " << ex );
     }
 }
 
 ChartController::TheModelRef::TheModelRef( TheModel* pTheModel, osl::Mutex& rMutex ) :
-    m_pTheModel(pTheModel),
     m_rModelMutex(rMutex)
 {
     osl::Guard< osl::Mutex > aGuard( m_rModelMutex );
-    if(m_pTheModel)
-        m_pTheModel->acquire();
+    m_xTheModel = pTheModel;
 }
 ChartController::TheModelRef::TheModelRef( const TheModelRef& rTheModel, ::osl::Mutex& rMutex ) :
     m_rModelMutex(rMutex)
 {
     osl::Guard< osl::Mutex > aGuard( m_rModelMutex );
-    m_pTheModel=rTheModel.operator->();
-    if(m_pTheModel)
-        m_pTheModel->acquire();
+    m_xTheModel = rTheModel.m_xTheModel;
 }
 ChartController::TheModelRef& ChartController::TheModelRef::operator=(TheModel* pTheModel)
 {
     osl::Guard< osl::Mutex > aGuard( m_rModelMutex );
-    if(m_pTheModel==pTheModel)
-        return *this;
-    if(m_pTheModel)
-        m_pTheModel->release();
-    m_pTheModel=pTheModel;
-    if(m_pTheModel)
-        m_pTheModel->acquire();
+    m_xTheModel = pTheModel;
     return *this;
 }
 ChartController::TheModelRef& ChartController::TheModelRef::operator=(const TheModelRef& rTheModel)
 {
     osl::Guard< osl::Mutex > aGuard( m_rModelMutex );
-    TheModel* pNew=rTheModel.operator->();
-    if(m_pTheModel==pNew)
-        return *this;
-    if(m_pTheModel)
-        m_pTheModel->release();
-    m_pTheModel=pNew;
-    if(m_pTheModel)
-        m_pTheModel->acquire();
+    m_xTheModel = rTheModel.operator->();
     return *this;
 }
 ChartController::TheModelRef::~TheModelRef()
 {
     osl::Guard< osl::Mutex > aGuard( m_rModelMutex );
-    if(m_pTheModel)
-        m_pTheModel->release();
+    m_xTheModel.clear();
 }
 bool ChartController::TheModelRef::is() const
 {
-    return (m_pTheModel != nullptr);
+    return m_xTheModel.is();
 }
 
 namespace {
@@ -285,6 +265,9 @@ css::uno::Reference<css::chart2::XChartType> getChartType(
     Reference< chart2::XCoordinateSystemContainer > xCooSysContainer( xDiagram, uno::UNO_QUERY_THROW );
 
     Sequence< Reference< chart2::XCoordinateSystem > > xCooSysSequence( xCooSysContainer->getCoordinateSystems());
+    if (!xCooSysSequence.getLength()) {
+        return css::uno::Reference<css::chart2::XChartType>();
+    }
 
     Reference< chart2::XChartTypeContainer > xChartTypeContainer( xCooSysSequence[0], uno::UNO_QUERY_THROW );
 
@@ -359,19 +342,16 @@ bool ChartController::impl_isDisposedOrSuspended() const
 // lang::XServiceInfo
 
 OUString SAL_CALL ChartController::getImplementationName()
-    throw( css::uno::RuntimeException, std::exception )
 {
     return OUString(CHART_CONTROLLER_SERVICE_IMPLEMENTATION_NAME);
 }
 
 sal_Bool SAL_CALL ChartController::supportsService( const OUString& rServiceName )
-    throw( css::uno::RuntimeException, std::exception )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 css::uno::Sequence< OUString > SAL_CALL ChartController::getSupportedServiceNames()
-    throw( css::uno::RuntimeException, std::exception )
 {
     return {
         CHART_CONTROLLER_SERVICE_NAME,
@@ -411,7 +391,6 @@ uno::Reference<ui::XSidebar> getSidebarFromModel(const uno::Reference<frame::XMo
 
 void SAL_CALL ChartController::attachFrame(
     const uno::Reference<frame::XFrame>& xFrame )
-        throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -460,24 +439,18 @@ void SAL_CALL ChartController::attachFrame(
         if (pParentComponent)
             pParentComponent->setVisible(true);
 
-        pParent = VCLUnoHelper::GetWindow( xContainerWindow );
+        pParent = VCLUnoHelper::GetWindow( xContainerWindow ).get();
     }
 
-    if(m_pChartWindow)
-    {
-        //@todo delete ...
-        m_pChartWindow->clear();
-        m_apDropTargetHelper.reset();
-    }
     {
         // calls to VCL
         SolarMutexGuard aSolarGuard;
-        m_pChartWindow = VclPtr<ChartWindow>::Create(this,pParent,pParent?pParent->GetStyle():0);
-        m_pChartWindow->SetBackground();//no Background
-        m_xViewWindow.set( m_pChartWindow->GetComponentInterface(), uno::UNO_QUERY );
-        m_pChartWindow->Show();
+        auto pChartWindow = VclPtr<ChartWindow>::Create(this,pParent,pParent?pParent->GetStyle():0);
+        pChartWindow->SetBackground();//no Background
+        m_xViewWindow.set( pChartWindow->GetComponentInterface(), uno::UNO_QUERY );
+        pChartWindow->Show();
         m_apDropTargetHelper.reset(
-            new ChartDropTargetHelper( m_pChartWindow->GetDropTarget(),
+            new ChartDropTargetHelper( pChartWindow->GetDropTarget(),
                                        uno::Reference< chart2::XChartDocument >( getModel(), uno::UNO_QUERY )));
 
         impl_createDrawViewController();
@@ -518,7 +491,7 @@ void SAL_CALL ChartController::attachFrame(
             }
             catch( const uno::Exception & ex )
             {
-                ASSERT_EXCEPTION( ex );
+                SAL_WARN("chart2", "Exception caught. " << ex );
             }
         }
     }
@@ -526,22 +499,21 @@ void SAL_CALL ChartController::attachFrame(
 
 //XModeChangeListener
 void SAL_CALL ChartController::modeChanged( const util::ModeChangeEvent& rEvent )
-    throw (uno::RuntimeException, std::exception)
 {
+    SolarMutexGuard aGuard;
+    auto pChartWindow(GetChartWindow());
     //adjust controller to view status changes
 
     if( rEvent.NewMode == "dirty" )
     {
         //the view has become dirty, we should repaint it if we have a window
-        SolarMutexGuard aGuard;
-        if( m_pChartWindow )
-            m_pChartWindow->ForceInvalidate();
+        if( pChartWindow )
+            pChartWindow->ForceInvalidate();
     }
     else if( rEvent.NewMode == "invalid" )
     {
         //the view is about to become invalid so end all actions on it
         impl_invalidateAccessible();
-        SolarMutexGuard aGuard;
         if( m_pDrawViewWrapper && m_pDrawViewWrapper->IsTextEdit() )
             this->EndTextEdit();
         if( m_pDrawViewWrapper )
@@ -555,7 +527,7 @@ void SAL_CALL ChartController::modeChanged( const util::ModeChangeEvent& rEvent
         //the view was rebuild so we can start some actions on it again
         if( !m_bConnectingToView )
         {
-            if(m_pChartWindow && m_aModel.is() )
+            if(pChartWindow && m_aModel.is() )
             {
                 m_bConnectingToView = true;
 
@@ -563,7 +535,6 @@ void SAL_CALL ChartController::modeChanged( const util::ModeChangeEvent& rEvent
                 if(m_pDrawModelWrapper)
                 {
                     {
-                        SolarMutexGuard aGuard;
                         if( m_pDrawViewWrapper )
                             m_pDrawViewWrapper->ReInit();
                     }
@@ -577,9 +548,8 @@ void SAL_CALL ChartController::modeChanged( const util::ModeChangeEvent& rEvent
                     impl_initializeAccessible();
 
                     {
-                        SolarMutexGuard aGuard;
-                        if( m_pChartWindow )
-                            m_pChartWindow->Invalidate();
+                        if( pChartWindow )
+                            pChartWindow->Invalidate();
                     }
                 }
 
@@ -590,7 +560,6 @@ void SAL_CALL ChartController::modeChanged( const util::ModeChangeEvent& rEvent
 }
 
 sal_Bool SAL_CALL ChartController::attachModel( const uno::Reference< frame::XModel > & xModel )
-        throw(uno::RuntimeException, std::exception)
 {
     impl_invalidateAccessible();
 
@@ -653,7 +622,7 @@ sal_Bool SAL_CALL ChartController::attachModel( const uno::Reference< frame::XMo
 
     // #i119999# Do not do this per default to allow the user to deselect the chart OLE with a single press to ESC
     // select chart area per default:
-    // select( uno::makeAny( ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_PAGE, OUString() ) ) );
+    // select( uno::Any( ObjectIdentifier::createClassifiedIdentifier( OBJECTTYPE_PAGE, OUString() ) ) );
 
     uno::Reference< lang::XMultiServiceFactory > xFact( getModel(), uno::UNO_QUERY );
     if( xFact.is())
@@ -668,8 +637,9 @@ sal_Bool SAL_CALL ChartController::attachModel( const uno::Reference< frame::XMo
     //the frameloader is responsible to call xModel->connectController
     {
         SolarMutexGuard aGuard2;
-        if( m_pChartWindow )
-            m_pChartWindow->Invalidate();
+        auto pChartWindow(GetChartWindow());
+        if( pChartWindow )
+            pChartWindow->Invalidate();
     }
 
     uno::Reference< document::XUndoManagerSupplier > xSuppUndo( getModel(), uno::UNO_QUERY_THROW );
@@ -679,7 +649,6 @@ sal_Bool SAL_CALL ChartController::attachModel( const uno::Reference< frame::XMo
 }
 
 uno::Reference< frame::XFrame > SAL_CALL ChartController::getFrame()
-    throw(uno::RuntimeException, std::exception)
 {
     //provides access to owner frame of this controller
     //return the frame containing this controller
@@ -688,7 +657,6 @@ uno::Reference< frame::XFrame > SAL_CALL ChartController::getFrame()
 }
 
 uno::Reference< frame::XModel > SAL_CALL ChartController::getModel()
-    throw(uno::RuntimeException, std::exception)
 {
     //provides access to currently attached model
     //returns the currently attached model
@@ -702,7 +670,6 @@ uno::Reference< frame::XModel > SAL_CALL ChartController::getModel()
 }
 
 uno::Any SAL_CALL ChartController::getViewData()
-    throw(uno::RuntimeException, std::exception)
 {
     //provides access to current view status
     //set of data that can be used to restore the current view status at later time
@@ -721,7 +688,6 @@ uno::Any SAL_CALL ChartController::getViewData()
 
 void SAL_CALL ChartController::restoreViewData(
     const uno::Any& /* Value */ )
-        throw(uno::RuntimeException, std::exception)
 {
     //restores the view status using the data gotten from a previous call to XController::getViewData()
 
@@ -733,7 +699,6 @@ void SAL_CALL ChartController::restoreViewData(
 }
 
 sal_Bool SAL_CALL ChartController::suspend( sal_Bool bSuspend )
-    throw(uno::RuntimeException, std::exception)
 {
     //is called to prepare the controller for closing the view
     //bSuspend==true: force the controller to suspend his work
@@ -772,7 +737,7 @@ void ChartController::impl_createDrawViewController()
     {
         if( m_pDrawModelWrapper )
         {
-            m_pDrawViewWrapper = new DrawViewWrapper(&m_pDrawModelWrapper->getSdrModel(),m_pChartWindow);
+            m_pDrawViewWrapper = new DrawViewWrapper(&m_pDrawModelWrapper->getSdrModel(),GetChartWindow());
             m_pDrawViewWrapper->attachParentReferenceDevice( getModel() );
         }
     }
@@ -792,7 +757,6 @@ void ChartController::impl_deleteDrawViewController()
 // XComponent (base of XController)
 
 void SAL_CALL ChartController::dispose()
-    throw(uno::RuntimeException, std::exception)
 {
     m_bDisposed = true;
 
@@ -840,8 +804,9 @@ void SAL_CALL ChartController::dispose()
 
         //--release all resources and references
         {
-            uno::Reference< chart2::X3DChartWindowProvider > x3DWindowProvider(getModel(), uno::UNO_QUERY_THROW);
-            x3DWindowProvider->setWindow(0);
+            uno::Reference< chart2::X3DChartWindowProvider > x3DWindowProvider(getModel(), uno::UNO_QUERY);
+            if(x3DWindowProvider.is())
+                x3DWindowProvider->setWindow(0);
 
             uno::Reference< util::XModeChangeBroadcaster > xViewBroadcaster( m_xChartView, uno::UNO_QUERY );
             if( xViewBroadcaster.is() )
@@ -855,9 +820,8 @@ void SAL_CALL ChartController::dispose()
             m_apDropTargetHelper.reset();
 
             //the accessible view is disposed within window destructor of m_pChartWindow
-            m_pChartWindow->clear();
-            m_pChartWindow = nullptr;//m_pChartWindow is deleted via UNO due to dispose of m_xViewWindow (triggered by Framework (Controller pretends to be XWindow also))
-            m_xViewWindow->dispose();
+            if(m_xViewWindow.is())
+                m_xViewWindow->dispose(); //ChartWindow is deleted via UNO due to dispose of m_xViewWindow (triggered by Framework (Controller pretends to be XWindow also))
             m_xChartView.clear();
         }
 
@@ -890,7 +854,7 @@ void SAL_CALL ChartController::dispose()
             }
             catch( const uno::Exception & ex )
             {
-                ASSERT_EXCEPTION( ex );
+                SAL_WARN("chart2", "Exception caught. " << ex );
             }
 #endif
             aModelRef->tryTermination();
@@ -904,13 +868,13 @@ void SAL_CALL ChartController::dispose()
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        assert(!m_xChartView.is());
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
  }
 
 void SAL_CALL ChartController::addEventListener(
     const uno::Reference<lang::XEventListener>& xListener )
-        throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     if( impl_isDisposedOrSuspended() )//@todo? allow adding of listeners in suspend mode?
@@ -922,7 +886,6 @@ void SAL_CALL ChartController::addEventListener(
 
 void SAL_CALL ChartController::removeEventListener(
     const uno::Reference<lang::XEventListener>& xListener )
-        throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     if( m_aLifeTimeManager.impl_isDisposed(false) )
@@ -936,7 +899,6 @@ void SAL_CALL ChartController::removeEventListener(
 void SAL_CALL ChartController::queryClosing(
     const lang::EventObject& rSource,
     sal_Bool /*bGetsOwnership*/ )
-        throw(util::CloseVetoException, uno::RuntimeException, std::exception)
 {
     //do not use the m_aControllerMutex here because this call is not allowed to block
 
@@ -956,7 +918,6 @@ void SAL_CALL ChartController::queryClosing(
 
 void SAL_CALL ChartController::notifyClosing(
     const lang::EventObject& rSource )
-        throw(uno::RuntimeException, std::exception)
 {
     //Listener should deregister himself and release all references to the closing object.
 
@@ -1008,7 +969,6 @@ bool ChartController::impl_releaseThisModel(
 // util::XEventListener (base of XCloseListener)
 void SAL_CALL ChartController::disposing(
     const lang::EventObject& rSource )
-        throw(uno::RuntimeException, std::exception)
 {
     if( !impl_releaseThisModel( rSource.Source ))
     {
@@ -1021,7 +981,6 @@ void SAL_CALL ChartController::layoutEvent(
     const lang::EventObject& aSource,
     sal_Int16 eLayoutEvent,
     const uno::Any& /* aInfo */ )
-        throw (uno::RuntimeException, std::exception)
 {
     if( eLayoutEvent == frame::LayoutManagerEvents::MERGEDMENUBAR )
     {
@@ -1102,7 +1061,6 @@ uno::Reference<frame::XDispatch> SAL_CALL
         const util::URL& rURL,
         const OUString& rTargetFrameName,
         sal_Int32 /* nSearchFlags */)
-            throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -1117,7 +1075,6 @@ uno::Reference<frame::XDispatch> SAL_CALL
 uno::Sequence<uno::Reference<frame::XDispatch > >
     ChartController::queryDispatches(
         const uno::Sequence<frame::DispatchDescriptor>& xDescripts )
-            throw(uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
@@ -1133,11 +1090,23 @@ uno::Sequence<uno::Reference<frame::XDispatch > >
 void SAL_CALL ChartController::dispatch(
     const util::URL& rURL,
     const uno::Sequence< beans::PropertyValue >& rArgs )
-        throw (uno::RuntimeException, std::exception)
 {
     OUString aCommand = rURL.Path;
 
-    if(aCommand == "Paste")
+    if(aCommand == "LOKSetTextSelection")
+    {
+        if (rArgs.getLength() == 3)
+        {
+            sal_Int32 nType = -1;
+            rArgs[0].Value >>= nType;
+            sal_Int32 nX = 0;
+            rArgs[1].Value >>= nX;
+            sal_Int32 nY = 0;
+            rArgs[2].Value >>= nY;
+            executeDispatch_LOKSetTextSelection(nType, nX, nY);
+        }
+    }
+    else if(aCommand == "Paste")
         this->executeDispatch_Paste();
     else if(aCommand == "Copy" )
         this->executeDispatch_Copy();
@@ -1149,8 +1118,9 @@ void SAL_CALL ChartController::dispatch(
     {
         ChartViewHelper::setViewToDirtyState( getModel() );
         SolarMutexGuard aGuard;
-        if( m_pChartWindow )
-            m_pChartWindow->Invalidate();
+        auto pChartWindow(GetChartWindow());
+        if( pChartWindow )
+            pChartWindow->Invalidate();
     }
     else if(aCommand == "DiagramData" )
         this->executeDispatch_EditData();
@@ -1316,7 +1286,6 @@ void SAL_CALL ChartController::dispatch(
 void SAL_CALL ChartController::addStatusListener(
     const uno::Reference<frame::XStatusListener >& /* xControl */,
     const util::URL& /* aURL */ )
-        throw (uno::RuntimeException, std::exception)
 {
     //@todo
 }
@@ -1324,7 +1293,6 @@ void SAL_CALL ChartController::addStatusListener(
 void SAL_CALL ChartController::removeStatusListener(
     const uno::Reference<frame::XStatusListener >& /* xControl */,
     const util::URL& /* aURL */ )
-        throw (uno::RuntimeException, std::exception)
 {
     //@todo
 }
@@ -1332,14 +1300,12 @@ void SAL_CALL ChartController::removeStatusListener(
 // XContextMenuInterception (optional interface)
 void SAL_CALL ChartController::registerContextMenuInterceptor(
     const uno::Reference< ui::XContextMenuInterceptor >& /* xInterceptor */)
-        throw(uno::RuntimeException, std::exception)
 {
     //@todo
 }
 
 void SAL_CALL ChartController::releaseContextMenuInterceptor(
     const uno::Reference< ui::XContextMenuInterceptor > & /* xInterceptor */)
-        throw(uno::RuntimeException, std::exception)
 {
     //@todo
 }
@@ -1350,11 +1316,11 @@ void SAL_CALL ChartController::releaseContextMenuInterceptor(
 void ChartController::executeDispatch_ChartType()
 {
     UndoLiveUpdateGuard aUndoGuard(
-        SCH_RESSTR( STR_ACTION_EDIT_CHARTTYPE ), m_xUndoManager );
+        SchResId( STR_ACTION_EDIT_CHARTTYPE ), m_xUndoManager );
 
     SolarMutexGuard aSolarGuard;
     //prepare and open dialog
-    ScopedVclPtrInstance< ChartTypeDialog > aDlg( m_pChartWindow, getModel() );
+    ScopedVclPtrInstance< ChartTypeDialog > aDlg( GetChartWindow(), getModel() );
     if( aDlg->Execute() == RET_OK )
     {
         impl_adaptDataSeriesAutoResize();
@@ -1371,11 +1337,11 @@ void ChartController::executeDispatch_SourceData()
         return;
 
     UndoLiveUpdateGuard aUndoGuard(
-        SCH_RESSTR(STR_ACTION_EDIT_DATA_RANGES), m_xUndoManager );
+        SchResId(STR_ACTION_EDIT_DATA_RANGES), m_xUndoManager );
     if( xChartDoc.is())
     {
         SolarMutexGuard aSolarGuard;
-        ScopedVclPtrInstance< ::chart::DataSourceDialog > aDlg( m_pChartWindow, xChartDoc, m_xCC );
+        ScopedVclPtrInstance< ::chart::DataSourceDialog > aDlg( GetChartWindow(), xChartDoc, m_xCC );
         if( aDlg->Execute() == RET_OK )
         {
             impl_adaptDataSeriesAutoResize();
@@ -1396,7 +1362,7 @@ void ChartController::executeDispatch_MoveSeries( bool bForward )
     UndoGuardWithSelection aUndoGuard(
         ActionDescriptionProvider::createDescription(
             (bForward ? ActionDescriptionProvider::ActionType::MoveToTop : ActionDescriptionProvider::ActionType::MoveToBottom),
-            SCH_RESSTR(STR_OBJECT_DATASERIES)),
+            SchResId(STR_OBJECT_DATASERIES)),
         m_xUndoManager );
 
     bool bChanged = DiagramHelper::moveSeries( ChartModelHelper::findDiagram( getModel() ), xGivenDataSeries, bForward );
@@ -1410,8 +1376,6 @@ void ChartController::executeDispatch_MoveSeries( bool bForward )
 // ____ XMultiServiceFactory ____
 uno::Reference< uno::XInterface > SAL_CALL
     ChartController::createInstance( const OUString& aServiceSpecifier )
-    throw (uno::Exception,
-           uno::RuntimeException, std::exception)
 {
     uno::Reference< uno::XInterface > xResult;
 
@@ -1424,7 +1388,6 @@ uno::Reference< uno::XInterface > SAL_CALL
     ChartController::createInstanceWithArguments(
         const OUString& ServiceSpecifier,
         const uno::Sequence< uno::Any >& /* Arguments */ )
-            throw (uno::Exception, uno::RuntimeException, std::exception)
 {
     // ignore Arguments
     return createInstance( ServiceSpecifier );
@@ -1432,7 +1395,6 @@ uno::Reference< uno::XInterface > SAL_CALL
 
 uno::Sequence< OUString > SAL_CALL
     ChartController::getAvailableServiceNames()
-        throw (uno::RuntimeException, std::exception)
 {
     uno::Sequence< OUString > aServiceNames { CHART_ACCESSIBLE_TEXT_SERVICE_NAME };
     return aServiceNames;
@@ -1441,7 +1403,6 @@ uno::Sequence< OUString > SAL_CALL
 // ____ XModifyListener ____
 void SAL_CALL ChartController::modified(
     const lang::EventObject& /* aEvent */ )
-        throw (uno::RuntimeException, std::exception)
 {
     // the source can also be a subobject of the ChartModel
     // @todo: change the source in ChartModel to always be the model itself ?
@@ -1493,6 +1454,34 @@ DrawViewWrapper* ChartController::GetDrawViewWrapper()
     return m_pDrawViewWrapper;
 }
 
+
+VclPtr<ChartWindow> ChartController::GetChartWindow()
+{
+    // clients getting the naked VCL Window from UNO should always have the
+    // solar mutex (and keep it over the lifetime of this ptr), as VCL might
+    // might deinit otherwise
+    DBG_TESTSOLARMUTEX();
+    if(!m_xViewWindow.is())
+        return nullptr;
+    return dynamic_cast<ChartWindow*>(VCLUnoHelper::GetWindow(m_xViewWindow).get());
+}
+
+bool ChartController::isAdditionalShapeSelected()
+{
+    return m_aSelection.isAdditionalShapeSelected();
+}
+
+void ChartController::SetAndApplySelection(const Reference<drawing::XShape>& rxShape)
+{
+    if(rxShape.is())
+    {
+        m_aSelection.setSelection(rxShape);
+        m_aSelection.applySelection(GetDrawViewWrapper());
+    }
+}
+
+
+
 uno::Reference< XAccessible > ChartController::CreateAccessible()
 {
     uno::Reference< XAccessible > xResult = new AccessibleChartView( GetDrawViewWrapper() );
@@ -1503,9 +1492,10 @@ uno::Reference< XAccessible > ChartController::CreateAccessible()
 void ChartController::impl_invalidateAccessible()
 {
     SolarMutexGuard aGuard;
-    if( m_pChartWindow )
+    auto pChartWindow(GetChartWindow());
+    if( pChartWindow )
     {
-        Reference< lang::XInitialization > xInit( m_pChartWindow->GetAccessible(false), uno::UNO_QUERY );
+        Reference< lang::XInitialization > xInit( pChartWindow->GetAccessible(false), uno::UNO_QUERY );
         if(xInit.is())
         {
             uno::Sequence< uno::Any > aArguments(3);//empty arguments -> invalid accessible
@@ -1516,39 +1506,39 @@ void ChartController::impl_invalidateAccessible()
 void ChartController::impl_initializeAccessible()
 {
     SolarMutexGuard aGuard;
-    if( m_pChartWindow )
-        this->impl_initializeAccessible( Reference< lang::XInitialization >( m_pChartWindow->GetAccessible(false), uno::UNO_QUERY ) );
+    auto pChartWindow(GetChartWindow());
+    if( pChartWindow )
+        this->impl_initializeAccessible( Reference< lang::XInitialization >( pChartWindow->GetAccessible(false), uno::UNO_QUERY ) );
 }
 void ChartController::impl_initializeAccessible( const uno::Reference< lang::XInitialization >& xInit )
 {
     if(xInit.is())
     {
         uno::Sequence< uno::Any > aArguments(5);
-        uno::Reference<view::XSelectionSupplier> xSelectionSupplier(this);
-        aArguments[0]=uno::makeAny(xSelectionSupplier);
-        uno::Reference<frame::XModel> xModel(getModel());
-        aArguments[1]=uno::makeAny(xModel);
-        aArguments[2]=uno::makeAny(m_xChartView);
+        aArguments[0] <<= uno::Reference<view::XSelectionSupplier>(this);
+        aArguments[1] <<= uno::Reference<frame::XModel>(getModel());
+        aArguments[2] <<= m_xChartView;
         uno::Reference< XAccessible > xParent;
         {
             SolarMutexGuard aGuard;
-            if( m_pChartWindow )
+            auto pChartWindow(GetChartWindow());
+            if( pChartWindow )
             {
-                vcl::Window* pParentWin( m_pChartWindow->GetAccessibleParentWindow());
+                vcl::Window* pParentWin( pChartWindow->GetAccessibleParentWindow());
                 if( pParentWin )
                     xParent.set( pParentWin->GetAccessible());
             }
         }
-        aArguments[3]=uno::makeAny(xParent);
-        aArguments[4]=uno::makeAny(m_xViewWindow);
+        aArguments[3] <<= xParent;
+        aArguments[4] <<= m_xViewWindow;
 
         xInit->initialize(aArguments);
     }
 }
 
-const ::std::set< OUString >& ChartController::impl_getAvailableCommands()
+const std::set< OUString >& ChartController::impl_getAvailableCommands()
 {
-    static ::std::set< OUString > s_AvailableCommands {
+    static std::set< OUString > s_AvailableCommands {
         // commands for container forward
         "AddDirect",           "NewDoc",                "Open",
         "Save",                "SaveAs",                "SendMail",
