@@ -17,52 +17,47 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "ChartController.hxx"
+#include <memory>
+#include <ChartController.hxx>
 
-#include "dlg_InsertAxis_Grid.hxx"
-#include "dlg_InsertDataLabel.hxx"
-#include "dlg_InsertLegend.hxx"
-#include "dlg_InsertErrorBars.hxx"
-#include "dlg_InsertTitle.hxx"
-#include "dlg_ObjectProperties.hxx"
+#include <dlg_InsertAxis_Grid.hxx>
+#include <dlg_InsertDataLabel.hxx>
+#include <dlg_InsertLegend.hxx>
+#include <dlg_InsertErrorBars.hxx>
+#include <dlg_InsertTitle.hxx>
+#include <dlg_ObjectProperties.hxx>
 
-#include "ChartWindow.hxx"
-#include "ChartModelHelper.hxx"
-#include "AxisHelper.hxx"
-#include "TitleHelper.hxx"
-#include "DiagramHelper.hxx"
-#include "macros.hxx"
-#include "chartview/DrawModelWrapper.hxx"
-#include "NumberFormatterWrapper.hxx"
-#include "ViewElementListProvider.hxx"
-#include "MultipleChartConverters.hxx"
-#include "ControllerLockGuard.hxx"
+#include <ChartWindow.hxx>
+#include <ChartModelHelper.hxx>
+#include <AxisHelper.hxx>
+#include <TitleHelper.hxx>
+#include <DiagramHelper.hxx>
+#include <chartview/DrawModelWrapper.hxx>
+#include <NumberFormatterWrapper.hxx>
+#include <ViewElementListProvider.hxx>
+#include <MultipleChartConverters.hxx>
+#include <ControllerLockGuard.hxx>
 #include "UndoGuard.hxx"
-#include "ResId.hxx"
-#include "Strings.hrc"
-#include "ReferenceSizeProvider.hxx"
-#include "ObjectIdentifier.hxx"
-#include "RegressionCurveHelper.hxx"
-#include "RegressionCurveItemConverter.hxx"
-#include "StatisticsHelper.hxx"
-#include "ErrorBarItemConverter.hxx"
-#include "MultipleItemConverter.hxx"
-#include "DataSeriesHelper.hxx"
-#include "ObjectNameProvider.hxx"
-#include "LegendHelper.hxx"
+#include <ResId.hxx>
+#include <strings.hrc>
+#include <ReferenceSizeProvider.hxx>
+#include <ObjectIdentifier.hxx>
+#include <RegressionCurveHelper.hxx>
+#include <RegressionCurveItemConverter.hxx>
+#include <StatisticsHelper.hxx>
+#include <ErrorBarItemConverter.hxx>
+#include <MultipleItemConverter.hxx>
+#include <DataSeriesHelper.hxx>
+#include <ObjectNameProvider.hxx>
+#include <LegendHelper.hxx>
 
 #include <com/sun/star/chart2/XRegressionCurve.hpp>
 #include <com/sun/star/chart/ErrorBarStyle.hpp>
 #include <svx/ActionDescriptionProvider.hxx>
 
-// header for define RET_OK
 #include <vcl/msgbox.hxx>
-// header for class OUStringBuffer
 #include <rtl/ustrbuf.hxx>
-// header for class Application
 #include <vcl/svapp.hxx>
-// header for class ::vos::OGuard
-#include <osl/mutex.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::chart2;
@@ -71,27 +66,17 @@ using ::com::sun::star::uno::Sequence;
 
 namespace
 {
-struct lcl_InsertMeanValueLine
+
+void lcl_InsertMeanValueLine( const uno::Reference< chart2::XDataSeries > & xSeries )
 {
-public:
-    lcl_InsertMeanValueLine( const uno::Reference< uno::XComponentContext > & xContext ) :
-            m_xContext( xContext )
-    {}
-
-    void operator()( const uno::Reference< chart2::XDataSeries > & xSeries )
+    uno::Reference< chart2::XRegressionCurveContainer > xRegCurveCnt(
+        xSeries, uno::UNO_QUERY );
+    if( xRegCurveCnt.is())
     {
-        uno::Reference< chart2::XRegressionCurveContainer > xRegCurveCnt(
-            xSeries, uno::UNO_QUERY );
-        if( xRegCurveCnt.is())
-        {
-            ::chart::RegressionCurveHelper::addMeanValueLine(
-                xRegCurveCnt, m_xContext, uno::Reference< beans::XPropertySet >( xSeries, uno::UNO_QUERY ));
-        }
+        ::chart::RegressionCurveHelper::addMeanValueLine(
+            xRegCurveCnt, uno::Reference< beans::XPropertySet >( xSeries, uno::UNO_QUERY ));
     }
-
-private:
-    uno::Reference< uno::XComponentContext > m_xContext;
-};
+}
 
 } // anonymous namespace
 
@@ -102,37 +87,37 @@ void ChartController::executeDispatch_InsertAxes()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_AXES )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_AXES )),
         m_xUndoManager );
 
     try
     {
         InsertAxisOrGridDialogData aDialogInput;
         uno::Reference< XDiagram > xDiagram = ChartModelHelper::findDiagram(getModel());
-        AxisHelper::getAxisOrGridExcistence( aDialogInput.aExistenceList, xDiagram, sal_True );
-        AxisHelper::getAxisOrGridPossibilities( aDialogInput.aPossibilityList, xDiagram, sal_True );
+        AxisHelper::getAxisOrGridExcistence( aDialogInput.aExistenceList, xDiagram );
+        AxisHelper::getAxisOrGridPossibilities( aDialogInput.aPossibilityList, xDiagram );
 
         SolarMutexGuard aGuard;
-        SchAxisDlg aDlg( m_pChartWindow, aDialogInput );
-        if( aDlg.Execute() == RET_OK )
+        ScopedVclPtrInstance<SchAxisDlg> aDlg( GetChartWindow(), aDialogInput );
+        if( aDlg->Execute() == RET_OK )
         {
             // lock controllers till end of block
             ControllerLockGuardUNO aCLGuard( getModel() );
 
             InsertAxisOrGridDialogData aDialogOutput;
-            aDlg.getResult( aDialogOutput );
-            boost::scoped_ptr< ReferenceSizeProvider > mpRefSizeProvider(
+            aDlg->getResult( aDialogOutput );
+            std::unique_ptr< ReferenceSizeProvider > pRefSizeProvider(
                 impl_createReferenceSizeProvider());
             bool bChanged = AxisHelper::changeVisibilityOfAxes( xDiagram
                 , aDialogInput.aExistenceList, aDialogOutput.aExistenceList, m_xCC
-                , mpRefSizeProvider.get() );
+                , pRefSizeProvider.get() );
             if( bChanged )
                 aUndoGuard.commit();
         }
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -140,33 +125,33 @@ void ChartController::executeDispatch_InsertGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_GRIDS )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_GRIDS )),
         m_xUndoManager );
 
     try
     {
         InsertAxisOrGridDialogData aDialogInput;
         uno::Reference< XDiagram > xDiagram = ChartModelHelper::findDiagram(getModel());
-        AxisHelper::getAxisOrGridExcistence( aDialogInput.aExistenceList, xDiagram, sal_False );
-        AxisHelper::getAxisOrGridPossibilities( aDialogInput.aPossibilityList, xDiagram, sal_False );
+        AxisHelper::getAxisOrGridExcistence( aDialogInput.aExistenceList, xDiagram, false );
+        AxisHelper::getAxisOrGridPossibilities( aDialogInput.aPossibilityList, xDiagram, false );
 
         SolarMutexGuard aGuard;
-        SchGridDlg aDlg( m_pChartWindow, aDialogInput );//aItemSet, b3D, bNet, bSecondaryX, bSecondaryY );
-        if( aDlg.Execute() == RET_OK )
+        ScopedVclPtrInstance<SchGridDlg> aDlg(GetChartWindow(), aDialogInput);//aItemSet, b3D, bNet, bSecondaryX, bSecondaryY );
+        if( aDlg->Execute() == RET_OK )
         {
             // lock controllers till end of block
             ControllerLockGuardUNO aCLGuard( getModel() );
             InsertAxisOrGridDialogData aDialogOutput;
-            aDlg.getResult( aDialogOutput );
+            aDlg->getResult( aDialogOutput );
             bool bChanged = AxisHelper::changeVisibilityOfGrids( xDiagram
-                , aDialogInput.aExistenceList, aDialogOutput.aExistenceList, m_xCC );
+                , aDialogInput.aExistenceList, aDialogOutput.aExistenceList );
             if( bChanged )
                 aUndoGuard.commit();
         }
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -174,7 +159,7 @@ void ChartController::executeDispatch_InsertTitles()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_TITLES )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_TITLES )),
         m_xUndoManager );
 
     try
@@ -183,13 +168,13 @@ void ChartController::executeDispatch_InsertTitles()
         aDialogInput.readFromModel( getModel() );
 
         SolarMutexGuard aGuard;
-        SchTitleDlg aDlg( m_pChartWindow, aDialogInput );
-        if( aDlg.Execute() == RET_OK )
+        ScopedVclPtrInstance< SchTitleDlg > aDlg( GetChartWindow(), aDialogInput );
+        if( aDlg->Execute() == RET_OK )
         {
             // lock controllers till end of block
             ControllerLockGuardUNO aCLGuard( getModel() );
-            TitleDialogData aDialogOutput( impl_createReferenceSizeProvider().release());
-            aDlg.getResult( aDialogOutput );
+            TitleDialogData aDialogOutput(impl_createReferenceSizeProvider());
+            aDlg->getResult( aDialogOutput );
             bool bChanged = aDialogOutput.writeDifferenceToModel( getModel(), m_xCC, &aDialogInput );
             if( bChanged )
                 aUndoGuard.commit();
@@ -197,7 +182,7 @@ void ChartController::executeDispatch_InsertTitles()
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -205,11 +190,11 @@ void ChartController::executeDispatch_DeleteLegend()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::DELETE, SCH_RESSTR( STR_OBJECT_LEGEND )),
+            ActionDescriptionProvider::ActionType::Delete, SchResId( STR_OBJECT_LEGEND )),
         m_xUndoManager );
 
-    ChartModel* pModel = dynamic_cast<ChartModel*>(getModel().get());
-    LegendHelper::hideLegend( *pModel );
+    ChartModel& rModel = dynamic_cast<ChartModel&>(*getModel().get());
+    LegendHelper::hideLegend(rModel);
     aUndoGuard.commit();
 }
 
@@ -217,11 +202,11 @@ void ChartController::executeDispatch_InsertLegend()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_LEGEND )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_LEGEND )),
         m_xUndoManager );
 
-    ChartModel* pModel = dynamic_cast<ChartModel*>(getModel().get());
-    Reference< chart2::XLegend > xLegend = LegendHelper::showLegend( *pModel, m_xCC );
+    ChartModel& rModel = dynamic_cast<ChartModel&>(*getModel().get());
+    Reference< chart2::XLegend > xLegend = LegendHelper::showLegend(rModel, m_xCC);
     aUndoGuard.commit();
 }
 
@@ -229,27 +214,27 @@ void ChartController::executeDispatch_OpenLegendDialog()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_LEGEND )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_LEGEND )),
         m_xUndoManager );
 
     try
     {
         //prepare and open dialog
         SolarMutexGuard aGuard;
-        SchLegendDlg aDlg( m_pChartWindow, m_xCC );
-        aDlg.init( getModel() );
-        if( aDlg.Execute() == RET_OK )
+        ScopedVclPtrInstance< SchLegendDlg > aDlg( GetChartWindow(), m_xCC );
+        aDlg->init( getModel() );
+        if( aDlg->Execute() == RET_OK )
         {
             // lock controllers till end of block
             ControllerLockGuardUNO aCLGuard( getModel() );
-            bool bChanged = aDlg.writeToModel( getModel() );
+            bool bChanged = aDlg->writeToModel( getModel() );
             if( bChanged )
                 aUndoGuard.commit();
         }
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -257,7 +242,7 @@ void ChartController::executeDispatch_InsertMenu_DataLabels()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_DATALABELS )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_DATALABELS )),
         m_xUndoManager );
 
     //if a series is selected insert labels for that series only:
@@ -296,12 +281,12 @@ void ChartController::executeDispatch_InsertMenu_DataLabels()
         NumberFormatterWrapper aNumberFormatterWrapper( xNumberFormatsSupplier );
         SvNumberFormatter* pNumberFormatter = aNumberFormatterWrapper.getSvNumberFormatter();
 
-        DataLabelsDialog aDlg( m_pChartWindow, aItemSet, pNumberFormatter);
+        ScopedVclPtrInstance< DataLabelsDialog > aDlg( GetChartWindow(), aItemSet, pNumberFormatter);
 
-        if( aDlg.Execute() == RET_OK )
+        if( aDlg->Execute() == RET_OK )
         {
             SfxItemSet aOutItemSet = aItemConverter.CreateEmptyItemSet();
-            aDlg.FillItemSet( aOutItemSet );
+            aDlg->FillItemSet( aOutItemSet );
             // lock controllers till end of block
             ControllerLockGuardUNO aCLGuard( getModel() );
             bool bChanged = aItemConverter.ApplyItemSet( aOutItemSet );//model should be changed now
@@ -311,7 +296,7 @@ void ChartController::executeDispatch_InsertMenu_DataLabels()
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -319,10 +304,10 @@ void ChartController::executeDispatch_InsertMeanValue()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_AVERAGE_LINE )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_AVERAGE_LINE )),
         m_xUndoManager );
-    lcl_InsertMeanValueLine( m_xCC ).operator()(
-        ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(), getModel() ));
+    lcl_InsertMeanValueLine( ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(),
+                                                                    getModel() ) );
     aUndoGuard.commit();
 }
 
@@ -330,7 +315,7 @@ void ChartController::executeDispatch_InsertMenu_MeanValues()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_AVERAGE_LINE )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_AVERAGE_LINE )),
         m_xUndoManager );
 
     uno::Reference< chart2::XDataSeries > xSeries(
@@ -338,13 +323,15 @@ void ChartController::executeDispatch_InsertMenu_MeanValues()
     if( xSeries.is() )
     {
         //if a series is selected insert mean value only for that series:
-        lcl_InsertMeanValueLine( m_xCC ).operator()(xSeries);
+        lcl_InsertMeanValueLine( xSeries );
     }
     else
     {
-        ::std::vector< uno::Reference< chart2::XDataSeries > > aSeries(
+        std::vector< uno::Reference< chart2::XDataSeries > > aSeries(
             DiagramHelper::getDataSeriesFromDiagram( ChartModelHelper::findDiagram( getModel() )));
-        ::std::for_each( aSeries.begin(), aSeries.end(), lcl_InsertMeanValueLine( m_xCC ));
+
+        for( const auto& xSrs : aSeries )
+            lcl_InsertMeanValueLine( xSrs );
     }
     aUndoGuard.commit();
 }
@@ -372,14 +359,13 @@ void ChartController::executeDispatch_InsertTrendline()
 
     UndoLiveUpdateGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_CURVE )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_CURVE )),
         m_xUndoManager );
 
     uno::Reference< chart2::XRegressionCurve > xCurve =
         RegressionCurveHelper::addRegressionCurve(
-            RegressionCurveHelper::REGRESSION_TYPE_LINEAR,
-            xRegressionCurveContainer,
-            m_xCC );
+            SvxChartRegress::Linear,
+            xRegressionCurveContainer );
 
     uno::Reference< beans::XPropertySet > xProperties( xCurve, uno::UNO_QUERY );
 
@@ -401,14 +387,17 @@ void ChartController::executeDispatch_InsertTrendline()
     aDialogParameter.init( getModel() );
     ViewElementListProvider aViewElementListProvider( m_pDrawModelWrapper.get());
     SolarMutexGuard aGuard;
-    SchAttribTabDlg aDialog( m_pChartWindow, &aItemSet, &aDialogParameter, &aViewElementListProvider,
-                          uno::Reference< util::XNumberFormatsSupplier >( getModel(), uno::UNO_QUERY ));
+    ScopedVclPtrInstance<SchAttribTabDlg> aDialog(
+        GetChartWindow(), &aItemSet, &aDialogParameter,
+        &aViewElementListProvider,
+        uno::Reference< util::XNumberFormatsSupplier >(
+                getModel(), uno::UNO_QUERY ) );
 
     // note: when a user pressed "OK" but didn't change any settings in the
     // dialog, the SfxTabDialog returns "Cancel"
-    if( aDialog.Execute() == RET_OK || aDialog.DialogWasClosedWithOK())
+    if( aDialog->Execute() == RET_OK || aDialog->DialogWasClosedWithOK())
     {
-        const SfxItemSet* pOutItemSet = aDialog.GetOutputItemSet();
+        const SfxItemSet* pOutItemSet = aDialog->GetOutputItemSet();
         if( pOutItemSet )
         {
             ControllerLockGuardUNO aCLGuard( getModel() );
@@ -430,14 +419,14 @@ void ChartController::executeDispatch_InsertErrorBars( bool bYError )
     {
         UndoLiveUpdateGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT,
-                SCH_RESSTR( bYError ? STR_OBJECT_ERROR_BARS_Y : STR_OBJECT_ERROR_BARS_X )),
+                ActionDescriptionProvider::ActionType::Insert,
+                SchResId( bYError ? STR_OBJECT_ERROR_BARS_Y : STR_OBJECT_ERROR_BARS_X )),
             m_xUndoManager );
 
         // add error bars with standard deviation
         uno::Reference< beans::XPropertySet > xErrorBarProp(
-            StatisticsHelper::addErrorBars( xSeries, m_xCC,
-                                            ::com::sun::star::chart::ErrorBarStyle::STANDARD_DEVIATION,
+            StatisticsHelper::addErrorBars( xSeries,
+                                            css::chart::ErrorBarStyle::STANDARD_DEVIATION,
                                             bYError));
 
         // get an appropriate item converter
@@ -456,17 +445,20 @@ void ChartController::executeDispatch_InsertErrorBars( bool bYError )
         aDialogParameter.init( getModel() );
         ViewElementListProvider aViewElementListProvider( m_pDrawModelWrapper.get());
         SolarMutexGuard aGuard;
-        SchAttribTabDlg aDlg( m_pChartWindow, &aItemSet, &aDialogParameter, &aViewElementListProvider,
-                              uno::Reference< util::XNumberFormatsSupplier >( getModel(), uno::UNO_QUERY ));
-        aDlg.SetAxisMinorStepWidthForErrorBarDecimals(
+        ScopedVclPtrInstance<SchAttribTabDlg> aDlg(
+                GetChartWindow(), &aItemSet, &aDialogParameter,
+                &aViewElementListProvider,
+                uno::Reference< util::XNumberFormatsSupplier >(
+                        getModel(), uno::UNO_QUERY ) );
+        aDlg->SetAxisMinorStepWidthForErrorBarDecimals(
             InsertErrorBarsDialog::getAxisMinorStepWidthForErrorBarDecimals( getModel(),
                                                                              m_xChartView, m_aSelection.getSelectedCID()));
 
         // note: when a user pressed "OK" but didn't change any settings in the
         // dialog, the SfxTabDialog returns "Cancel"
-        if( aDlg.Execute() == RET_OK || aDlg.DialogWasClosedWithOK())
+        if( aDlg->Execute() == RET_OK || aDlg->DialogWasClosedWithOK())
         {
-            const SfxItemSet* pOutItemSet = aDlg.GetOutputItemSet();
+            const SfxItemSet* pOutItemSet = aDlg->GetOutputItemSet();
             if( pOutItemSet )
             {
                 ControllerLockGuardUNO aCLGuard( getModel() );
@@ -480,7 +472,7 @@ void ChartController::executeDispatch_InsertErrorBars( bool bYError )
         //if no series is selected insert error bars for all series
         UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT,
+                ActionDescriptionProvider::ActionType::Insert,
                 ObjectNameProvider::getName_ObjectForAllSeries( objType ) ),
             m_xUndoManager );
 
@@ -493,18 +485,18 @@ void ChartController::executeDispatch_InsertErrorBars( bool bYError )
 
             //prepare and open dialog
             SolarMutexGuard aGuard;
-            InsertErrorBarsDialog aDlg(
-                m_pChartWindow, aItemSet,
+            ScopedVclPtrInstance<InsertErrorBarsDialog> aDlg(
+                GetChartWindow(), aItemSet,
                 uno::Reference< chart2::XChartDocument >( getModel(), uno::UNO_QUERY ),
                 bYError ? ErrorBarResources::ERROR_BAR_Y : ErrorBarResources::ERROR_BAR_X);
 
-            aDlg.SetAxisMinorStepWidthForErrorBarDecimals(
+            aDlg->SetAxisMinorStepWidthForErrorBarDecimals(
                 InsertErrorBarsDialog::getAxisMinorStepWidthForErrorBarDecimals( getModel(), m_xChartView, OUString() ) );
 
-            if( aDlg.Execute() == RET_OK )
+            if( aDlg->Execute() == RET_OK )
             {
                 SfxItemSet aOutItemSet = aItemConverter.CreateEmptyItemSet();
-                aDlg.FillItemSet( aOutItemSet );
+                aDlg->FillItemSet( aOutItemSet );
 
                 // lock controllers till end of block
                 ControllerLockGuardUNO aCLGuard( getModel() );
@@ -515,7 +507,7 @@ void ChartController::executeDispatch_InsertErrorBars( bool bYError )
         }
         catch(const uno::RuntimeException& e)
         {
-            ASSERT_EXCEPTION( e );
+            SAL_WARN("chart2", "Exception caught. " << e );
         }
     }
 }
@@ -535,13 +527,14 @@ void ChartController::executeDispatch_InsertTrendlineEquation( bool bInsertR2 )
         uno::Reference< beans::XPropertySet > xEqProp( xRegCurve->getEquationProperties());
         if( xEqProp.is())
         {
-            // using assignment for broken gcc 3.3
-            UndoGuard aUndoGuard = UndoGuard(
+            UndoGuard aUndoGuard(
                 ActionDescriptionProvider::createDescription(
-                    ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_CURVE_EQUATION )),
+                    ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_CURVE_EQUATION )),
                 m_xUndoManager );
-            xEqProp->setPropertyValue( "ShowEquation", uno::makeAny( true ));
-            xEqProp->setPropertyValue( "ShowCorrelationCoefficient", uno::makeAny( bInsertR2 ));
+            xEqProp->setPropertyValue( "ShowEquation", uno::Any( true ));
+            xEqProp->setPropertyValue( "XName", uno::Any( OUString("x") ));
+            xEqProp->setPropertyValue( "YName", uno::Any( OUString("f(x)") ));
+            xEqProp->setPropertyValue( "ShowCorrelationCoefficient", uno::Any( bInsertR2 ));
             aUndoGuard.commit();
         }
     }
@@ -553,11 +546,11 @@ void ChartController::executeDispatch_InsertR2Value()
         ObjectIdentifier::getObjectPropertySet( m_aSelection.getSelectedCID(), getModel() ), uno::UNO_QUERY );
     if( xEqProp.is())
     {
-        UndoGuard aUndoGuard = UndoGuard(
+        UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_CURVE_EQUATION )),
+                ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_CURVE_EQUATION )),
             m_xUndoManager );
-        xEqProp->setPropertyValue( "ShowCorrelationCoefficient", uno::makeAny( true ));
+        xEqProp->setPropertyValue( "ShowCorrelationCoefficient", uno::Any( true ));
         aUndoGuard.commit();
     }
 }
@@ -568,11 +561,11 @@ void ChartController::executeDispatch_DeleteR2Value()
         ObjectIdentifier::getObjectPropertySet( m_aSelection.getSelectedCID(), getModel() ), uno::UNO_QUERY );
     if( xEqProp.is())
     {
-        UndoGuard aUndoGuard = UndoGuard(
+        UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_CURVE_EQUATION )),
+                ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_CURVE_EQUATION )),
             m_xUndoManager );
-        xEqProp->setPropertyValue( "ShowCorrelationCoefficient", uno::makeAny( false ));
+        xEqProp->setPropertyValue( "ShowCorrelationCoefficient", uno::Any( false ));
         aUndoGuard.commit();
     }
 }
@@ -585,7 +578,7 @@ void ChartController::executeDispatch_DeleteMeanValue()
     {
         UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::DELETE, SCH_RESSTR( STR_OBJECT_AVERAGE_LINE )),
+                ActionDescriptionProvider::ActionType::Delete, SchResId( STR_OBJECT_AVERAGE_LINE )),
             m_xUndoManager );
         RegressionCurveHelper::removeMeanValueLine( xRegCurveCnt );
         aUndoGuard.commit();
@@ -600,7 +593,7 @@ void ChartController::executeDispatch_DeleteTrendline()
     {
         UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::DELETE, SCH_RESSTR( STR_OBJECT_CURVE )),
+                ActionDescriptionProvider::ActionType::Delete, SchResId( STR_OBJECT_CURVE )),
             m_xUndoManager );
         RegressionCurveHelper::removeAllExceptMeanValueLine( xRegCurveCnt );
         aUndoGuard.commit();
@@ -615,7 +608,7 @@ void ChartController::executeDispatch_DeleteTrendlineEquation()
     {
         UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::DELETE, SCH_RESSTR( STR_OBJECT_CURVE_EQUATION )),
+                ActionDescriptionProvider::ActionType::Delete, SchResId( STR_OBJECT_CURVE_EQUATION )),
             m_xUndoManager );
         RegressionCurveHelper::removeEquations( xRegCurveCnt );
         aUndoGuard.commit();
@@ -630,7 +623,7 @@ void ChartController::executeDispatch_DeleteErrorBars( bool bYError )
     {
         UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::DELETE, SCH_RESSTR( STR_OBJECT_CURVE )),
+                ActionDescriptionProvider::ActionType::Delete, SchResId( STR_OBJECT_CURVE )),
             m_xUndoManager );
         StatisticsHelper::removeErrorBars( xDataSeries, bYError );
         aUndoGuard.commit();
@@ -643,8 +636,8 @@ void ChartController::executeDispatch_InsertDataLabels()
         ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(), getModel() ), uno::UNO_QUERY );
     if( xSeries.is() )
     {
-        UndoGuard aUndoGuard = UndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::INSERT,
-            SCH_RESSTR( STR_OBJECT_DATALABELS )),
+        UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::ActionType::Insert,
+            SchResId( STR_OBJECT_DATALABELS )),
             m_xUndoManager );
         DataSeriesHelper::insertDataLabelsToSeriesAndAllPoints( xSeries );
         aUndoGuard.commit();
@@ -653,8 +646,8 @@ void ChartController::executeDispatch_InsertDataLabels()
 
 void ChartController::executeDispatch_InsertDataLabel()
 {
-    UndoGuard aUndoGuard = UndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::INSERT,
-        SCH_RESSTR( STR_OBJECT_LABEL )),
+    UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::ActionType::Insert,
+        SchResId( STR_OBJECT_LABEL )),
         m_xUndoManager );
     DataSeriesHelper::insertDataLabelToPoint( ObjectIdentifier::getObjectPropertySet( m_aSelection.getSelectedCID(), getModel() ) );
     aUndoGuard.commit();
@@ -666,8 +659,8 @@ void ChartController::executeDispatch_DeleteDataLabels()
         ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(), getModel() ), uno::UNO_QUERY );
     if( xSeries.is() )
     {
-        UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::DELETE,
-            SCH_RESSTR( STR_OBJECT_DATALABELS )),
+        UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::ActionType::Delete,
+            SchResId( STR_OBJECT_DATALABELS )),
             m_xUndoManager );
         DataSeriesHelper::deleteDataLabelsFromSeriesAndAllPoints( xSeries );
         aUndoGuard.commit();
@@ -676,8 +669,8 @@ void ChartController::executeDispatch_DeleteDataLabels()
 
 void ChartController::executeDispatch_DeleteDataLabel()
 {
-    UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::DELETE,
-        SCH_RESSTR( STR_OBJECT_LABEL )),
+    UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::ActionType::Delete,
+        SchResId( STR_OBJECT_LABEL )),
         m_xUndoManager );
     DataSeriesHelper::deleteDataLabelsFromPoint( ObjectIdentifier::getObjectPropertySet( m_aSelection.getSelectedCID(), getModel() ) );
     aUndoGuard.commit();
@@ -685,8 +678,8 @@ void ChartController::executeDispatch_DeleteDataLabel()
 
 void ChartController::executeDispatch_ResetAllDataPoints()
 {
-    UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::FORMAT,
-        SCH_RESSTR( STR_OBJECT_DATAPOINTS )),
+    UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::ActionType::Format,
+        SchResId( STR_OBJECT_DATAPOINTS )),
         m_xUndoManager );
     uno::Reference< chart2::XDataSeries > xSeries( ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(), getModel() ), uno::UNO_QUERY );
     if( xSeries.is() )
@@ -695,8 +688,8 @@ void ChartController::executeDispatch_ResetAllDataPoints()
 }
 void ChartController::executeDispatch_ResetDataPoint()
 {
-    UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::FORMAT,
-        SCH_RESSTR( STR_OBJECT_DATAPOINT )),
+    UndoGuard aUndoGuard( ActionDescriptionProvider::createDescription( ActionDescriptionProvider::ActionType::Format,
+        SchResId( STR_OBJECT_DATAPOINT )),
         m_xUndoManager );
     uno::Reference< chart2::XDataSeries > xSeries( ObjectIdentifier::getDataSeriesForCID( m_aSelection.getSelectedCID(), getModel() ), uno::UNO_QUERY );
     if( xSeries.is() )
@@ -715,7 +708,7 @@ void ChartController::executeDispatch_InsertAxisTitle()
         {
             UndoGuard aUndoGuard(
             ActionDescriptionProvider::createDescription(
-                ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_TITLE )),
+                ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_TITLE )),
             m_xUndoManager );
 
             Reference< XAxis > xAxis = ObjectIdentifier::getAxisForCID( m_aSelection.getSelectedCID(), getModel() );
@@ -732,14 +725,14 @@ void ChartController::executeDispatch_InsertAxisTitle()
             else
                 eTitleType = TitleHelper::Z_AXIS_TITLE;
 
-            boost::scoped_ptr< ReferenceSizeProvider > apRefSizeProvider( impl_createReferenceSizeProvider());
+            std::unique_ptr< ReferenceSizeProvider > apRefSizeProvider( impl_createReferenceSizeProvider());
             xTitle = TitleHelper::createTitle( eTitleType, ObjectNameProvider::getTitleNameByType(eTitleType), getModel(), m_xCC, apRefSizeProvider.get() );
             aUndoGuard.commit();
         }
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -747,7 +740,7 @@ void ChartController::executeDispatch_InsertAxis()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_AXIS )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_AXIS )),
         m_xUndoManager );
 
     try
@@ -761,7 +754,7 @@ void ChartController::executeDispatch_InsertAxis()
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -769,7 +762,7 @@ void ChartController::executeDispatch_DeleteAxis()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::DELETE, SCH_RESSTR( STR_OBJECT_AXIS )),
+            ActionDescriptionProvider::ActionType::Delete, SchResId( STR_OBJECT_AXIS )),
         m_xUndoManager );
 
     try
@@ -783,7 +776,7 @@ void ChartController::executeDispatch_DeleteAxis()
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -791,7 +784,7 @@ void ChartController::executeDispatch_InsertMajorGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_GRID )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_GRID )),
         m_xUndoManager );
 
     try
@@ -805,7 +798,7 @@ void ChartController::executeDispatch_InsertMajorGrid()
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -813,7 +806,7 @@ void ChartController::executeDispatch_DeleteMajorGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::DELETE, SCH_RESSTR( STR_OBJECT_GRID )),
+            ActionDescriptionProvider::ActionType::Delete, SchResId( STR_OBJECT_GRID )),
         m_xUndoManager );
 
     try
@@ -827,7 +820,7 @@ void ChartController::executeDispatch_DeleteMajorGrid()
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -835,7 +828,7 @@ void ChartController::executeDispatch_InsertMinorGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::INSERT, SCH_RESSTR( STR_OBJECT_GRID )),
+            ActionDescriptionProvider::ActionType::Insert, SchResId( STR_OBJECT_GRID )),
         m_xUndoManager );
 
     try
@@ -851,7 +844,7 @@ void ChartController::executeDispatch_InsertMinorGrid()
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
@@ -859,7 +852,7 @@ void ChartController::executeDispatch_DeleteMinorGrid()
 {
     UndoGuard aUndoGuard(
         ActionDescriptionProvider::createDescription(
-            ActionDescriptionProvider::DELETE, SCH_RESSTR(STR_OBJECT_GRID)),
+            ActionDescriptionProvider::ActionType::Delete, SchResId(STR_OBJECT_GRID)),
         m_xUndoManager );
 
     try
@@ -875,7 +868,7 @@ void ChartController::executeDispatch_DeleteMinorGrid()
     }
     catch(const uno::RuntimeException& e)
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
 }
 
