@@ -17,22 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "ChartModel.hxx"
-#include "servicenames.hxx"
-#include "MediaDescriptorHelper.hxx"
-#include "macros.hxx"
-#include "DataSourceHelper.hxx"
-#include "ChartModelHelper.hxx"
-#include "DiagramHelper.hxx"
-#include "DisposeHelper.hxx"
-#include "ControllerLockGuard.hxx"
-#include "ObjectIdentifier.hxx"
+#include <ChartModel.hxx>
+#include <servicenames.hxx>
+#include <MediaDescriptorHelper.hxx>
+#include <DataSourceHelper.hxx>
+#include <ChartModelHelper.hxx>
+#include <DiagramHelper.hxx>
+#include <DisposeHelper.hxx>
+#include <ControllerLockGuard.hxx>
+#include <ObjectIdentifier.hxx>
 #include "PageBackground.hxx"
-#include "CloneHelper.hxx"
-#include "NameContainer.hxx"
+#include <CloneHelper.hxx>
+#include <NameContainer.hxx>
 #include "UndoManager.hxx"
-#include "ChartView.hxx"
-#include "PopupRequest.hxx"
+#include <ChartView.hxx>
+#include <PopupRequest.hxx>
 #include <svx/charthelper.hxx>
 
 #include <vcl/openglwin.hxx>
@@ -41,6 +40,7 @@
 #include <com/sun/star/chart2/data/XPivotTableDataProvider.hpp>
 
 #include <comphelper/processfactory.hxx>
+#include <comphelper/propertysequence.hxx>
 #include <cppuhelper/supportsservice.hxx>
 
 #include <svl/numuno.hxx>
@@ -599,7 +599,6 @@ void SAL_CALL ChartModel::removeEventListener( const uno::Reference< lang::XEven
         return; //behave passive if already disposed or closed
 
     m_aLifeTimeManager.m_aListenerContainer.removeInterface( cppu::UnoType<lang::XEventListener>::get(), xListener );
-    return;
 }
 
 // util::XCloseBroadcaster (base of XCloseable)
@@ -614,7 +613,6 @@ void SAL_CALL ChartModel::removeCloseListener( const uno::Reference< util::XClos
         return; //behave passive if already disposed or closed
 
     m_aLifeTimeManager.m_aListenerContainer.removeInterface( cppu::UnoType<util::XCloseListener>::get(), xListener );
-    return;
 }
 
 // util::XCloseable
@@ -640,26 +638,8 @@ void SAL_CALL ChartModel::close( sal_Bool bDeliverOwnership )
 
         if( m_aLifeTimeManager.g_close_isNeedToCancelLongLastingCalls( bDeliverOwnership, aVetoException ) )
         {
-            ////you can empty this block, if you never start longlasting calls or
-            ////if your longlasting calls are per default not cancelable (check how you have constructed your LifeTimeManager)
-
-            bool bLongLastingCallsAreCanceled = false;
-            try
-            {
-                //try to cancel running longlasting calls
-                //// @todo
-            }
-            catch (const uno::Exception&)
-            {
-                //// @todo
-                //do not throw anything here!! (without endTryClose)
-            }
-            //if not successful canceled
-            if(!bLongLastingCallsAreCanceled)
-            {
-                m_aLifeTimeManager.g_close_endTryClose( bDeliverOwnership );
-                throw aVetoException;
-            }
+            m_aLifeTimeManager.g_close_endTryClose( bDeliverOwnership );
+            throw aVetoException;
         }
 
     }
@@ -753,25 +733,12 @@ Reference< chart2::data::XDataSource > ChartModel::impl_createDefaultData()
                 xIni->initialize(aArgs);
             }
             //create data
-            uno::Sequence<beans::PropertyValue> aArgs(4);
-            aArgs[0] = beans::PropertyValue(
-                "CellRangeRepresentation", -1,
-                uno::Any( OUString("all") ), beans::PropertyState_DIRECT_VALUE );
-            aArgs[1] = beans::PropertyValue(
-                "HasCategories",
-                -1,
-                uno::Any( true ),
-                beans::PropertyState_DIRECT_VALUE );
-            aArgs[2] = beans::PropertyValue(
-                "FirstCellAsLabel",
-                -1,
-                uno::Any( true ),
-                beans::PropertyState_DIRECT_VALUE );
-            aArgs[3] = beans::PropertyValue(
-                "DataRowSource",
-                -1,
-                uno::Any( css::chart::ChartDataRowSource_COLUMNS ),
-                beans::PropertyState_DIRECT_VALUE );
+            uno::Sequence<beans::PropertyValue> aArgs( comphelper::InitPropertySequence({
+                { "CellRangeRepresentation", uno::Any( OUString("all") ) },
+                { "HasCategories", uno::Any( true ) },
+                { "FirstCellAsLabel", uno::Any( true ) },
+                { "DataRowSource", uno::Any( css::chart::ChartDataRowSource_COLUMNS ) }
+                }));
             xDataSource = m_xInternalDataProvider->createDataSource( aArgs );
         }
     }
@@ -898,7 +865,7 @@ void SAL_CALL ChartModel::setArguments( const Sequence< beans::PropertyValue >&
         }
         catch (const uno::Exception& ex)
         {
-            ASSERT_EXCEPTION( ex );
+            SAL_WARN("chart2", "Exception caught. " << ex );
         }
         unlockControllers();
     }
@@ -919,7 +886,7 @@ Reference< chart2::data::XRangeHighlighter > SAL_CALL ChartModel::getRangeHighli
 {
     if( ! m_xRangeHighlighter.is())
     {
-        uno::Reference< view::XSelectionSupplier > xSelSupp( this->getCurrentController(), uno::UNO_QUERY );
+        uno::Reference< view::XSelectionSupplier > xSelSupp( getCurrentController(), uno::UNO_QUERY );
         if( xSelSupp.is() )
             m_xRangeHighlighter.set( ChartModelHelper::createRangeHighlighter( xSelSupp ));
     }
@@ -1007,7 +974,7 @@ uno::Any SAL_CALL ChartModel::queryInterface( const uno::Type& aType )
         }
         catch (const uno::Exception& ex)
         {
-            ASSERT_EXCEPTION( ex );
+            SAL_WARN("chart2", "Exception caught. " << ex );
         }
     }
 
@@ -1050,7 +1017,6 @@ awt::Size SAL_CALL ChartModel::getVisualAreaSize( ::sal_Int64 nAspect )
 {
     OSL_ENSURE( nAspect == embed::Aspects::MSOLE_CONTENT,
                 "No aspects other than content are supported" );
-    (void)(nAspect); // avoid warning in non-debug builds
     // other possible aspects are MSOLE_THUMBNAIL, MSOLE_ICON and MSOLE_DOCPRINT
 
     return m_aVisualAreaSize;
@@ -1060,7 +1026,6 @@ embed::VisualRepresentation SAL_CALL ChartModel::getPreferredVisualRepresentatio
 {
     OSL_ENSURE( nAspect == embed::Aspects::MSOLE_CONTENT,
                 "No aspects other than content are supported" );
-    (void)(nAspect); // avoid warning in non-debug builds
 
     embed::VisualRepresentation aResult;
 
@@ -1070,7 +1035,7 @@ embed::VisualRepresentation SAL_CALL ChartModel::getPreferredVisualRepresentatio
 
         //get view from old api wrapper
         Reference< datatransfer::XTransferable > xTransferable(
-            this->createInstance( CHART_VIEW_SERVICE_NAME ), uno::UNO_QUERY );
+            createInstance( CHART_VIEW_SERVICE_NAME ), uno::UNO_QUERY );
         if( xTransferable.is() )
         {
             datatransfer::DataFlavor aDataFlavor( lcl_aGDIMetaFileMIMEType,
@@ -1088,7 +1053,7 @@ embed::VisualRepresentation SAL_CALL ChartModel::getPreferredVisualRepresentatio
     }
     catch (const uno::Exception& ex)
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 
     return aResult;
@@ -1098,7 +1063,6 @@ embed::VisualRepresentation SAL_CALL ChartModel::getPreferredVisualRepresentatio
 {
     OSL_ENSURE( nAspect == embed::Aspects::MSOLE_CONTENT,
                 "No aspects other than content are supported" );
-    (void)(nAspect); // avoid warning in non-debug builds
     return embed::EmbedMapUnits::ONE_100TH_MM;
 }
 
@@ -1106,28 +1070,24 @@ embed::VisualRepresentation SAL_CALL ChartModel::getPreferredVisualRepresentatio
 uno::Any SAL_CALL ChartModel::getTransferData( const datatransfer::DataFlavor& aFlavor )
 {
     uno::Any aResult;
-    if( this->isDataFlavorSupported( aFlavor ))
-    {
-        try
-        {
-            //get view from old api wrapper
-            Reference< datatransfer::XTransferable > xTransferable(
-                this->createInstance( CHART_VIEW_SERVICE_NAME ), uno::UNO_QUERY );
-            if( xTransferable.is() &&
-                xTransferable->isDataFlavorSupported( aFlavor ))
-            {
-                aResult = xTransferable->getTransferData( aFlavor );
-            }
-        }
-        catch (const uno::Exception& ex)
-        {
-            ASSERT_EXCEPTION( ex );
-        }
-    }
-    else
-    {
+    if( !isDataFlavorSupported( aFlavor ) )
         throw datatransfer::UnsupportedFlavorException(
             aFlavor.MimeType, static_cast< ::cppu::OWeakObject* >( this ));
+
+    try
+    {
+        //get view from old api wrapper
+        Reference< datatransfer::XTransferable > xTransferable(
+            createInstance( CHART_VIEW_SERVICE_NAME ), uno::UNO_QUERY );
+        if( xTransferable.is() &&
+            xTransferable->isDataFlavorSupported( aFlavor ))
+        {
+            aResult = xTransferable->getTransferData( aFlavor );
+        }
+    }
+    catch (const uno::Exception& ex)
+    {
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 
     return aResult;
@@ -1146,7 +1106,7 @@ Sequence< datatransfer::DataFlavor > SAL_CALL ChartModel::getTransferDataFlavors
 
 sal_Bool SAL_CALL ChartModel::isDataFlavorSupported( const datatransfer::DataFlavor& aFlavor )
 {
-    return aFlavor.MimeType.equals(lcl_aGDIMetaFileMIMETypeHighContrast);
+    return aFlavor.MimeType == lcl_aGDIMetaFileMIMETypeHighContrast;
 }
 
 namespace
@@ -1233,7 +1193,6 @@ Reference< uno::XInterface > SAL_CALL ChartModel::createInstanceWithArguments(
             const OUString& rServiceSpecifier , const Sequence< Any >& Arguments )
 {
     OSL_ENSURE( Arguments.getLength(), "createInstanceWithArguments: Warning: Arguments are ignored" );
-    (void)(Arguments); // avoid warning in non-debug builds
     return createInstance( rServiceSpecifier );
 }
 
@@ -1271,8 +1230,8 @@ Reference< util::XNumberFormatsSupplier > const & ChartModel::getNumberFormatsSu
 // ____ XUnoTunnel ___
 ::sal_Int64 SAL_CALL ChartModel::getSomething( const Sequence< ::sal_Int8 >& aIdentifier )
 {
-    if( aIdentifier.getLength() == 16 && 0 == memcmp( SvNumberFormatsSupplierObj::getUnoTunnelId().getConstArray(),
-                                                         aIdentifier.getConstArray(), 16 ) )
+    if( aIdentifier.getLength() == 16 && memcmp( SvNumberFormatsSupplierObj::getUnoTunnelId().getConstArray(),
+                                                         aIdentifier.getConstArray(), 16 ) == 0 )
     {
         Reference< lang::XUnoTunnel > xTunnel( getNumberFormatsSupplier(), uno::UNO_QUERY );
         if( xTunnel.is() )
@@ -1325,7 +1284,7 @@ uno::Sequence< Reference< chart2::data::XLabeledDataSequence > > SAL_CALL ChartM
 OUString SAL_CALL ChartModel::dump()
 {
     uno::Reference< qa::XDumper > xDumper(
-            this->createInstance( CHART_VIEW_SERVICE_NAME ), uno::UNO_QUERY );
+            createInstance( CHART_VIEW_SERVICE_NAME ), uno::UNO_QUERY );
     if (xDumper.is())
         return xDumper->dump();
 
