@@ -17,14 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "ChartModel.hxx"
-#include "MediaDescriptorHelper.hxx"
-#include "ChartDebugTrace.hxx"
-#include "macros.hxx"
-#include "ChartViewHelper.hxx"
-#include "ChartModelHelper.hxx"
-#include "AxisHelper.hxx"
-#include "ThreeDHelper.hxx"
+#include <memory>
+#include <ChartModel.hxx>
+#include <MediaDescriptorHelper.hxx>
+#include <ChartViewHelper.hxx>
+#include <ChartModelHelper.hxx>
+#include <DataSourceHelper.hxx>
+#include <AxisHelper.hxx>
+#include <ThreeDHelper.hxx>
+#include <DiagramHelper.hxx>
 
 #include <com/sun/star/chart2/LegendPosition.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
@@ -37,21 +38,26 @@
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <com/sun/star/embed/XStorage.hpp>
 #include <com/sun/star/embed/StorageFactory.hpp>
+#include <com/sun/star/io/IOException.hpp>
 #include <com/sun/star/lang/XSingleServiceFactory.hpp>
 #include <com/sun/star/sheet/XSpreadsheetDocument.hpp>
 #include <com/sun/star/uno/XComponentContext.hpp>
 #include <com/sun/star/io/TempFile.hpp>
 #include <com/sun/star/io/XSeekable.hpp>
+#include <com/sun/star/ucb/CommandFailedException.hpp>
+
+#include <com/sun/star/chart2/data/XPivotTableDataProvider.hpp>
 
 #include <ucbhelper/content.hxx>
 #include <unotools/ucbstreamhelper.hxx>
 #include <vcl/cvtgrf.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/storagehelper.hxx>
+#include <comphelper/sequence.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
 
 #include <algorithm>
-#include <functional>
 
 using namespace ::com::sun::star;
 
@@ -61,14 +67,14 @@ using ::osl::MutexGuard;
 
 namespace
 {
-struct lcl_PropNameEquals : public ::std::unary_function< beans::PropertyValue, bool >
+struct lcl_PropNameEquals
 {
-    lcl_PropNameEquals( const OUString & rStrToCompareWith ) :
+    explicit lcl_PropNameEquals( const OUString & rStrToCompareWith ) :
             m_aStr( rStrToCompareWith )
     {}
     bool operator() ( const beans::PropertyValue & rProp )
     {
-        return rProp.Name.equals( m_aStr );
+        return rProp.Name == m_aStr;
     }
 private:
     OUString m_aStr;
@@ -82,10 +88,9 @@ T lcl_getProperty(
     T aResult;
     if( rMediaDescriptor.getLength())
     {
-        OUString aPropName( rPropName );
         const beans::PropertyValue * pIt = rMediaDescriptor.getConstArray();
         const beans::PropertyValue * pEndIt = pIt +  + rMediaDescriptor.getLength();
-        pIt = ::std::find_if( pIt, pEndIt, lcl_PropNameEquals( aPropName ));
+        pIt = std::find_if( pIt, pEndIt, lcl_PropNameEquals( rPropName ));
         if( pIt != pEndIt )
             (*pIt).Value >>= aResult;
     }
@@ -98,7 +103,7 @@ void lcl_addStorageToMediaDescriptor(
 {
     rOutMD.realloc( rOutMD.getLength() + 1 );
     rOutMD[rOutMD.getLength() - 1] = beans::PropertyValue(
-        "Storage", -1, uno::makeAny( xStorage ), beans::PropertyState_DIRECT_VALUE );
+        "Storage", -1, uno::Any( xStorage ), beans::PropertyState_DIRECT_VALUE );
 }
 
 Reference< embed::XStorage > lcl_createStorage(
@@ -114,7 +119,7 @@ Reference< embed::XStorage > lcl_createStorage(
     try
     {
         Reference< io::XStream > xStream(
-            ::ucbhelper::Content( rURL, Reference< ::com::sun::star::ucb::XCommandEnvironment >(), comphelper::getProcessComponentContext()).openStream(),
+            ::ucbhelper::Content( rURL, Reference< css::ucb::XCommandEnvironment >(), comphelper::getProcessComponentContext()).openStream(),
             uno::UNO_QUERY );
 
         Reference< lang::XSingleServiceFactory > xStorageFact( embed::StorageFactory::create( xContext ) );
@@ -126,9 +131,13 @@ Reference< embed::XStorage > lcl_createStorage(
             xStorageFact->createInstanceWithArguments( aStorageArgs ), uno::UNO_QUERY_THROW );
         OSL_ENSURE( xStorage.is(), "No Storage" );
     }
-    catch( const ::com::sun::star::ucb::ContentCreationException & rEx )
+    catch(const css::ucb::ContentCreationException& rEx)
     {
-        ASSERT_EXCEPTION( rEx );
+        SAL_WARN("chart2", "Exception caught. " << rEx );
+    }
+    catch(const css::ucb::CommandFailedException& rEx)
+    {
+        SAL_WARN("chart2", "Exception caught. " << rEx );
     }
 
     return xStorage;
@@ -177,7 +186,7 @@ Reference< document::XFilter > ChartModel::impl_createFilter(
         }
         catch( const uno::Exception & ex )
         {
-            ASSERT_EXCEPTION( ex );
+            SAL_WARN("chart2", "Exception caught. " << ex );
         }
         OSL_ENSURE( xFilter.is(), "Filter not found via factory" );
     }
@@ -185,7 +194,7 @@ Reference< document::XFilter > ChartModel::impl_createFilter(
     // fall-back: create XML-Filter
     if( ! xFilter.is())
     {
-        OSL_TRACE( "No FilterName passed in MediaDescriptor" );
+        SAL_WARN("chart2", "No FilterName passed in MediaDescriptor" );
         xFilter.set(
             m_xContext->getServiceManager()->createInstanceWithContext(
                 "com.sun.star.comp.chart2.XMLFilter", m_xContext ),
@@ -198,9 +207,6 @@ Reference< document::XFilter > ChartModel::impl_createFilter(
 // frame::XStorable2
 
 void SAL_CALL ChartModel::storeSelf( const Sequence< beans::PropertyValue >& rMediaDescriptor )
-    throw (lang::IllegalArgumentException,
-           io::IOException,
-           uno::RuntimeException)
 {
     // only some parameters are allowed (see also SfxBaseModel)
     // "VersionComment", "Author", "InteractionHandler", "StatusIndicator"
@@ -211,31 +217,26 @@ void SAL_CALL ChartModel::storeSelf( const Sequence< beans::PropertyValue >& rMe
 
 // frame::XStorable (base of XStorable2)
 sal_Bool SAL_CALL ChartModel::hasLocation()
-    throw(uno::RuntimeException)
 {
     //@todo guard
     return !m_aResource.isEmpty();
 }
 
 OUString SAL_CALL ChartModel::getLocation()
-    throw(uno::RuntimeException)
 {
     return impl_g_getLocation();
 }
 
 sal_Bool SAL_CALL ChartModel::isReadonly()
-    throw(uno::RuntimeException)
 {
     //@todo guard
     return m_bReadOnly;
 }
 
 void SAL_CALL ChartModel::store()
-    throw(io::IOException,
-          uno::RuntimeException)
 {
     apphelper::LifeTimeGuard aGuard(m_aLifeTimeManager);
-    if(!aGuard.startApiCall(sal_True)) //start LongLastingCall
+    if(!aGuard.startApiCall(true)) //start LongLastingCall
         return; //behave passive if already disposed or closed or throw exception @todo?
 
     OUString aLocation = m_aResource;
@@ -255,17 +256,16 @@ void SAL_CALL ChartModel::store()
 void SAL_CALL ChartModel::storeAsURL(
     const OUString& rURL,
     const uno::Sequence< beans::PropertyValue >& rMediaDescriptor )
-    throw(io::IOException, uno::RuntimeException)
 {
     apphelper::LifeTimeGuard aGuard(m_aLifeTimeManager);
-    if(!aGuard.startApiCall(sal_True)) //start LongLastingCall
+    if(!aGuard.startApiCall(true)) //start LongLastingCall
         return; //behave passive if already disposed or closed or throw exception @todo?
 
     apphelper::MediaDescriptorHelper aMediaDescriptorHelper(rMediaDescriptor);
     uno::Sequence< beans::PropertyValue > aReducedMediaDescriptor(
         aMediaDescriptorHelper.getReducedForModel() );
 
-    m_bReadOnly = sal_False;
+    m_bReadOnly = false;
     aGuard.clear();
 
     // create new storage
@@ -281,14 +281,11 @@ void SAL_CALL ChartModel::storeAsURL(
 void SAL_CALL ChartModel::storeToURL(
     const OUString& rURL,
     const uno::Sequence< beans::PropertyValue >& rMediaDescriptor )
-    throw(io::IOException,
-          uno::RuntimeException)
 {
     apphelper::LifeTimeGuard aGuard(m_aLifeTimeManager);
-    if(!aGuard.startApiCall(sal_True)) //start LongLastingCall
+    if(!aGuard.startApiCall(true)) //start LongLastingCall
         return; //behave passive if already disposed or closed or throw exception @todo?
     //do not change the internal state of the document here
-    //...
 
     aGuard.clear();
 
@@ -320,7 +317,7 @@ void SAL_CALL ChartModel::storeToURL(
         }
         catch( const uno::Exception & ex )
         {
-            ASSERT_EXCEPTION( ex );
+            SAL_WARN("chart2", "Exception caught. " << ex );
         }
     }
     else
@@ -350,7 +347,7 @@ void ChartModel::impl_store(
         }
         catch( const uno::Exception & ex )
         {
-            ASSERT_EXCEPTION( ex );
+            SAL_WARN("chart2", "Exception caught. " << ex );
         }
     }
     else
@@ -358,7 +355,7 @@ void ChartModel::impl_store(
         OSL_FAIL( "No filter" );
     }
 
-    setModified( sal_False );
+    setModified( false );
 
     //#i66865#
     //for data change notification during chart is not loaded:
@@ -372,7 +369,7 @@ void ChartModel::impl_store(
         {
             xPropSet->setPropertyValue(
                 "SavedObject",
-                uno::makeAny( aMDHelper.HierarchicalDocumentName ) );
+                uno::Any( aMDHelper.HierarchicalDocumentName ) );
         }
         catch ( const uno::Exception& )
         {
@@ -383,7 +380,7 @@ void ChartModel::impl_store(
 void ChartModel::insertDefaultChart()
 {
     lockControllers();
-    createInternalDataProvider( sal_False );
+    createInternalDataProvider( false );
     try
     {
         // create default chart
@@ -399,7 +396,7 @@ void ChartModel::insertDefaultChart()
                 if( bSupportsCategories )
                 {
                     aParam.realloc( 1 );
-                    aParam[0] = beans::PropertyValue( "HasCategories", -1, uno::makeAny( true ),
+                    aParam[0] = beans::PropertyValue( "HasCategories", -1, uno::Any( true ),
                                                       beans::PropertyState_DIRECT_VALUE );
                 }
 
@@ -407,7 +404,7 @@ void ChartModel::insertDefaultChart()
 
                 setFirstDiagram( xDiagram );
 
-                bool bIsRTL = Application::GetSettings().GetLayoutRTL();
+                bool bIsRTL = AllSettings::GetMathLayoutRTL();
                 //reverse x axis for rtl charts
                 if( bIsRTL )
                     AxisHelper::setRTLAxisLayout( AxisHelper::getCoordinateSystemByIndex( xDiagram, 0 ) );
@@ -419,13 +416,13 @@ void ChartModel::insertDefaultChart()
                 Reference< beans::XPropertySet > xLegendProperties( xLegend, uno::UNO_QUERY );
                 if( xLegendProperties.is() )
                 {
-                    xLegendProperties->setPropertyValue( "FillStyle", uno::makeAny( drawing::FillStyle_NONE ));
-                    xLegendProperties->setPropertyValue( "LineStyle", uno::makeAny( drawing::LineStyle_NONE ));
-                    xLegendProperties->setPropertyValue( "LineColor", uno::makeAny( static_cast< sal_Int32 >( 0xb3b3b3 ) ));  // gray30
-                    xLegendProperties->setPropertyValue( "FillColor", uno::makeAny( static_cast< sal_Int32 >( 0xe6e6e6 ) ) ); // gray10
+                    xLegendProperties->setPropertyValue( "FillStyle", uno::Any( drawing::FillStyle_NONE ));
+                    xLegendProperties->setPropertyValue( "LineStyle", uno::Any( drawing::LineStyle_NONE ));
+                    xLegendProperties->setPropertyValue( "LineColor", uno::Any( static_cast< sal_Int32 >( 0xb3b3b3 ) ));  // gray30
+                    xLegendProperties->setPropertyValue( "FillColor", uno::Any( static_cast< sal_Int32 >( 0xe6e6e6 ) ) ); // gray10
 
                     if( bIsRTL )
-                        xLegendProperties->setPropertyValue( "AnchorPosition", uno::makeAny( chart2::LegendPosition_LINE_START ));
+                        xLegendProperties->setPropertyValue( "AnchorPosition", uno::Any( chart2::LegendPosition_LINE_START ));
                 }
                 if(xDiagram.is())
                     xDiagram->setLegend( xLegend );
@@ -434,8 +431,8 @@ void ChartModel::insertDefaultChart()
                 Reference< beans::XPropertySet > xDiagramProperties( xDiagram, uno::UNO_QUERY );
                 if( xDiagramProperties.is() )
                 {
-                    xDiagramProperties->setPropertyValue( "RightAngledAxes", uno::makeAny( sal_True ));
-                    xDiagramProperties->setPropertyValue( "D3DScenePerspective", uno::makeAny( drawing::ProjectionMode_PARALLEL ));
+                    xDiagramProperties->setPropertyValue( "RightAngledAxes", uno::Any( true ));
+                    xDiagramProperties->setPropertyValue( "D3DScenePerspective", uno::Any( drawing::ProjectionMode_PARALLEL ));
                     ThreeDHelper::setScheme( xDiagram, ThreeDLookScheme_Realistic );
                 }
 
@@ -445,57 +442,44 @@ void ChartModel::insertDefaultChart()
                     Reference< beans::XPropertySet > xWall( xDiagram->getWall() );
                     if( xWall.is() )
                     {
-                        xWall->setPropertyValue( "LineStyle", uno::makeAny( drawing::LineStyle_SOLID ) );
-                        xWall->setPropertyValue( "FillStyle", uno::makeAny( drawing::FillStyle_NONE ) );
-                        xWall->setPropertyValue( "LineColor", uno::makeAny( static_cast< sal_Int32 >( 0xb3b3b3 ) ) ); // gray30
-                        xWall->setPropertyValue( "FillColor", uno::makeAny( static_cast< sal_Int32 >( 0xe6e6e6 ) ) ); // gray10
+                        xWall->setPropertyValue( "LineStyle", uno::Any( drawing::LineStyle_SOLID ) );
+                        xWall->setPropertyValue( "FillStyle", uno::Any( drawing::FillStyle_NONE ) );
+                        xWall->setPropertyValue( "LineColor", uno::Any( static_cast< sal_Int32 >( 0xb3b3b3 ) ) ); // gray30
+                        xWall->setPropertyValue( "FillColor", uno::Any( static_cast< sal_Int32 >( 0xe6e6e6 ) ) ); // gray10
                     }
                     Reference< beans::XPropertySet > xFloor( xDiagram->getFloor() );
                     if( xFloor.is() )
                     {
-                        xFloor->setPropertyValue( "LineStyle", uno::makeAny( drawing::LineStyle_NONE ) );
-                        xFloor->setPropertyValue( "FillStyle", uno::makeAny( drawing::FillStyle_SOLID ) );
-                        xFloor->setPropertyValue( "LineColor", uno::makeAny( static_cast< sal_Int32 >( 0xb3b3b3 ) ) ); // gray30
-                        xFloor->setPropertyValue( "FillColor", uno::makeAny( static_cast< sal_Int32 >( 0xcccccc ) ) ); // gray20
+                        xFloor->setPropertyValue( "LineStyle", uno::Any( drawing::LineStyle_NONE ) );
+                        xFloor->setPropertyValue( "FillStyle", uno::Any( drawing::FillStyle_SOLID ) );
+                        xFloor->setPropertyValue( "LineColor", uno::Any( static_cast< sal_Int32 >( 0xb3b3b3 ) ) ); // gray30
+                        xFloor->setPropertyValue( "FillColor", uno::Any( static_cast< sal_Int32 >( 0xcccccc ) ) ); // gray20
                     }
 
                 }
             }
             catch( const uno::Exception & ex )
             {
-                ASSERT_EXCEPTION( ex );
+                SAL_WARN("chart2", "Exception caught. " << ex );
             }
         }
         ChartModelHelper::setIncludeHiddenCells( false, *this );
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
-    setModified( sal_False );
+    setModified( false );
     unlockControllers();
-
-#if OSL_DEBUG_LEVEL >= CHART_TRACE_OSL_DEBUG_LEVEL
-    OSL_TRACE( "ChartModel::initNew: Showing ChartDocument structure" );
-    ::chart::debug::ChartDebugTraceDocument( Reference< chart2::XChartDocument >( this ));
-#endif
 }
 
 // frame::XLoadable
 void SAL_CALL ChartModel::initNew()
-    throw (frame::DoubleInitializationException,
-           io::IOException,
-           uno::Exception,
-           uno::RuntimeException)
 {
 }
 
 void SAL_CALL ChartModel::load(
     const Sequence< beans::PropertyValue >& rMediaDescriptor )
-    throw (frame::DoubleInitializationException,
-           io::IOException,
-           uno::Exception,
-           uno::RuntimeException)
 {
     Reference< embed::XStorage > xStorage;
     OUString aURL;
@@ -510,13 +494,13 @@ void SAL_CALL ChartModel::load(
                  aMDHelper.ISSET_InputStream )
         {
             if( aMDHelper.ISSET_FilterName &&
-                (aMDHelper.FilterName.equals( "StarChart 5.0") ||
-                 aMDHelper.FilterName.equals( "StarChart 4.0") ||
-                 aMDHelper.FilterName.equals( "StarChart 3.0") ))
+                (aMDHelper.FilterName == "StarChart 5.0" ||
+                 aMDHelper.FilterName == "StarChart 4.0" ||
+                 aMDHelper.FilterName == "StarChart 3.0" ))
             {
                 attachResource( aMDHelper.URL, rMediaDescriptor );
-                impl_load( rMediaDescriptor, 0 ); // cannot create a storage from binary streams, but I do not need the storage here anyhow
-                m_bReadOnly = sal_True;
+                impl_load( rMediaDescriptor, nullptr ); // cannot create a storage from binary streams, but I do not need the storage here anyhow
+                m_bReadOnly = true;
                 return;
             }
 
@@ -528,7 +512,7 @@ void SAL_CALL ChartModel::load(
                 Sequence< uno::Any > aStorageArgs( 2 );
                 aStorageArgs[0] <<= aMDHelper.Stream;
                 // todo: check if stream is read-only
-                aStorageArgs[1] <<= (embed::ElementModes::READ); //WRITE | embed::ElementModes::NOCREATE);
+                aStorageArgs[1] <<= embed::ElementModes::READ; //WRITE | embed::ElementModes::NOCREATE);
 
                 xStorage.set( xStorageFact->createInstanceWithArguments( aStorageArgs ),
                     uno::UNO_QUERY_THROW );
@@ -539,7 +523,7 @@ void SAL_CALL ChartModel::load(
                 // convert XInputStream to XStorage via the storage factory
                 Sequence< uno::Any > aStorageArgs( 2 );
                 aStorageArgs[0] <<= aMDHelper.InputStream;
-                aStorageArgs[1] <<= (embed::ElementModes::READ);
+                aStorageArgs[1] <<= embed::ElementModes::READ;
 
                 xStorage.set( xStorageFact->createInstanceWithArguments( aStorageArgs ),
                     uno::UNO_QUERY_THROW );
@@ -551,7 +535,7 @@ void SAL_CALL ChartModel::load(
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 
     if( xStorage.is())
@@ -590,7 +574,7 @@ void ChartModel::impl_load(
     if( xStorage.is() )
         impl_loadGraphics( xStorage );
 
-    setModified( sal_False );
+    setModified( false );
 
     // switchToStorage without notifying listeners (which shouldn't exist at
     // this time, anyway)
@@ -627,7 +611,7 @@ void ChartModel::impl_loadGraphics(
 
                     if( xElementStream.is() )
                     {
-                        boost::scoped_ptr< SvStream > apIStm(
+                        std::unique_ptr< SvStream > apIStm(
                             ::utl::UcbStreamHelper::CreateStream(
                                 xElementStream, true ) );
 
@@ -639,7 +623,7 @@ void ChartModel::impl_loadGraphics(
                                     *apIStm.get(),
                                     aGraphic ) )
                             {
-                                m_aGraphicObjectVector.push_back( aGraphic );
+                                m_aGraphicObjectVector.emplace_back(aGraphic );
                             }
                         }
                     }
@@ -654,7 +638,6 @@ void ChartModel::impl_loadGraphics(
 
 // util::XModifiable
 void SAL_CALL ChartModel::impl_notifyModifiedListeners()
-    throw( uno::RuntimeException)
 {
     {
         MutexGuard aGuard( m_aModelMutex );
@@ -665,7 +648,7 @@ void SAL_CALL ChartModel::impl_notifyModifiedListeners()
     ChartViewHelper::setViewToDirtyState( this );
 
     ::cppu::OInterfaceContainerHelper* pIC = m_aLifeTimeManager.m_aListenerContainer
-        .getContainer( ::getCppuType((const uno::Reference< util::XModifyListener >*)0) );
+        .getContainer( cppu::UnoType<util::XModifyListener>::get());
     if( pIC )
     {
         lang::EventObject aEvent( static_cast< lang::XComponent*>(this) );
@@ -680,15 +663,12 @@ void SAL_CALL ChartModel::impl_notifyModifiedListeners()
 }
 
 sal_Bool SAL_CALL ChartModel::isModified()
-    throw(uno::RuntimeException)
 {
     //@todo guard
     return m_bModified;
 }
 
 void SAL_CALL ChartModel::setModified( sal_Bool bModified )
-    throw(beans::PropertyVetoException,
-          uno::RuntimeException)
 {
     apphelper::LifeTimeGuard aGuard(m_aLifeTimeManager);
     if(!aGuard.startApiCall())//@todo ? is this a long lasting call??
@@ -709,37 +689,58 @@ void SAL_CALL ChartModel::setModified( sal_Bool bModified )
 // util::XModifyBroadcaster (base of XModifiable)
 void SAL_CALL ChartModel::addModifyListener(
     const uno::Reference< util::XModifyListener >& xListener )
-    throw(uno::RuntimeException)
 {
     if( m_aLifeTimeManager.impl_isDisposedOrClosed() )
         return; //behave passive if already disposed or closed
 
     m_aLifeTimeManager.m_aListenerContainer.addInterface(
-        ::getCppuType((const uno::Reference< util::XModifyListener >*)0), xListener );
+        cppu::UnoType<util::XModifyListener>::get(), xListener );
 }
 
 void SAL_CALL ChartModel::removeModifyListener(
     const uno::Reference< util::XModifyListener >& xListener )
-    throw(uno::RuntimeException)
 {
     if( m_aLifeTimeManager.impl_isDisposedOrClosed(false) )
         return; //behave passive if already disposed or closed
 
     m_aLifeTimeManager.m_aListenerContainer.removeInterface(
-        ::getCppuType((const uno::Reference< util::XModifyListener >*)0), xListener );
+        cppu::UnoType<util::XModifyListener>::get(), xListener );
 }
 
 // util::XModifyListener
-void SAL_CALL ChartModel::modified( const lang::EventObject& )
-    throw (uno::RuntimeException)
+void SAL_CALL ChartModel::modified( const lang::EventObject& rEvenObject)
 {
-    if( m_nInLoad == 0 )
-        setModified( sal_True );
+    uno::Reference<chart2::data::XPivotTableDataProvider> xPivotTableDataProvider(rEvenObject.Source, uno::UNO_QUERY);
+    if (xPivotTableDataProvider.is())
+    {
+        lockControllers();
+        uno::Reference<chart2::data::XDataProvider> xDataProvider(xPivotTableDataProvider, uno::UNO_QUERY);
+        try
+        {
+            uno::Sequence<beans::PropertyValue> aArguments =
+                DataSourceHelper::createArguments("PivotChart", uno::Sequence<sal_Int32>(), true, true, true);
+
+            Reference<chart2::data::XDataSource> xDataSource(xDataProvider->createDataSource(aArguments));
+            Reference<lang::XMultiServiceFactory> xFactory(getChartTypeManager(), uno::UNO_QUERY);
+            Reference<chart2::XDiagram> xDiagram(getFirstDiagram());
+
+            DiagramHelper::tTemplateWithServiceName aTemplateAndService = DiagramHelper::getTemplateForDiagram(xDiagram, xFactory);
+            css::uno::Reference<css::chart2::XChartTypeTemplate> xChartTypeTemplate(aTemplateAndService.first);
+            xChartTypeTemplate->changeDiagramData(xDiagram, xDataSource, aArguments);
+        }
+        catch (const uno::Exception & ex)
+        {
+            SAL_WARN("chart2", "Exception caught. " << ex);
+        }
+        unlockControllers();
+    }
+
+    if (m_nInLoad == 0)
+        setModified(true);
 }
 
 // lang::XEventListener (base of util::XModifyListener)
 void SAL_CALL ChartModel::disposing( const lang::EventObject& )
-    throw (uno::RuntimeException)
 {
     // child was disposed -- should not happen from outside
 }
@@ -748,11 +749,6 @@ void SAL_CALL ChartModel::disposing( const lang::EventObject& )
 void SAL_CALL ChartModel::loadFromStorage(
     const Reference< embed::XStorage >& xStorage,
     const Sequence< beans::PropertyValue >& rMediaDescriptor )
-    throw (lang::IllegalArgumentException,
-           frame::DoubleInitializationException,
-           io::IOException,
-           uno::Exception,
-           uno::RuntimeException)
 {
     attachResource( OUString(), rMediaDescriptor );
     impl_load( rMediaDescriptor, xStorage );
@@ -761,37 +757,25 @@ void SAL_CALL ChartModel::loadFromStorage(
 void SAL_CALL ChartModel::storeToStorage(
     const Reference< embed::XStorage >& xStorage,
     const Sequence< beans::PropertyValue >& rMediaDescriptor )
-    throw (lang::IllegalArgumentException,
-           io::IOException,
-           uno::Exception,
-           uno::RuntimeException)
 {
     impl_store( rMediaDescriptor, xStorage );
 }
 
 void SAL_CALL ChartModel::switchToStorage( const Reference< embed::XStorage >& xStorage )
-    throw (lang::IllegalArgumentException,
-           io::IOException,
-           uno::Exception,
-           uno::RuntimeException)
 {
     m_xStorage = xStorage;
     impl_notifyStorageChangeListeners();
 }
 
 Reference< embed::XStorage > SAL_CALL ChartModel::getDocumentStorage()
-    throw (io::IOException,
-           uno::Exception,
-           uno::RuntimeException)
 {
     return m_xStorage;
 }
 
 void SAL_CALL ChartModel::impl_notifyStorageChangeListeners()
-    throw( uno::RuntimeException)
 {
     ::cppu::OInterfaceContainerHelper* pIC = m_aLifeTimeManager.m_aListenerContainer
-          .getContainer( ::getCppuType((const uno::Reference< document::XStorageChangeListener >*)0) );
+          .getContainer( cppu::UnoType<document::XStorageChangeListener>::get());
     if( pIC )
     {
         ::cppu::OInterfaceIteratorHelper aIt( *pIC );
@@ -805,23 +789,21 @@ void SAL_CALL ChartModel::impl_notifyStorageChangeListeners()
 }
 
 void SAL_CALL ChartModel::addStorageChangeListener( const Reference< document::XStorageChangeListener >& xListener )
-    throw (uno::RuntimeException)
 {
     if( m_aLifeTimeManager.impl_isDisposedOrClosed() )
         return; //behave passive if already disposed or closed
 
     m_aLifeTimeManager.m_aListenerContainer.addInterface(
-        ::getCppuType((const uno::Reference< document::XStorageChangeListener >*)0), xListener );
+        cppu::UnoType<document::XStorageChangeListener>::get(), xListener );
 }
 
 void SAL_CALL ChartModel::removeStorageChangeListener( const Reference< document::XStorageChangeListener >& xListener )
-    throw (uno::RuntimeException)
 {
     if( m_aLifeTimeManager.impl_isDisposedOrClosed(false) )
         return; //behave passive if already disposed or closed
 
     m_aLifeTimeManager.m_aListenerContainer.removeInterface(
-        ::getCppuType((const uno::Reference< document::XStorageChangeListener >*)0), xListener );
+        cppu::UnoType<document::XStorageChangeListener>::get(), xListener );
 }
 
 } //  namespace chart
