@@ -18,11 +18,9 @@
  */
 
 #include "FormattedString.hxx"
-#include "ContainerHelper.hxx"
 
-#include "CharacterProperties.hxx"
-#include "PropertyHelper.hxx"
-#include "macros.hxx"
+#include <CharacterProperties.hxx>
+#include <PropertyHelper.hxx>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <cppuhelper/supportsservice.hxx>
 
@@ -30,8 +28,6 @@ using namespace ::com::sun::star;
 
 using ::com::sun::star::beans::Property;
 using ::com::sun::star::uno::Sequence;
-using ::com::sun::star::uno::Reference;
-using ::com::sun::star::uno::Any;
 using ::osl::MutexGuard;
 
 namespace
@@ -42,14 +38,9 @@ struct StaticFormattedStringDefaults_Initializer
     ::chart::tPropertyValueMap* operator()()
     {
         static ::chart::tPropertyValueMap aStaticDefaults;
-        lcl_AddDefaultsToMap( aStaticDefaults );
+        ::chart::CharacterProperties::AddDefaultsToMap( aStaticDefaults );
         return &aStaticDefaults;
     }
-private:
-    static void lcl_AddDefaultsToMap( ::chart::tPropertyValueMap & rOutMap )
-    {
-        ::chart::CharacterProperties::AddDefaultsToMap( rOutMap );
-    }
 };
 
 struct StaticFormattedStringDefaults : public rtl::StaticAggregate< ::chart::tPropertyValueMap, StaticFormattedStringDefaults_Initializer >
@@ -67,10 +58,10 @@ struct StaticFormattedStringInfoHelper_Initializer
 private:
     static Sequence< Property > lcl_GetPropertySequence()
     {
-        ::std::vector< ::com::sun::star::beans::Property > aProperties;
+        std::vector< css::beans::Property > aProperties;
         ::chart::CharacterProperties::AddPropertiesToVector( aProperties );
 
-        ::std::sort( aProperties.begin(), aProperties.end(),
+        std::sort( aProperties.begin(), aProperties.end(),
                      ::chart::PropertyNameLess() );
 
         return comphelper::containerToSequence( aProperties );
@@ -101,8 +92,7 @@ struct StaticFormattedStringInfo : public rtl::StaticAggregate< uno::Reference<
 namespace chart
 {
 
-FormattedString::FormattedString(
-        uno::Reference< uno::XComponentContext > const & /* xContext */ ) :
+FormattedString::FormattedString() :
         ::property::OPropertySet( m_aMutex ),
     m_aString(),
     m_xModifyEventForwarder( ModifyListenerHelper::createModifyEventForwarder())
@@ -121,21 +111,18 @@ FormattedString::~FormattedString()
 
 // ____ XCloneable ____
 uno::Reference< util::XCloneable > SAL_CALL FormattedString::createClone()
-    throw (uno::RuntimeException, std::exception)
 {
     return uno::Reference< util::XCloneable >( new FormattedString( *this ));
 }
 
 // ____ XFormattedString ____
 OUString SAL_CALL FormattedString::getString()
-    throw (uno::RuntimeException, std::exception)
 {
     MutexGuard aGuard( GetMutex());
     return m_aString;
 }
 
 void SAL_CALL FormattedString::setString( const OUString& String )
-    throw (uno::RuntimeException, std::exception)
 {
     {
         MutexGuard aGuard( GetMutex());
@@ -148,7 +135,6 @@ void SAL_CALL FormattedString::setString( const OUString& String )
 
 // ____ XModifyBroadcaster ____
 void SAL_CALL FormattedString::addModifyListener( const uno::Reference< util::XModifyListener >& aListener )
-    throw (uno::RuntimeException, std::exception)
 {
     try
     {
@@ -157,12 +143,11 @@ void SAL_CALL FormattedString::addModifyListener( const uno::Reference< util::XM
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 }
 
 void SAL_CALL FormattedString::removeModifyListener( const uno::Reference< util::XModifyListener >& aListener )
-    throw (uno::RuntimeException, std::exception)
 {
     try
     {
@@ -171,20 +156,18 @@ void SAL_CALL FormattedString::removeModifyListener( const uno::Reference< util:
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 }
 
 // ____ XModifyListener ____
 void SAL_CALL FormattedString::modified( const lang::EventObject& aEvent )
-    throw (uno::RuntimeException, std::exception)
 {
     m_xModifyEventForwarder->modified( aEvent );
 }
 
 // ____ XEventListener (base of XModifyListener) ____
 void SAL_CALL FormattedString::disposing( const lang::EventObject& /* Source */ )
-    throw (uno::RuntimeException, std::exception)
 {
     // nothing
 }
@@ -200,18 +183,8 @@ void FormattedString::fireModifyEvent()
     m_xModifyEventForwarder->modified( lang::EventObject( static_cast< uno::XWeak* >( this )));
 }
 
-Sequence< OUString > FormattedString::getSupportedServiceNames_Static()
-{
-    Sequence< OUString > aServices( 2 );
-
-    aServices[ 0 ] = "com.sun.star.chart2.FormattedString";
-    aServices[ 1 ] = "com.sun.star.beans.PropertySet";
-    return aServices;
-}
-
 // ____ OPropertySet ____
 uno::Any FormattedString::GetDefaultValue( sal_Int32 nHandle ) const
-    throw (beans::UnknownPropertyException, uno::RuntimeException)
 {
     const tPropertyValueMap& rStaticDefaults = *StaticFormattedStringDefaults::get();
     tPropertyValueMap::const_iterator aFound( rStaticDefaults.find( nHandle ) );
@@ -228,7 +201,6 @@ uno::Any FormattedString::GetDefaultValue( sal_Int32 nHandle ) const
 
 // ____ XPropertySet ____
 uno::Reference< beans::XPropertySetInfo > SAL_CALL FormattedString::getPropertySetInfo()
-    throw (uno::RuntimeException, std::exception)
 {
     return *StaticFormattedStringInfo::get();
 }
@@ -242,35 +214,29 @@ IMPLEMENT_FORWARD_XTYPEPROVIDER2( FormattedString, FormattedString_Base, ::prope
 
 // implement XServiceInfo methods basing upon getSupportedServiceNames_Static
 OUString SAL_CALL FormattedString::getImplementationName()
-    throw( css::uno::RuntimeException, std::exception )
-{
-    return getImplementationName_Static();
-}
-
-OUString FormattedString::getImplementationName_Static()
 {
     return OUString("com.sun.star.comp.chart.FormattedString");
 }
 
 sal_Bool SAL_CALL FormattedString::supportsService( const OUString& rServiceName )
-    throw( css::uno::RuntimeException, std::exception )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 css::uno::Sequence< OUString > SAL_CALL FormattedString::getSupportedServiceNames()
-    throw( css::uno::RuntimeException, std::exception )
 {
-    return getSupportedServiceNames_Static();
+    return {
+        "com.sun.star.chart2.FormattedString",
+        "com.sun.star.beans.PropertySet" };
 }
 
 } //  namespace chart
 
 extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
-com_sun_star_comp_chart_FormattedString_get_implementation(css::uno::XComponentContext *context,
+com_sun_star_comp_chart_FormattedString_get_implementation(css::uno::XComponentContext *,
         css::uno::Sequence<css::uno::Any> const &)
 {
-    return cppu::acquire(new ::chart::FormattedString(context));
+    return cppu::acquire(new ::chart::FormattedString);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
