@@ -18,20 +18,19 @@
  */
 
 #include "ChartTypeTemplate.hxx"
-#include "PropertyHelper.hxx"
-#include "macros.hxx"
-#include "DataSeriesHelper.hxx"
+#include <PropertyHelper.hxx>
+#include <DataSeriesHelper.hxx>
 #include "DataInterpreter.hxx"
-#include "CommonConverters.hxx"
-#include "ContainerHelper.hxx"
-#include "ChartTypeHelper.hxx"
+#include <CommonConverters.hxx>
+#include <ChartTypeHelper.hxx>
+
+#include <CartesianCoordinateSystem.hxx>
+#include <AxisHelper.hxx>
+#include <LegendHelper.hxx>
+#include <DiagramHelper.hxx>
+#include <AxisIndexDefines.hxx>
+#include <unonames.hxx>
 
-#include "CartesianCoordinateSystem.hxx"
-#include "AxisHelper.hxx"
-#include "LegendHelper.hxx"
-#include "DiagramHelper.hxx"
-#include "ChartDebugTrace.hxx"
-#include "AxisIndexDefines.hxx"
 #include <cppuhelper/component_context.hxx>
 #include <com/sun/star/chart/ChartSolidType.hpp>
 #include <com/sun/star/chart2/AxisType.hpp>
@@ -46,7 +45,6 @@ using namespace ::com::sun::star::chart2;
 
 using ::com::sun::star::uno::Sequence;
 using ::com::sun::star::uno::Reference;
-using ::com::sun::star::uno::Any;
 
 namespace
 {
@@ -65,7 +63,7 @@ void lcl_applyDefaultStyle(
         if( xSeriesProp.is() && xColorScheme.is() )
             xSeriesProp->setPropertyValue(
                 "Color",
-                uno::makeAny( xColorScheme->getColorByIndex( nIndex )));
+                uno::Any( xColorScheme->getColorByIndex( nIndex )));
     }
 }
 
@@ -114,7 +112,7 @@ void lcl_ensureCorrectMissingValueTreatment( const Reference< chart2::XDiagram >
             ::chart::ChartTypeHelper::getSupportedMissingValueTreatments( xChartType ) );
 
         if( aAvailableMissingValueTreatment.getLength() )
-            xDiaProp->setPropertyValue( "MissingValueTreatment", uno::makeAny( aAvailableMissingValueTreatment[0] ) );
+            xDiaProp->setPropertyValue( "MissingValueTreatment", uno::Any( aAvailableMissingValueTreatment[0] ) );
         else
             xDiaProp->setPropertyValue( "MissingValueTreatment", uno::Any() );
     }
@@ -140,7 +138,6 @@ ChartTypeTemplate::~ChartTypeTemplate()
 uno::Reference< XDiagram > SAL_CALL ChartTypeTemplate::createDiagramByDataSource(
     const uno::Reference< data::XDataSource >& xDataSource,
     const uno::Sequence< beans::PropertyValue >& aArguments )
-    throw (uno::RuntimeException)
 {
     Reference< XDiagram > xDia;
 
@@ -168,24 +165,22 @@ uno::Reference< XDiagram > SAL_CALL ChartTypeTemplate::createDiagramByDataSource
         }
 
         Sequence< Reference< XChartType > > aOldChartTypesSeq;
-        FillDiagram( xDia, aData.Series, aData.Categories, aOldChartTypesSeq, true );
+        FillDiagram( xDia, aData.Series, aData.Categories, aOldChartTypesSeq );
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 
     return xDia;
 }
 
 sal_Bool SAL_CALL ChartTypeTemplate::supportsCategories()
-    throw (uno::RuntimeException)
 {
-    return sal_True;
+    return true;
 }
 
 void SAL_CALL ChartTypeTemplate::changeDiagram( const uno::Reference< XDiagram >& xDiagram )
-    throw (uno::RuntimeException)
 {
     if( ! xDiagram.is())
         return;
@@ -218,7 +213,7 @@ void SAL_CALL ChartTypeTemplate::changeDiagram( const uno::Reference< XDiagram >
             if( aData.Categories.is())
             {
                 aParam.realloc( 1 );
-                aParam[0] = beans::PropertyValue( "HasCategories", -1, uno::makeAny( true ),
+                aParam[0] = beans::PropertyValue( "HasCategories", -1, uno::Any( true ),
                                                   beans::PropertyState_DIRECT_VALUE );
             }
             aData = xInterpreter->interpretDataSource( xSource, aParam, aFlatSeriesSeq );
@@ -251,11 +246,11 @@ void SAL_CALL ChartTypeTemplate::changeDiagram( const uno::Reference< XDiagram >
             }
         }
 
-        FillDiagram( xDiagram, aSeriesSeq, aData.Categories, aOldChartTypesSeq, false );
+        FillDiagram( xDiagram, aSeriesSeq, aData.Categories, aOldChartTypesSeq );
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 }
 
@@ -263,7 +258,6 @@ void SAL_CALL ChartTypeTemplate::changeDiagramData(
     const Reference< chart2::XDiagram >& xDiagram,
     const Reference< chart2::data::XDataSource >& xDataSource,
     const Sequence< beans::PropertyValue >& aArguments )
-    throw (uno::RuntimeException)
 {
     if( ! (xDiagram.is() &&
            xDataSource.is()) )
@@ -273,7 +267,7 @@ void SAL_CALL ChartTypeTemplate::changeDiagramData(
     {
         // interpret new data and re-use existing series
         Sequence< Reference< XDataSeries > > aFlatSeriesSeq(
-            ::chart::ContainerHelper::ContainerToSequence( DiagramHelper::getDataSeriesFromDiagram( xDiagram )));
+            comphelper::containerToSequence( DiagramHelper::getDataSeriesFromDiagram( xDiagram )));
         const sal_Int32 nFormerSeriesCount = aFlatSeriesSeq.getLength();
         Reference< chart2::XDataInterpreter > xInterpreter( getDataInterpreter());
         chart2::InterpretedData aData =
@@ -298,29 +292,24 @@ void SAL_CALL ChartTypeTemplate::changeDiagramData(
 
         Sequence< Reference< XChartType > > aChartTypes(
             DiagramHelper::getChartTypesFromDiagram( xDiagram ));
-        sal_Int32 nMax = ::std::min( aChartTypes.getLength(), aSeriesSeq.getLength());
+        sal_Int32 nMax = std::min( aChartTypes.getLength(), aSeriesSeq.getLength());
         for( i=0; i<nMax; ++i )
         {
             Reference< XDataSeriesContainer > xDSCnt( aChartTypes[i], uno::UNO_QUERY_THROW );
             xDSCnt->setDataSeries( aSeriesSeq[i] );
         }
-#if OSL_DEBUG_LEVEL >= CHART_TRACE_OSL_DEBUG_LEVEL
-    OSL_TRACE( "ChartTypeTemplate::changeDiagramData: Showing Diagram structure" );
-    ::chart::debug::ChartDebugTraceDiagram( xDiagram );
-#endif
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 }
 
 sal_Bool SAL_CALL ChartTypeTemplate::matchesTemplate(
     const Reference< chart2::XDiagram >& xDiagram,
     sal_Bool /* bAdaptProperties */ )
-    throw (uno::RuntimeException)
 {
-    sal_Bool bResult = sal_False;
+    bool bResult = false;
 
     if( ! xDiagram.is())
         return bResult;
@@ -337,7 +326,11 @@ sal_Bool SAL_CALL ChartTypeTemplate::matchesTemplate(
         if( bResult )
         {
             Sequence< Reference< XChartType > > aFormerlyUsedChartTypes;
-            const OUString aChartTypeToMatch( getChartTypeForNewSeries(aFormerlyUsedChartTypes)->getChartType());
+            Reference<XChartType> xOldCT = getChartTypeForNewSeries(aFormerlyUsedChartTypes);
+            if (!xOldCT.is())
+                return false;
+
+            const OUString aChartTypeToMatch = xOldCT->getChartType();
             const sal_Int32 nDimensionToMatch = getDimension();
             for( sal_Int32 nCooSysIdx=0; bResult && (nCooSysIdx < aCooSysSeq.getLength()); ++nCooSysIdx )
             {
@@ -348,8 +341,11 @@ sal_Bool SAL_CALL ChartTypeTemplate::matchesTemplate(
                 Sequence< Reference< XChartType > > aChartTypeSeq( xCTCnt->getChartTypes());
                 for( sal_Int32 nCTIdx=0; bResult && (nCTIdx < aChartTypeSeq.getLength()); ++nCTIdx )
                 {
+                    if (!aChartTypeSeq[nCTIdx].is())
+                        return false;
+
                     // match chart type
-                    bResult = bResult && aChartTypeSeq[nCTIdx]->getChartType().equals( aChartTypeToMatch );
+                    bResult = bResult && aChartTypeSeq[nCTIdx]->getChartType() == aChartTypeToMatch;
                     bool bFound=false;
                     bool bAmbiguous=false;
                     // match stacking mode
@@ -364,17 +360,16 @@ sal_Bool SAL_CALL ChartTypeTemplate::matchesTemplate(
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 
     return bResult;
 }
 
 Reference< chart2::XDataInterpreter > SAL_CALL ChartTypeTemplate::getDataInterpreter()
-    throw (uno::RuntimeException)
 {
     if( ! m_xDataInterpreter.is())
-        m_xDataInterpreter.set( new DataInterpreter( GetComponentContext() ) );
+        m_xDataInterpreter.set( new DataInterpreter );
 
     return m_xDataInterpreter;
 }
@@ -384,7 +379,6 @@ void SAL_CALL ChartTypeTemplate::applyStyle(
     ::sal_Int32 nChartTypeIndex,
     ::sal_Int32 /* nSeriesIndex */,
     ::sal_Int32 /* nSeriesCount */ )
-    throw (uno::RuntimeException)
 {
     // sset stacking mode
     Reference< beans::XPropertySet > xSeriesProp( xSeries, uno::UNO_QUERY );
@@ -393,11 +387,11 @@ void SAL_CALL ChartTypeTemplate::applyStyle(
         try
         {
             StackMode eStackMode = getStackMode( nChartTypeIndex );
-            const uno::Any aPropValue = uno::makeAny(
-                ( (eStackMode == StackMode_Y_STACKED) ||
-                  (eStackMode == StackMode_Y_STACKED_PERCENT) )
+            const uno::Any aPropValue = uno::Any(
+                ( (eStackMode == StackMode::YStacked) ||
+                  (eStackMode == StackMode::YStackedPercent) )
                 ? chart2::StackingDirection_Y_STACKING
-                : (eStackMode == StackMode_Z_STACKED )
+                : (eStackMode == StackMode::ZStacked )
                 ? chart2::StackingDirection_Z_STACKING
                 : chart2::StackingDirection_NO_STACKING );
             xSeriesProp->setPropertyValue( "StackingDirection", aPropValue );
@@ -405,7 +399,7 @@ void SAL_CALL ChartTypeTemplate::applyStyle(
             //ensure valid label placement
             {
                 uno::Sequence < sal_Int32 > aAvailablePlacements( ChartTypeHelper::getSupportedLabelPlacements(
-                            getChartTypeForIndex( nChartTypeIndex ), getDimension(), isSwapXAndY(), xSeries ) );
+                            getChartTypeForIndex( nChartTypeIndex ), isSwapXAndY(), xSeries ) );
                 lcl_ensureCorrectLabelPlacement( xSeriesProp, aAvailablePlacements );
 
                 uno::Sequence< sal_Int32 > aAttributedDataPointIndexList;
@@ -416,13 +410,12 @@ void SAL_CALL ChartTypeTemplate::applyStyle(
         }
         catch( const uno::Exception & ex )
         {
-            ASSERT_EXCEPTION( ex );
+            SAL_WARN("chart2", "Exception caught. " << ex );
         }
     }
 }
 
 void SAL_CALL ChartTypeTemplate::applyStyles( const Reference< chart2::XDiagram >& xDiagram )
-    throw (uno::RuntimeException)
 {
     // apply chart-type specific styles, like "symbols on" for example
     Sequence< Sequence< Reference< XDataSeries > > > aNewSeriesSeq(
@@ -439,23 +432,22 @@ void SAL_CALL ChartTypeTemplate::applyStyles( const Reference< chart2::XDiagram
 }
 
 void SAL_CALL ChartTypeTemplate::resetStyles( const Reference< chart2::XDiagram >& xDiagram )
-    throw (uno::RuntimeException)
 {
     // reset number format if we had percent stacking on
-    sal_Bool bPercent = (getStackMode(0) == StackMode_Y_STACKED_PERCENT);
+    bool bPercent = (getStackMode(0) == StackMode::YStackedPercent);
     if( bPercent )
     {
         Sequence< Reference< chart2::XAxis > > aAxisSeq( AxisHelper::getAllAxesOfDiagram( xDiagram ) );
         for( sal_Int32 i=0; i<aAxisSeq.getLength(); ++i )
         {
-            if( 1== AxisHelper::getDimensionIndexOfAxis( aAxisSeq[i], xDiagram ) )
+            if( AxisHelper::getDimensionIndexOfAxis( aAxisSeq[i], xDiagram )== 1 )
             {
                 Reference< beans::XPropertySet > xAxisProp( aAxisSeq[i], uno::UNO_QUERY );
                 if( xAxisProp.is())
                 {
                     // set number format to source format
-                    xAxisProp->setPropertyValue("LinkNumberFormatToSource", uno::makeAny(true));
-                    xAxisProp->setPropertyValue("NumberFormat", uno::Any());
+                    xAxisProp->setPropertyValue(CHART_UNONAME_LINK_TO_SRC_NUMFMT, uno::Any(true));
+                    xAxisProp->setPropertyValue(CHART_UNONAME_NUMFMT, uno::Any());
                 }
             }
         }
@@ -496,7 +488,7 @@ void SAL_CALL ChartTypeTemplate::resetStyles( const Reference< chart2::XDiagram
                             continue;
 
                         uno::Sequence < sal_Int32 > aAvailablePlacements( ChartTypeHelper::getSupportedLabelPlacements(
-                            xChartType, getDimension(), isSwapXAndY(), xSeries ) );
+                            xChartType, isSwapXAndY(), xSeries ) );
                         if(!aAvailablePlacements.getLength())
                             continue;
 
@@ -514,12 +506,10 @@ void SAL_CALL ChartTypeTemplate::resetStyles( const Reference< chart2::XDiagram
         }
     }
 
-    return;
 }
 
 // ____ XServiceName ____
     OUString SAL_CALL ChartTypeTemplate::getServiceName()
-    throw (uno::RuntimeException)
 {
     return m_aServiceName;
 }
@@ -531,7 +521,7 @@ sal_Int32 ChartTypeTemplate::getDimension() const
 
 StackMode ChartTypeTemplate::getStackMode( sal_Int32 /* nChartTypeIndex */ ) const
 {
-    return StackMode_NONE;
+    return StackMode::NONE;
 }
 
 bool ChartTypeTemplate::isSwapXAndY() const
@@ -570,7 +560,7 @@ void ChartTypeTemplate::createCoordinateSystems(
     {
         bool bOk = true;
         for( sal_Int32 i=0; bOk && i<aCoordinateSystems.getLength(); ++i )
-            bOk = bOk && ( xCooSys->getCoordinateSystemType().equals( aCoordinateSystems[i]->getCoordinateSystemType()) &&
+            bOk = bOk && ( xCooSys->getCoordinateSystemType() == aCoordinateSystems[i]->getCoordinateSystemType() &&
                            (xCooSys->getDimension() == aCoordinateSystems[i]->getDimension()) );
         // coordinate systems are ok
         if( bOk )
@@ -636,7 +626,7 @@ void ChartTypeTemplate::adaptScales(
                         {
 
                             Reference< XChartType > xChartType( getChartTypeForNewSeries(Sequence< Reference< XChartType > >() ));
-                            bool bSupportsDates = ::chart::ChartTypeHelper::isSupportingDateAxis( xChartType, 2, nDimensionX );
+                            bool bSupportsDates = ::chart::ChartTypeHelper::isSupportingDateAxis( xChartType, nDimensionX );
                             if( aData.AxisType != AxisType::CATEGORY && ( aData.AxisType != AxisType::DATE || !bSupportsDates) )
                             {
                                 aData.AxisType = AxisType::CATEGORY;
@@ -660,7 +650,7 @@ void ChartTypeTemplate::adaptScales(
                     Reference< chart2::XAxis > xAxis( xCooSys->getAxisByDimension( 1,nI ));
                     if( xAxis.is())
                     {
-                        sal_Bool bPercent = (getStackMode(0) == StackMode_Y_STACKED_PERCENT);
+                        bool bPercent = (getStackMode(0) == StackMode::YStackedPercent);
                         chart2::ScaleData aScaleData = xAxis->getScaleData();
 
                         if( bPercent != (aScaleData.AxisType==AxisType::PERCENT) )
@@ -677,15 +667,14 @@ void ChartTypeTemplate::adaptScales(
         }
         catch( const uno::Exception & ex )
         {
-            ASSERT_EXCEPTION( ex );
+            SAL_WARN("chart2", "Exception caught. " << ex );
         }
     }
 }
 
 void ChartTypeTemplate::adaptDiagram( const Reference< XDiagram > & /* xDiagram */ )
 {
-    return;
-}
+    }
 
 void ChartTypeTemplate::createAxes(
     const Sequence< Reference< XCoordinateSystem > > & rCoordSys )
@@ -693,8 +682,7 @@ void ChartTypeTemplate::createAxes(
     //create missing axes
     if( rCoordSys.getLength() > 0 )
     {
-        sal_Int32 nCooSysIdx = 0;
-        Reference< XCoordinateSystem > xCooSys( rCoordSys[nCooSysIdx] );
+        Reference< XCoordinateSystem > xCooSys( rCoordSys[0] );
         if(!xCooSys.is())
             return;
 
@@ -746,15 +734,15 @@ void ChartTypeTemplate::adaptAxes(
                     if( nAxisIndex == MAIN_AXIS_INDEX || nAxisIndex == SECONDARY_AXIS_INDEX )
                     {
                         // adapt scales
-                        sal_Bool bPercent = (getStackMode(0) == StackMode_Y_STACKED_PERCENT);
+                        bool bPercent = (getStackMode(0) == StackMode::YStackedPercent);
                         if( bPercent && nDim == 1 )
                         {
                             Reference< beans::XPropertySet > xAxisProp( xAxis, uno::UNO_QUERY );
                             if( xAxisProp.is())
                             {
                                 // set number format to source format
-                                xAxisProp->setPropertyValue("LinkNumberFormatToSource", uno::makeAny(true));
-                                xAxisProp->setPropertyValue("NumberFormat", uno::Any());
+                                xAxisProp->setPropertyValue(CHART_UNONAME_LINK_TO_SRC_NUMFMT, uno::Any(true));
+                                xAxisProp->setPropertyValue(CHART_UNONAME_NUMFMT, uno::Any());
                             }
                         }
                     }
@@ -772,9 +760,8 @@ sal_Int32 ChartTypeTemplate::getAxisCountByDimension( sal_Int32 nDimension )
 void ChartTypeTemplate::FillDiagram(
     const Reference< XDiagram >& xDiagram,
     const Sequence< Sequence< Reference< XDataSeries > > >& aSeriesSeq,
-    Reference< data::XLabeledDataSequence > xCategories,
-    const Sequence< Reference< XChartType > >& aOldChartTypesSeq,
-    bool /* bCreate */ )
+    const Reference< data::XLabeledDataSequence >& xCategories,
+    const Sequence< Reference< XChartType > >& aOldChartTypesSeq )
 {
     adaptDiagram( xDiagram );
 
@@ -794,13 +781,8 @@ void ChartTypeTemplate::FillDiagram(
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
-
-#if OSL_DEBUG_LEVEL >= CHART_TRACE_OSL_DEBUG_LEVEL
-    OSL_TRACE( "ChartTypeTemplate::FillDiagram: Showing Diagram structure" );
-    ::chart::debug::ChartDebugTraceDiagram( xDiagram );
-#endif
 }
 
 void ChartTypeTemplate::createChartTypes(
@@ -855,8 +837,8 @@ void ChartTypeTemplate::createChartTypes(
                     Sequence< Reference< XDataSeries > > aNewSeriesSeq( xDSCnt->getDataSeries());
                     sal_Int32 nNewStartIndex = aNewSeriesSeq.getLength();
                     aNewSeriesSeq.realloc( nNewStartIndex + aSeriesSeq[nSeriesIdx].getLength() );
-                    ::std::copy( aSeriesSeq[nSeriesIdx].getConstArray(),
-                                 aSeriesSeq[nSeriesIdx].getConstArray() + aSeriesSeq[nSeriesIdx].getLength(),
+                    std::copy( aSeriesSeq[nSeriesIdx].begin(),
+                                 aSeriesSeq[nSeriesIdx].end(),
                                  aNewSeriesSeq.getArray() + nNewStartIndex );
                     xDSCnt->setDataSeries( aNewSeriesSeq );
                 }
@@ -869,11 +851,11 @@ void ChartTypeTemplate::createChartTypes(
     }
     catch( const uno::Exception & ex )
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 }
 
-void ChartTypeTemplate::copyPropertiesFromOldToNewCoordianteSystem(
+void ChartTypeTemplate::copyPropertiesFromOldToNewCoordinateSystem(
                     const Sequence< Reference< XChartType > > & rOldChartTypesSeq,
                     const Reference< XChartType > & xNewChartType )
 {
@@ -888,7 +870,7 @@ void ChartTypeTemplate::copyPropertiesFromOldToNewCoordianteSystem(
     for( nN=0; nN<rOldChartTypesSeq.getLength();++nN)
     {
         Reference< XChartType > xOldType( rOldChartTypesSeq[nN] );
-        if( xOldType.is() && xOldType->getChartType().equals( aNewChartType ) )
+        if( xOldType.is() && xOldType->getChartType() == aNewChartType )
         {
             xSource.set( Reference< beans::XPropertySet >(xOldType, uno::UNO_QUERY ) );
             if( xSource.is() )
@@ -899,25 +881,6 @@ void ChartTypeTemplate::copyPropertiesFromOldToNewCoordianteSystem(
         comphelper::copyProperties( xSource, xDestination );
 }
 
-// ________
-
-Sequence< OUString > ChartTypeTemplate::getSupportedServiceNames_Static()
-{
-    Sequence< OUString > aServices( 3 );
-    aServices[ 0 ] = "com.sun.star.chart2.ChartTypeTemplate";
-    aServices[ 1 ] = "com.sun.star.layout.LayoutElement";
-    aServices[ 2 ] = "com.sun.star.beans.PropertySet";
-    return aServices;
-}
-
-Reference< uno::XComponentContext > ChartTypeTemplate::GetComponentContext() const
-{
-    return m_xContext;
-}
-
-// implement XServiceInfo methods basing upon getSupportedServiceNames_Static
-APPHELPER_XSERVICEINFO_IMPL( ChartTypeTemplate,
-                             OUString("com.sun.star.comp.chart.ChartTypeTemplate") );
 } //  namespace chart
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
