@@ -17,10 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "SceneProperties.hxx"
-#include "macros.hxx"
-#include "ChartTypeHelper.hxx"
-#include "ThreeDHelper.hxx"
+#include <SceneProperties.hxx>
+#include <ChartTypeHelper.hxx>
+#include <ThreeDHelper.hxx>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/drawing/HomogenMatrix.hpp>
 #include <com/sun/star/drawing/ShadeMode.hpp>
@@ -28,9 +27,6 @@
 #include <com/sun/star/drawing/ProjectionMode.hpp>
 #include <com/sun/star/drawing/CameraGeometry.hpp>
 
-// for F_PI
-#include <tools/solar.h>
-
 using namespace ::com::sun::star;
 
 using ::com::sun::star::beans::Property;
@@ -39,266 +35,233 @@ namespace chart
 {
 
 void SceneProperties::AddPropertiesToVector(
-    ::std::vector< Property > & rOutProperties )
+    std::vector< Property > & rOutProperties )
 {
     // transformation matrix
-    rOutProperties.push_back(
-        Property( "D3DTransformMatrix",
+    rOutProperties.emplace_back( "D3DTransformMatrix",
                   PROP_SCENE_TRANSF_MATRIX,
-                  ::getCppuType( reinterpret_cast< const drawing::HomogenMatrix * >(0)),
+                  cppu::UnoType<drawing::HomogenMatrix>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // distance: deprecated ( this is not used by the chart view; it's only here for compatibility with old chart  )
-    rOutProperties.push_back(
-        Property( "D3DSceneDistance",
+    rOutProperties.emplace_back( "D3DSceneDistance",
                   PROP_SCENE_DISTANCE,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // focalLength: deprecated ( this is not used by the chart view; it's only here for compatibility with old chart  )
-    rOutProperties.push_back(
-        Property( "D3DSceneFocalLength",
+    rOutProperties.emplace_back( "D3DSceneFocalLength",
                   PROP_SCENE_FOCAL_LENGTH,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // shadowSlant
-    rOutProperties.push_back(
-        Property( "D3DSceneShadowSlant",
+    rOutProperties.emplace_back( "D3DSceneShadowSlant",
                   PROP_SCENE_SHADOW_SLANT,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // shadeMode
-    rOutProperties.push_back(
-        Property( "D3DSceneShadeMode",
+    rOutProperties.emplace_back( "D3DSceneShadeMode",
                   PROP_SCENE_SHADE_MODE,
-                  ::getCppuType( reinterpret_cast< const drawing::ShadeMode * >(0)),
+                  cppu::UnoType<drawing::ShadeMode>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // ambientColor
-    rOutProperties.push_back(
-        Property( "D3DSceneAmbientColor",
+    rOutProperties.emplace_back( "D3DSceneAmbientColor",
                   PROP_SCENE_AMBIENT_COLOR,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // lightingMode
-    rOutProperties.push_back(
-        Property( "D3DSceneTwoSidedLighting",
+    rOutProperties.emplace_back( "D3DSceneTwoSidedLighting",
                   PROP_SCENE_TWO_SIDED_LIGHTING,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // camera geometry
-    rOutProperties.push_back(
-        Property( "D3DCameraGeometry",
+    rOutProperties.emplace_back( "D3DCameraGeometry",
                   PROP_SCENE_CAMERA_GEOMETRY,
-                  ::getCppuType( reinterpret_cast< const drawing::CameraGeometry * >(0)),
+                  cppu::UnoType<drawing::CameraGeometry>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // perspective
-    rOutProperties.push_back(
-        Property( "D3DScenePerspective",
+    rOutProperties.emplace_back( "D3DScenePerspective",
                   PROP_SCENE_PERSPECTIVE,
-                  ::getCppuType( reinterpret_cast< const drawing::ProjectionMode * >(0)),
+                  cppu::UnoType<drawing::ProjectionMode>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 
     // Light Sources
     // light source 1
-    rOutProperties.push_back(
-        Property( "D3DSceneLightColor1",
+    rOutProperties.emplace_back( "D3DSceneLightColor1",
                   PROP_SCENE_LIGHT_COLOR_1,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightDirection1",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightDirection1",
                   PROP_SCENE_LIGHT_DIRECTION_1,
-                  ::getCppuType( reinterpret_cast< const drawing::Direction3D * >(0)),
+                  cppu::UnoType<drawing::Direction3D>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightOn1",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightOn1",
                   PROP_SCENE_LIGHT_ON_1,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
     // light source 2
-    rOutProperties.push_back(
-        Property( "D3DSceneLightColor2",
+    rOutProperties.emplace_back( "D3DSceneLightColor2",
                   PROP_SCENE_LIGHT_COLOR_2,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightDirection2",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightDirection2",
                   PROP_SCENE_LIGHT_DIRECTION_2,
-                  ::getCppuType( reinterpret_cast< const drawing::Direction3D * >(0)),
+                  cppu::UnoType<drawing::Direction3D>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightOn2",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightOn2",
                   PROP_SCENE_LIGHT_ON_2,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
     // light source 3
-    rOutProperties.push_back(
-        Property( "D3DSceneLightColor3",
+    rOutProperties.emplace_back( "D3DSceneLightColor3",
                   PROP_SCENE_LIGHT_COLOR_3,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightDirection3",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightDirection3",
                   PROP_SCENE_LIGHT_DIRECTION_3,
-                  ::getCppuType( reinterpret_cast< const drawing::Direction3D * >(0)),
+                  cppu::UnoType<drawing::Direction3D>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightOn3",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightOn3",
                   PROP_SCENE_LIGHT_ON_3,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
     // light source 4
-    rOutProperties.push_back(
-        Property( "D3DSceneLightColor4",
+    rOutProperties.emplace_back( "D3DSceneLightColor4",
                   PROP_SCENE_LIGHT_COLOR_4,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightDirection4",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightDirection4",
                   PROP_SCENE_LIGHT_DIRECTION_4,
-                  ::getCppuType( reinterpret_cast< const drawing::Direction3D * >(0)),
+                  cppu::UnoType<drawing::Direction3D>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightOn4",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightOn4",
                   PROP_SCENE_LIGHT_ON_4,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
     // light source 5
-    rOutProperties.push_back(
-        Property( "D3DSceneLightColor5",
+    rOutProperties.emplace_back( "D3DSceneLightColor5",
                   PROP_SCENE_LIGHT_COLOR_5,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightDirection5",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightDirection5",
                   PROP_SCENE_LIGHT_DIRECTION_5,
-                  ::getCppuType( reinterpret_cast< const drawing::Direction3D * >(0)),
+                  cppu::UnoType<drawing::Direction3D>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightOn5",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightOn5",
                   PROP_SCENE_LIGHT_ON_5,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
     // light source 6
-    rOutProperties.push_back(
-        Property( "D3DSceneLightColor6",
+    rOutProperties.emplace_back( "D3DSceneLightColor6",
                   PROP_SCENE_LIGHT_COLOR_6,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightDirection6",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightDirection6",
                   PROP_SCENE_LIGHT_DIRECTION_6,
-                  ::getCppuType( reinterpret_cast< const drawing::Direction3D * >(0)),
+                  cppu::UnoType<drawing::Direction3D>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightOn6",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightOn6",
                   PROP_SCENE_LIGHT_ON_6,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
     // light source 7
-    rOutProperties.push_back(
-        Property( "D3DSceneLightColor7",
+    rOutProperties.emplace_back( "D3DSceneLightColor7",
                   PROP_SCENE_LIGHT_COLOR_7,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightDirection7",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightDirection7",
                   PROP_SCENE_LIGHT_DIRECTION_7,
-                  ::getCppuType( reinterpret_cast< const drawing::Direction3D * >(0)),
+                  cppu::UnoType<drawing::Direction3D>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightOn7",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightOn7",
                   PROP_SCENE_LIGHT_ON_7,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
     // light source 8
-    rOutProperties.push_back(
-        Property( "D3DSceneLightColor8",
+    rOutProperties.emplace_back( "D3DSceneLightColor8",
                   PROP_SCENE_LIGHT_COLOR_8,
-                  ::getCppuType( reinterpret_cast< const sal_Int32 * >(0)),
+                  cppu::UnoType<sal_Int32>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightDirection8",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightDirection8",
                   PROP_SCENE_LIGHT_DIRECTION_8,
-                  ::getCppuType( reinterpret_cast< const drawing::Direction3D * >(0)),
+                  cppu::UnoType<drawing::Direction3D>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
-    rOutProperties.push_back(
-        Property( "D3DSceneLightOn8",
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
+    rOutProperties.emplace_back( "D3DSceneLightOn8",
                   PROP_SCENE_LIGHT_ON_8,
-                  ::getBooleanCppuType(),
+                  cppu::UnoType<bool>::get(),
                   beans::PropertyAttribute::BOUND
                   | beans::PropertyAttribute::MAYBEVOID
-                  | beans::PropertyAttribute::MAYBEDEFAULT ));
+                  | beans::PropertyAttribute::MAYBEDEFAULT );
 }
 
 void SceneProperties::AddDefaultsToMap(
@@ -321,7 +284,7 @@ void SceneProperties::AddDefaultsToMap(
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_SHADE_MODE, drawing::ShadeMode_SMOOTH );
 
     ::chart::PropertyHelper::setPropertyValueDefault< sal_Int32 >(
-        rOutMap, PROP_SCENE_AMBIENT_COLOR, ChartTypeHelper::getDefaultAmbientLightColor(ThreeDLookScheme_Simple,0));
+        rOutMap, PROP_SCENE_AMBIENT_COLOR, ChartTypeHelper::getDefaultAmbientLightColor(false,nullptr));
 
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_TWO_SIDED_LIGHTING, true );
 
@@ -343,9 +306,9 @@ void SceneProperties::AddDefaultsToMap(
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_ON_7, false );
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_ON_8, false );
 
-    uno::Any aDefaultLightDirection( uno::makeAny( drawing::Direction3D( 0.0, 0.0, 1.0 ) ) );
+    uno::Any aDefaultLightDirection( drawing::Direction3D( 0.0, 0.0, 1.0 ) );
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_DIRECTION_1, aDefaultLightDirection );
-    ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_DIRECTION_2, ChartTypeHelper::getDefaultSimpleLightDirection(0));
+    ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_DIRECTION_2, ChartTypeHelper::getDefaultSimpleLightDirection(nullptr));
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_DIRECTION_3, aDefaultLightDirection );
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_DIRECTION_4, aDefaultLightDirection );
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_DIRECTION_5, aDefaultLightDirection );
@@ -354,7 +317,7 @@ void SceneProperties::AddDefaultsToMap(
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_DIRECTION_8, aDefaultLightDirection );
 
     uno::Any aDefaultLightColor;
-    aDefaultLightColor <<= ChartTypeHelper::getDefaultDirectLightColor(ThreeDLookScheme_Simple,0);
+    aDefaultLightColor <<= ChartTypeHelper::getDefaultDirectLightColor(false,nullptr);
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_COLOR_1, aDefaultLightColor );
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_COLOR_2, aDefaultLightColor );
     ::chart::PropertyHelper::setPropertyValueDefault( rOutMap, PROP_SCENE_LIGHT_COLOR_3, aDefaultLightColor );
