@@ -17,13 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "comphelper_module.hxx"
-#include "comphelper_services.hxx"
-
 #include <com/sun/star/ucb/XAnyCompareFactory.hpp>
 #include <com/sun/star/i18n/Collator.hpp>
 #include <com/sun/star/lang/Locale.hpp>
 #include <com/sun/star/uno/Sequence.h>
+#include <com/sun/star/uno/XComponentContext.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <cppuhelper/implbase.hxx>
 #include <cppuhelper/supportsservice.hxx>
@@ -43,14 +41,14 @@ class AnyCompare : public ::cppu::WeakImplHelper< XAnyCompare >
     Reference< XCollator > m_xCollator;
 
 public:
-    AnyCompare( Reference< XComponentContext > xContext, const Locale& rLocale )
+    AnyCompare( Reference< XComponentContext > const & xContext, const Locale& rLocale )
     {
         m_xCollator = Collator::create( xContext );
         m_xCollator->loadDefaultCollator( rLocale,
                                           0 ); //???
     }
 
-    virtual sal_Int16 SAL_CALL compare( const Any& any1, const Any& any2 ) throw(RuntimeException, std::exception) override;
+    virtual sal_Int16 SAL_CALL compare( const Any& any1, const Any& any2 ) override;
 };
 
 class AnyCompareFactory : public cppu::WeakImplHelper< XAnyCompareFactory, XInitialization, XServiceInfo >
@@ -60,28 +58,22 @@ class AnyCompareFactory : public cppu::WeakImplHelper< XAnyCompareFactory, XInit
     Locale                              m_Locale;
 
 public:
-    explicit AnyCompareFactory( Reference< XComponentContext > xContext ) : m_xContext( xContext )
+    explicit AnyCompareFactory( Reference< XComponentContext > const & xContext ) : m_xContext( xContext )
     {}
 
     // XAnyCompareFactory
-    virtual Reference< XAnyCompare > SAL_CALL createAnyCompareByName ( const OUString& aPropertyName ) throw(css::uno::RuntimeException, std::exception) override;
+    virtual Reference< XAnyCompare > SAL_CALL createAnyCompareByName ( const OUString& aPropertyName ) override;
 
     // XInitialization
-    virtual void SAL_CALL initialize( const Sequence< Any >& aArguments )
-            throw ( Exception, RuntimeException, std::exception ) override;
+    virtual void SAL_CALL initialize( const Sequence< Any >& aArguments ) override;
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName(  ) throw(RuntimeException, std::exception) override;
-    virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName ) throw(RuntimeException, std::exception) override;
-    virtual Sequence< OUString > SAL_CALL getSupportedServiceNames(  ) throw(RuntimeException, std::exception) override;
-
-    // XServiceInfo - static versions (used for component registration)
-    static OUString SAL_CALL getImplementationName_static();
-    static Sequence< OUString > SAL_CALL getSupportedServiceNames_static();
-    static Reference< XInterface > SAL_CALL Create( const Reference< XComponentContext >& );
+    virtual OUString SAL_CALL getImplementationName(  ) override;
+    virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName ) override;
+    virtual Sequence< OUString > SAL_CALL getSupportedServiceNames(  ) override;
 };
 
-sal_Int16 SAL_CALL AnyCompare::compare( const Any& any1, const Any& any2 ) throw(css::uno::RuntimeException, std::exception)
+sal_Int16 SAL_CALL AnyCompare::compare( const Any& any1, const Any& any2 )
 {
     sal_Int16 aResult = 0;
 
@@ -96,7 +88,7 @@ sal_Int16 SAL_CALL AnyCompare::compare( const Any& any1, const Any& any2 ) throw
     return aResult;
 }
 
-Reference< XAnyCompare > SAL_CALL AnyCompareFactory::createAnyCompareByName( const OUString& aPropertyName ) throw(css::uno::RuntimeException, std::exception)
+Reference< XAnyCompare > SAL_CALL AnyCompareFactory::createAnyCompareByName( const OUString& aPropertyName )
 {
     // for now only OUString properties compare is implemented
     // so no check for the property name is done
@@ -107,7 +99,7 @@ Reference< XAnyCompare > SAL_CALL AnyCompareFactory::createAnyCompareByName( con
     return Reference< XAnyCompare >();
 }
 
-void SAL_CALL AnyCompareFactory::initialize( const Sequence< Any >& aArguments ) throw ( Exception, RuntimeException, std::exception )
+void SAL_CALL AnyCompareFactory::initialize( const Sequence< Any >& aArguments )
 {
     if( aArguments.getLength() )
     {
@@ -119,42 +111,29 @@ void SAL_CALL AnyCompareFactory::initialize( const Sequence< Any >& aArguments )
     }
 }
 
-OUString SAL_CALL AnyCompareFactory::getImplementationName(  ) throw( RuntimeException, std::exception )
-{
-    return getImplementationName_static();
-}
-
-OUString SAL_CALL AnyCompareFactory::getImplementationName_static(  )
+OUString SAL_CALL AnyCompareFactory::getImplementationName(  )
 {
     return OUString( "AnyCompareFactory" );
 }
 
-sal_Bool SAL_CALL AnyCompareFactory::supportsService( const OUString& ServiceName ) throw(RuntimeException, std::exception)
+sal_Bool SAL_CALL AnyCompareFactory::supportsService( const OUString& ServiceName )
 {
     return cppu::supportsService(this, ServiceName);
 }
 
-Sequence< OUString > SAL_CALL AnyCompareFactory::getSupportedServiceNames(  ) throw(RuntimeException, std::exception)
-{
-    return getSupportedServiceNames_static();
-}
-
-Sequence< OUString > SAL_CALL AnyCompareFactory::getSupportedServiceNames_static(  )
+Sequence< OUString > SAL_CALL AnyCompareFactory::getSupportedServiceNames(  )
 {
     const OUString aServiceName( "com.sun.star.ucb.AnyCompareFactory" );
     const Sequence< OUString > aSeq( &aServiceName, 1 );
     return aSeq;
 }
 
-Reference< XInterface > SAL_CALL AnyCompareFactory::Create(
-                const Reference< XComponentContext >& rxContext )
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+AnyCompareFactory_get_implementation(
+    css::uno::XComponentContext *context,
+    css::uno::Sequence<css::uno::Any> const &)
 {
-    return static_cast<cppu::OWeakObject*>(new AnyCompareFactory( rxContext ));
-}
-
-void createRegistryInfo_AnyCompareFactory()
-{
-    static ::comphelper::module::OAutoRegistration< AnyCompareFactory > aAutoRegistration;
+    return cppu::acquire(new AnyCompareFactory(context));
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
