@@ -21,6 +21,7 @@
 #include <com/sun/star/container/XIndexAccess.hpp>
 #include <com/sun/star/container/XChild.hpp>
 #include <comphelper/container.hxx>
+#include <o3tl/any.hxx>
 #include <osl/diagnose.h>
 
 
@@ -28,8 +29,7 @@ namespace comphelper
 {
 
 
-
-IndexAccessIterator::IndexAccessIterator(css::uno::Reference< css::uno::XInterface> xStartingPoint)
+IndexAccessIterator::IndexAccessIterator(css::uno::Reference< css::uno::XInterface> const & xStartingPoint)
     :m_xStartingPoint(xStartingPoint)
     ,m_xCurrentObject(nullptr)
 {
@@ -39,7 +39,7 @@ IndexAccessIterator::IndexAccessIterator(css::uno::Reference< css::uno::XInterfa
 IndexAccessIterator::~IndexAccessIterator() {}
 
 
-css::uno::Reference< css::uno::XInterface> IndexAccessIterator::Next()
+css::uno::Reference< css::uno::XInterface> const & IndexAccessIterator::Next()
 {
     bool bCheckingStartingPoint = !m_xCurrentObject.is();
         // Is the current node the starting point?
@@ -66,7 +66,7 @@ css::uno::Reference< css::uno::XInterface> IndexAccessIterator::Next()
             if (xContainerAccess.is() && xContainerAccess->getCount() && ShouldStepInto(xContainerAccess))
             {
                 css::uno::Any aElement(xContainerAccess->getByIndex(0));
-                xSearchLoop = *static_cast<css::uno::Reference< css::uno::XInterface> const *>(aElement.getValue());
+                xSearchLoop = *o3tl::doAccess<css::uno::Reference<css::uno::XInterface>>(aElement);
                 bCheckingStartingPoint = false;
 
                 m_arrChildIndizies.push_back((sal_Int32)0);
@@ -91,10 +91,10 @@ css::uno::Reference< css::uno::XInterface> IndexAccessIterator::Next()
                         ++nOldSearchChildIndex;
                         // and check the next child
                         css::uno::Any aElement(xContainerAccess->getByIndex(nOldSearchChildIndex));
-                        xSearchLoop = *static_cast<css::uno::Reference< css::uno::XInterface> const *>(aElement.getValue());
+                        xSearchLoop = *o3tl::doAccess<css::uno::Reference<css::uno::XInterface>>(aElement);
                         bCheckingStartingPoint = false;
                         // and update its position in the list.
-                        m_arrChildIndizies.push_back((sal_Int32)nOldSearchChildIndex);
+                        m_arrChildIndizies.push_back(nOldSearchChildIndex);
 
                         break;
                     }
@@ -137,5 +137,4 @@ css::uno::Reference< css::uno::XInterface> IndexAccessIterator::Next()
 }   // namespace comphelper
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
