@@ -28,13 +28,13 @@ namespace comphelper
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::task;
 
-    void SAL_CALL OInteractionPassword::setPassword( const OUString& _Password ) throw (RuntimeException, std::exception)
+    void SAL_CALL OInteractionPassword::setPassword( const OUString& Password )
     {
-        m_sPassword = _Password;
+        m_sPassword = Password;
     }
 
 
-    OUString SAL_CALL OInteractionPassword::getPassword(  ) throw (RuntimeException, std::exception)
+    OUString SAL_CALL OInteractionPassword::getPassword(  )
     {
         return m_sPassword;
     }
@@ -45,7 +45,7 @@ namespace comphelper
     }
 
     OInteractionRequest::OInteractionRequest(const Any& rRequestDescription,
-            Sequence<Reference<XInteractionContinuation>> const& rContinuations)
+            std::vector<Reference<XInteractionContinuation>> const& rContinuations)
         : m_aRequest(rRequestDescription)
         , m_aContinuations(rContinuations)
     {
@@ -56,27 +56,24 @@ namespace comphelper
         OSL_ENSURE(_rxContinuation.is(), "OInteractionRequest::addContinuation: invalid argument!");
         if (_rxContinuation.is())
         {
-            sal_Int32 nOldLen = m_aContinuations.getLength();
-            m_aContinuations.realloc(nOldLen + 1);
-            m_aContinuations[nOldLen] = _rxContinuation;
+            m_aContinuations.push_back(_rxContinuation);
         }
     }
 
 
-    Any SAL_CALL OInteractionRequest::getRequest(  ) throw(RuntimeException, std::exception)
+    Any SAL_CALL OInteractionRequest::getRequest(  )
     {
         return m_aRequest;
     }
 
 
-    Sequence< Reference< XInteractionContinuation > > SAL_CALL OInteractionRequest::getContinuations(  ) throw(RuntimeException, std::exception)
+    Sequence< Reference< XInteractionContinuation > > SAL_CALL OInteractionRequest::getContinuations(  )
     {
-        return m_aContinuations;
+        return comphelper::containerToSequence(m_aContinuations);
     }
 
 
 }   // namespace comphelper
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
