@@ -21,6 +21,8 @@ static bool g_bPartInInvalidation(false);
 
 static bool g_bTiledPainting(false);
 
+static bool g_bDialogPainting(false);
+
 static bool g_bTiledAnnotations(true);
 
 void setActive(bool bActive)
@@ -53,6 +55,16 @@ bool isTiledPainting()
     return g_bTiledPainting;
 }
 
+void setDialogPainting(bool bDialogPainting)
+{
+    g_bDialogPainting = bDialogPainting;
+}
+
+bool isDialogPainting()
+{
+    return g_bDialogPainting;
+}
+
 void setTiledAnnotations(bool bTiledAnnotations)
 {
     g_bTiledAnnotations = bTiledAnnotations;
