@@ -32,7 +32,7 @@
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/lang/IllegalArgumentException.hpp>
 #include <com/sun/star/uno/genfunc.h>
-
+#include <rtl/ustrbuf.hxx>
 #include <algorithm>
 
 
@@ -90,15 +90,15 @@ void copyProperties(const Reference<XPropertySet>& _rxSource,
             catch (Exception&)
             {
 #if OSL_DEBUG_LEVEL > 0
-                OStringBuffer aBuffer;
+                OUStringBuffer aBuffer;
                 aBuffer.append( "::comphelper::copyProperties: could not copy property '" );
-                aBuffer.append( OString( pSourceProps->Name.getStr(), pSourceProps->Name.getLength(), RTL_TEXTENCODING_ASCII_US ) );
+                aBuffer.append( pSourceProps->Name );
                 aBuffer.append( "' to the destination set (a '" );
 
                 Reference< XServiceInfo > xSI( _rxDest, UNO_QUERY );
                 if ( xSI.is() )
                 {
-                    aBuffer.append( OUStringToOString( xSI->getImplementationName(), osl_getThreadTextEncoding() ) );
+                    aBuffer.append( xSI->getImplementationName() );
                 }
                 else
                 {
@@ -108,20 +108,19 @@ void copyProperties(const Reference<XPropertySet>& _rxSource,
 
                 Any aException( ::cppu::getCaughtException() );
                 aBuffer.append( "Caught an exception of type '" );
-                OUString sExceptionType( aException.getValueTypeName() );
-                aBuffer.append( OString( sExceptionType.getStr(), sExceptionType.getLength(), RTL_TEXTENCODING_ASCII_US ) );
+                aBuffer.append( aException.getValueTypeName() );
                 aBuffer.append( "'" );
 
                 Exception aBaseException;
                 if ( ( aException >>= aBaseException ) && !aBaseException.Message.isEmpty() )
                 {
                     aBuffer.append( ", saying '" );
-                    aBuffer.append( OString( aBaseException.Message.getStr(), aBaseException.Message.getLength(), osl_getThreadTextEncoding() ) );
+                    aBuffer.append( aBaseException.Message );
                     aBuffer.append( "'" );
                 }
                 aBuffer.append( "." );
 
-                OSL_FAIL( aBuffer.getStr() );
+                SAL_WARN( "comphelper", aBuffer.makeStringAndClear() );
 #endif
             }
         }
@@ -144,15 +143,14 @@ void RemoveProperty(Sequence<Property>& _rProps, const OUString& _rPropName)
 {
     sal_Int32 nLen = _rProps.getLength();
 
-    // binaere Suche
+    // binary search
     const Property* pProperties = _rProps.getConstArray();
     Property aNameProp(_rPropName, 0, Type(), 0);
-    const Property* pResult = ::std::lower_bound(pProperties, pProperties + nLen, aNameProp, PropertyCompareByName());
+    const Property* pResult = std::lower_bound(pProperties, pProperties + nLen, aNameProp, PropertyCompareByName());
 
-    // gefunden ?
-    if ( pResult && (pResult != pProperties + nLen) && (pResult->Name == _rPropName) )
+    if ( pResult != _rProps.end() && pResult->Name == _rPropName )
     {
-        OSL_ENSURE(pResult->Name.equals(_rPropName), "::RemoveProperty Properties nicht sortiert");
+        OSL_ENSURE(pResult->Name == _rPropName, "::RemoveProperty Properties not sorted");
         removeElementAt(_rProps, pResult - pProperties);
     }
 }
@@ -162,13 +160,12 @@ void ModifyPropertyAttributes(Sequence<Property>& seqProps, const OUString& sPro
 {
     sal_Int32 nLen = seqProps.getLength();
 
-    // binaere Suche
+    // binary search
     Property* pProperties = seqProps.getArray();
     Property aNameProp(sPropName, 0, Type(), 0);
-    Property* pResult = ::std::lower_bound(pProperties, pProperties + nLen, aNameProp, PropertyCompareByName());
+    Property* pResult = std::lower_bound(pProperties, pProperties + nLen, aNameProp, PropertyCompareByName());
 
-    // gefunden ?
-    if ( pResult && (pResult != pProperties + nLen) && (pResult->Name == sPropName) )
+    if ( (pResult != seqProps.end()) && (pResult->Name == sPropName) )
     {
         pResult->Attributes |= nAddAttrib;
         pResult->Attributes &= ~nRemoveAttrib;
