@@ -17,6 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <com/sun/star/io/BufferSizeExceededException.hpp>
+#include <com/sun/star/io/NotConnectedException.hpp>
+#include <com/sun/star/lang/IllegalArgumentException.hpp>
 #include <comphelper/seqstream.hxx>
 
 #include <osl/diagnose.h>
@@ -54,8 +59,6 @@ inline sal_Int32 SequenceInputStream::avail()
 // css::io::XInputStream
 
 sal_Int32 SAL_CALL SequenceInputStream::readBytes( Sequence<sal_Int8>& aData, sal_Int32 nBytesToRead )
-    throw(NotConnectedException, BufferSizeExceededException,
-          IOException, RuntimeException, std::exception)
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -76,8 +79,6 @@ sal_Int32 SAL_CALL SequenceInputStream::readBytes( Sequence<sal_Int8>& aData, sa
 
 
 sal_Int32 SAL_CALL SequenceInputStream::readSomeBytes( Sequence<sal_Int8>& aData, sal_Int32 nMaxBytesToRead )
-    throw(NotConnectedException, BufferSizeExceededException,
-          IOException, RuntimeException, std::exception)
 {
     // all data is available at once
     return readBytes(aData, nMaxBytesToRead);
@@ -85,8 +86,6 @@ sal_Int32 SAL_CALL SequenceInputStream::readSomeBytes( Sequence<sal_Int8>& aData
 
 
 void SAL_CALL SequenceInputStream::skipBytes( sal_Int32 nBytesToSkip )
-    throw(NotConnectedException, BufferSizeExceededException,
-          IOException, RuntimeException, std::exception)
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -103,7 +102,6 @@ void SAL_CALL SequenceInputStream::skipBytes( sal_Int32 nBytesToSkip )
 
 
 sal_Int32 SAL_CALL SequenceInputStream::available(  )
-    throw(NotConnectedException, IOException, RuntimeException, std::exception)
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -112,7 +110,6 @@ sal_Int32 SAL_CALL SequenceInputStream::available(  )
 
 
 void SAL_CALL SequenceInputStream::closeInput(  )
-    throw(NotConnectedException, IOException, RuntimeException, std::exception)
 {
     if (m_nPos == -1)
         throw NotConnectedException(OUString(), *this);
@@ -120,19 +117,19 @@ void SAL_CALL SequenceInputStream::closeInput(  )
     m_nPos = -1;
 }
 
-void SAL_CALL SequenceInputStream::seek( sal_Int64 location ) throw (IllegalArgumentException, IOException, RuntimeException, std::exception)
+void SAL_CALL SequenceInputStream::seek( sal_Int64 location )
 {
     if ( location > m_aData.getLength() || location < 0 || location > SAL_MAX_INT32 )
         throw IllegalArgumentException();
     m_nPos = (sal_Int32) location;
 }
 
-sal_Int64 SAL_CALL SequenceInputStream::getPosition() throw (IOException, RuntimeException, std::exception)
+sal_Int64 SAL_CALL SequenceInputStream::getPosition()
 {
     return m_nPos;
 }
 
-sal_Int64 SAL_CALL SequenceInputStream::getLength(  ) throw (IOException, RuntimeException, std::exception)
+sal_Int64 SAL_CALL SequenceInputStream::getLength(  )
 {
     return m_aData.getLength();
 }
@@ -152,7 +149,7 @@ OSequenceOutputStream::OSequenceOutputStream(Sequence< sal_Int8 >& _rSeq, double
 }
 
 
-void SAL_CALL OSequenceOutputStream::writeBytes( const Sequence< sal_Int8 >& _rData ) throw(NotConnectedException, BufferSizeExceededException, IOException, RuntimeException, std::exception)
+void SAL_CALL OSequenceOutputStream::writeBytes( const Sequence< sal_Int8 >& _rData )
 {
     MutexGuard aGuard(m_aMutex);
     if (!m_bConnected)
@@ -192,7 +189,7 @@ void SAL_CALL OSequenceOutputStream::writeBytes( const Sequence< sal_Int8 >& _rD
 }
 
 
-void SAL_CALL OSequenceOutputStream::flush(  ) throw(NotConnectedException, BufferSizeExceededException, IOException, RuntimeException, std::exception)
+void SAL_CALL OSequenceOutputStream::flush(  )
 {
     MutexGuard aGuard(m_aMutex);
     if (!m_bConnected)
@@ -202,12 +199,9 @@ void SAL_CALL OSequenceOutputStream::flush(  ) throw(NotConnectedException, Buff
     m_rSequence.realloc(m_nSize);
 }
 
-
-void SAL_CALL OSequenceOutputStream::closeOutput(  ) throw(NotConnectedException, BufferSizeExceededException, IOException, RuntimeException, std::exception)
+void OSequenceOutputStream::finalizeOutput()
 {
     MutexGuard aGuard(m_aMutex);
-    if (!m_bConnected)
-        throw NotConnectedException();
 
     // cut the sequence to the real size
     m_rSequence.realloc(m_nSize);
@@ -215,6 +209,15 @@ void SAL_CALL OSequenceOutputStream::closeOutput(  ) throw(NotConnectedException
     m_bConnected = false;
 }
 
+void SAL_CALL OSequenceOutputStream::closeOutput()
+{
+    MutexGuard aGuard(m_aMutex);
+    if (!m_bConnected)
+        throw NotConnectedException();
+
+    finalizeOutput();
+}
+
 } // namespace comphelper
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
