@@ -44,7 +44,8 @@ class RefCounting:
     public RecursiveASTVisitor<RefCounting>, public loplugin::Plugin
 {
 public:
-    explicit RefCounting(InstantiationData const & data): Plugin(data) {}
+    explicit RefCounting(loplugin::InstantiationData const & data): Plugin(data)
+    {}
 
     virtual void run() override { TraverseDecl(compiler.getASTContext().getTranslationUnitDecl()); }
 
@@ -69,25 +70,27 @@ public:
     }
 private:
     void checkUnoReference(QualType qt, const Decl* decl,
-                           const std::string& rParentName, const std::string& rDeclName);
+                           const RecordDecl* parent, const std::string& rDeclName);
 
     bool visitTemporaryObjectExpr(Expr const * expr);
 };
 
+typedef std::function<bool(Decl const *)> DeclChecker;
+
 bool BaseCheckNotSubclass(const CXXRecordDecl *BaseDefinition, void *p) {
     if (!BaseDefinition)
         return true;
-    const char *pString = static_cast<const char *>(p);
-    if (BaseDefinition->getQualifiedNameAsString() == pString) {
+    auto const & base = *static_cast<const DeclChecker *>(p);
+    if (base(BaseDefinition)) {
         return false;
     }
     return true;
 }
 
-bool isDerivedFrom(const CXXRecordDecl *decl, const char *pString) {
+bool isDerivedFrom(const CXXRecordDecl *decl, DeclChecker base) {
     if (!decl)
         return false;
-    if (decl->getQualifiedNameAsString() == pString)
+    if (base(decl))
         return true;
     if (!decl->hasDefinition()) {
         return false;
@@ -97,11 +100,10 @@ bool isDerivedFrom(const CXXRecordDecl *decl, const char *pString) {
 #if CLANG_VERSION < 30800
             BaseCheckNotSubclass,
 #else
-            [pString](const CXXRecordDecl *BaseDefinition) -> bool
-                { return BaseCheckNotSubclass(
-                        BaseDefinition, const_cast<char *>(pString)); },
+            [&base](const CXXRecordDecl *BaseDefinition) -> bool
+                { return BaseCheckNotSubclass(BaseDefinition, &base); },
 #endif
-            static_cast<void*>(const_cast<char*>(pString)), true))
+            &base, true))
     {
         return true;
     }
@@ -109,45 +111,45 @@ bool isDerivedFrom(const CXXRecordDecl *decl, const char *pString) {
 }
 
 
-bool containsXInterfaceSubclass(const Type* pType0);
+bool containsXInterfaceSubclass(const clang::Type* pType0);
 
 bool containsXInterfaceSubclass(const QualType& qType) {
     return containsXInterfaceSubclass(qType.getTypePtr());
 }
 
-bool containsXInterfaceSubclass(const Type* pType0) {
+bool containsXInterfaceSubclass(const clang::Type* pType0) {
     if (!pType0)
         return false;
-    const Type* pType = pType0->getUnqualifiedDesugaredType();
+    const clang::Type* pType = pType0->getUnqualifiedDesugaredType();
     if (!pType)
         return false;
     const CXXRecordDecl* pRecordDecl = pType->getAsCXXRecordDecl();
     if (pRecordDecl) {
         pRecordDecl = pRecordDecl->getCanonicalDecl();
         // these classes override acquire/release and forwards to its parent
-        if (isDerivedFrom(pRecordDecl, "ListenerMultiplexerBase")) { // module UnoTools
+        if (isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("ListenerMultiplexerBase").GlobalNamespace()); })) { // module UnoTools
             return false;
         }
-        if (isDerivedFrom(pRecordDecl, "toolkit::GridEventForwarder")) { // module toolkit
+        if (isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("GridEventForwarder").Namespace("toolkit").GlobalNamespace()); })) { // module toolkit
             return false;
         }
-        if (isDerivedFrom(pRecordDecl, "OWeakSubObject")) { // module svx
+        if (isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("OWeakSubObject").GlobalNamespace()); })) { // module svx
             return false;
         }
-        if (isDerivedFrom(pRecordDecl, "dbaui::OSbaWeakSubObject")) { // module dbaccess
+        if (isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("OSbaWeakSubObject").Namespace("dbaui").GlobalNamespace()); })) { // module dbaccess
             return false;
         }
         // The actual problem child is SlideView, of which this is the parent.
         // Everything in the hierarchy above this wants to be managed via boost::shared_ptr
-        if (isDerivedFrom(pRecordDecl, "slideshow::internal::UnoView")) { // module slideshow
+        if (isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("UnoView").Namespace("internal").Namespace("slideshow").GlobalNamespace()); })) { // module slideshow
             return false;
         }
         // FIXME This class has private operator new, and I cannot figure out how it can be dynamically instantiated
-        if (isDerivedFrom(pRecordDecl, "XPropertyList")) { // module svx
+        if (isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("XPropertyList").GlobalNamespace()); })) { // module svx
             return false;
         }
         // tdf#114596
-        if (isDerivedFrom(pRecordDecl, "dbaccess::OBookmarkContainer")) { // module dbaccess
+        if (isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("OBookmarkContainer").Namespace("dbaccess").GlobalNamespace()); })) { // module dbaccess
             return false;
         }
     }
@@ -232,18 +234,18 @@ bool containsXInterfaceSubclass(const Type* pType0) {
         // ignore
         return false;
     } else if (pType->isArrayType()) {
-        const ArrayType* pArrayType = dyn_cast<ArrayType>(pType);
+        const clang::ArrayType* pArrayType = dyn_cast<clang::ArrayType>(pType);
         QualType elementType = pArrayType->getElementType();
         return containsXInterfaceSubclass(elementType);
     } else {
-        return isDerivedFrom(pRecordDecl, "com::sun::star::uno::XInterface");
+        return isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("XInterface").Namespace("uno").Namespace("star").Namespace("sun").Namespace("com").GlobalNamespace()); });
     }
 }
 
-bool containsSvRefBaseSubclass(const Type* pType0) {
+bool containsSvRefBaseSubclass(const clang::Type* pType0) {
     if (!pType0)
         return false;
-    const Type* pType = pType0->getUnqualifiedDesugaredType();
+    const clang::Type* pType = pType0->getUnqualifiedDesugaredType();
     if (!pType)
         return false;
     const CXXRecordDecl* pRecordDecl = pType->getAsCXXRecordDecl();
@@ -253,9 +255,11 @@ bool containsSvRefBaseSubclass(const Type* pType0) {
     if (pRecordDecl) {
         const ClassTemplateSpecializationDecl* pTemplate = dyn_cast<ClassTemplateSpecializationDecl>(pRecordDecl);
         if (pTemplate) {
-            std::string aName = pTemplate->getQualifiedNameAsString();
-            if (aName == "tools::SvRef")
+            if (loplugin::DeclCheck(pTemplate).Class("SvRef")
+                .Namespace("tools").GlobalNamespace())
+            {
                 return false;
+            }
             for(unsigned i=0; i<pTemplate->getTemplateArgs().size(); ++i) {
                 const TemplateArgument& rArg = pTemplate->getTemplateArgs()[i];
                 if (rArg.getKind() == TemplateArgument::ArgKind::Type &&
@@ -270,18 +274,18 @@ bool containsSvRefBaseSubclass(const Type* pType0) {
         // ignore
         return false;
     } else if (pType->isArrayType()) {
-        const ArrayType* pArrayType = dyn_cast<ArrayType>(pType);
+        const clang::ArrayType* pArrayType = dyn_cast<clang::ArrayType>(pType);
         QualType elementType = pArrayType->getElementType();
         return containsSvRefBaseSubclass(elementType.getTypePtr());
     } else {
-        return isDerivedFrom(pRecordDecl, "tools::SvRefBase");
+        return isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("SvRefBase").Namespace("tools").GlobalNamespace()); });
     }
 }
 
-bool containsSalhelperReferenceObjectSubclass(const Type* pType0) {
+bool containsSalhelperReferenceObjectSubclass(const clang::Type* pType0) {
     if (!pType0)
         return false;
-    const Type* pType = pType0->getUnqualifiedDesugaredType();
+    const clang::Type* pType = pType0->getUnqualifiedDesugaredType();
     if (!pType)
         return false;
     const CXXRecordDecl* pRecordDecl = pType->getAsCXXRecordDecl();
@@ -291,9 +295,13 @@ bool containsSalhelperReferenceObjectSubclass(const Type* pType0) {
     if (pRecordDecl) {
         const ClassTemplateSpecializationDecl* pTemplate = dyn_cast<ClassTemplateSpecializationDecl>(pRecordDecl);
         if (pTemplate) {
-            std::string aName = pTemplate->getQualifiedNameAsString();
-            if (aName == "rtl::Reference" || aName == "store::OStoreHandle")
+            auto const dc = loplugin::DeclCheck(pTemplate);
+            if (dc.Class("Reference").Namespace("rtl").GlobalNamespace()
+                || (dc.Class("OStoreHandle").Namespace("store")
+                    .GlobalNamespace()))
+            {
                 return false;
+            }
             for(unsigned i=0; i<pTemplate->getTemplateArgs().size(); ++i) {
                 const TemplateArgument& rArg = pTemplate->getTemplateArgs()[i];
                 if (rArg.getKind() == TemplateArgument::ArgKind::Type &&
@@ -308,11 +316,11 @@ bool containsSalhelperReferenceObjectSubclass(const Type* pType0) {
         // ignore
         return false;
     } else if (pType->isArrayType()) {
-        const ArrayType* pArrayType = dyn_cast<ArrayType>(pType);
+        const clang::ArrayType* pArrayType = dyn_cast<clang::ArrayType>(pType);
         QualType elementType = pArrayType->getElementType();
         return containsSalhelperReferenceObjectSubclass(elementType.getTypePtr());
     } else {
-        return isDerivedFrom(pRecordDecl, "salhelper::SimpleReferenceObject");
+        return isDerivedFrom(pRecordDecl, [](Decl const * decl) -> bool { return bool(loplugin::DeclCheck(decl).Class("SimpleReferenceObject").Namespace("salhelper").GlobalNamespace()); });
     }
 }
 
@@ -330,7 +338,7 @@ static bool containsStaticTypeMethod(const CXXRecordDecl* x)
     return false;
 }
 
-void RefCounting::checkUnoReference(QualType qt, const Decl* decl, const std::string& rParentName, const std::string& rDeclName)
+void RefCounting::checkUnoReference(QualType qt, const Decl* decl, const RecordDecl* parent, const std::string& rDeclName)
 {
     if (loplugin::TypeCheck(qt).Class("Reference").Namespace("uno").Namespace("star").Namespace("sun").Namespace("com").GlobalNamespace()) {
         const CXXRecordDecl* pRecordDecl = qt->getAsCXXRecordDecl();
@@ -340,11 +348,13 @@ void RefCounting::checkUnoReference(QualType qt, const Decl* decl, const std::st
         if (templateParam && !containsStaticTypeMethod(templateParam)) {
             report(
                 DiagnosticsEngine::Warning,
-                "uno::Reference " + rDeclName + " with template parameter that does not contain ::static_type() "
-                + qt.getAsString()
-                + ", parent is " + rParentName
-                + ", should probably be using rtl::Reference instead",
+                ("uno::Reference %0 with template parameter that does not"
+                 " contain ::static_type() %1%select{|, parent is %3,}2 should"
+                 " probably be using rtl::Reference instead"),
                 decl->getLocation())
+              << rDeclName << qt << (parent != nullptr)
+              << (parent != nullptr
+                  ? parent->getQualifiedNameAsString() : std::string())
               << decl->getSourceRange();
         }
     }
@@ -390,32 +400,74 @@ bool RefCounting::VisitFieldDecl(const FieldDecl * fieldDecl) {
         return true;
     }
 
-    std::string aParentName = fieldDecl->getParent()->getQualifiedNameAsString();
+    // check for dodgy code managing ref-counted stuff with shared_ptr or unique_ptr or similar stuff
+    QualType firstTemplateParamType;
+    if (auto recordType = fieldDecl->getType()->getUnqualifiedDesugaredType()->getAs<RecordType>()) {
+        auto const tc = loplugin::TypeCheck(fieldDecl->getType());
+        if (tc.Class("unique_ptr").StdNamespace()
+            || tc.Class("shared_ptr").StdNamespace()
+            || tc.Class("intrusive_ptr").Namespace("boost").GlobalNamespace())
+        {
+            auto templateDecl = dyn_cast<ClassTemplateSpecializationDecl>(recordType->getDecl());
+            if (templateDecl && templateDecl->getTemplateArgs().size() > 0)
+                firstTemplateParamType = templateDecl->getTemplateArgs()[0].getAsType();
+        }
+    }
 
     if (containsSvRefBaseSubclass(fieldDecl->getType().getTypePtr())) {
         report(
             DiagnosticsEngine::Warning,
-            "SvRefBase subclass being directly heap managed, should be managed via tools::SvRef, "
-            + fieldDecl->getType().getAsString()
-            + ", parent is " + aParentName,
+            "SvRefBase subclass %0 being directly heap managed, should be managed via tools::SvRef, "
+            ", parent is %1",
             fieldDecl->getLocation())
-          << fieldDecl->getSourceRange();
+            << fieldDecl->getType()
+            << fieldDecl->getParent()
+            << fieldDecl->getSourceRange();
+    }
+
+    if (!firstTemplateParamType.isNull() && containsSvRefBaseSubclass(firstTemplateParamType.getTypePtr()))
+    {
+        report(
+            DiagnosticsEngine::Warning,
+            "SvRefBase subclass %0 being managed via smart pointer, should be managed via tools::SvRef, "
+            "parent is %1",
+            fieldDecl->getLocation())
+            << firstTemplateParamType
+            << fieldDecl->getParent()
+            << fieldDecl->getSourceRange();
     }
 
     if (containsSalhelperReferenceObjectSubclass(fieldDecl->getType().getTypePtr())) {
         report(
             DiagnosticsEngine::Warning,
-            "salhelper::SimpleReferenceObject subclass being directly heap managed, should be managed via rtl::Reference, "
-            + fieldDecl->getType().getAsString()
-            + ", parent is " + aParentName,
+            "salhelper::SimpleReferenceObject subclass %0 being directly heap managed, should be managed via rtl::Reference, "
+            "parent is %1",
             fieldDecl->getLocation())
-          << fieldDecl->getSourceRange();
+            << fieldDecl->getType()
+            << fieldDecl->getParent()
+            << fieldDecl->getSourceRange();
     }
 
-    if ( aParentName == "com::sun::star::uno::BaseReference"
-         || aParentName == "cppu::detail::element_alias"
+    if (!firstTemplateParamType.isNull() && containsSalhelperReferenceObjectSubclass(firstTemplateParamType.getTypePtr()))
+    {
+        report(
+            DiagnosticsEngine::Warning,
+            "salhelper::SimpleReferenceObject subclass %0 being managed via smart pointer, should be managed via rtl::Reference, "
+            "parent is %1",
+            fieldDecl->getLocation())
+            << firstTemplateParamType
+            << fieldDecl->getParent()
+            << fieldDecl->getSourceRange();
+    }
+
+    auto const dc = loplugin::DeclCheck(fieldDecl->getParent());
+    if ( (dc.Class("BaseReference").Namespace("uno").Namespace("star")
+          .Namespace("sun").Namespace("com").GlobalNamespace())
+         || (dc.Union("element_alias").Namespace("detail").Namespace("cppu")
+             .GlobalNamespace())
          // this is playing some kind of game to avoid circular references
-         || aParentName == "ucbhelper::ResultSetDataSupplier")
+         || (dc.Class("ResultSetDataSupplier").Namespace("ucbhelper")
+             .GlobalNamespace()))
     {
         return true;
     }
@@ -423,14 +475,32 @@ bool RefCounting::VisitFieldDecl(const FieldDecl * fieldDecl) {
     if (containsXInterfaceSubclass(fieldDecl->getType())) {
         report(
             DiagnosticsEngine::Warning,
-            "XInterface subclass being directly heap managed, should be managed via uno::Reference, "
-            + fieldDecl->getType().getAsString()
-            + ", parent is " + aParentName,
+            "XInterface subclass %0 being directly heap managed, should be managed via uno::Reference, "
+            "parent is %1",
             fieldDecl->getLocation())
-          << fieldDecl->getSourceRange();
+            << fieldDecl->getType()
+            << fieldDecl->getParent()
+            << fieldDecl->getSourceRange();
     }
 
-    checkUnoReference(fieldDecl->getType(), fieldDecl, aParentName, "field");
+// Not in general (dbaccess::DocumentEvents, dbaccess/source/core/dataaccess/databasedocument.hxx):
+#if 0
+    if (!firstTemplateParamType.isNull() && containsXInterfaceSubclass(firstTemplateParamType))
+    {
+        report(
+            DiagnosticsEngine::Warning,
+            "XInterface subclass %0 being managed via smart pointer, should be managed via uno::Reference, "
+            "parent is %1",
+            fieldDecl->getLocation())
+            << firstTemplateParamType
+            << fieldDecl->getParent()
+            << fieldDecl->getSourceRange();
+    }
+#endif
+
+    checkUnoReference(
+        fieldDecl->getType(), fieldDecl,
+        fieldDecl->getParent(), "field");
 
     return true;
 }
@@ -470,7 +540,7 @@ bool RefCounting::VisitVarDecl(const VarDecl * varDecl) {
               << varDecl->getSourceRange();
         }
     }
-    checkUnoReference(varDecl->getType(), varDecl, "", "var");
+    checkUnoReference(varDecl->getType(), varDecl, nullptr, "var");
     return true;
 }
 
@@ -484,7 +554,7 @@ bool RefCounting::VisitFunctionDecl(const FunctionDecl * functionDecl) {
     if (methodDecl && methodDecl->size_overridden_methods() > 0) {
             return true;
     }
-    checkUnoReference(compat::getReturnType(*functionDecl), functionDecl, "", "return");
+    checkUnoReference(compat::getReturnType(*functionDecl), functionDecl, nullptr, "return");
     return true;
 }
 
