@@ -39,7 +39,6 @@ package complex.connectivity.hsqldb;
 import org.hsqldb.lib.StopWatch;
 
 import java.util.Random;
-import com.sun.star.lang.*;
 import com.sun.star.uno.UnoRuntime;
 import com.sun.star.sdbc.*;
 
@@ -68,57 +67,50 @@ import com.sun.star.sdbc.*;
 public class TestCacheSize {
 
     // program can edit the *.properties file to set cache_size
-    protected boolean filedb = true;
+    private boolean filedb = true;
 
     // shutdown performed mid operation - not for mem: or hsql: URL's
-    protected boolean shutdown = true;
+    private boolean shutdown = true;
 
     // fixed
-    protected String url = "sdbc:embedded:hsqldb";
+    private String url = "sdbc:embedded:hsqldb";
 
     // frequent reporting of progress
-    boolean reportProgress = false;
-
-    XMultiServiceFactory servicefactory = null;
+    private boolean reportProgress = false;
 
     // type of the big table {MEMORY | CACHED | TEXT}
-    String tableType      = "CACHED";
-    int    cacheScale     = 17;
-    int    cacheSizeScale = 8;
+    private String tableType      = "CACHED";
+    private int    cacheScale     = 17;
 
     // script format {TEXT, BINARY, COMPRESSED}
-    String logType       = "TEXT";
-    int     writeDelay    = 60;
-    boolean indexZip      = true;
-    boolean indexLastName = false;
-    boolean addForeignKey = false;
-    boolean refIntegrity  = true;
+    private String logType       = "TEXT";
+    private int     writeDelay    = 60;
+    private boolean indexZip      = true;
+    private boolean indexLastName = false;
+    private boolean addForeignKey = false;
+    private boolean refIntegrity  = true;
 
     // speeds up inserts when tableType=="CACHED"
-    boolean createTempTable = false;
+    private boolean createTempTable = false;
 
     // introduces fragmentation to the .data file during insert
-    boolean deleteWhileInsert         = false;
-    int     deleteWhileInsertInterval = 10000;
+    private boolean deleteWhileInsert         = false;
+    private int     deleteWhileInsertInterval = 10000;
 
     // size of the tables used in test
-    int bigrows   = 10000;
-    int smallrows = 0xfff;
+    private int bigrows   = 10000;
+    private int smallrows = 0xfff;
 
     // if the extra table needs to be created and filled up
-    boolean multikeytable = false;
+    private boolean multikeytable = false;
 
-    //
-    String     user;
-    String     password;
-    XStatement  sStatement;
-    XConnection cConnection;
-    XDataSource ds;
-    XDriver drv;
-    com.sun.star.beans.PropertyValue[] info;
 
-    public TestCacheSize(XMultiServiceFactory _xmulti,com.sun.star.beans.PropertyValue[] _info,XDriver _drv){
-        servicefactory = _xmulti;
+    private XStatement  sStatement;
+    private XConnection cConnection;
+    private XDriver drv;
+    private com.sun.star.beans.PropertyValue[] info;
+
+    public TestCacheSize(com.sun.star.beans.PropertyValue[] _info,XDriver _drv){
         drv = _drv;
         info = _info;
     }
@@ -129,15 +121,10 @@ public class TestCacheSize {
 
     public void setUp() {
 
-        user     = "sa";
-        password = "";
-
         try {
             sStatement  = null;
             cConnection = null;
 
-            //Class.forName("org.hsqldb.jdbcDriver");
-
             if (filedb) {
 
                 cConnection = drv.connect(url,info);
@@ -147,9 +134,6 @@ public class TestCacheSize {
                 sStatement.execute("SET LOGSIZE " + 0);
                 sStatement.execute("SHUTDOWN");
                 cConnection.close();
-//                props.setProperty("hsqldb.cache_scale", "" + cacheScale);
-//                props.setProperty("hsqldb.cache_size_scale",
-                                  //"" + cacheSizeScale);
             }
         } catch (Exception e) {
             e.printStackTrace();
@@ -255,7 +239,6 @@ public class TestCacheSize {
                 System.out.println("multi key table");
             }
 
-//            sStatement.execute("CREATE INDEX idx3 ON tempTEST (zip);");
             System.out.println("Setup time: " + sw.elapsedTime());
             fillUpBigTable(filler, randomgen);
 
@@ -339,12 +322,9 @@ public class TestCacheSize {
             }
         }
 
-//            sStatement.execute("INSERT INTO test SELECT * FROM temptest;");
-//            sStatement.execute("DROP TABLE temptest;");
-//            sStatement.execute(ddl7);
         System.out.println("Total insert: " + i);
         System.out.println("Insert time: " + sw.elapsedTime() + " rps: "
-                           + (i * 1000 / (sw.elapsedTime() + 1)));
+                           + (1000L * i / (sw.elapsedTime() + 1)));
     }
 
     private void fillUpMultiTable(String filler,
@@ -397,7 +377,7 @@ public class TestCacheSize {
 
         System.out.println("Multi Key Total insert: " + i);
         System.out.println("Insert time: " + sw.elapsedTime() + " rps: "
-                           + (i * 1000 / (sw.elapsedTime() + 1)));
+                           + (1000L * i / (sw.elapsedTime() + 1)));
     }
 
     public void tearDown() {}
@@ -487,7 +467,7 @@ public class TestCacheSize {
                         || (slow && (i + 1) % 100 == 0)) {
                     System.out.println("Select " + (i + 1) + " : "
                                        + sw.elapsedTime() + " rps: "
-                                       + (i * 1000 / (sw.elapsedTime() + 1)));
+                                       + (1000L * i / (sw.elapsedTime() + 1)));
                 }
             }
         } catch (SQLException e) {
@@ -496,7 +476,7 @@ public class TestCacheSize {
 
         System.out.println("Select random zip " + i + " rows : "
                            + sw.elapsedTime() + " rps: "
-                           + (i * 1000 / (sw.elapsedTime() + 1)));
+                           + (1000L * i / (sw.elapsedTime() + 1)));
         sw.zero();
 
         try {
@@ -520,7 +500,7 @@ public class TestCacheSize {
 
         System.out.println("Select random id " + i + " rows : "
                            + sw.elapsedTime() + " rps: "
-                           + (i * 1000 / (sw.elapsedTime() + 1)));
+                           + (1000L * i / (sw.elapsedTime() + 1)));
         sw.zero();
 
         try {
@@ -544,7 +524,7 @@ public class TestCacheSize {
 
         System.out.println("Select random zip from zip table " + i
                            + " rows : " + sw.elapsedTime() + " rps: "
-                           + (i * 1000 / (sw.elapsedTime() + 1)));
+                           + (1000L * i / (sw.elapsedTime() + 1)));
     }
 
     private void checkUpdates() {
@@ -579,7 +559,7 @@ public class TestCacheSize {
         System.out.println("Update with random zip " + i
                            + " UPDATE commands, " + count + " rows : "
                            + sw.elapsedTime() + " rps: "
-                           + (count * 1000 / (sw.elapsedTime() + 1)));
+                           + (1000L * count / (sw.elapsedTime() + 1)));
         sw.zero();
 
         try {
@@ -597,7 +577,7 @@ public class TestCacheSize {
                         || (slow && (i + 1) % 100 == 0)) {
                     System.out.println("Update " + (i + 1) + " : "
                                        + sw.elapsedTime() + " rps: "
-                                       + (i * 1000 / (sw.elapsedTime() + 1)));
+                                       + (1000L * i / (sw.elapsedTime() + 1)));
                 }
             }
         } catch (SQLException e) {
@@ -606,6 +586,6 @@ public class TestCacheSize {
 
         System.out.println("Update with random id " + i + " rows : "
                            + sw.elapsedTime() + " rps: "
-                           + (i * 1000 / (sw.elapsedTime() + 1)));
+                           + (1000L * i / (sw.elapsedTime() + 1)));
     }
 }
