@@ -1867,8 +1867,8 @@ Sequence<sal_Int8>  ORowSetValue::getSequence() const
             case DataType::VARCHAR:
             case DataType::LONGVARCHAR:
                 {
-                    OUString sVal(m_aValue.m_pString);
-                    aSeq = Sequence<sal_Int8>(reinterpret_cast<const sal_Int8*>(sVal.getStr()),sizeof(sal_Unicode)*sVal.getLength());
+                    aSeq = Sequence<sal_Int8>(reinterpret_cast<const sal_Int8*>(m_aValue.m_pString->buffer),
+                                              sizeof(sal_Unicode) * m_aValue.m_pString->length);
                 }
                 break;
             case DataType::BINARY:
@@ -2208,7 +2208,6 @@ void ORowSetValue::fill(sal_Int32 _nPos,
 
 void ORowSetValue::impl_fill( const sal_Int32 _nType, bool _bNullable, const detail::IValueSource& _rValueSource )
 {
-    bool bReadData = true;
     switch(_nType)
     {
     case DataType::CHAR:
@@ -2288,7 +2287,7 @@ void ORowSetValue::impl_fill( const sal_Int32 _nType, bool _bNullable, const det
         (*this) = _rValueSource.getObject();
         break;
     }
-    if ( bReadData && _bNullable && _rValueSource.wasNull() )
+    if ( _bNullable && _rValueSource.wasNull() )
         setNull();
     setTypeKind(_nType);
 }
