@@ -18,8 +18,8 @@
  */
 
 #include <comphelper/sequence.hxx>
-#include "ado/ADatabaseMetaDataResultSet.hxx"
-#include "ado/ADatabaseMetaDataResultSetMetaData.hxx"
+#include <ado/ADatabaseMetaDataResultSet.hxx>
+#include <ado/ADatabaseMetaDataResultSetMetaData.hxx>
 #include <com/sun/star/sdbc/DataType.hpp>
 #include <com/sun/star/sdbc/ColumnValue.hpp>
 #include <com/sun/star/sdbc/KeyRule.hpp>
@@ -42,7 +42,6 @@ using namespace connectivity::ado;
 using namespace cppu;
 using namespace ::comphelper;
 
-using namespace ::com::sun::star::lang;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::beans;
@@ -53,12 +52,12 @@ ODatabaseMetaDataResultSet::ODatabaseMetaDataResultSet(ADORecordset* _pRecordSet
     :ODatabaseMetaDataResultSet_BASE(m_aMutex)
     ,OPropertySetHelper(ODatabaseMetaDataResultSet_BASE::rBHelper)
     ,m_pRecordSet(_pRecordSet)
-    ,m_aStatement(NULL)
-    ,m_xMetaData(NULL)
+    ,m_aStatement(nullptr)
+    ,m_xMetaData(nullptr)
     ,m_nRowPos(0)
-    ,m_bWasNull(sal_False)
-    ,m_bEOF(sal_False)
-    ,m_bOnFirstAfterOpen(sal_False)
+    ,m_bWasNull(false)
+    ,m_bEOF(false)
+    ,m_bOnFirstAfterOpen(false)
 {
     osl_atomic_increment( &m_refCount );
     m_aColMapping.push_back(-1);
@@ -70,7 +69,7 @@ ODatabaseMetaDataResultSet::ODatabaseMetaDataResultSet(ADORecordset* _pRecordSet
         m_bOnFirstAfterOpen = bIsAtBOF != VARIANT_TRUE;
     }
     else
-        m_bOnFirstAfterOpen = sal_False;
+        m_bOnFirstAfterOpen = false;
     osl_atomic_decrement( &m_refCount );
     //  allocBuffer();
 }
@@ -89,33 +88,33 @@ void ODatabaseMetaDataResultSet::disposing()
     ::osl::MutexGuard aGuard(m_aMutex);
     if(m_pRecordSet)
         m_pRecordSet->Close();
-    m_aStatement    = NULL;
+    m_aStatement    = nullptr;
 m_xMetaData.clear();
 }
 
-Any SAL_CALL ODatabaseMetaDataResultSet::queryInterface( const Type & rType ) throw(RuntimeException)
+Any SAL_CALL ODatabaseMetaDataResultSet::queryInterface( const Type & rType )
 {
     Any aRet = OPropertySetHelper::queryInterface(rType);
     return aRet.hasValue() ? aRet : ODatabaseMetaDataResultSet_BASE::queryInterface(rType);
 }
 
-::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type > SAL_CALL ODatabaseMetaDataResultSet::getTypes(  ) throw(::com::sun::star::uno::RuntimeException)
+css::uno::Sequence< css::uno::Type > SAL_CALL ODatabaseMetaDataResultSet::getTypes(  )
 {
-    ::cppu::OTypeCollection aTypes( cppu::UnoType<com::sun::star::beans::XMultiPropertySet>::get(),
-                                    cppu::UnoType<com::sun::star::beans::XFastPropertySet>::get(),
-                                    cppu::UnoType<com::sun::star::beans::XPropertySet>::get());
+    ::cppu::OTypeCollection aTypes( cppu::UnoType<css::beans::XMultiPropertySet>::get(),
+                                    cppu::UnoType<css::beans::XFastPropertySet>::get(),
+                                    cppu::UnoType<css::beans::XPropertySet>::get());
 
     return ::comphelper::concatSequences(aTypes.getTypes(),ODatabaseMetaDataResultSet_BASE::getTypes());
 }
 
-void ODatabaseMetaDataResultSet::checkRecordSet() throw(SQLException)
+void ODatabaseMetaDataResultSet::checkRecordSet()
 {
     if(!m_pRecordSet)
         throwFunctionSequenceException(*this);
 }
 
 
-sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::findColumn( const OUString& columnName ) throw(SQLException, RuntimeException)
+sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::findColumn( const OUString& columnName )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed );
@@ -137,7 +136,7 @@ sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::findColumn( const OUString& colum
 }
 #define BLOCK_SIZE 256
 
-Reference< ::com::sun::star::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getBinaryStream( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+Reference< css::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getBinaryStream( sal_Int32 columnIndex )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -171,37 +170,37 @@ Reference< ::com::sun::star::io::XInputStream > SAL_CALL ODatabaseMetaDataResult
                     break;
             }
         }
-        return index ? Reference< ::com::sun::star::io::XInputStream >(new SequenceInputStream(aData)) : Reference< ::com::sun::star::io::XInputStream >();
+        return index ? Reference< css::io::XInputStream >(new SequenceInputStream(aData)) : Reference< css::io::XInputStream >();
     }
     // else we ask for a bytesequence
     aField.get_Value(m_aValue);
     if(m_aValue.isNull())
-        return NULL;
-    return new SequenceInputStream(m_aValue);
+        return nullptr;
+    return new SequenceInputStream(m_aValue.getByteSequence());
 }
 
-Reference< ::com::sun::star::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getCharacterStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
+Reference< css::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getCharacterStream( sal_Int32 /*columnIndex*/ )
 {
     ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getCharacterStream", *this );
-    return NULL;
+    return nullptr;
 }
 
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::getBoolean( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::getBoolean( sal_Int32 columnIndex )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
     if ( !m_aValueRange.empty()  && columnIndex == 11 && (m_aValueRangeIter = m_aValueRange.find(columnIndex)) != m_aValueRange.end() )
     {
         getValue(2);
-        if ( static_cast<sal_Int16>(m_aValue) != adCurrency )
-            return sal_False;
+        if ( m_aValue.getInt16() != adCurrency )
+            return false;
     }
-    return getValue(columnIndex);
+    return getValue(columnIndex).getBool();
 }
 
 
-sal_Int8 SAL_CALL ODatabaseMetaDataResultSet::getByte( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+sal_Int8 SAL_CALL ODatabaseMetaDataResultSet::getByte( sal_Int32 columnIndex )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -212,39 +211,39 @@ sal_Int8 SAL_CALL ODatabaseMetaDataResultSet::getByte( sal_Int32 columnIndex ) t
     if(m_aValue.isNull())
         return 0;
     if ( !m_aValueRange.empty() && (m_aValueRangeIter = m_aValueRange.find(columnIndex)) != m_aValueRange.end())
-        return (sal_Int8)(*m_aValueRangeIter).second[(sal_Int32)m_aValue];
+        return (sal_Int8)(*m_aValueRangeIter).second[m_aValue.getInt32()];
     else if(m_aStrValueRange.size() && (m_aStrValueRangeIter = m_aStrValueRange.find(columnIndex)) != m_aStrValueRange.end())
-        return (sal_Int8)(*m_aStrValueRangeIter).second[m_aValue];
+        return (sal_Int8)(*m_aStrValueRangeIter).second[m_aValue.getString()];
 
-    return m_aValue;
+    return m_aValue.getInt8();
 }
 
 
-Sequence< sal_Int8 > SAL_CALL ODatabaseMetaDataResultSet::getBytes( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+Sequence< sal_Int8 > SAL_CALL ODatabaseMetaDataResultSet::getBytes( sal_Int32 columnIndex )
 {
-    return getValue(columnIndex);
+    return getValue(columnIndex).getByteSequence();
 }
 
 
-::com::sun::star::util::Date SAL_CALL ODatabaseMetaDataResultSet::getDate( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+css::util::Date SAL_CALL ODatabaseMetaDataResultSet::getDate( sal_Int32 columnIndex )
 {
-    return getValue(columnIndex);
+    return getValue(columnIndex).getDate();
 }
 
 
-double SAL_CALL ODatabaseMetaDataResultSet::getDouble( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+double SAL_CALL ODatabaseMetaDataResultSet::getDouble( sal_Int32 columnIndex )
 {
-    return getValue(columnIndex);
+    return getValue(columnIndex).getDouble();
 }
 
 
-float SAL_CALL ODatabaseMetaDataResultSet::getFloat( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+float SAL_CALL ODatabaseMetaDataResultSet::getFloat( sal_Int32 columnIndex )
 {
-    return getValue(columnIndex);
+    return getValue(columnIndex).getFloat();
 }
 
 
-sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::getInt( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::getInt( sal_Int32 columnIndex )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -256,29 +255,29 @@ sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::getInt( sal_Int32 columnIndex ) t
         return 0;
 
     if(m_aValueRange.size() && (m_aValueRangeIter = m_aValueRange.find(columnIndex)) != m_aValueRange.end())
-        return (*m_aValueRangeIter).second[(sal_Int32)m_aValue];
+        return (*m_aValueRangeIter).second[m_aValue.getInt32()];
     else if(m_aStrValueRange.size() && (m_aStrValueRangeIter = m_aStrValueRange.find(columnIndex)) != m_aStrValueRange.end())
-        return (*m_aStrValueRangeIter).second[m_aValue];
+        return (*m_aStrValueRangeIter).second[m_aValue.getString()];
 
-    return m_aValue;
+    return m_aValue.getInt32();
 }
 
 
-sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::getRow(  ) throw(SQLException, RuntimeException)
+sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::getRow(  )
 {
     ::dbtools::throwFeatureNotImplementedSQLException( "XResultSet::getRow", *this );
     return 0;
 }
 
 
-sal_Int64 SAL_CALL ODatabaseMetaDataResultSet::getLong( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
+sal_Int64 SAL_CALL ODatabaseMetaDataResultSet::getLong( sal_Int32 /*columnIndex*/ )
 {
     ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getLong", *this );
     return sal_Int64(0);
 }
 
 
-Reference< XResultSetMetaData > SAL_CALL ODatabaseMetaDataResultSet::getMetaData(  ) throw(SQLException, RuntimeException)
+Reference< XResultSetMetaData > SAL_CALL ODatabaseMetaDataResultSet::getMetaData(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -292,35 +291,34 @@ Reference< XResultSetMetaData > SAL_CALL ODatabaseMetaDataResultSet::getMetaData
     return m_xMetaData;
 }
 
-Reference< XArray > SAL_CALL ODatabaseMetaDataResultSet::getArray( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
+Reference< XArray > SAL_CALL ODatabaseMetaDataResultSet::getArray( sal_Int32 /*columnIndex*/ )
 {
     ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRow", *this );
-    return NULL;
+    return nullptr;
 }
 
 
-
-Reference< XClob > SAL_CALL ODatabaseMetaDataResultSet::getClob( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
+Reference< XClob > SAL_CALL ODatabaseMetaDataResultSet::getClob( sal_Int32 /*columnIndex*/ )
 {
     ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRow", *this );
-    return NULL;
+    return nullptr;
 }
 
-Reference< XBlob > SAL_CALL ODatabaseMetaDataResultSet::getBlob( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
+Reference< XBlob > SAL_CALL ODatabaseMetaDataResultSet::getBlob( sal_Int32 /*columnIndex*/ )
 {
     ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRow", *this );
-    return NULL;
+    return nullptr;
 }
 
 
-Reference< XRef > SAL_CALL ODatabaseMetaDataResultSet::getRef( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException)
+Reference< XRef > SAL_CALL ODatabaseMetaDataResultSet::getRef( sal_Int32 /*columnIndex*/ )
 {
     ::dbtools::throwFeatureNotImplementedSQLException( "XRow::getRow", *this );
-    return NULL;
+    return nullptr;
 }
 
 
-Any SAL_CALL ODatabaseMetaDataResultSet::getObject( sal_Int32 columnIndex, const Reference< ::com::sun::star::container::XNameAccess >& /*typeMap*/ ) throw(SQLException, RuntimeException)
+Any SAL_CALL ODatabaseMetaDataResultSet::getObject( sal_Int32 columnIndex, const Reference< css::container::XNameAccess >& /*typeMap*/ )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -333,7 +331,7 @@ Any SAL_CALL ODatabaseMetaDataResultSet::getObject( sal_Int32 columnIndex, const
 }
 
 
-sal_Int16 SAL_CALL ODatabaseMetaDataResultSet::getShort( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+sal_Int16 SAL_CALL ODatabaseMetaDataResultSet::getShort( sal_Int32 columnIndex )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -344,15 +342,15 @@ sal_Int16 SAL_CALL ODatabaseMetaDataResultSet::getShort( sal_Int32 columnIndex )
         return 0;
 
     if(m_aValueRange.size() && (m_aValueRangeIter = m_aValueRange.find(columnIndex)) != m_aValueRange.end())
-        return (sal_Int16)(*m_aValueRangeIter).second[(sal_Int32)m_aValue];
+        return (sal_Int16)(*m_aValueRangeIter).second[m_aValue.getInt32()];
     else if(m_aStrValueRange.size() && (m_aStrValueRangeIter = m_aStrValueRange.find(columnIndex)) != m_aStrValueRange.end())
-        return (sal_Int16)(*m_aStrValueRangeIter).second[m_aValue];
+        return (sal_Int16)(*m_aStrValueRangeIter).second[m_aValue.getString()];
 
-    return m_aValue;
+    return m_aValue.getInt16();
 }
 
 
-OUString SAL_CALL ODatabaseMetaDataResultSet::getString( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+OUString SAL_CALL ODatabaseMetaDataResultSet::getString( sal_Int32 columnIndex )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -363,28 +361,25 @@ OUString SAL_CALL ODatabaseMetaDataResultSet::getString( sal_Int32 columnIndex )
     if(m_aValue.isNull())
         return OUString();
     if(m_aIntValueRange.size() && (m_aIntValueRangeIter = m_aIntValueRange.find(columnIndex)) != m_aIntValueRange.end())
-        return (*m_aIntValueRangeIter).second[m_aValue];
+        return (*m_aIntValueRangeIter).second[m_aValue.getInt32()];
 
-    return m_aValue;
+    return m_aValue.getString();
 }
 
 
-
-
-::com::sun::star::util::Time SAL_CALL ODatabaseMetaDataResultSet::getTime( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+css::util::Time SAL_CALL ODatabaseMetaDataResultSet::getTime( sal_Int32 columnIndex )
 {
-    return getValue(columnIndex);
+    return getValue(columnIndex).getTime();
 }
 
 
-
-::com::sun::star::util::DateTime SAL_CALL ODatabaseMetaDataResultSet::getTimestamp( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+css::util::DateTime SAL_CALL ODatabaseMetaDataResultSet::getTimestamp( sal_Int32 columnIndex )
 {
-    return getValue(columnIndex);
+    return getValue(columnIndex).getDateTime();
 }
 
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isAfterLast(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isAfterLast(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -397,7 +392,7 @@ sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isAfterLast(  ) throw(SQLException
     return bIsAtEOF == VARIANT_TRUE;
 }
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isFirst(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isFirst(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -408,7 +403,7 @@ sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isFirst(  ) throw(SQLException, Ru
     return m_nRowPos == 1;
 }
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isLast(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isLast(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -416,10 +411,10 @@ sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isLast(  ) throw(SQLException, Run
     checkRecordSet();
 
 
-    return sal_True;
+    return true;
 }
 
-void SAL_CALL ODatabaseMetaDataResultSet::beforeFirst(  ) throw(SQLException, RuntimeException)
+void SAL_CALL ODatabaseMetaDataResultSet::beforeFirst(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -431,7 +426,7 @@ void SAL_CALL ODatabaseMetaDataResultSet::beforeFirst(  ) throw(SQLException, Ru
         previous();
 }
 
-void SAL_CALL ODatabaseMetaDataResultSet::afterLast(  ) throw(SQLException, RuntimeException)
+void SAL_CALL ODatabaseMetaDataResultSet::afterLast(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -441,11 +436,11 @@ void SAL_CALL ODatabaseMetaDataResultSet::afterLast(  ) throw(SQLException, Runt
 
     if(last())
         next();
-    m_bEOF = sal_True;
+    m_bEOF = true;
 }
 
 
-void SAL_CALL ODatabaseMetaDataResultSet::close(  ) throw(SQLException, RuntimeException)
+void SAL_CALL ODatabaseMetaDataResultSet::close(  )
 {
     {
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -456,32 +451,32 @@ void SAL_CALL ODatabaseMetaDataResultSet::close(  ) throw(SQLException, RuntimeE
 }
 
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::first(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::first(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
 
 
     if(!m_pRecordSet)
-        return sal_False;
+        return false;
 
-    sal_Bool bRet = SUCCEEDED(m_pRecordSet->MoveFirst());
+    bool bRet = SUCCEEDED(m_pRecordSet->MoveFirst());
     if ( bRet )
         m_nRowPos = 1;
     return bRet;
 }
 
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::last(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::last(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed );
 
 
-    return m_pRecordSet && SUCCEEDED(m_pRecordSet->MoveLast()) ? sal_True : sal_False;
+    return m_pRecordSet && SUCCEEDED(m_pRecordSet->MoveLast());
 }
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::absolute( sal_Int32 row ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::absolute( sal_Int32 row )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -491,53 +486,53 @@ sal_Bool SAL_CALL ODatabaseMetaDataResultSet::absolute( sal_Int32 row ) throw(SQ
     {
         OLEVariant aEmpty;
         aEmpty.setNoArg();
-        sal_Bool bRet = SUCCEEDED(m_pRecordSet->Move(row,aEmpty));
+        bool bRet = SUCCEEDED(m_pRecordSet->Move(row,aEmpty));
         if(bRet)
             m_nRowPos = row;
         return bRet;
     }
-    return sal_False;
+    return false;
 }
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::relative( sal_Int32 row ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::relative( sal_Int32 row )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
 
 
     if(!m_pRecordSet)
-        return sal_False;
+        return false;
 
     OLEVariant aEmpty;
     aEmpty.setNoArg();
-    sal_Bool bRet = SUCCEEDED(m_pRecordSet->Move(row,aEmpty));
+    bool bRet = SUCCEEDED(m_pRecordSet->Move(row,aEmpty));
     if(bRet)
         m_nRowPos += row;
     return bRet;
 }
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::previous(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::previous(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
 
 
     if(!m_pRecordSet)
-        return sal_False;
+        return false;
 
-    sal_Bool bRet = SUCCEEDED(m_pRecordSet->MovePrevious());
+    bool bRet = SUCCEEDED(m_pRecordSet->MovePrevious());
     if(bRet)
         --m_nRowPos;
     return bRet;
 }
 
-Reference< XInterface > SAL_CALL ODatabaseMetaDataResultSet::getStatement(  ) throw(SQLException, RuntimeException)
+Reference< XInterface > SAL_CALL ODatabaseMetaDataResultSet::getStatement(  )
 {
     return m_aStatement.get();
 }
 
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::rowDeleted(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::rowDeleted(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -545,24 +540,24 @@ sal_Bool SAL_CALL ODatabaseMetaDataResultSet::rowDeleted(  ) throw(SQLException,
     checkRecordSet();
 
 
-    RecordStatusEnum eRec;
-    m_pRecordSet->get_Status((sal_Int32*)&eRec);
-    return (eRec & adRecDeleted) == adRecDeleted;
+    sal_Int32 eRec;
+    m_pRecordSet->get_Status(&eRec);
+    return (RecordStatusEnum(eRec) & adRecDeleted) == adRecDeleted;
 }
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::rowInserted(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::rowInserted(  )
 {   ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
 
     checkRecordSet();
 
 
-    RecordStatusEnum eRec;
-    m_pRecordSet->get_Status((sal_Int32*)&eRec);
-    return (eRec & adRecNew) == adRecNew;
+    sal_Int32 eRec;
+    m_pRecordSet->get_Status(&eRec);
+    return (RecordStatusEnum(eRec) & adRecNew) == adRecNew;
 }
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::rowUpdated(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::rowUpdated(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -570,20 +565,20 @@ sal_Bool SAL_CALL ODatabaseMetaDataResultSet::rowUpdated(  ) throw(SQLException,
     checkRecordSet();
 
 
-    RecordStatusEnum eRec;
-    m_pRecordSet->get_Status((sal_Int32*)&eRec);
-    return (eRec & adRecModified) == adRecModified;
+    sal_Int32 eRec;
+    m_pRecordSet->get_Status(&eRec);
+    return (RecordStatusEnum(eRec) & adRecModified) == adRecModified;
 }
 
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isBeforeFirst(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isBeforeFirst(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
 
 
     if(!m_pRecordSet)
-        return sal_True;
+        return true;
 
     VARIANT_BOOL bIsAtBOF;
     m_pRecordSet->get_BOF(&bIsAtBOF);
@@ -591,26 +586,26 @@ sal_Bool SAL_CALL ODatabaseMetaDataResultSet::isBeforeFirst(  ) throw(SQLExcepti
 }
 
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::next(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::next(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
 
 
     if(!m_pRecordSet)
-        return sal_False;
+        return false;
 
     if(m_bOnFirstAfterOpen)
     {
-        m_bOnFirstAfterOpen = sal_False;
-        return sal_True;
+        m_bOnFirstAfterOpen = false;
+        return true;
     }
     else
         return SUCCEEDED(m_pRecordSet->MoveNext());
 }
 
 
-sal_Bool SAL_CALL ODatabaseMetaDataResultSet::wasNull(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaDataResultSet::wasNull(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -621,7 +616,7 @@ sal_Bool SAL_CALL ODatabaseMetaDataResultSet::wasNull(  ) throw(SQLException, Ru
     return m_aValue.isNull();
 }
 
-void SAL_CALL ODatabaseMetaDataResultSet::refreshRow(  ) throw(SQLException, RuntimeException)
+void SAL_CALL ODatabaseMetaDataResultSet::refreshRow(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -629,11 +624,11 @@ void SAL_CALL ODatabaseMetaDataResultSet::refreshRow(  ) throw(SQLException, Run
     checkRecordSet();
 
 
-    m_pRecordSet->Resync(adAffectCurrent,adResyncAllValues);
+    m_pRecordSet->Resync(adAffectCurrent);
 }
 
 
-void SAL_CALL ODatabaseMetaDataResultSet::cancel(  ) throw(RuntimeException)
+void SAL_CALL ODatabaseMetaDataResultSet::cancel(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -644,35 +639,31 @@ void SAL_CALL ODatabaseMetaDataResultSet::cancel(  ) throw(RuntimeException)
     m_pRecordSet->Cancel();
 }
 
-void SAL_CALL ODatabaseMetaDataResultSet::clearWarnings(  ) throw(SQLException, RuntimeException)
+void SAL_CALL ODatabaseMetaDataResultSet::clearWarnings(  )
 {
 }
 
-Any SAL_CALL ODatabaseMetaDataResultSet::getWarnings(  ) throw(SQLException, RuntimeException)
+Any SAL_CALL ODatabaseMetaDataResultSet::getWarnings(  )
 {
     return Any();
 }
 
-sal_Int32 ODatabaseMetaDataResultSet::getResultSetConcurrency() const
-    throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
+sal_Int32 ODatabaseMetaDataResultSet::getResultSetConcurrency()
 {
     return ResultSetConcurrency::READ_ONLY;
 }
 
-sal_Int32 ODatabaseMetaDataResultSet::getResultSetType() const
-    throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
+sal_Int32 ODatabaseMetaDataResultSet::getResultSetType()
 {
     return ResultSetType::FORWARD_ONLY;
 }
 
-sal_Int32 ODatabaseMetaDataResultSet::getFetchDirection() const
-    throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
+sal_Int32 ODatabaseMetaDataResultSet::getFetchDirection()
 {
     return FetchDirection::FORWARD;
 }
 
 sal_Int32 ODatabaseMetaDataResultSet::getFetchSize() const
-    throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
 {
     sal_Int32 nValue=-1;
     if(m_pRecordSet)
@@ -680,21 +671,18 @@ sal_Int32 ODatabaseMetaDataResultSet::getFetchSize() const
     return nValue;
 }
 
-OUString ODatabaseMetaDataResultSet::getCursorName() const
-    throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
+OUString ODatabaseMetaDataResultSet::getCursorName()
 {
     return OUString();
 }
 
 
 void ODatabaseMetaDataResultSet::setFetchDirection(sal_Int32 /*_par0*/)
-    throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
 {
     ::dbtools::throwFeatureNotImplementedSQLException( "ResultSet::FetchDirection", *this );
 }
 
 void ODatabaseMetaDataResultSet::setFetchSize(sal_Int32 _par0)
-    throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
 {
     if(m_pRecordSet)
         m_pRecordSet->put_CacheSize(_par0);
@@ -703,18 +691,18 @@ void ODatabaseMetaDataResultSet::setFetchSize(sal_Int32 _par0)
 ::cppu::IPropertyArrayHelper* ODatabaseMetaDataResultSet::createArrayHelper( ) const
 {
 
-    Sequence< com::sun::star::beans::Property > aProps(5);
-    com::sun::star::beans::Property* pProperties = aProps.getArray();
+    Sequence< css::beans::Property > aProps(5);
+    css::beans::Property* pProperties = aProps.getArray();
     sal_Int32 nPos = 0;
-    pProperties[nPos++] = ::com::sun::star::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_CURSORNAME),
+    pProperties[nPos++] = css::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_CURSORNAME),
         PROPERTY_ID_CURSORNAME, cppu::UnoType<OUString>::get(), 0);
-    pProperties[nPos++] = ::com::sun::star::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_FETCHDIRECTION),
+    pProperties[nPos++] = css::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_FETCHDIRECTION),
         PROPERTY_ID_FETCHDIRECTION, cppu::UnoType<sal_Int32>::get(), 0);
-    pProperties[nPos++] = ::com::sun::star::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_FETCHSIZE),
+    pProperties[nPos++] = css::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_FETCHSIZE),
         PROPERTY_ID_FETCHSIZE, cppu::UnoType<sal_Int32>::get(), 0);
-    pProperties[nPos++] = ::com::sun::star::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_RESULTSETCONCURRENCY),
+    pProperties[nPos++] = css::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_RESULTSETCONCURRENCY),
         PROPERTY_ID_RESULTSETCONCURRENCY, cppu::UnoType<sal_Int32>::get(), 0);
-    pProperties[nPos++] = ::com::sun::star::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_RESULTSETTYPE),
+    pProperties[nPos++] = css::beans::Property(::connectivity::OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_RESULTSETTYPE),
         PROPERTY_ID_RESULTSETTYPE, cppu::UnoType<sal_Int32>::get(), 0);
 
     return new ::cppu::OPropertyArrayHelper(aProps);
@@ -722,7 +710,7 @@ void ODatabaseMetaDataResultSet::setFetchSize(sal_Int32 _par0)
 
 ::cppu::IPropertyArrayHelper & ODatabaseMetaDataResultSet::getInfoHelper()
 {
-    return *const_cast<ODatabaseMetaDataResultSet*>(this)->getArrayHelper();
+    return *getArrayHelper();
 }
 
 sal_Bool ODatabaseMetaDataResultSet::convertFastPropertyValue(
@@ -730,14 +718,13 @@ sal_Bool ODatabaseMetaDataResultSet::convertFastPropertyValue(
                             Any & rOldValue,
                             sal_Int32 nHandle,
                             const Any& rValue )
-                                throw (::com::sun::star::lang::IllegalArgumentException)
 {
     switch(nHandle)
     {
         case PROPERTY_ID_CURSORNAME:
         case PROPERTY_ID_RESULTSETCONCURRENCY:
         case PROPERTY_ID_RESULTSETTYPE:
-            throw ::com::sun::star::lang::IllegalArgumentException();
+            throw css::lang::IllegalArgumentException();
         case PROPERTY_ID_FETCHDIRECTION:
             return ::comphelper::tryPropertyValue(rConvertedValue, rOldValue, rValue, getFetchDirection());
         case PROPERTY_ID_FETCHSIZE:
@@ -745,14 +732,13 @@ sal_Bool ODatabaseMetaDataResultSet::convertFastPropertyValue(
         default:
             ;
     }
-    return sal_False;
+    return false;
 }
 
 void ODatabaseMetaDataResultSet::setFastPropertyValue_NoBroadcast(
                                 sal_Int32 nHandle,
                                 const Any& /*rValue*/
                                                  )
-                                                 throw (Exception)
 {
     switch(nHandle)
     {
@@ -761,7 +747,7 @@ void ODatabaseMetaDataResultSet::setFastPropertyValue_NoBroadcast(
         case PROPERTY_ID_RESULTSETTYPE:
         case PROPERTY_ID_FETCHDIRECTION:
         case PROPERTY_ID_FETCHSIZE:
-            throw Exception();
+            throw Exception("cannot set prop " + OUString::number(nHandle), nullptr);
         default:
             OSL_FAIL("setFastPropertyValue_NoBroadcast: Illegal handle value!");
     }
@@ -911,7 +897,7 @@ void ODatabaseMetaDataResultSet::setColumnsMap()
 
     m_aValueRange[12] = aMap;
 
-    ::std::map< sal_Int32,OUString> aMap2;
+    std::map< sal_Int32,OUString> aMap2;
     aMap2[0] = "YES";
     aMap2[1] = "NO";
     m_aIntValueRange[18] = aMap2;
@@ -1044,7 +1030,7 @@ void ODatabaseMetaDataResultSet::setIndexInfoMap()
     aMap[1] = 0;
     m_aValueRange[8] = aMap2;
 
-    ::std::map< sal_Int32,OUString> aMap3;
+    std::map< sal_Int32,OUString> aMap3;
     aMap3[0]                    = "";
     aMap3[DB_COLLATION_ASC]     = "A";
     aMap3[DB_COLLATION_DESC]    = "D";
@@ -1067,7 +1053,7 @@ void ODatabaseMetaDataResultSet::setTablePrivilegesMap()
     m_aColMapping.push_back(6);
     m_aColMapping.push_back(7);
 
-    ::std::map< sal_Int32,OUString> aMap;
+    std::map< sal_Int32,OUString> aMap;
     aMap[0] = "YES";
     aMap[1] = "NO";
     m_aIntValueRange[7] = aMap;
@@ -1094,7 +1080,7 @@ void ODatabaseMetaDataResultSet::setCrossReferenceMap()
     m_aColMapping.push_back(16);
     m_aColMapping.push_back(18);
 
-    ::std::map< OUString,sal_Int32> aMap;
+    std::map< OUString,sal_Int32> aMap;
     aMap[ OUString("CASCADE")] = KeyRule::CASCADE;
     aMap[ OUString("RESTRICT")] = KeyRule::RESTRICT;
     aMap[ OUString("SET NULL")] = KeyRule::SET_NULL;
@@ -1109,13 +1095,13 @@ void ODatabaseMetaDataResultSet::setCrossReferenceMap()
     m_xMetaData = pMetaData;
 }
 
-void ODatabaseMetaDataResultSet::setTypeInfoMap(sal_Bool _bJetEngine)
+void ODatabaseMetaDataResultSet::setTypeInfoMap(bool _bJetEngine)
 {
     sal_Int32 i=1;
     for(;i<19;i++)
         m_aColMapping.push_back(i);
 
-    ::std::map< OUString,sal_Int32> aMap1;
+    std::map< OUString,sal_Int32> aMap1;
     aMap1[ OUString()] = 10;
 
     m_aStrValueRange[18] = aMap1;
@@ -1197,12 +1183,12 @@ void SAL_CALL ODatabaseMetaDataResultSet::release() throw()
     ODatabaseMetaDataResultSet_BASE::release();
 }
 
-::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > SAL_CALL ODatabaseMetaDataResultSet::getPropertySetInfo(  ) throw(::com::sun::star::uno::RuntimeException)
+css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL ODatabaseMetaDataResultSet::getPropertySetInfo(  )
 {
     return ::cppu::OPropertySetHelper::createPropertySetInfo(getInfoHelper());
 }
 
-OLEVariant ODatabaseMetaDataResultSet::getValue(sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+OLEVariant ODatabaseMetaDataResultSet::getValue(sal_Int32 columnIndex )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(ODatabaseMetaDataResultSet_BASE::rBHelper.bDisposed);
@@ -1215,5 +1201,4 @@ OLEVariant ODatabaseMetaDataResultSet::getValue(sal_Int32 columnIndex ) throw(SQ
 }
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
