@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "calc/CTable.hxx"
+#include <calc/CTable.hxx>
 #include <com/sun/star/sdbc/ColumnValue.hpp>
 #include <com/sun/star/sdbc/DataType.hpp>
 #include <com/sun/star/sdbc/XRow.hpp>
@@ -35,8 +35,8 @@
 #include <com/sun/star/util/XNumberFormatsSupplier.hpp>
 #include <com/sun/star/text/XText.hpp>
 #include <svl/converter.hxx>
-#include "calc/CConnection.hxx"
-#include "calc/CColumns.hxx"
+#include <calc/CConnection.hxx>
+#include <component/CColumns.hxx>
 #include <connectivity/sdbcx/VColumn.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <osl/thread.h>
@@ -115,7 +115,7 @@ static void lcl_GetDataArea( const Reference<XSpreadsheet>& xSheet, sal_Int32& r
         //  If the used area is larger than the contiguous cell area, find non-empty
         //  cells in that area.
 
-        xUsed->gotoEndOfUsedArea( sal_False );
+        xUsed->gotoEndOfUsedArea( false );
         CellRangeAddress aUsedAddr = xRange->getRangeAddress();
 
         if ( aUsedAddr.EndColumn > aRegionAddr.EndColumn )
@@ -305,7 +305,6 @@ static void lcl_GetColumnInfo( const Reference<XSpreadsheet>& xSheet, const Refe
 }
 
 
-
 static void lcl_SetValue( ORowSetValue& rValue, const Reference<XSpreadsheet>& xSheet,
                     sal_Int32 nStartCol, sal_Int32 nStartRow, bool bHasHeaders,
                     const ::Date& rNullDate,
@@ -349,7 +348,7 @@ static void lcl_SetValue( ORowSetValue& rValue, const Reference<XSpreadsheet>& x
                 if ( eCellType == CellContentType_VALUE )
                 {
                     ::Date aDate( rNullDate );
-                    aDate += (long)::rtl::math::approxFloor( xCell->getValue() );
+                    aDate.AddDays(::rtl::math::approxFloor( xCell->getValue() ));
                     rValue = aDate.GetUNODate();
                 }
                 else
@@ -363,7 +362,7 @@ static void lcl_SetValue( ORowSetValue& rValue, const Reference<XSpreadsheet>& x
                     sal_Int64 nIntTime = static_cast<sal_Int64>(rtl::math::round( fTime * static_cast<double>(::tools::Time::nanoSecPerDay) ));
                     if ( nIntTime ==  ::tools::Time::nanoSecPerDay)
                         nIntTime = 0;                       // 23:59:59.9999999995 and above is 00:00:00.00
-                    ::com::sun::star::util::Time aTime;
+                    css::util::Time aTime;
                     aTime.NanoSeconds = (sal_uInt32)( nIntTime % ::tools::Time::nanoSecPerSec );
                     nIntTime /= ::tools::Time::nanoSecPerSec;
                     aTime.Seconds = (sal_uInt16)( nIntTime % 60 );
@@ -391,7 +390,7 @@ static void lcl_SetValue( ORowSetValue& rValue, const Reference<XSpreadsheet>& x
                         ++nIntDays;                         // (next day)
                     }
 
-                    ::com::sun::star::util::DateTime aDateTime;
+                    css::util::DateTime aDateTime;
 
                     aDateTime.NanoSeconds = (sal_uInt16)( nIntTime % ::tools::Time::nanoSecPerSec );
                     nIntTime /= ::tools::Time::nanoSecPerSec;
@@ -403,7 +402,7 @@ static void lcl_SetValue( ORowSetValue& rValue, const Reference<XSpreadsheet>& x
                     aDateTime.Hours = (sal_uInt16) nIntTime;
 
                     ::Date aDate( rNullDate );
-                    aDate += nIntDays;
+                    aDate.AddDays( nIntDays );
                     aDateTime.Day = aDate.GetDay();
                     aDateTime.Month = aDate.GetMonth();
                     aDateTime.Year = aDate.GetYear();
@@ -420,7 +419,6 @@ static void lcl_SetValue( ORowSetValue& rValue, const Reference<XSpreadsheet>& x
 }
 
 
-
 static OUString lcl_GetColumnStr( sal_Int32 nColumn )
 {
     if ( nColumn < 26 )
@@ -462,10 +460,7 @@ void OCalcTable::fillColumns()
         switch ( eType )
         {
             case DataType::VARCHAR:
-                {
-                    static const OUString s_sType("VARCHAR");
-                    aTypeName = s_sType;
-                }
+                aTypeName = "VARCHAR";
                 break;
             case DataType::DECIMAL:
                 aTypeName = "DECIMAL";
@@ -512,21 +507,20 @@ void OCalcTable::fillColumns()
 
 
 OCalcTable::OCalcTable(sdbcx::OCollection* _pTables,OCalcConnection* _pConnection,
-                    const OUString& _Name,
-                    const OUString& _Type,
-                    const OUString& _Description ,
-                    const OUString& _SchemaName,
-                    const OUString& _CatalogName
-                ) : OCalcTable_BASE(_pTables,_pConnection,_Name,
-                                  _Type,
-                                  _Description,
-                                  _SchemaName,
-                                  _CatalogName)
-                ,m_pConnection(_pConnection)
+                    const OUString& Name,
+                    const OUString& Type,
+                    const OUString& Description ,
+                    const OUString& SchemaName,
+                    const OUString& CatalogName
+                ) : OCalcTable_BASE(_pTables,_pConnection,Name,
+                                  Type,
+                                  Description,
+                                  SchemaName,
+                                  CatalogName)
+                ,m_pCalcConnection(_pConnection)
                 ,m_nStartCol(0)
                 ,m_nStartRow(0)
                 ,m_nDataCols(0)
-                ,m_nDataRows(0)
                 ,m_bHasHeaders(false)
                 ,m_aNullDate(::Date::EMPTY)
 {
@@ -535,7 +529,7 @@ OCalcTable::OCalcTable(sdbcx::OCollection* _pTables,OCalcConnection* _pConnectio
 void OCalcTable::construct()
 {
     //  get sheet object
-    Reference< XSpreadsheetDocument> xDoc = m_pConnection->acquireDoc();
+    Reference< XSpreadsheetDocument> xDoc = m_pCalcConnection->acquireDoc();
     if (xDoc.is())
     {
         Reference<XSpreadsheets> xSheets = xDoc->getSheets();
@@ -601,7 +595,7 @@ void OCalcTable::construct()
         Reference<XPropertySet> xProp( xDoc, UNO_QUERY );
         if (xProp.is())
         {
-            ::com::sun::star::util::Date aDateStruct;
+            css::util::Date aDateStruct;
             if ( xProp->getPropertyValue("NullDate") >>= aDateStruct )
                 m_aNullDate = ::Date( aDateStruct.Day, aDateStruct.Month, aDateStruct.Year );
         }
@@ -614,183 +608,39 @@ void OCalcTable::construct()
     refreshColumns();
 }
 
-void OCalcTable::refreshColumns()
-{
-    ::osl::MutexGuard aGuard( m_aMutex );
-
-    TStringVector aVector;
-
-    OSQLColumns::Vector::const_iterator aEnd = m_aColumns->get().end();
-    for(OSQLColumns::Vector::const_iterator aIter = m_aColumns->get().begin();aIter != aEnd;++aIter)
-        aVector.push_back(Reference< XNamed>(*aIter,UNO_QUERY)->getName());
-
-    if(m_pColumns)
-        m_pColumns->reFill(aVector);
-    else
-        m_pColumns  = new OCalcColumns(this,m_aMutex,aVector);
-}
-
-void OCalcTable::refreshIndexes()
-{
-    //  Calc table has no index
-}
-
-
 void SAL_CALL OCalcTable::disposing()
 {
     OFileTable::disposing();
     ::osl::MutexGuard aGuard(m_aMutex);
-    m_aColumns = NULL;
-    if ( m_pConnection )
-        m_pConnection->releaseDoc();
-    m_pConnection = NULL;
+    m_aColumns = nullptr;
+    if ( m_pCalcConnection )
+        m_pCalcConnection->releaseDoc();
+    m_pCalcConnection = nullptr;
 
 }
 
-Sequence< Type > SAL_CALL OCalcTable::getTypes(  ) throw(RuntimeException, std::exception)
-{
-    Sequence< Type > aTypes = OTable_TYPEDEF::getTypes();
-    ::std::vector<Type> aOwnTypes;
-    aOwnTypes.reserve(aTypes.getLength());
-
-    const Type* pBegin = aTypes.getConstArray();
-    const Type* pEnd = pBegin + aTypes.getLength();
-    for(;pBegin != pEnd;++pBegin)
-    {
-        if(!(   *pBegin == cppu::UnoType<XKeysSupplier>::get()||
-                *pBegin == cppu::UnoType<XIndexesSupplier>::get()||
-                *pBegin == cppu::UnoType<XRename>::get()||
-                *pBegin == cppu::UnoType<XAlterTable>::get()||
-                *pBegin == cppu::UnoType<XDataDescriptorFactory>::get()))
-            aOwnTypes.push_back(*pBegin);
-    }
-    aOwnTypes.push_back(cppu::UnoType<com::sun::star::lang::XUnoTunnel>::get());
-
-    return Sequence< Type >(aOwnTypes.data(), aOwnTypes.size());
-}
-
-
-Any SAL_CALL OCalcTable::queryInterface( const Type & rType ) throw(RuntimeException, std::exception)
-{
-    if( rType == cppu::UnoType<XKeysSupplier>::get()||
-        rType == cppu::UnoType<XIndexesSupplier>::get()||
-        rType == cppu::UnoType<XRename>::get()||
-        rType == cppu::UnoType<XAlterTable>::get()||
-        rType == cppu::UnoType<XDataDescriptorFactory>::get())
-        return Any();
-
-    const Any aRet = ::cppu::queryInterface(rType,static_cast< ::com::sun::star::lang::XUnoTunnel*> (this));
-    return aRet.hasValue() ? aRet : OTable_TYPEDEF::queryInterface(rType);
-}
-
-
 Sequence< sal_Int8 > OCalcTable::getUnoTunnelImplementationId()
 {
-    static ::cppu::OImplementationId * pId = 0;
-    if (! pId)
-    {
-        ::osl::MutexGuard aGuard( ::osl::Mutex::getGlobalMutex() );
-        if (! pId)
-        {
-            static ::cppu::OImplementationId aId;
-            pId = &aId;
-        }
-    }
-    return pId->getImplementationId();
+    static ::cppu::OImplementationId implId;
+
+    return implId.getImplementationId();
 }
 
-// com::sun::star::lang::XUnoTunnel
+// css::lang::XUnoTunnel
 
-sal_Int64 OCalcTable::getSomething( const Sequence< sal_Int8 > & rId ) throw (RuntimeException, std::exception)
+sal_Int64 OCalcTable::getSomething( const Sequence< sal_Int8 > & rId )
 {
     return (rId.getLength() == 16 && 0 == memcmp(getUnoTunnelImplementationId().getConstArray(),  rId.getConstArray(), 16 ) )
                 ? reinterpret_cast< sal_Int64 >( this )
                 : OCalcTable_BASE::getSomething(rId);
 }
 
-sal_Int32 OCalcTable::getCurrentLastPos() const
-{
-    return m_nDataRows;
-}
-
-bool OCalcTable::seekRow(IResultSetHelper::Movement eCursorPosition, sal_Int32 nOffset, sal_Int32& nCurPos)
-{
-    // prepare positioning:
-
-    sal_uInt32 nNumberOfRecords = m_nDataRows;
-    sal_uInt32 nTempPos = m_nFilePos;
-    m_nFilePos = nCurPos;
-
-    switch(eCursorPosition)
-    {
-        case IResultSetHelper::NEXT:
-            m_nFilePos++;
-            break;
-        case IResultSetHelper::PRIOR:
-            if (m_nFilePos > 0)
-                m_nFilePos--;
-            break;
-        case IResultSetHelper::FIRST:
-            m_nFilePos = 1;
-            break;
-        case IResultSetHelper::LAST:
-            m_nFilePos = nNumberOfRecords;
-            break;
-        case IResultSetHelper::RELATIVE1:
-            m_nFilePos = (((sal_Int32)m_nFilePos) + nOffset < 0) ? 0L
-                            : (sal_uInt32)(((sal_Int32)m_nFilePos) + nOffset);
-            break;
-        case IResultSetHelper::ABSOLUTE1:
-        case IResultSetHelper::BOOKMARK:
-            m_nFilePos = (sal_uInt32)nOffset;
-            break;
-    }
-
-    if (m_nFilePos > (sal_Int32)nNumberOfRecords)
-        m_nFilePos = (sal_Int32)nNumberOfRecords + 1;
-
-    if (m_nFilePos == 0 || m_nFilePos == (sal_Int32)nNumberOfRecords + 1)
-        goto Error;
-    else
-    {
-        //! read buffer / setup row object etc?
-    }
-    goto End;
-
-Error:
-    switch(eCursorPosition)
-    {
-        case IResultSetHelper::PRIOR:
-        case IResultSetHelper::FIRST:
-            m_nFilePos = 0;
-            break;
-        case IResultSetHelper::LAST:
-        case IResultSetHelper::NEXT:
-        case IResultSetHelper::ABSOLUTE1:
-        case IResultSetHelper::RELATIVE1:
-            if (nOffset > 0)
-                m_nFilePos = nNumberOfRecords + 1;
-            else if (nOffset < 0)
-                m_nFilePos = 0;
-            break;
-        case IResultSetHelper::BOOKMARK:
-            m_nFilePos = nTempPos;   // previous position
-    }
-    //  aStatus.Set(SDB_STAT_NO_DATA_FOUND);
-    return false;
-
-End:
-    nCurPos = m_nFilePos;
-    return true;
-}
-
 bool OCalcTable::fetchRow( OValueRefRow& _rRow, const OSQLColumns & _rCols,
-                           bool _bUseTableDefs, bool bRetrieveData )
+                           bool bRetrieveData )
 {
     // read the bookmark
 
-    bool bIsCurRecordDeleted = false;
-    _rRow->setDeleted(bIsCurRecordDeleted);
+    _rRow->setDeleted(false);
     *(_rRow->get())[0] = m_nFilePos;
 
     if (!bRetrieveData)
@@ -806,12 +656,7 @@ bool OCalcTable::fetchRow( OValueRefRow& _rRow, const OSQLColumns & _rCols,
     {
         if ( (_rRow->get())[i]->isBound() )
         {
-            sal_Int32 nType = 0;
-            if ( _bUseTableDefs )
-                nType = m_aTypes[i-1];
-            else
-                (*aIter)->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_TYPE)) >>= nType;
-
+            sal_Int32 nType = m_aTypes[i-1];
 
             lcl_SetValue( (_rRow->get())[i]->get(), m_xSheet, m_nStartCol, m_nStartRow, m_bHasHeaders,
                                 m_aNullDate, m_nFilePos, i, nType );
@@ -820,12 +665,4 @@ bool OCalcTable::fetchRow( OValueRefRow& _rRow, const OSQLColumns & _rCols,
     return true;
 }
 
-void OCalcTable::FileClose()
-{
-    ::osl::MutexGuard aGuard(m_aMutex);
-
-    OCalcTable_BASE::FileClose();
-}
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
