@@ -17,7 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "dbase/DDatabaseMetaData.hxx"
+#include <dbase/DDatabaseMetaData.hxx>
+#include <com/sun/star/lang/WrappedTargetRuntimeException.hpp>
 #include <com/sun/star/sdbc/DataType.hpp>
 #include <com/sun/star/sdbc/ResultSetType.hpp>
 #include <com/sun/star/sdbc/ColumnValue.hpp>
@@ -25,14 +26,12 @@
 #include <com/sun/star/sdbc/ResultSetConcurrency.hpp>
 #include <com/sun/star/sdbcx/XColumnsSupplier.hpp>
 #include <com/sun/star/sdbcx/XIndexesSupplier.hpp>
-#include "FDatabaseMetaDataResultSet.hxx"
+#include <FDatabaseMetaDataResultSet.hxx>
 #include <com/sun/star/lang/XUnoTunnel.hpp>
-#include "dbase/DIndex.hxx"
-#include "connectivity/FValue.hxx"
-#include <comphelper/extract.hxx>
+#include <dbase/DIndex.hxx>
+#include <connectivity/FValue.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/types.hxx>
-#include <tools/string.hxx>
 #include <ucbhelper/content.hxx>
 
 using namespace ::comphelper;
@@ -48,16 +47,14 @@ using namespace ::com::sun::star::lang;
 
 ODbaseDatabaseMetaData::ODbaseDatabaseMetaData(::connectivity::file::OConnection* _pCon)    :ODatabaseMetaData(_pCon)
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::ODbaseDatabaseMetaData" );
 }
-// -------------------------------------------------------------------------
+
 ODbaseDatabaseMetaData::~ODbaseDatabaseMetaData()
 {
 }
-// -------------------------------------------------------------------------
+
 Reference< XResultSet > ODbaseDatabaseMetaData::impl_getTypeInfo_throw(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::impl_getTypeInfo_throw" );
     ::osl::MutexGuard aGuard( m_aMutex );
 
     ::connectivity::ODatabaseMetaDataResultSet* pResult = new ::connectivity::ODatabaseMetaDataResultSet(::connectivity::ODatabaseMetaDataResultSet::eTypeInfo);
@@ -120,13 +117,13 @@ Reference< XResultSet > ODbaseDatabaseMetaData::impl_getTypeInfo_throw(  )
         aRow[13] = new ORowSetValueDecorator(OUString("B"));
         aRows.push_back(aRow);
 
-        aRow[11] = new ORowSetValueDecorator(sal_True);
+        aRow[11] = new ORowSetValueDecorator(true);
         aRow[13] = new ORowSetValueDecorator(OUString("Y"));
         aRows.push_back(aRow);
 
         aRow[1] = new ORowSetValueDecorator(OUString("TIMESTAMP"));
         aRow[2] = new ORowSetValueDecorator(DataType::TIMESTAMP);
-        aRow[11] = new ORowSetValueDecorator(sal_False);
+        aRow[11] = new ORowSetValueDecorator(false);
         aRow[13] = new ORowSetValueDecorator(OUString("T"));
         aRows.push_back(aRow);
 
@@ -154,15 +151,13 @@ Reference< XResultSet > ODbaseDatabaseMetaData::impl_getTypeInfo_throw(  )
     pResult->setRows(aRows);
     return xRef;
 }
-// -------------------------------------------------------------------------
+
 Reference< XResultSet > SAL_CALL ODbaseDatabaseMetaData::getColumns(
     const Any& /*catalog*/, const OUString& /*schemaPattern*/, const OUString& tableNamePattern,
-        const OUString& columnNamePattern ) throw(SQLException, RuntimeException)
+        const OUString& columnNamePattern )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::getColumns" );
     ::osl::MutexGuard aGuard( m_aMutex );
 
-
     Reference< XTablesSupplier > xTables = m_pConnection->createCatalog();
     if(!xTables.is())
         throw SQLException();
@@ -174,83 +169,93 @@ Reference< XResultSet > SAL_CALL ODbaseDatabaseMetaData::getColumns(
     ODatabaseMetaDataResultSet::ORows aRows;
     ODatabaseMetaDataResultSet::ORow aRow(19);
 
-    aRow[10] = new ORowSetValueDecorator((sal_Int32)10);
-    Sequence< OUString> aTabNames(xNames->getElementNames());
-    const OUString* pTabBegin    = aTabNames.getConstArray();
-    const OUString* pTabEnd      = pTabBegin + aTabNames.getLength();
-    for(;pTabBegin != pTabEnd;++pTabBegin)
+    try
     {
-        if(match(tableNamePattern,*pTabBegin,'\0'))
+        aRow[10] = new ORowSetValueDecorator((sal_Int32)10);
+        Sequence< OUString> aTabNames(xNames->getElementNames());
+        const OUString* pTabBegin    = aTabNames.getConstArray();
+        const OUString* pTabEnd      = pTabBegin + aTabNames.getLength();
+        for(;pTabBegin != pTabEnd;++pTabBegin)
         {
-            Reference< XColumnsSupplier> xTable;
-            ::cppu::extractInterface(xTable,xNames->getByName(*pTabBegin));
-            OSL_ENSURE(xTable.is(),"Table not found! Normallya exception had to be thrown here!");
-            aRow[3] = new ORowSetValueDecorator(*pTabBegin);
-
-            Reference< XNameAccess> xColumns = xTable->getColumns();
-            if(!xColumns.is())
-                throw SQLException();
-
-            Sequence< OUString> aColNames(xColumns->getElementNames());
-
-            const OUString* pBegin = aColNames.getConstArray();
-            const OUString* pEnd = pBegin + aColNames.getLength();
-            Reference< XPropertySet> xColumn;
-            for(sal_Int32 i=1;pBegin != pEnd;++pBegin,++i)
+            if(match(tableNamePattern,*pTabBegin,'\0'))
             {
-                if(match(columnNamePattern,*pBegin,'\0'))
-                {
-                    aRow[4] = new ORowSetValueDecorator(*pBegin);
+                Reference< XColumnsSupplier> xTable(
+                    xNames->getByName(*pTabBegin), css::uno::UNO_QUERY);
+                OSL_ENSURE(xTable.is(),"Table not found! Normally a exception had to be thrown here!");
+                aRow[3] = new ORowSetValueDecorator(*pTabBegin);
 
-                    ::cppu::extractInterface(xColumn,xColumns->getByName(*pBegin));
-                    OSL_ENSURE(xColumn.is(),"Columns contains a column who isn't a fastpropertyset!");
-                    aRow[5] = new ORowSetValueDecorator(getINT32(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_TYPE))));
-                    aRow[6] = new ORowSetValueDecorator(getString(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_TYPENAME))));
-                    aRow[7] = new ORowSetValueDecorator(getINT32(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_PRECISION))));
-                    aRow[9] = new ORowSetValueDecorator(getINT32(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_SCALE))));
-                    aRow[11] = new ORowSetValueDecorator(getINT32(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_ISNULLABLE))));
-                    aRow[13] = new ORowSetValueDecorator(getString(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_DEFAULTVALUE))));
-                    switch((sal_Int32)aRow[5]->getValue())
+                Reference< XNameAccess> xColumns = xTable->getColumns();
+                if(!xColumns.is())
+                    throw SQLException();
+
+                Sequence< OUString> aColNames(xColumns->getElementNames());
+
+                const OUString* pBegin = aColNames.getConstArray();
+                const OUString* pEnd = pBegin + aColNames.getLength();
+                Reference< XPropertySet> xColumn;
+                for(sal_Int32 i=1;pBegin != pEnd;++pBegin,++i)
+                {
+                    if(match(columnNamePattern,*pBegin,'\0'))
                     {
-                    case DataType::CHAR:
-                    case DataType::VARCHAR:
-                        aRow[16] = new ORowSetValueDecorator((sal_Int32)254);
-                        break;
-                    case DataType::LONGVARCHAR:
-                        aRow[16] = new ORowSetValueDecorator((sal_Int32)65535);
-                        break;
-                    default:
-                        aRow[16] = new ORowSetValueDecorator((sal_Int32)0);
+                        aRow[4] = new ORowSetValueDecorator(*pBegin);
+
+                        xColumn.set(
+                            xColumns->getByName(*pBegin), css::uno::UNO_QUERY);
+                        OSL_ENSURE(xColumn.is(),"Columns contains a column who isn't a fastpropertyset!");
+                        aRow[5] = new ORowSetValueDecorator(getINT32(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_TYPE))));
+                        aRow[6] = new ORowSetValueDecorator(getString(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_TYPENAME))));
+                        aRow[7] = new ORowSetValueDecorator(getINT32(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_PRECISION))));
+                        aRow[9] = new ORowSetValueDecorator(getINT32(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_SCALE))));
+                        aRow[11] = new ORowSetValueDecorator(getINT32(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_ISNULLABLE))));
+                        aRow[13] = new ORowSetValueDecorator(getString(xColumn->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_DEFAULTVALUE))));
+                        switch((sal_Int32)aRow[5]->getValue())
+                        {
+                        case DataType::CHAR:
+                        case DataType::VARCHAR:
+                            aRow[16] = new ORowSetValueDecorator((sal_Int32)254);
+                            break;
+                        case DataType::LONGVARCHAR:
+                            aRow[16] = new ORowSetValueDecorator((sal_Int32)65535);
+                            break;
+                        default:
+                            aRow[16] = new ORowSetValueDecorator((sal_Int32)0);
+                        }
+                        aRow[17] = new ORowSetValueDecorator(i);
+                        switch(sal_Int32(aRow[11]->getValue()))
+                        {
+                        case ColumnValue::NO_NULLS:
+                            aRow[18] = new ORowSetValueDecorator(OUString("NO"));
+                            break;
+                        case ColumnValue::NULLABLE:
+                            aRow[18] = new ORowSetValueDecorator(OUString("YES"));
+                            break;
+                        default:
+                            aRow[18] = new ORowSetValueDecorator(OUString());
+                        }
+                        aRows.push_back(aRow);
                     }
-                    aRow[17] = new ORowSetValueDecorator(i);
-                    switch(sal_Int32(aRow[11]->getValue()))
-                    {
-                    case ColumnValue::NO_NULLS:
-                        aRow[18] = new ORowSetValueDecorator(OUString("NO"));
-                        break;
-                    case ColumnValue::NULLABLE:
-                        aRow[18] = new ORowSetValueDecorator(OUString("YES"));
-                        break;
-                    default:
-                        aRow[18] = new ORowSetValueDecorator(OUString());
-                    }
-                    aRows.push_back(aRow);
                 }
             }
         }
     }
+    catch (const WrappedTargetException& e)
+    {
+        SQLException aSql;
+        if (e.TargetException >>= aSql)
+            throw aSql;
+        throw WrappedTargetRuntimeException(e.Message, e.Context, e.TargetException);
+    }
     ::connectivity::ODatabaseMetaDataResultSet* pResult = new ::connectivity::ODatabaseMetaDataResultSet(::connectivity::ODatabaseMetaDataResultSet::eColumns);
     Reference< XResultSet > xRef = pResult;
     pResult->setRows(aRows);
 
     return xRef;
 }
-// -------------------------------------------------------------------------
+
 Reference< XResultSet > SAL_CALL ODbaseDatabaseMetaData::getIndexInfo(
     const Any& /*catalog*/, const OUString& /*schema*/, const OUString& table,
-        sal_Bool unique, sal_Bool /*approximate*/ ) throw(SQLException, RuntimeException)
+        sal_Bool unique, sal_Bool /*approximate*/ )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::getIndexInfo" );
     ::osl::MutexGuard aGuard( m_aMutex );
 
         Reference< XTablesSupplier > xTables = m_pConnection->createCatalog();
@@ -267,8 +272,8 @@ Reference< XResultSet > SAL_CALL ODbaseDatabaseMetaData::getIndexInfo(
     aRow[5]     = new ORowSetValueDecorator(OUString());
     aRow[10]    = new ORowSetValueDecorator(OUString("A"));
 
-    Reference< XIndexesSupplier> xTable;
-    ::cppu::extractInterface(xTable,xNames->getByName(table));
+    Reference< XIndexesSupplier> xTable(
+        xNames->getByName(table), css::uno::UNO_QUERY);
     aRow[3] = new ORowSetValueDecorator(table);
     aRow[7] = new ORowSetValueDecorator((sal_Int32)3);
 
@@ -283,7 +288,7 @@ Reference< XResultSet > SAL_CALL ODbaseDatabaseMetaData::getIndexInfo(
     Reference< XPropertySet> xIndex;
     for(;pBegin != pEnd;++pBegin)
     {
-        ::cppu::extractInterface(xIndex,xIndexes->getByName(*pBegin));
+        xIndex.set(xIndexes->getByName(*pBegin), css::uno::UNO_QUERY);
         OSL_ENSURE(xIndex.is(),"Indexes contains a column who isn't a fastpropertyset!");
 
         if(unique && !getBOOL(xIndex->getPropertyValue(OMetaConnection::getPropMap().getNameByIndex(PROPERTY_ID_ISUNIQUE))))
@@ -308,7 +313,6 @@ Reference< XResultSet > SAL_CALL ODbaseDatabaseMetaData::getIndexInfo(
 
         const OUString* pColBegin = aColNames.getConstArray();
         const OUString* pColEnd = pColBegin + aColNames.getLength();
-        Reference< XPropertySet> xColumn;
         for(sal_Int32 j=1;pColBegin != pColEnd;++pColBegin,++j)
         {
             aRow[8] = new ORowSetValueDecorator(j);
@@ -322,81 +326,68 @@ Reference< XResultSet > SAL_CALL ODbaseDatabaseMetaData::getIndexInfo(
     pResult->setRows(aRows);
     return xRef;
 }
-// -------------------------------------------------------------------------
-OUString SAL_CALL ODbaseDatabaseMetaData::getURL(  ) throw(SQLException, RuntimeException)
+
+OUString SAL_CALL ODbaseDatabaseMetaData::getURL(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::getURL" );
     ::osl::MutexGuard aGuard( m_aMutex );
-    return OUString("sdbc:dbase:") + m_pConnection->getURL();
+    return "sdbc:dbase:" + m_pConnection->getURL();
 }
-// -------------------------------------------------------------------------
-sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxBinaryLiteralLength(  ) throw(SQLException, RuntimeException)
+
+sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxBinaryLiteralLength(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::getMaxBinaryLiteralLength" );
-    return STRING_MAXLEN;
+    return SAL_MAX_INT32;
 }
-// -------------------------------------------------------------------------
-sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxCharLiteralLength(  ) throw(SQLException, RuntimeException)
+
+sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxCharLiteralLength(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::getMaxCharLiteralLength" );
     return 254;
 }
-// -------------------------------------------------------------------------
-sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxColumnNameLength(  ) throw(SQLException, RuntimeException)
+
+sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxColumnNameLength(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::getMaxColumnNameLength" );
     return 10;
 }
-// -------------------------------------------------------------------------
-sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxColumnsInIndex(  ) throw(SQLException, RuntimeException)
+
+sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxColumnsInIndex(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::getMaxColumnsInIndex" );
     return 1;
 }
-// -------------------------------------------------------------------------
-sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxColumnsInTable(  ) throw(SQLException, RuntimeException)
+
+sal_Int32 SAL_CALL ODbaseDatabaseMetaData::getMaxColumnsInTable(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::getMaxColumnsInTable" );
     return 128;
 }
-// -----------------------------------------------------------------------------
-sal_Bool SAL_CALL ODbaseDatabaseMetaData::supportsAlterTableWithAddColumn(  ) throw(SQLException, RuntimeException)
+
+sal_Bool SAL_CALL ODbaseDatabaseMetaData::supportsAlterTableWithAddColumn(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::supportsAlterTableWithAddColumn" );
-    return sal_True;
+    return true;
 }
-// -------------------------------------------------------------------------
-sal_Bool SAL_CALL ODbaseDatabaseMetaData::supportsAlterTableWithDropColumn(  ) throw(SQLException, RuntimeException)
+
+sal_Bool SAL_CALL ODbaseDatabaseMetaData::supportsAlterTableWithDropColumn(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::supportsAlterTableWithDropColumn" );
-    return sal_False;
+    return false;
 }
-// -----------------------------------------------------------------------------
-sal_Bool SAL_CALL ODbaseDatabaseMetaData::isReadOnly(  ) throw(SQLException, RuntimeException)
+
+sal_Bool SAL_CALL ODbaseDatabaseMetaData::isReadOnly(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::isReadOnly" );
     ::osl::MutexGuard aGuard( m_aMutex );
 
-    sal_Bool bReadOnly = sal_False;
-    static OUString sReadOnly(  "IsReadOnly" );
+    bool bReadOnly = false;
     ::ucbhelper::Content aFile(m_pConnection->getContent(),Reference< XCommandEnvironment >(), comphelper::getProcessComponentContext());
-    aFile.getPropertyValue(sReadOnly) >>= bReadOnly;
+    aFile.getPropertyValue("IsReadOnly") >>= bReadOnly;
 
     return bReadOnly;
 }
-// -----------------------------------------------------------------------------
-sal_Bool ODbaseDatabaseMetaData::impl_storesMixedCaseQuotedIdentifiers_throw(  )
+
+bool ODbaseDatabaseMetaData::impl_storesMixedCaseQuotedIdentifiers_throw(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::impl_storesMixedCaseQuotedIdentifiers_throw" );
-    return sal_True;
+    return true;
 }
-// -----------------------------------------------------------------------------
-sal_Bool ODbaseDatabaseMetaData::impl_supportsMixedCaseQuotedIdentifiers_throw(  )
+
+bool ODbaseDatabaseMetaData::impl_supportsMixedCaseQuotedIdentifiers_throw(  )
 {
-    SAL_INFO( "connectivity.drivers", "dbase Ocke.Janssen@sun.com ODbaseDatabaseMetaData::impl_supportsMixedCaseQuotedIdentifiers_throw" );
-    return sal_True;
+    return true;
 }
-// -----------------------------------------------------------------------------
 
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
