@@ -8,6 +8,7 @@
  */
 
 #include "Columns.hxx"
+#include "Column.hxx"
 
 #include <com/sun/star/sdbc/XRow.hpp>
 
@@ -26,11 +27,16 @@ Columns::Columns(Table& rTable,
                  Mutex& rMutex,
                  const TStringVector& rVector):
     OColumnsHelper(rTable,
-                   sal_True, // TODO: is this case sensitivity?
+                   true, // TODO: is this case sensitivity?
                    rMutex,
                    rVector)
 {
     OColumnsHelper::setParent(&rTable);
 }
 
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
\ No newline at end of file
+Reference< css::beans::XPropertySet > Columns::createDescriptor()
+{
+    return new Column;
+}
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
