@@ -17,16 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "hsqldb/HCatalog.hxx"
-#include "hsqldb/HUsers.hxx"
-#include "hsqldb/HTables.hxx"
-#include "hsqldb/HViews.hxx"
+#include <hsqldb/HCatalog.hxx>
+#include <hsqldb/HUsers.hxx>
+#include <hsqldb/HTables.hxx>
+#include <hsqldb/HViews.hxx>
+#include <com/sun/star/sdbc/SQLException.hpp>
 #include <com/sun/star/sdbc/XRow.hpp>
 #include <com/sun/star/sdbc/XResultSet.hpp>
 #include <comphelper/types.hxx>
 
 
-// -------------------------------------------------------------------------
 using namespace connectivity;
 using namespace connectivity::hsqldb;
 using namespace ::com::sun::star::uno;
@@ -35,30 +35,28 @@ using namespace ::com::sun::star::sdbcx;
 using namespace ::com::sun::star::sdbc;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::lang;
-// -------------------------------------------------------------------------
+
 OHCatalog::OHCatalog(const Reference< XConnection >& _xConnection) : sdbcx::OCatalog(_xConnection)
                 ,m_xConnection(_xConnection)
 {
 }
-// -----------------------------------------------------------------------------
+
 void OHCatalog::refreshObjects(const Sequence< OUString >& _sKindOfObject,TStringVector& _rNames)
 {
     Reference< XResultSet > xResult = m_xMetaData->getTables(Any(),
-                                                            OUString("%"),
-                                                            OUString("%"),
+                                                            "%",
+                                                            "%",
                                                             _sKindOfObject);
     fillNames(xResult,_rNames);
 }
-// -------------------------------------------------------------------------
+
 void OHCatalog::refreshTables()
 {
     TStringVector aVector;
-    static const OUString s_sTableTypeView("VIEW");
-    static const OUString s_sTableTypeTable("TABLE");
 
     Sequence< OUString > sTableTypes(2);
-    sTableTypes[0] = s_sTableTypeView;
-    sTableTypes[1] = s_sTableTypeTable;
+    sTableTypes[0] = "VIEW";
+    sTableTypes[1] = "TABLE";
 
     refreshObjects(sTableTypes,aVector);
 
@@ -67,13 +65,12 @@ void OHCatalog::refreshTables()
     else
         m_pTables = new OTables(m_xMetaData,*this,m_aMutex,aVector);
 }
-// -------------------------------------------------------------------------
+
 void OHCatalog::refreshViews()
 {
-    Sequence< OUString > aTypes(1);
-    aTypes[0] = "VIEW";
+    Sequence< OUString > aTypes { "VIEW" };
 
-    sal_Bool bSupportsViews = sal_False;
+    bool bSupportsViews = false;
     try
     {
         Reference<XResultSet> xRes = m_xMetaData->getTableTypes();
@@ -99,20 +96,19 @@ void OHCatalog::refreshViews()
     else
         m_pViews = new HViews( m_xConnection, *this, m_aMutex, aVector );
 }
-// -------------------------------------------------------------------------
+
 void OHCatalog::refreshGroups()
 {
 }
-// -------------------------------------------------------------------------
+
 void OHCatalog::refreshUsers()
 {
     TStringVector aVector;
     Reference< XStatement > xStmt = m_xConnection->createStatement(  );
-    Reference< XResultSet >  xResult = xStmt->executeQuery(OUString("select User from hsqldb.user group by User"));
+    Reference< XResultSet >  xResult = xStmt->executeQuery("select User from hsqldb.user group by User");
     if ( xResult.is() )
     {
         Reference< XRow > xRow(xResult,UNO_QUERY);
-        TString2IntMap aMap;
         while( xResult->next() )
             aVector.push_back(xRow->getString(1));
         ::comphelper::disposeComponent(xResult);
@@ -124,33 +120,31 @@ void OHCatalog::refreshUsers()
     else
         m_pUsers = new OUsers(*this,m_aMutex,aVector,m_xConnection,this);
 }
-// -----------------------------------------------------------------------------
-Any SAL_CALL OHCatalog::queryInterface( const Type & rType ) throw(RuntimeException)
+
+Any SAL_CALL OHCatalog::queryInterface( const Type & rType )
 {
-    if ( rType == ::getCppuType((const Reference<XGroupsSupplier>*)0) )
+    if ( rType == cppu::UnoType<XGroupsSupplier>::get())
         return Any();
 
     return OCatalog::queryInterface(rType);
 }
-// -----------------------------------------------------------------------------
-Sequence< Type > SAL_CALL OHCatalog::getTypes(  ) throw(RuntimeException)
+
+Sequence< Type > SAL_CALL OHCatalog::getTypes(  )
 {
     Sequence< Type > aTypes = OCatalog::getTypes();
-    ::std::vector<Type> aOwnTypes;
+    std::vector<Type> aOwnTypes;
     aOwnTypes.reserve(aTypes.getLength());
     const Type* pBegin = aTypes.getConstArray();
     const Type* pEnd = pBegin + aTypes.getLength();
     for(;pBegin != pEnd;++pBegin)
     {
-        if ( !(*pBegin == ::getCppuType((const Reference<XGroupsSupplier>*)0)))
+        if ( !(*pBegin == cppu::UnoType<XGroupsSupplier>::get()))
         {
             aOwnTypes.push_back(*pBegin);
         }
     }
-    const Type* pTypes = aOwnTypes.empty() ? 0 : &aOwnTypes[0];
-    return Sequence< Type >(pTypes, aOwnTypes.size());
+    return Sequence< Type >(aOwnTypes.data(), aOwnTypes.size());
 }
-// -----------------------------------------------------------------------------
 
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
