@@ -17,8 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "hsqldb/HColumns.hxx"
-#include "TConnection.hxx"
+#include <hsqldb/HColumns.hxx>
+#include <TConnection.hxx>
 
 
 using namespace ::comphelper;
@@ -33,22 +33,20 @@ using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::lang;
 
 OHSQLColumns::OHSQLColumns( ::cppu::OWeakObject& _rParent
-                                ,bool _bCase
                                 ,::osl::Mutex& _rMutex
                                 ,const TStringVector &_rVector
-                                ,bool _bUseHardRef
-            ) : OColumnsHelper(_rParent,_bCase,_rMutex,_rVector,_bUseHardRef)
+            ) : OColumnsHelper(_rParent,true/*_bCase*/,_rMutex,_rVector,true/*_bUseHardRef*/)
 {
 }
 
 Reference< XPropertySet > OHSQLColumns::createDescriptor()
 {
-    return new OHSQLColumn(true);
+    return new OHSQLColumn;
 }
 
 
-OHSQLColumn::OHSQLColumn(   bool    _bCase)
-    : connectivity::sdbcx::OColumn( _bCase )
+OHSQLColumn::OHSQLColumn()
+    : connectivity::sdbcx::OColumn( true/*_bCase*/ )
 {
     construct();
 }
@@ -69,7 +67,7 @@ void OHSQLColumn::construct()
     return *OHSQLColumn_PROP::getArrayHelper(isNew() ? 1 : 0);
 }
 
-Sequence< OUString > SAL_CALL OHSQLColumn::getSupportedServiceNames(  ) throw(RuntimeException, std::exception)
+Sequence< OUString > SAL_CALL OHSQLColumn::getSupportedServiceNames(  )
 {
     Sequence< OUString > aSupported { "com.sun.star.sdbcx.Column" };
 
