@@ -17,16 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "java/lang/Class.hxx"
+#include <java/lang/Class.hxx>
 #include <connectivity/CommonTools.hxx>
 #include <com/sun/star/uno/Exception.hpp>
 #include <com/sun/star/lang/WrappedTargetRuntimeException.hpp>
-#include "java/tools.hxx"
-#include "java/sql/SQLException.hxx"
-#include <osl/mutex.hxx>
+#include <java/tools.hxx>
+#include <java/sql/SQLException.hxx>
 #include <osl/thread.h>
-#include "java/LocalRef.hxx"
-#include "resource/jdbc_log.hrc"
+#include <java/LocalRef.hxx>
+#include <strings.hxx>
 
 #include <comphelper/logging.hxx>
 
@@ -40,7 +39,7 @@ using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::lang;
 
 
-::rtl::Reference< jvmaccess::VirtualMachine > getJavaVM2(const ::rtl::Reference< jvmaccess::VirtualMachine >& _rVM = ::rtl::Reference< jvmaccess::VirtualMachine >(),
+::rtl::Reference< jvmaccess::VirtualMachine > const & getJavaVM2(const ::rtl::Reference< jvmaccess::VirtualMachine >& _rVM = ::rtl::Reference< jvmaccess::VirtualMachine >(),
                                                         bool _bSet = false)
 {
     static ::rtl::Reference< jvmaccess::VirtualMachine > s_VM;
@@ -115,7 +114,7 @@ java_lang_Object::java_lang_Object( JNIEnv * pXEnv, jobject myObj )
         object = pXEnv->NewGlobalRef( myObj );
 }
 
-java_lang_Object::~java_lang_Object()
+java_lang_Object::~java_lang_Object() COVERITY_NOEXCEPT_FALSE
 {
     if( object )
     {
@@ -197,13 +196,13 @@ namespace
 }
 
 
-void java_lang_Object::ThrowLoggedSQLException( const ::comphelper::ResourceBasedEventLogger& _rLogger, JNIEnv* _pEnvironment,
+void java_lang_Object::ThrowLoggedSQLException( const ::comphelper::EventLogger& _rLogger, JNIEnv* _pEnvironment,
     const Reference< XInterface >& _rxContext )
 {
     SQLException aException;
     if ( lcl_translateJNIExceptionToUNOException( _pEnvironment, _rxContext, aException ) )
     {
-        _rLogger.log( ::com::sun::star::logging::LogLevel::SEVERE, STR_LOG_THROWING_EXCEPTION, aException.Message, aException.SQLState, aException.ErrorCode );
+        _rLogger.log( css::logging::LogLevel::SEVERE, STR_LOG_THROWING_EXCEPTION, aException.Message, aException.SQLState, aException.ErrorCode );
         throw aException;
     }
 }
@@ -468,7 +467,7 @@ jclass java_lang_Object::findMyClass(const char* _pClassName)
 {
     // the class must be fetched only once, therefore static
     SDBThreadAttach t;
-    jclass tempClass = t.pEnv->FindClass(_pClassName); OSL_ENSURE(tempClass,"Java : FindClass nicht erfolgreich!");
+    jclass tempClass = t.pEnv->FindClass(_pClassName); OSL_ENSURE(tempClass,"Java : FindClass not successful!");
     if(!tempClass)
     {
         t.pEnv->ExceptionDescribe();
