@@ -26,7 +26,7 @@
 #include <com/sun/star/frame/Desktop.hpp>
 #include <rtl/ustrbuf.hxx>
 #include <tools/diagnose_ex.h>
-#include "resource/macab_res.hrc"
+#include <strings.hrc>
 #include <comphelper/processfactory.hxx>
 #include <cppuhelper/supportsservice.hxx>
 
@@ -87,7 +87,7 @@ namespace
     template< typename FUNCTION >
     void lcl_getFunctionFromModuleOrUnload( oslModule& _rModule, const sal_Char* _pAsciiSymbolName, FUNCTION& _rFunction )
     {
-        _rFunction = NULL;
+        _rFunction = nullptr;
         if ( _rModule )
         {
 
@@ -96,7 +96,7 @@ namespace
 
             if ( !_rFunction )
             {   // did not find the symbol
-                OSL_FAIL( OString( OString( "lcl_getFunctionFromModuleOrUnload: could not find the symbol " ) + OString( _pAsciiSymbolName ) ).getStr() );
+                SAL_WARN( "connectivity.macab", "lcl_getFunctionFromModuleOrUnload: could not find the symbol " << _pAsciiSymbolName );
                 osl_unloadModule( _rModule );
                 _rModule = nullptr;
             }
@@ -177,7 +177,7 @@ void MacabImplModule::shutdown()
 // = MacabDriver
 
 MacabDriver::MacabDriver(
-    const Reference< ::com::sun::star::uno::XComponentContext >& _rxContext)
+    const Reference< css::uno::XComponentContext >& _rxContext)
     : MacabDriver_BASE(m_aMutex),
       m_xContext(_rxContext),
       m_aImplModule()
@@ -202,7 +202,7 @@ void MacabDriver::disposing()
 {
     ::osl::MutexGuard aGuard(m_aMutex);
 
-    // when driver will be destroied so all our connections have to be destroied as well
+    // when driver will be destroyed so all our connections have to be destroyed as well
     for (OWeakRefArray::iterator i = m_xConnections.begin(); m_xConnections.end() != i; ++i)
     {
         Reference< XComponent > xComp(i->get(), UNO_QUERY);
@@ -215,12 +215,12 @@ void MacabDriver::disposing()
 }
 // static ServiceInfo
 
-OUString MacabDriver::getImplementationName_Static(  ) throw(RuntimeException)
+OUString MacabDriver::getImplementationName_Static(  )
 {
     return OUString("com.sun.star.comp.sdbc.macab.Driver");
 }
 
-Sequence< OUString > MacabDriver::getSupportedServiceNames_Static(  ) throw (RuntimeException)
+Sequence< OUString > MacabDriver::getSupportedServiceNames_Static(  )
 {
     // which service is supported
     // for more information @see com.sun.star.sdbc.Driver
@@ -229,22 +229,22 @@ Sequence< OUString > MacabDriver::getSupportedServiceNames_Static(  ) throw (Run
     return aSNS;
 }
 
-OUString SAL_CALL MacabDriver::getImplementationName(  ) throw(RuntimeException)
+OUString SAL_CALL MacabDriver::getImplementationName(  )
 {
     return getImplementationName_Static();
 }
 
-sal_Bool SAL_CALL MacabDriver::supportsService( const OUString& _rServiceName ) throw(RuntimeException)
+sal_Bool SAL_CALL MacabDriver::supportsService( const OUString& _rServiceName )
 {
     return cppu::supportsService(this, _rServiceName);
 }
 
-Sequence< OUString > SAL_CALL MacabDriver::getSupportedServiceNames(  ) throw(RuntimeException)
+Sequence< OUString > SAL_CALL MacabDriver::getSupportedServiceNames(  )
 {
     return getSupportedServiceNames_Static();
 }
 
-Reference< XConnection > SAL_CALL MacabDriver::connect( const OUString& url, const Sequence< PropertyValue >& info ) throw(SQLException, RuntimeException)
+Reference< XConnection > SAL_CALL MacabDriver::connect( const OUString& url, const Sequence< PropertyValue >& info )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
 
@@ -268,44 +268,43 @@ Reference< XConnection > SAL_CALL MacabDriver::connect( const OUString& url, con
 }
 
 sal_Bool SAL_CALL MacabDriver::acceptsURL( const OUString& url )
-        throw(SQLException, RuntimeException)
 {
     ::osl::MutexGuard aGuard(m_aMutex);
 
     if ( !m_aImplModule.isMacOSPresent() )
-        return sal_False;
+        return false;
 
     // here we have to look whether we support this URL format
     return url == "sdbc:address:macab";
 }
 
-Sequence< DriverPropertyInfo > SAL_CALL MacabDriver::getPropertyInfo( const OUString&, const Sequence< PropertyValue >& ) throw(SQLException, RuntimeException)
+Sequence< DriverPropertyInfo > SAL_CALL MacabDriver::getPropertyInfo( const OUString&, const Sequence< PropertyValue >& )
 {
     // if you have something special to say, return it here :-)
     return Sequence< DriverPropertyInfo >();
 }
 
-sal_Int32 SAL_CALL MacabDriver::getMajorVersion(  ) throw(RuntimeException)
+sal_Int32 SAL_CALL MacabDriver::getMajorVersion(  )
 {
     return MACAB_DRIVER_VERSION_MAJOR;
 }
 
-sal_Int32 SAL_CALL MacabDriver::getMinorVersion(  ) throw(RuntimeException)
+sal_Int32 SAL_CALL MacabDriver::getMinorVersion(  )
 {
     return MACAB_DRIVER_VERSION_MINOR;
 }
 
-void SAL_CALL MacabDriver::queryTermination( const EventObject& ) throw (TerminationVetoException, RuntimeException)
+void SAL_CALL MacabDriver::queryTermination( const EventObject& )
 {
     // nothing to do, nothing to veto
 }
 
-void SAL_CALL MacabDriver::notifyTermination( const EventObject& ) throw (RuntimeException)
+void SAL_CALL MacabDriver::notifyTermination( const EventObject& )
 {
     m_aImplModule.shutdown();
 }
 
-void SAL_CALL MacabDriver::disposing( const EventObject& ) throw (RuntimeException)
+void SAL_CALL MacabDriver::disposing( const EventObject& )
 {
     // not interested in (this is the disposing of the desktop, if any)
 }
@@ -318,7 +317,7 @@ OUString MacabDriver::impl_getConfigurationSettingsPath()
     return aPath.makeStringAndClear();
 }
 
-Reference< XInterface >  SAL_CALL MacabDriver::Create( const Reference< XMultiServiceFactory >& _rxFactory ) throw( Exception )
+Reference< XInterface >  SAL_CALL MacabDriver::Create( const Reference< XMultiServiceFactory >& _rxFactory )
 {
     return *(new MacabDriver(comphelper::getComponentContext(_rxFactory)));
 }
