@@ -19,30 +19,13 @@
 
 #include "MTables.hxx"
 #include "MTable.hxx"
-#include <com/sun/star/sdbc/XRow.hpp>
-#include <com/sun/star/sdbc/XResultSet.hpp>
-#include <com/sun/star/sdbc/ColumnValue.hpp>
-#include <com/sun/star/sdbc/KeyRule.hpp>
-#include <com/sun/star/sdbcx/KeyType.hpp>
 #include "MCatalog.hxx"
-#include "MConnection.hxx"
-#include <comphelper/extract.hxx>
-#include "connectivity/dbtools.hxx"
-#include "connectivity/dbexception.hxx"
-#include <cppuhelper/interfacecontainer.h>
 #include <comphelper/types.hxx>
 
-using namespace ::comphelper;
 using namespace connectivity;
-using namespace ::cppu;
 using namespace connectivity::mork;
 using namespace ::com::sun::star::uno;
-using namespace ::com::sun::star::beans;
-using namespace ::com::sun::star::sdbcx;
 using namespace ::com::sun::star::sdbc;
-using namespace ::com::sun::star::container;
-using namespace ::com::sun::star::lang;
-using namespace dbtools;
 
 sdbcx::ObjectType OTables::createObject(const OUString& _rName)
 {
@@ -50,12 +33,11 @@ sdbcx::ObjectType OTables::createObject(const OUString& _rName)
     aSchema = "%";
     aName = _rName;
 
-    Sequence< OUString > aTypes(1);
-    aTypes[0] = "%";
+    Sequence< OUString > aTypes { "%" };
 
     Reference< XResultSet > xResult = m_xMetaData->getTables(Any(),aSchema,aName,aTypes);
 
-    sdbcx::ObjectType xRet = NULL;
+    sdbcx::ObjectType xRet = nullptr;
     if(xResult.is())
     {
         Reference< XRow > xRow(xResult,UNO_QUERY);
@@ -71,12 +53,12 @@ sdbcx::ObjectType OTables::createObject(const OUString& _rName)
     return xRet;
 }
 
-void OTables::impl_refresh(  ) throw(RuntimeException)
+void OTables::impl_refresh(  )
 {
     static_cast<OCatalog&>(m_rParent).refreshTables();
 }
 
-void OTables::disposing(void)
+void OTables::disposing()
 {
 m_xMetaData.clear();
     OCollection::disposing();
