@@ -26,15 +26,18 @@ namespace connectivity
 {
     namespace mozab
     {
-        ProfileStruct::ProfileStruct(MozillaProductType aProduct, const OUString& aProfileName,
-            const OUString& aProfilePath
-          )
+        ProfileStruct::ProfileStruct()
         {
-            product=aProduct;
-            profileName = aProfileName;
-            profilePath = aProfilePath;
         }
-        OUString ProfileStruct::getProfilePath()
+
+        ProfileStruct::ProfileStruct(const OUString& aProfileName,
+                                     const OUString& aProfilePath)
+            : profileName(aProfileName)
+            , profilePath(aProfilePath)
+        {
+        }
+
+        const OUString& ProfileStruct::getProfilePath() const
         {
             return profilePath;
         }
@@ -42,38 +45,38 @@ namespace connectivity
         ProfileAccess::~ProfileAccess()
         {
         }
+
         ProfileAccess::ProfileAccess()
         {
             LoadProductsInfo();
         }
 
-        sal_Int32 ProfileAccess::LoadProductsInfo()
+        void ProfileAccess::LoadProductsInfo()
         {
             //tdf#39279: LO should search Thunderbird first then Seamonkey and finally Firefox
             //load thunderbird profiles to m_ProductProfileList
-            sal_Int32 count = LoadXPToolkitProfiles(MozillaProductType_Thunderbird);
+            LoadXPToolkitProfiles(MozillaProductType_Thunderbird);
 
             //load SeaMonkey 2 profiles to m_ProductProfileList
-            count += LoadXPToolkitProfiles(MozillaProductType_Mozilla);
+            LoadXPToolkitProfiles(MozillaProductType_Mozilla);
 
             //load firefox profiles to m_ProductProfileList
-            //firefox profile does not containt address book, but maybe others need them
-            count += LoadXPToolkitProfiles(MozillaProductType_Firefox);
-            return count;
+            //firefox profile does not contain address book, but maybe others need them
+            LoadXPToolkitProfiles(MozillaProductType_Firefox);
         }
         //Thunderbird and firefox profiles are saved in profiles.ini
-        sal_Int32 ProfileAccess::LoadXPToolkitProfiles(MozillaProductType product)
+        void ProfileAccess::LoadXPToolkitProfiles(MozillaProductType product)
         {
-            sal_Int32 index=product;
-            ProductStruct &m_Product = m_ProductProfileList[index];
+            sal_Int32 index=(sal_Int32)product;
+            ProductStruct &rProduct = m_ProductProfileList[index];
 
             OUString regDir = getRegistryDir(product);
             OUString profilesIni = regDir + "profiles.ini";
             IniParser parser( profilesIni );
-            IniSectionMap &mAllSection = parser.getAllSection();
+            IniSectionMap &rAllSection = parser.getAllSection();
 
-            IniSectionMap::iterator iBegin = mAllSection.begin();
-            IniSectionMap::iterator iEnd = mAllSection.end();
+            IniSectionMap::iterator iBegin = rAllSection.begin();
+            IniSectionMap::const_iterator iEnd = rAllSection.end();
             for(;iBegin != iEnd;++iBegin)
             {
                 ini_Section *aSection = &(*iBegin).second;
@@ -82,8 +85,8 @@ namespace connectivity
                 OUString sIsRelative;
                 OUString sIsDefault;
 
-                for(NameValueList::iterator itor=aSection->lList.begin();
-                    itor != aSection->lList.end();
+                for(NameValueVector::iterator itor=aSection->vVector.begin();
+                    itor != aSection->vVector.end();
                     ++itor)
                 {
                         struct ini_NameValue * aValue = &(*itor);
@@ -122,10 +125,7 @@ namespace connectivity
                         fullProfilePath = profilePath;
                     }
 
-                    ProfileStruct*  profileItem     = new ProfileStruct(product,profileName,
-                            fullProfilePath
-                        );
-                    m_Product.mProfileList[profileName] = profileItem;
+                    rProduct.mProfileList[profileName] = ProfileStruct(profileName,fullProfilePath);
 
                     sal_Int32 isDefault = 0;
                     if (!sIsDefault.isEmpty())
@@ -133,80 +133,73 @@ namespace connectivity
                         isDefault = sIsDefault.toInt32();
                     }
                     if (isDefault)
-                        m_Product.mCurrentProfileName = profileName;
+                        rProduct.mCurrentProfileName = profileName;
 
                 }
 
             }
-            return static_cast< ::sal_Int32 >(m_Product.mProfileList.size());
         }
 
-        OUString ProfileAccess::getProfilePath( ::com::sun::star::mozilla::MozillaProductType product, const OUString& profileName ) throw (::com::sun::star::uno::RuntimeException)
+        OUString ProfileAccess::getProfilePath( css::mozilla::MozillaProductType product, const OUString& profileName )
         {
-            sal_Int32 index=product;
-            ProductStruct &m_Product = m_ProductProfileList[index];
-            if (m_Product.mProfileList.empty() || m_Product.mProfileList.find(profileName) == m_Product.mProfileList.end())
+            sal_Int32 index=(sal_Int32)product;
+            ProductStruct &rProduct = m_ProductProfileList[index];
+            if (rProduct.mProfileList.empty() || rProduct.mProfileList.find(profileName) == rProduct.mProfileList.end())
             {
                 //Profile not found
                 return OUString();
             }
             else
-                return m_Product.mProfileList[profileName]->getProfilePath();
+                return rProduct.mProfileList[profileName].getProfilePath();
         }
 
-        ::sal_Int32 ProfileAccess::getProfileCount( ::com::sun::star::mozilla::MozillaProductType product) throw (::com::sun::star::uno::RuntimeException)
+        ::sal_Int32 ProfileAccess::getProfileCount( css::mozilla::MozillaProductType product)
         {
-            sal_Int32 index=product;
-            ProductStruct &m_Product = m_ProductProfileList[index];
-            return static_cast< ::sal_Int32 >(m_Product.mProfileList.size());
+            sal_Int32 index=(sal_Int32)product;
+            ProductStruct &rProduct = m_ProductProfileList[index];
+            return static_cast< ::sal_Int32 >(rProduct.mProfileList.size());
         }
-        ::sal_Int32 ProfileAccess::getProfileList( ::com::sun::star::mozilla::MozillaProductType product, ::com::sun::star::uno::Sequence< OUString >& list ) throw (::com::sun::star::uno::RuntimeException)
+        ::sal_Int32 ProfileAccess::getProfileList( css::mozilla::MozillaProductType product, css::uno::Sequence< OUString >& list )
         {
-            sal_Int32 index=product;
-            ProductStruct &m_Product = m_ProductProfileList[index];
-            list.realloc(static_cast<sal_Int32>(m_Product.mProfileList.size()));
+            sal_Int32 index=(sal_Int32)product;
+            ProductStruct &rProduct = m_ProductProfileList[index];
+            list.realloc(static_cast<sal_Int32>(rProduct.mProfileList.size()));
             sal_Int32 i=0;
-            for(ProfileList::iterator itor=m_Product.mProfileList.begin();
-                itor != m_Product.mProfileList.end();
+            for(ProfileList::const_iterator itor=rProduct.mProfileList.begin();
+                itor != rProduct.mProfileList.end();
                 ++itor)
             {
-                ProfileStruct * aProfile = (*itor).second;
-                list[i] = aProfile->getProfileName();
+                const ProfileStruct& rProfile = (*itor).second;
+                list[i] = rProfile.getProfileName();
                 i++;
             }
 
-            return static_cast< ::sal_Int32 >(m_Product.mProfileList.size());
+            return static_cast< ::sal_Int32 >(rProduct.mProfileList.size());
         }
 
-        OUString ProfileAccess::getDefaultProfile( ::com::sun::star::mozilla::MozillaProductType product ) throw (::com::sun::star::uno::RuntimeException)
+        OUString ProfileAccess::getDefaultProfile( css::mozilla::MozillaProductType product )
         {
-            sal_Int32 index=product;
-            ProductStruct &m_Product = m_ProductProfileList[index];
-            if (!m_Product.mCurrentProfileName.isEmpty())
+            sal_Int32 index=(sal_Int32)product;
+            ProductStruct &rProduct = m_ProductProfileList[index];
+            if (!rProduct.mCurrentProfileName.isEmpty())
             {
-                //default profile setted in mozilla registry
-                return m_Product.mCurrentProfileName;
+                //default profile set in mozilla registry
+                return rProduct.mCurrentProfileName;
             }
-            if (m_Product.mProfileList.empty())
+            if (rProduct.mProfileList.empty())
             {
                 //there are not any profiles
                 return OUString();
             }
-            ProfileStruct * aProfile = (*m_Product.mProfileList.begin()).second;
-            return aProfile->getProfileName();
-        }
-        bool ProfileAccess::isProfileLocked( ::com::sun::star::mozilla::MozillaProductType product, const OUString& profileName ) throw (::com::sun::star::uno::RuntimeException)
-        {
-            (void)product; /* avoid warning about unused parameter */
-            (void)profileName; /* avoid warning about unused parameter */
-            return true;
+            const ProfileStruct& rProfile = (*rProduct.mProfileList.begin()).second;
+            return rProfile.getProfileName();
         }
 
-        bool ProfileAccess::getProfileExists( ::com::sun::star::mozilla::MozillaProductType product, const OUString& profileName ) throw (::com::sun::star::uno::RuntimeException)
+        bool ProfileAccess::getProfileExists( css::mozilla::MozillaProductType product, const OUString& profileName )
         {
-            sal_Int32 index=product;
-            ProductStruct &m_Product = m_ProductProfileList[index];
-            if (m_Product.mProfileList.empty() || m_Product.mProfileList.find(profileName) == m_Product.mProfileList.end())
+            sal_Int32 index=(sal_Int32)product;
+            ProductStruct &rProduct = m_ProductProfileList[index];
+            if (rProduct.mProfileList.empty() || rProduct.mProfileList.find(profileName) == rProduct.mProfileList.end())
             {
                 return false;
             }
