@@ -100,9 +100,8 @@ sal_Bool Driver::acceptsURL( const OUString& url )
 }
 
 Sequence< DriverPropertyInfo > Driver::getPropertyInfo(
-    const OUString& url,const Sequence< PropertyValue >& info )
+    const OUString&,const Sequence< PropertyValue >& )
 {
-    (void)url; (void)info;
     return Sequence< DriverPropertyInfo > ();
 }
 
@@ -170,7 +169,7 @@ public:
         cppu::ComponentFactoryFunc fptr,
         const Sequence< OUString > & serviceNames,
         const Reference< XComponentContext > & defaultContext) :
-        cppu::WeakComponentImplHelper< XSingleComponentFactory, XServiceInfo >( this->m_mutex ),
+        cppu::WeakComponentImplHelper< XSingleComponentFactory, XServiceInfo >( m_mutex ),
         m_create( fptr ),
         m_serviceNames( serviceNames ),
         m_implName( rImplementationName_ ),
@@ -214,9 +213,8 @@ private:
 };
 
 Reference< XInterface > OOneInstanceComponentFactory::createInstanceWithArgumentsAndContext(
-    Sequence< Any > const &rArguments, const Reference< XComponentContext > & ctx )
+    Sequence< Any > const &, const Reference< XComponentContext > & ctx )
 {
-    (void)rArguments;
     return createInstanceWithContext( ctx );
 }
 
