@@ -43,11 +43,11 @@
 
 #include <com/sun/star/sdbcx/XColumnsSupplier.hpp>
 #include <com/sun/star/sdbc/ColumnValue.hpp>
+#include <com/sun/star/sdbc/SQLException.hpp>
 #include <com/sun/star/sdbc/XRow.hpp>
 
 #include <string.h>
 
-using osl::Mutex;
 using osl::MutexGuard;
 
 
@@ -55,10 +55,8 @@ using com::sun::star::uno::Any;
 using com::sun::star::uno::RuntimeException;
 using com::sun::star::uno::Exception;
 using com::sun::star::uno::Reference;
-using com::sun::star::uno::XInterface;
 using com::sun::star::uno::UNO_QUERY;
 
-using com::sun::star::lang::IllegalArgumentException;
 
 using com::sun::star::sdbc::SQLException;
 using com::sun::star::sdbc::XStatement;
@@ -79,7 +77,7 @@ namespace pq_sdbc_driver
 //     OUString tableName;
 //     OUString schemaTableName;
 //     OUString typeName;
-//     com::sun::star::sdbc::DataType type;
+//     css::sdbc::DataType type;
 //     sal_Int32 precision;
 //     sal_Int32 scale;
 //     sal_Bool isCurrency;
@@ -115,14 +113,14 @@ static void extractPrecisionAndScale( sal_Int32 atttypmod, sal_Int32 *precision,
 }
 
 ResultSetMetaData::ResultSetMetaData(
-    const ::rtl::Reference< RefCountedMutex > & refMutex,
-    const ::com::sun::star::uno::Reference< com::sun::star::sdbc::XResultSet >  & origin,
+    const ::rtl::Reference< comphelper::RefCountedMutex > & refMutex,
+    const css::uno::Reference< css::sdbc::XResultSet >  & origin,
     ResultSet * pResultSet,
     ConnectionSettings **ppSettings,
-    PGresult *pResult,
+    PGresult const *pResult,
     const OUString &schemaName,
     const OUString &tableName ) :
-    m_refMutex( refMutex ),
+    m_xMutex( refMutex ),
     m_ppSettings( ppSettings ),
     m_origin( origin ),
     m_tableName( tableName ),
@@ -147,9 +145,9 @@ ResultSetMetaData::ResultSetMetaData(
             & ( m_colDesc[col].precision ),
             & ( m_colDesc[col].scale ) );
         char *name = PQfname( pResult, col );
-        m_colDesc[col].name = OUString( name, strlen(name) , (*m_ppSettings)->encoding );
+        m_colDesc[col].name = OUString( name, strlen(name) , ConnectionSettings::encoding );
         m_colDesc[col].typeOid = PQftype( pResult, col );
-        m_colDesc[col].type = com::sun::star::sdbc::DataType::LONGVARCHAR;
+        m_colDesc[col].type = css::sdbc::DataType::LONGVARCHAR;
     }
 }
 
@@ -201,7 +199,7 @@ void ResultSetMetaData::checkTable()
         if( m_tableName.getLength() )
         {
 
-            Reference< com::sun::star::container::XNameAccess > tables = (*m_ppSettings)->tables;
+            Reference< css::container::XNameAccess > tables = (*m_ppSettings)->tables;
             if( ! tables.is() )
             {
 
@@ -227,7 +225,7 @@ sal_Int32 ResultSetMetaData::getIntColumnProperty( const OUString & name, int in
     sal_Int32 ret = def; // give defensive answers, when data is not available
     try
     {
-        MutexGuard guard( m_refMutex->mutex );
+        MutexGuard guard( m_xMutex->GetMutex() );
         checkColumnIndex( index );
         Reference< XPropertySet > set = getColumnByIndex( index );
 
@@ -236,7 +234,7 @@ sal_Int32 ResultSetMetaData::getIntColumnProperty( const OUString & name, int in
             set->getPropertyValue( name ) >>= ret;
         }
     }
-    catch( com::sun::star::uno::Exception & )
+    catch( css::uno::Exception & )
     {
     }
     return ret;
@@ -247,7 +245,7 @@ bool ResultSetMetaData::getBoolColumnProperty( const OUString & name, int index,
     bool ret = def;
     try
     {
-        MutexGuard guard( m_refMutex->mutex );
+        MutexGuard guard( m_xMutex->GetMutex() );
         checkColumnIndex( index );
         Reference< XPropertySet > set = getColumnByIndex( index );
         if( set.is() )
@@ -255,14 +253,14 @@ bool ResultSetMetaData::getBoolColumnProperty( const OUString & name, int index,
             set->getPropertyValue( name ) >>= ret;
         }
     }
-    catch( com::sun::star::uno::Exception & )
+    catch( css::uno::Exception & )
     {
     }
 
     return ret;
 }
 
-Reference< com::sun::star::beans::XPropertySet > ResultSetMetaData::getColumnByIndex( int index )
+Reference< css::beans::XPropertySet > ResultSetMetaData::getColumnByIndex( int index )
 {
     Reference< XPropertySet > ret;
     checkTable();
@@ -284,116 +282,100 @@ Reference< com::sun::star::beans::XPropertySet > ResultSetMetaData::getColumnByI
 
 // Methods
 sal_Int32 ResultSetMetaData::getColumnCount(  )
-    throw (SQLException, RuntimeException, std::exception)
 {
     return m_colCount;
 }
 
 sal_Bool ResultSetMetaData::isAutoIncrement( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
 
     bool ret = getBoolColumnProperty( getStatics().IS_AUTO_INCREMENT, column, false );
     return ret;
 }
 
-sal_Bool ResultSetMetaData::isCaseSensitive( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
+sal_Bool ResultSetMetaData::isCaseSensitive( sal_Int32 )
 {
-    (void) column;
-    return sal_True; // ??? hmm, numeric types or
+    return true; // ??? hmm, numeric types or
 }
 
-sal_Bool ResultSetMetaData::isSearchable( sal_Int32 column ) throw (SQLException, RuntimeException, std::exception)
+sal_Bool ResultSetMetaData::isSearchable( sal_Int32 )
 {
-    (void) column;
-    return sal_True; // mmm, what types are not searchable ?
+    return true; // mmm, what types are not searchable ?
 }
 
-sal_Bool ResultSetMetaData::isCurrency( sal_Int32 column ) throw (SQLException, RuntimeException, std::exception)
+sal_Bool ResultSetMetaData::isCurrency( sal_Int32 column )
 {
     return getBoolColumnProperty( getStatics().IS_CURRENCY, column, false );
 }
 
 sal_Int32 ResultSetMetaData::isNullable( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
     return getIntColumnProperty(
-        getStatics().IS_NULLABLE, column, com::sun::star::sdbc::ColumnValue::NULLABLE_UNKNOWN );
+        getStatics().IS_NULLABLE, column, css::sdbc::ColumnValue::NULLABLE_UNKNOWN );
 }
 
-sal_Bool ResultSetMetaData::isSigned( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
+sal_Bool ResultSetMetaData::isSigned( sal_Int32 )
 {
-    (void) column;
-    return sal_True;
+    return true;
 }
 
 sal_Int32 ResultSetMetaData::getColumnDisplaySize( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
-    MutexGuard guard( m_refMutex->mutex );
+    MutexGuard guard( m_xMutex->GetMutex() );
     checkColumnIndex( column );
     return m_colDesc[column-1].displaySize;
 }
 
 OUString ResultSetMetaData::getColumnLabel( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
     return getColumnName( column);
 }
 
-OUString ResultSetMetaData::getColumnName( sal_Int32 column ) throw (SQLException, RuntimeException, std::exception)
+OUString ResultSetMetaData::getColumnName( sal_Int32 column )
 {
-    MutexGuard guard( m_refMutex->mutex );
+    MutexGuard guard( m_xMutex->GetMutex() );
     checkColumnIndex( column );
 
     return m_colDesc[column-1].name;
 }
 
-OUString ResultSetMetaData::getSchemaName( sal_Int32 column ) throw (SQLException, RuntimeException, std::exception)
+OUString ResultSetMetaData::getSchemaName( sal_Int32 )
 {
-    (void) column;
     return m_schemaName;
 }
 
 sal_Int32 ResultSetMetaData::getPrecision( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
-    MutexGuard guard( m_refMutex->mutex );
+    MutexGuard guard( m_xMutex->GetMutex() );
     checkColumnIndex( column );
     return m_colDesc[column-1].precision;
 }
 
 sal_Int32 ResultSetMetaData::getScale( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
-    MutexGuard guard( m_refMutex->mutex );
+    MutexGuard guard( m_xMutex->GetMutex() );
     checkColumnIndex( column );
     return m_colDesc[column-1].scale;
 }
 
 OUString ResultSetMetaData::getTableName( sal_Int32 )
-    throw (SQLException, RuntimeException, std::exception)
 {
 // LEM TODO This is very fishy.. Should probably return the table to which that column belongs!
     return m_tableName;
 }
 
 OUString ResultSetMetaData::getCatalogName( sal_Int32 )
-    throw (SQLException, RuntimeException, std::exception)
 {
     // can do this through XConnection.getCatalog() !
     return OUString();
 }
 sal_Int32 ResultSetMetaData::getColumnType( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
     int ret = getIntColumnProperty( getStatics().TYPE, column, -100 );
     if( -100 == ret )
     {
         checkForTypes();
-        if( com::sun::star::sdbc::DataType::LONGVARCHAR == m_colDesc[column-1].type && m_pResultSet )
+        if( css::sdbc::DataType::LONGVARCHAR == m_colDesc[column-1].type && m_pResultSet )
             m_colDesc[column-1].type = m_pResultSet->guessDataType( column );
         ret = m_colDesc[column-1].type;
     }
@@ -401,12 +383,11 @@ sal_Int32 ResultSetMetaData::getColumnType( sal_Int32 column )
 }
 
 OUString ResultSetMetaData::getColumnTypeName( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
     OUString ret; // give defensive answers, when data is not available
     try
     {
-        MutexGuard guard( m_refMutex->mutex );
+        MutexGuard guard( m_xMutex->GetMutex() );
         checkColumnIndex( column );
         Reference< XPropertySet > set = getColumnByIndex( column );
 
@@ -420,51 +401,40 @@ OUString ResultSetMetaData::getColumnTypeName( sal_Int32 column )
             ret = m_colDesc[column-1].typeName;
         }
     }
-    catch( com::sun::star::uno::Exception & )
+    catch( css::uno::Exception & )
     {
     }
     return ret;
 }
 
 
-sal_Bool ResultSetMetaData::isReadOnly( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
+sal_Bool ResultSetMetaData::isReadOnly( sal_Int32 )
 {
-    (void) column;
-    return sal_False;
+    return false;
 }
 
 sal_Bool ResultSetMetaData::isWritable( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
     return ! isReadOnly( column ); // what's the sense if this method ?
 }
 
 sal_Bool ResultSetMetaData::isDefinitelyWritable( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
 {
     return isWritable(column); // uhh, now it becomes really esoteric ....
 }
-OUString ResultSetMetaData::getColumnServiceName( sal_Int32 column )
-    throw (SQLException, RuntimeException, std::exception)
+OUString ResultSetMetaData::getColumnServiceName( sal_Int32 )
 {
-    (void) column;
     return OUString();
 }
 
 void ResultSetMetaData::checkColumnIndex(sal_Int32 columnIndex)
-    throw (::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException)
 {
     if( columnIndex < 1 || columnIndex > m_colCount )
     {
-        OUStringBuffer buf(128);
-
-        buf.append( "pq_resultsetmetadata: index out of range (expected 1 to " );
-        buf.append( m_colCount );
-        buf.append( ", got " );
-        buf.append( columnIndex );
         throw SQLException(
-            buf.makeStringAndClear(), *this, OUString(), 1, Any() );
+            "pq_resultsetmetadata: index out of range (expected 1 to "
+            + OUString::number( m_colCount ) + ", got " + OUString::number( columnIndex ),
+            *this, OUString(), 1, Any() );
     }
 }
 
