@@ -35,7 +35,8 @@
  ************************************************************************/
 
 #include <rtl/ustrbuf.hxx>
-
+#include <com/sun/star/container/ElementExistException.hpp>
+#include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
 #include <cppuhelper/implbase.hxx>
 
 #include "pq_xcontainer.hxx"
@@ -133,12 +134,12 @@ public:
 };
 
 Container::Container(
-    const ::rtl::Reference< RefCountedMutex > & refMutex,
+    const ::rtl::Reference< comphelper::RefCountedMutex > & refMutex,
     const css::uno::Reference< css::sdbc::XConnection >  & origin,
     ConnectionSettings *pSettings,
     const OUString &type)
-    : ContainerBase( refMutex->mutex ),
-      m_refMutex( refMutex ),
+    : ContainerBase( refMutex->GetMutex() ),
+      m_xMutex( refMutex ),
       m_pSettings( pSettings ),
       m_origin( origin ),
       m_type( type )
@@ -146,25 +147,19 @@ Container::Container(
 }
 
 Any Container::getByName( const OUString& aName )
-    throw (NoSuchElementException,WrappedTargetException,RuntimeException, std::exception)
 {
     String2IntMap::const_iterator ii = m_name2index.find( aName );
     if( ii == m_name2index.end() )
     {
-        OUStringBuffer buf(128);
-        buf.append( "Element "  );
-        buf.append( aName );
-        buf.append( " unknown in " );
-        buf.append( m_type );
-        buf.append( "-Container" );
-        throw NoSuchElementException( buf.makeStringAndClear() , *this );
+        throw NoSuchElementException(
+            "Element " + aName + " unknown in " + m_type + "-Container",
+            *this );
     }
     OSL_ASSERT( ii->second >= 0 && ii->second < (int)m_values.size() );
     return m_values[ ii->second ];
 }
 
 Sequence< OUString > Container::getElementNames(  )
-        throw (css::uno::RuntimeException, std::exception)
 {
     Sequence< OUString > ret( m_values.size() );
     for( String2IntMap::const_iterator ii = m_name2index.begin();
@@ -179,44 +174,34 @@ Sequence< OUString > Container::getElementNames(  )
 }
 
 sal_Bool Container::hasByName( const OUString& aName )
-        throw (css::uno::RuntimeException, std::exception)
 {
     return m_name2index.find( aName ) != m_name2index.end();
 }
     // Methods
 Type Container::getElementType(  )
-        throw (css::uno::RuntimeException, std::exception)
 {
     return Type();
 }
 
 sal_Bool Container::hasElements(  )
-        throw (css::uno::RuntimeException, std::exception)
 {
     return ! m_name2index.empty();
 }
 
 Any Container::getByIndex( sal_Int32 Index )
-    throw (css::lang::IndexOutOfBoundsException,
-           css::lang::WrappedTargetException,
-           css::uno::RuntimeException, std::exception)
 {
     if( Index < 0 || Index >= (sal_Int32)m_values.size() )
     {
-        OUStringBuffer buf(128);
-        buf.append( "Index " );
-        buf.append( Index );
-        buf.append(" out of range for " );
-        buf.append( m_type );
-        buf.append("-Container, expected 0 <= x <= " );
-        buf.append( (sal_Int32 ) (m_values.size() -1));
-        throw IndexOutOfBoundsException( buf.makeStringAndClear(), *this );
+        throw IndexOutOfBoundsException(
+            "Index " + OUString::number( Index )
+            + " out of range for " + m_type + "-Container, expected 0 <= x <= "
+            + OUString::number(m_values.size() -1),
+            *this );
     }
     return m_values[Index];
 }
 
 sal_Int32 Container::getCount()
-        throw (css::uno::RuntimeException, std::exception)
 {
     return m_values.size();
 }
@@ -234,25 +219,17 @@ public:
 
 public:
     // XEnumeration
-    virtual sal_Bool SAL_CALL hasMoreElements(  )
-        throw (css::uno::RuntimeException, std::exception) override;
-    virtual css::uno::Any SAL_CALL nextElement(  )
-        throw (css::container::NoSuchElementException,
-               css::lang::WrappedTargetException,
-               css::uno::RuntimeException, std::exception) override;
+    virtual sal_Bool SAL_CALL hasMoreElements(  ) override;
+    virtual css::uno::Any SAL_CALL nextElement(  ) override;
 
 };
 
 sal_Bool ContainerEnumeration::hasMoreElements()
-        throw (css::uno::RuntimeException, std::exception)
 {
     return (int)m_vec.size() > m_index +1;
 }
 
 css::uno::Any ContainerEnumeration::nextElement()
-        throw (css::container::NoSuchElementException,
-               css::lang::WrappedTargetException,
-               css::uno::RuntimeException, std::exception)
 {
     if( ! hasMoreElements() )
     {
@@ -264,21 +241,18 @@ css::uno::Any ContainerEnumeration::nextElement()
 }
 
 Reference< XEnumeration > Container::createEnumeration(  )
-    throw (css::uno::RuntimeException, std::exception)
 {
     return new ContainerEnumeration( m_values );
 }
 
 void Container::addRefreshListener(
     const css::uno::Reference< css::util::XRefreshListener >& l )
-    throw (css::uno::RuntimeException, std::exception)
 {
     rBHelper.addListener( cppu::UnoType<decltype(l)>::get() , l );
 }
 
 void Container::removeRefreshListener(
     const css::uno::Reference< css::util::XRefreshListener >& l )
-    throw (css::uno::RuntimeException, std::exception)
 {
     rBHelper.removeListener( cppu::UnoType<decltype(l)>::get() , l );
 }
@@ -292,7 +266,7 @@ void Container::rename( const OUString &oldName, const OUString &newName )
 {
     Any newValue;
     {
-        osl::MutexGuard guard ( m_refMutex->mutex );
+        osl::MutexGuard guard ( m_xMutex->GetMutex() );
         String2IntMap::iterator ii = m_name2index.find( oldName );
         if( ii != m_name2index.end() )
         {
@@ -307,47 +281,30 @@ void Container::rename( const OUString &oldName, const OUString &newName )
 }
 
 void Container::dropByName( const OUString& elementName )
-    throw (css::sdbc::SQLException,
-           css::container::NoSuchElementException,
-           css::uno::RuntimeException, std::exception)
 {
-    osl::MutexGuard guard( m_refMutex->mutex );
+    osl::MutexGuard guard( m_xMutex->GetMutex() );
     String2IntMap::const_iterator ii = m_name2index.find( elementName );
     if( ii == m_name2index.end() )
     {
-        OUStringBuffer buf( 128 );
-        buf.append( "Column " );
-        buf.append( elementName );
-        buf.append( " is unknown in " );
-        buf.append( m_type );
-//         buf.appendAscii( " " );
-//         buf.append( m_schemaName );
-//         buf.appendAscii( "." );
-//         buf.append( m_tableName );
-        buf.append( " container, so it can't be dropped" );
         throw css::container::NoSuchElementException(
-            buf.makeStringAndClear(), *this );
+            "Column " + elementName + " is unknown in "
+            + m_type + " container, so it can't be dropped",
+            *this );
     }
     dropByIndex( ii->second );
 }
 
 void Container::dropByIndex( sal_Int32 index )
-    throw (css::sdbc::SQLException,
-           css::lang::IndexOutOfBoundsException,
-           css::uno::RuntimeException, std::exception)
 {
-    osl::MutexGuard guard( m_refMutex->mutex );
+    osl::MutexGuard guard( m_xMutex->GetMutex() );
     if( index < 0 ||  index >=(sal_Int32)m_values.size() )
     {
-        OUStringBuffer buf( 128 );
-        buf.append( "Index out of range (allowed 0 to " );
-        buf.append((sal_Int32)(m_values.size() -1) );
-        buf.append( ", got " );
-        buf.append( index );
-        buf.append( ") in " );
-        buf.append( m_type );
         throw css::lang::IndexOutOfBoundsException(
-            buf.makeStringAndClear(), *this );
+            "Index out of range (allowed 0 to "
+            + OUString::number(m_values.size() -1)
+            + ", got " + OUString::number( index )
+            + ") in " + m_type,
+            *this );
     }
 
     OUString name;
@@ -387,21 +344,15 @@ void Container::dropByIndex( sal_Int32 index )
 void Container::append(
     const OUString & name,
     const css::uno::Reference< css::beans::XPropertySet >& descriptor )
-    throw ( css::container::ElementExistException )
 
 {
-    osl::MutexGuard guard( m_refMutex->mutex );
+    osl::MutexGuard guard( m_xMutex->GetMutex() );
 
     if( hasByName( name ) )
     {
-        OUStringBuffer buf( 128 );
-        buf.append( "a ");
-        buf.append( m_type );
-        buf.append( " with name " );
-        buf.append( name );
-        buf.append( " already exists in this container" );
         throw css::container::ElementExistException(
-            buf.makeStringAndClear() , *this );
+            "a " + m_type + " with name " + name + " already exists in this container",
+            *this );
     }
 
     int index = m_values.size();
@@ -413,9 +364,6 @@ void Container::append(
 
 void Container::appendByDescriptor(
     const css::uno::Reference< css::beans::XPropertySet >& descriptor)
-    throw (css::sdbc::SQLException,
-           css::container::ElementExistException,
-           css::uno::RuntimeException, std::exception)
 {
     append( extractStringProperty( descriptor, getStatics().NAME ), descriptor );
 }
@@ -423,14 +371,12 @@ void Container::appendByDescriptor(
 
 void Container::addContainerListener(
         const css::uno::Reference< css::container::XContainerListener >& l )
-        throw (css::uno::RuntimeException, std::exception)
 {
     rBHelper.addListener( cppu::UnoType<decltype(l)>::get() , l );
 }
 
 void Container::removeContainerListener(
         const css::uno::Reference< css::container::XContainerListener >& l )
-        throw (css::uno::RuntimeException, std::exception)
 {
     rBHelper.removeListener( cppu::UnoType<decltype(l)>::get() , l );
 }
@@ -438,7 +384,6 @@ void Container::removeContainerListener(
 
 void Container::fire( const EventBroadcastHelper &helper )
 {
-    Reference< css::util::XRefreshListener > l;
     cppu::OInterfaceContainerHelper *container = rBHelper.getContainer( helper.getType() );
     if( container )
     {
@@ -451,7 +396,7 @@ void Container::fire( const EventBroadcastHelper &helper )
             }
             catch ( css::uno::RuntimeException & )
             {
-                OSL_ENSURE( false, "exception catched" );
+                OSL_ENSURE( false, "exception caught" );
                 // loose coupling, a runtime exception shall not break anything
                 // TODO: log away as warning !
             }
