@@ -21,7 +21,7 @@
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <comphelper/sequence.hxx>
 #include <cppuhelper/supportsservice.hxx>
-#include "TConnection.hxx"
+#include <TConnection.hxx>
 #include <com/sun/star/sdbc/ColumnValue.hpp>
 
 using namespace connectivity;
@@ -33,25 +33,25 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::sdbc;
 
 
-OUString SAL_CALL OColumn::getImplementationName(  ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+OUString SAL_CALL OColumn::getImplementationName(  )
 {
     if(isNew())
-        return OUString("com.sun.star.sdbcx.VColumnDescription");
+        return OUString("com.sun.star.sdbcx.VColumnDescriptor");
     return OUString("com.sun.star.sdbcx.VColumn");
 }
 
-::com::sun::star::uno::Sequence< OUString > SAL_CALL OColumn::getSupportedServiceNames(  ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< OUString > SAL_CALL OColumn::getSupportedServiceNames(  )
 {
-    ::com::sun::star::uno::Sequence< OUString > aSupported(1);
+    css::uno::Sequence< OUString > aSupported(1);
     if(isNew())
-        aSupported[0] = "com.sun.star.sdbcx.ColumnDescription";
+        aSupported[0] = "com.sun.star.sdbcx.ColumnDescriptor";
     else
         aSupported[0] = "com.sun.star.sdbcx.Column";
 
     return aSupported;
 }
 
-sal_Bool SAL_CALL OColumn::supportsService( const OUString& _rServiceName ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL OColumn::supportsService( const OUString& _rServiceName )
 {
     return cppu::supportsService(this, _rServiceName);
 }
@@ -70,38 +70,38 @@ OColumn::OColumn(bool _bCase)
     construct();
 }
 
-OColumn::OColumn(   const OUString& _Name,
-                    const OUString& _TypeName,
-                    const OUString& _DefaultValue,
-                    const OUString& _Description,
-                    sal_Int32       _IsNullable,
-                    sal_Int32       _Precision,
-                    sal_Int32       _Scale,
-                    sal_Int32       _Type,
-                    bool            _IsAutoIncrement,
-                    bool            _IsRowVersion,
-                    bool            _IsCurrency,
+OColumn::OColumn(   const OUString& Name,
+                    const OUString& TypeName,
+                    const OUString& DefaultValue,
+                    const OUString& Description,
+                    sal_Int32       IsNullable,
+                    sal_Int32       Precision,
+                    sal_Int32       Scale,
+                    sal_Int32       Type,
+                    bool            IsAutoIncrement,
+                    bool            IsRowVersion,
+                    bool            IsCurrency,
                     bool            _bCase,
-                    const OUString& _CatalogName,
-                    const OUString& _SchemaName,
-                    const OUString& _TableName)
+                    const OUString& CatalogName,
+                    const OUString& SchemaName,
+                    const OUString& TableName)
     :OColumnDescriptor_BASE(m_aMutex)
     ,ODescriptor(OColumnDescriptor_BASE::rBHelper,_bCase)
-    ,m_TypeName(_TypeName)
-    ,m_Description(_Description)
-    ,m_DefaultValue(_DefaultValue)
-    ,m_IsNullable(_IsNullable)
-    ,m_Precision(_Precision)
-    ,m_Scale(_Scale)
-    ,m_Type(_Type)
-    ,m_IsAutoIncrement(_IsAutoIncrement)
-    ,m_IsRowVersion(_IsRowVersion)
-    ,m_IsCurrency(_IsCurrency)
-    ,m_CatalogName(_CatalogName)
-    ,m_SchemaName(_SchemaName)
-    ,m_TableName(_TableName)
+    ,m_TypeName(TypeName)
+    ,m_Description(Description)
+    ,m_DefaultValue(DefaultValue)
+    ,m_IsNullable(IsNullable)
+    ,m_Precision(Precision)
+    ,m_Scale(Scale)
+    ,m_Type(Type)
+    ,m_IsAutoIncrement(IsAutoIncrement)
+    ,m_IsRowVersion(IsRowVersion)
+    ,m_IsCurrency(IsCurrency)
+    ,m_CatalogName(CatalogName)
+    ,m_SchemaName(SchemaName)
+    ,m_TableName(TableName)
 {
-    m_Name = _Name;
+    m_Name = Name;
 
     construct();
 }
@@ -130,7 +130,7 @@ void SAL_CALL OColumn::release() throw()
     OColumnDescriptor_BASE::release();
 }
 
-Any SAL_CALL OColumn::queryInterface( const Type & rType ) throw(RuntimeException, std::exception)
+Any SAL_CALL OColumn::queryInterface( const Type & rType )
 {
     Any aRet = ODescriptor::queryInterface( rType);
     if(!aRet.hasValue())
@@ -143,7 +143,7 @@ Any SAL_CALL OColumn::queryInterface( const Type & rType ) throw(RuntimeExceptio
     return aRet;
 }
 
-Sequence< Type > SAL_CALL OColumn::getTypes(  ) throw(RuntimeException, std::exception)
+Sequence< Type > SAL_CALL OColumn::getTypes(  )
 {
     if(isNew())
         return ::comphelper::concatSequences(ODescriptor::getTypes(),OColumnDescriptor_BASE::getTypes());
@@ -181,7 +181,7 @@ void OColumn::disposing()
 
 }
 
-Reference< XPropertySet > SAL_CALL OColumn::createDataDescriptor(  ) throw(RuntimeException, std::exception)
+Reference< XPropertySet > SAL_CALL OColumn::createDataDescriptor(  )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     checkDisposed(OColumnDescriptor_BASE::rBHelper.bDisposed);
@@ -206,18 +206,18 @@ Reference< XPropertySet > SAL_CALL OColumn::createDataDescriptor(  ) throw(Runti
     return pNewColumn;
 }
 
-::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > SAL_CALL OColumn::getPropertySetInfo(  ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL OColumn::getPropertySetInfo(  )
 {
     return ::cppu::OPropertySetHelper::createPropertySetInfo(getInfoHelper());
 }
 
 // XNamed
-OUString SAL_CALL OColumn::getName(  ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+OUString SAL_CALL OColumn::getName(  )
 {
     return m_Name;
 }
 
-void SAL_CALL OColumn::setName( const OUString& aName ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+void SAL_CALL OColumn::setName( const OUString& aName )
 {
     m_Name = aName;
 }
