@@ -20,6 +20,7 @@
 #include <sal/types.h>
 
 #include <stdlib.h>
+#include <type_traits>
 
 #include <cppunit/TestSuite.h>
 #include <cppunit/TestFixture.h>
@@ -27,42 +28,42 @@
 #include <cppunit/plugin/TestPlugIn.h>
 #include <cppunit/extensions/HelperMacros.h>
 
-#include "Enum1.hpp"
-#include "Enum2.hpp"
-#include "Exception1.hpp"
-#include "Exception2.hpp"
-#include "Exception2a.hpp"
-#include "Exception2b.hpp"
-#include "Interface1.hpp"
-#include "Interface2.hpp"
-#include "Interface2a.hpp"
-#include "Interface2b.hpp"
-#include "Interface3.hpp"
-#include "Poly.hpp"
-#include "Struct1.hpp"
-#include "Struct2.hpp"
-#include "Struct2a.hpp"
-#include "Struct2b.hpp"
-#include "boost/noncopyable.hpp"
-#include "boost/type_traits/is_same.hpp"
-#include "com/sun/star/uno/Any.hxx"
-#include "com/sun/star/uno/Reference.hxx"
-#include "com/sun/star/uno/RuntimeException.hpp"
-#include "com/sun/star/uno/Sequence.hxx"
-#include "com/sun/star/uno/Type.hxx"
-#include "com/sun/star/uno/XInterface.hpp"
-#include "osl/diagnose.h"
-#include "osl/interlck.h"
-#include "rtl/string.h"
-#include "rtl/ustring.h"
-#include "rtl/ustring.hxx"
+#include <Enum1.hpp>
+#include <Enum2.hpp>
+#include <Exception1.hpp>
+#include <Exception2.hpp>
+#include <Exception2a.hpp>
+#include <Exception2b.hpp>
+#include <Interface1.hpp>
+#include <Interface2.hpp>
+#include <Interface2a.hpp>
+#include <Interface2b.hpp>
+#include <Interface3.hpp>
+#include <Poly.hpp>
+#include <Struct1.hpp>
+#include <Struct2.hpp>
+#include <Struct2a.hpp>
+#include <Struct2b.hpp>
+#include <com/sun/star/uno/Any.hxx>
+#include <com/sun/star/uno/Reference.hxx>
+#include <com/sun/star/uno/RuntimeException.hpp>
+#include <com/sun/star/uno/Sequence.hxx>
+#include <com/sun/star/uno/Type.hxx>
+#include <com/sun/star/uno/XInterface.hpp>
+#include <osl/interlck.h>
+#include <rtl/string.h>
+#include <rtl/ustring.h>
+#include <rtl/ustring.hxx>
 
 namespace {
 
-class Base: private boost::noncopyable {
+class Base {
 public:
     Base(): m_count(0) {}
 
+    Base(const Base&) = delete;
+    const Base& operator=(const Base&) = delete;
+
     void acquire() {
         if (osl_atomic_increment(&m_count) == SAL_MAX_INT32) {
             abort();
@@ -84,19 +85,18 @@ private:
 
 class Impl1: public Interface1, private Base {
 public:
-    virtual css::uno::Any SAL_CALL queryInterface(css::uno::Type const & type)
-        throw (css::uno::RuntimeException, std::exception) override
+    virtual css::uno::Any SAL_CALL queryInterface(css::uno::Type const & type) override
     {
         if (type == cppu::UnoType<css::uno::XInterface>::get()) {
             css::uno::Reference< css::uno::XInterface > ref(
                 static_cast< css::uno::XInterface * >(this));
             return css::uno::Any(&ref, type);
-        } else if (type == cppu::UnoType<Interface1>::get()) {
+        }
+        if (type == cppu::UnoType<Interface1>::get()) {
             css::uno::Reference< Interface1 > ref(this);
             return css::uno::Any(&ref, type);
-        } else {
-            return css::uno::Any();
         }
+        return css::uno::Any();
     }
 
     virtual void SAL_CALL acquire() throw () override {
@@ -110,26 +110,27 @@ public:
 
 class Impl2: public Interface2a, public Interface3, private Base {
 public:
-    virtual css::uno::Any SAL_CALL queryInterface(css::uno::Type const & type)
-        throw (css::uno::RuntimeException, std::exception) override
+    virtual css::uno::Any SAL_CALL queryInterface(css::uno::Type const & type) override
     {
         if (type == cppu::UnoType<css::uno::XInterface>::get()) {
             css::uno::Reference< css::uno::XInterface > ref(
                 static_cast< css::uno::XInterface * >(
                     static_cast< Interface2a * >(this)));
             return css::uno::Any(&ref, type);
-        } else if (type == cppu::UnoType<Interface2>::get()) {
+        }
+        if (type == cppu::UnoType<Interface2>::get()) {
             css::uno::Reference< Interface2 > ref(this);
             return css::uno::Any(&ref, type);
-        } else if (type == cppu::UnoType<Interface2a>::get()) {
+        }
+        if (type == cppu::UnoType<Interface2a>::get()) {
             css::uno::Reference< Interface2a > ref(this);
             return css::uno::Any(&ref, type);
-        } else if (type == cppu::UnoType<Interface3>::get()) {
+        }
+        if (type == cppu::UnoType<Interface3>::get()) {
             css::uno::Reference< Interface3 > ref(this);
             return css::uno::Any(&ref, type);
-        } else {
-            return css::uno::Any();
         }
+        return css::uno::Any();
     }
 
     virtual void SAL_CALL acquire() throw () override {
@@ -143,26 +144,27 @@ public:
 
 class Impl2b: public Interface2b, private Base {
 public:
-    virtual css::uno::Any SAL_CALL queryInterface(css::uno::Type const & type)
-        throw (css::uno::RuntimeException, std::exception) override
+    virtual css::uno::Any SAL_CALL queryInterface(css::uno::Type const & type) override
     {
         if (type == cppu::UnoType<css::uno::XInterface>::get()) {
             css::uno::Reference< css::uno::XInterface > ref(
                 static_cast< css::uno::XInterface * >(
                     static_cast< Interface2a * >(this)));
             return css::uno::Any(&ref, type);
-        } else if (type == cppu::UnoType<Interface2>::get()) {
+        }
+        if (type == cppu::UnoType<Interface2>::get()) {
             css::uno::Reference< Interface2 > ref(this);
             return css::uno::Any(&ref, type);
-        } else if (type == cppu::UnoType<Interface2a>::get()) {
+        }
+        if (type == cppu::UnoType<Interface2a>::get()) {
             css::uno::Reference< Interface2a > ref(this);
             return css::uno::Any(&ref, type);
-        } else if (type == cppu::UnoType<Interface2b>::get()) {
+        }
+        if (type == cppu::UnoType<Interface2b>::get()) {
             css::uno::Reference< Interface2b > ref(this);
             return css::uno::Any(&ref, type);
-        } else {
-            return css::uno::Any();
         }
+        return css::uno::Any();
     }
 
     virtual void SAL_CALL acquire() throw () override {
@@ -225,215 +227,239 @@ public:
 
 void Test::testVoid() {
     css::uno::Any a;
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<void>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<void>::get()));
     {
         bool b = true;
-        CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
+        CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b));
+        CPPUNIT_ASSERT_MESSAGE("bool", b);
     }
     {
         sal_Bool b = true;
-        CPPUNIT_ASSERT_MESSAGE("sal_Bool", !(a >>= b) && b);
+        CPPUNIT_ASSERT_MESSAGE("sal_Bool", !(a >>= b));
+        CPPUNIT_ASSERT_MESSAGE("sal_Bool", b);
     }
     {
         sal_Int8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
-    }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Int8", sal_Int8(2), b);
     }
     {
         sal_Int16 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Int16", sal_Int16(2), b);
     }
     {
         sal_uInt16 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt16", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_uInt16", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_uInt16", sal_uInt16(2), b);
     }
     {
         sal_Int32 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_Int32", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_Int32", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Int32", sal_Int32(2), b);
     }
     {
         sal_uInt32 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt32", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_uInt32", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_uInt32", sal_uInt32(2), b);
     }
     {
         sal_Int64 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_Int64", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_Int64", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Int64", sal_Int64(2), b);
     }
     {
         sal_uInt64 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt64", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_uInt64", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_uInt64", sal_uInt64(2), b);
     }
     {
         float b = 2;
-        CPPUNIT_ASSERT_MESSAGE("float", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("float", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("float", 2.0f, b);
     }
     {
         double b = 2;
-        CPPUNIT_ASSERT_MESSAGE("double", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("double", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("double", 2.0, b);
     }
     {
         sal_Unicode b = '2';
-        CPPUNIT_ASSERT_MESSAGE("sal_Unicode", !(a >>= b) && b == '2');
+        CPPUNIT_ASSERT_MESSAGE("sal_Unicode", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Unicode", u'2', b);
     }
     {
         rtl::OUString b("2");
-        CPPUNIT_ASSERT_MESSAGE( "rtl::OUString", !(a >>= b) && b == "2" );
+        CPPUNIT_ASSERT_MESSAGE( "rtl::OUString", !(a >>= b) );
+        CPPUNIT_ASSERT_EQUAL_MESSAGE( "rtl::OUString", OUString("2"), b );
     }
     {
         css::uno::Type b(cppu::UnoType<OUString>::get());
         CPPUNIT_ASSERT_MESSAGE(
             "css::uno::Type",
-            !(a >>= b) && b == cppu::UnoType<OUString>::get());
-    }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
+            !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE(
+            "css::uno::Type",
+            cppu::UnoType<OUString>::get(), b);
     }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
-            "css::uno::Sequence<rtl::OUString>", !(a >>= b) && b.getLength() == 2);
+            "css::uno::Sequence<rtl::OUString>", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE(
+            "css::uno::Sequence<rtl::OUString>", sal_Int32(2), b.getLength());
     }
     {
         Enum1 b = Enum1_M2;
-        CPPUNIT_ASSERT_MESSAGE("Enum1", !(a >>= b) && b == Enum1_M2);
+        CPPUNIT_ASSERT_MESSAGE("Enum1", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("Enum1", Enum1_M2, b);
     }
     {
         Struct1 b(2);
-        CPPUNIT_ASSERT_MESSAGE("Struct1", !(a >>= b) && b.member == 2);
+        CPPUNIT_ASSERT_MESSAGE("Struct1", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("Struct1", sal_Int32(2), b.member);
     }
     {
         Exception1 b(
             rtl::OUString(), css::uno::Reference< css::uno::XInterface >(), 2);
-        CPPUNIT_ASSERT_MESSAGE("Exception1", !(a >>= b) && b.member == 2);
+        CPPUNIT_ASSERT_MESSAGE("Exception1", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("Exception1", sal_Int32(2), b.member);
     }
     {
         css::uno::Reference< Interface1 > i(new Impl1);
         css::uno::Reference< Interface1 > b(i);
-        CPPUNIT_ASSERT_MESSAGE("Interface1", !(a >>= b) && b == i);
+        CPPUNIT_ASSERT_MESSAGE("Interface1", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("Interface1", i, b);
     }
 }
 
 void Test::testBoolean() {
     css::uno::Any a(false);
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<bool>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<bool>::get()));
     {
         bool b = true;
-        CPPUNIT_ASSERT_MESSAGE("bool", (a >>= b) && !b);
+        CPPUNIT_ASSERT_MESSAGE("bool", (a >>= b));
+        CPPUNIT_ASSERT_MESSAGE("bool", !b);
     }
     {
         sal_Bool b = true;
-        CPPUNIT_ASSERT_MESSAGE("sal_Bool", (a >>= b) && !b);
+        CPPUNIT_ASSERT_MESSAGE("sal_Bool", (a >>= b));
+        CPPUNIT_ASSERT_MESSAGE("sal_Bool", !b);
     }
     {
         sal_Int8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
-    }
-    {
-        sal_uInt8 b = 2;
-        if (boost::is_same< sal_uInt8, sal_Bool >::value) {
-            CPPUNIT_ASSERT_MESSAGE("@sal_uInt8", (a >>= b) && b == 0);
-        } else {
-            CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-        }
+        CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Int8", sal_Int8(2), b);
     }
     {
         sal_Int16 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Int16", sal_Int16(2), b);
     }
     {
         sal_uInt16 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt16", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_uInt16", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_uInt16", sal_uInt16(2), b);
     }
     {
         sal_Int32 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_Int32", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_Int32", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Int32", sal_Int32(2), b);
     }
     {
         sal_uInt32 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt32", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_uInt32", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_uInt32", sal_uInt32(2), b);
     }
     {
         sal_Int64 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_Int64", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_Int64", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Int64", sal_Int64(2), b);
     }
     {
         sal_uInt64 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt64", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_uInt64", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_uInt64", sal_uInt64(2), b);
     }
     {
         float b = 2;
-        CPPUNIT_ASSERT_MESSAGE("float", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("float", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("float", 2.0f, b);
     }
     {
         double b = 2;
-        CPPUNIT_ASSERT_MESSAGE("double", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("double", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("double", 2.0, b);
     }
     {
         sal_Unicode b = '2';
-        CPPUNIT_ASSERT_MESSAGE("sal_Unicode", !(a >>= b) && b == '2');
+        CPPUNIT_ASSERT_MESSAGE("sal_Unicode", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Unicode", u'2', b);
     }
     {
         rtl::OUString b("2");
-        CPPUNIT_ASSERT_MESSAGE( "rtl::OUString", !(a >>= b) && b == "2" );
+        CPPUNIT_ASSERT_MESSAGE( "rtl::OUString", !(a >>= b) );
+        CPPUNIT_ASSERT_EQUAL_MESSAGE( "rtl::OUString", OUString("2"), b );
     }
     {
         css::uno::Type b(cppu::UnoType<OUString>::get());
         CPPUNIT_ASSERT_MESSAGE(
             "css::uno::Type",
-            !(a >>= b) && b == cppu::UnoType<OUString>::get());
-    }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
+            !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE(
+            "css::uno::Type",
+            cppu::UnoType<OUString>::get(), b);
     }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
             "css::uno::Sequence<rtl::OUString>",
-            !(a >>= b) && b.getLength() == 2);
+            !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE(
+            "css::uno::Sequence<rtl::OUString>",
+            sal_Int32(2), b.getLength());
     }
     {
         Enum1 b = Enum1_M2;
-        CPPUNIT_ASSERT_MESSAGE("Enum1", !(a >>= b) && b == Enum1_M2);
+        CPPUNIT_ASSERT_MESSAGE("Enum1", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("Enum1", Enum1_M2, b);
     }
     {
         Struct1 b(2);
-        CPPUNIT_ASSERT_MESSAGE("Struct1", !(a >>= b) && b.member == 2);
+        CPPUNIT_ASSERT_MESSAGE("Struct1", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("Struct1", sal_Int32(2), b.member);
     }
     {
         Exception1 b(
             rtl::OUString(), css::uno::Reference< css::uno::XInterface >(), 2);
-        CPPUNIT_ASSERT_MESSAGE("Exception1", !(a >>= b) && b.member == 2);
+        CPPUNIT_ASSERT_MESSAGE("Exception1", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("Exception1", sal_Int32(2), b.member);
     }
     {
         css::uno::Reference< Interface1 > i(new Impl1);
         css::uno::Reference< Interface1 > b(i);
-        CPPUNIT_ASSERT_MESSAGE("Interface1", !(a >>= b) && b == i);
+        CPPUNIT_ASSERT_MESSAGE("Interface1", !(a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("Interface1", i, b);
     }
 }
 
 void Test::testByte() {
     css::uno::Any a(static_cast< sal_Int8 >(1));
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<sal_Int8>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<sal_Int8>::get()));
     {
         bool b = true;
-        CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
+        CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b));
+        CPPUNIT_ASSERT_MESSAGE("bool", b);
     }
     {
         sal_Bool b = true;
-        CPPUNIT_ASSERT_MESSAGE("sal_Bool", !(a >>= b) && b);
+        CPPUNIT_ASSERT_MESSAGE("sal_Bool", !(a >>= b));
+        CPPUNIT_ASSERT_MESSAGE("sal_Bool", b);
     }
     {
         sal_Int8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_Int8", (a >>= b) && b == 1);
-    }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
+        CPPUNIT_ASSERT_MESSAGE("sal_Int8", (a >>= b));
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("sal_Int8", sal_Int8(1), b);
     }
     {
         sal_Int16 b = 2;
@@ -469,7 +495,7 @@ void Test::testByte() {
     }
     {
         sal_Unicode b = '2';
-        if (boost::is_same< sal_Unicode, sal_uInt16 >::value) {
+        if (std::is_same< sal_Unicode, sal_uInt16 >::value) {
             CPPUNIT_ASSERT_MESSAGE("@sal_Unicode", (a >>= b) && b == 1);
         } else {
             CPPUNIT_ASSERT_MESSAGE("sal_Unicode", !(a >>= b) && b == '2');
@@ -485,10 +511,6 @@ void Test::testByte() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -517,7 +539,7 @@ void Test::testByte() {
 
 void Test::testShort() {
     css::uno::Any a(static_cast< sal_Int16 >(1));
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<sal_Int16>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<sal_Int16>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -530,10 +552,6 @@ void Test::testShort() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", (a >>= b) && b == 1);
@@ -568,7 +586,7 @@ void Test::testShort() {
     }
     {
         sal_Unicode b = '2';
-        if (boost::is_same< sal_Unicode, sal_uInt16 >::value) {
+        if (std::is_same< sal_Unicode, sal_uInt16 >::value) {
             CPPUNIT_ASSERT_MESSAGE("@sal_Unicode", (a >>= b) && b == 1);
         } else {
             CPPUNIT_ASSERT_MESSAGE("sal_Unicode", !(a >>= b) && b == '2');
@@ -584,10 +602,6 @@ void Test::testShort() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -618,7 +632,7 @@ void Test::testUnsignedShort() {
     sal_uInt16 n = 1;
     css::uno::Any a(&n, cppu::UnoType<cppu::UnoUnsignedShortType>::get());
     CPPUNIT_ASSERT(
-        a.getValueType() == cppu::UnoType<cppu::UnoUnsignedShortType>::get());
+        bool(a.getValueType() == cppu::UnoType<cppu::UnoUnsignedShortType>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -631,10 +645,6 @@ void Test::testUnsignedShort() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", (a >>= b) && b == 1);
@@ -669,7 +679,7 @@ void Test::testUnsignedShort() {
     }
     {
         sal_Unicode b = '2';
-        if (boost::is_same< sal_Unicode, sal_uInt16 >::value) {
+        if (std::is_same< sal_Unicode, sal_uInt16 >::value) {
             CPPUNIT_ASSERT_MESSAGE("@sal_Unicode", (a >>= b) && b == 1);
         } else {
             CPPUNIT_ASSERT_MESSAGE("sal_Unicode", !(a >>= b) && b == '2');
@@ -685,10 +695,6 @@ void Test::testUnsignedShort() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -717,7 +723,7 @@ void Test::testUnsignedShort() {
 
 void Test::testLong() {
     css::uno::Any a(static_cast< sal_Int32 >(1));
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<sal_Int32>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<sal_Int32>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -730,10 +736,6 @@ void Test::testLong() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -780,10 +782,6 @@ void Test::testLong() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -812,7 +810,7 @@ void Test::testLong() {
 
 void Test::testUnsignedLong() {
     css::uno::Any a(static_cast< sal_uInt32 >(1));
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<sal_uInt32>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<sal_uInt32>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -825,10 +823,6 @@ void Test::testUnsignedLong() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -875,10 +869,6 @@ void Test::testUnsignedLong() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -907,7 +897,7 @@ void Test::testUnsignedLong() {
 
 void Test::testHyper() {
     css::uno::Any a(static_cast< sal_Int64 >(1));
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<sal_Int64>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<sal_Int64>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -920,10 +910,6 @@ void Test::testHyper() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -970,10 +956,6 @@ void Test::testHyper() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1002,7 +984,7 @@ void Test::testHyper() {
 
 void Test::testUnsignedHyper() {
     css::uno::Any a(static_cast< sal_uInt64 >(1));
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<sal_uInt64>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<sal_uInt64>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1015,10 +997,6 @@ void Test::testUnsignedHyper() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1065,10 +1043,6 @@ void Test::testUnsignedHyper() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1097,7 +1071,7 @@ void Test::testUnsignedHyper() {
 
 void Test::testFloat() {
     css::uno::Any a(1.f);
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<float>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<float>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1110,10 +1084,6 @@ void Test::testFloat() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1160,10 +1130,6 @@ void Test::testFloat() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1192,7 +1158,7 @@ void Test::testFloat() {
 
 void Test::testDouble() {
     css::uno::Any a(1.);
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<double>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<double>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1205,10 +1171,6 @@ void Test::testDouble() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1255,10 +1217,6 @@ void Test::testDouble() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1288,7 +1246,7 @@ void Test::testDouble() {
 void Test::testChar() {
     sal_Unicode c = '1';
     css::uno::Any a(&c, cppu::UnoType<cppu::UnoCharType>::get());
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<cppu::UnoCharType>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<cppu::UnoCharType>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1301,10 +1259,6 @@ void Test::testChar() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1339,7 +1293,7 @@ void Test::testChar() {
     }
     {
         sal_Unicode b = '2';
-        if (boost::is_same< sal_Unicode, sal_uInt16 >::value) {
+        if (std::is_same< sal_Unicode, sal_uInt16 >::value) {
             CPPUNIT_ASSERT_MESSAGE("@sal_Unicode", !(a >>= b) && b == '2');
         } else {
             CPPUNIT_ASSERT_MESSAGE("sal_Unicode", (a >>= b) && b == '1');
@@ -1355,10 +1309,6 @@ void Test::testChar() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1387,7 +1337,7 @@ void Test::testChar() {
 
 void Test::testString() {
     css::uno::Any a(rtl::OUString("1"));
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<OUString>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<OUString>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1400,10 +1350,6 @@ void Test::testString() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1450,10 +1396,6 @@ void Test::testString() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1482,7 +1424,7 @@ void Test::testString() {
 
 void Test::testType() {
     css::uno::Any a(cppu::UnoType<sal_Int32>::get());
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<css::uno::Type>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<css::uno::Type>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1495,10 +1437,6 @@ void Test::testType() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1544,10 +1482,6 @@ void Test::testType() {
         CPPUNIT_ASSERT_MESSAGE(
             "css::uno::Type", (a >>= b) && b == cppu::UnoType<sal_Int32>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1578,8 +1512,8 @@ void Test::testSequence() {
     sal_Int32 n = 1;
     css::uno::Any a(css::uno::Sequence< sal_Int32 >(&n, 1));
     CPPUNIT_ASSERT(
-        a.getValueType()
-        == cppu::UnoType<css::uno::Sequence<sal_Int32>>::get());
+        bool(a.getValueType()
+        == cppu::UnoType<css::uno::Sequence<sal_Int32>>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1592,10 +1526,6 @@ void Test::testSequence() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1642,10 +1572,6 @@ void Test::testSequence() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1680,7 +1606,7 @@ void Test::testSequence() {
 
 void Test::testEnum() {
     css::uno::Any a(Enum2_M1);
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<Enum2>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<Enum2>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1693,10 +1619,6 @@ void Test::testEnum() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1743,10 +1665,6 @@ void Test::testEnum() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1779,7 +1697,7 @@ void Test::testEnum() {
 
 void Test::testStruct() {
     css::uno::Any a(Struct2a(1, 3));
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<Struct2a>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<Struct2a>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1792,10 +1710,6 @@ void Test::testStruct() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1842,10 +1756,6 @@ void Test::testStruct() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -1888,10 +1798,10 @@ void Test::testStruct() {
 void Test::testPoly() {
     css::uno::Any a;
     a <<= Poly< css::uno::Sequence< ::sal_Unicode > >();
-    CPPUNIT_ASSERT_MESSAGE( "type name", a.getValueType().getTypeName() == "Poly<[]char>" );
-    CPPUNIT_ASSERT_MESSAGE(
+    CPPUNIT_ASSERT_EQUAL_MESSAGE( "type name", OUString("Poly<[]char>"), a.getValueType().getTypeName() );
+    CPPUNIT_ASSERT_EQUAL_MESSAGE(
         "constructor",
-        a == css::uno::Any(Poly< css::uno::Sequence< ::sal_Unicode > >()));
+        css::uno::Any(Poly< css::uno::Sequence< ::sal_Unicode > >()), a);
 }
 
 void Test::testException() {
@@ -1899,7 +1809,7 @@ void Test::testException() {
         Exception2a(
             rtl::OUString(), css::uno::Reference< css::uno::XInterface >(), 1,
             3));
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<Exception2a>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<Exception2a>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -1912,10 +1822,6 @@ void Test::testException() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -1962,10 +1868,6 @@ void Test::testException() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -2013,7 +1915,7 @@ void Test::testException() {
 void Test::testInterface() {
     css::uno::Reference< Interface2a > i2(new Impl2);
     css::uno::Any a(i2);
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<Interface2a>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<Interface2a>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -2026,10 +1928,6 @@ void Test::testInterface() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -2076,10 +1974,6 @@ void Test::testInterface() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
@@ -2125,7 +2019,7 @@ void Test::testInterface() {
 
 void Test::testNull() {
     css::uno::Any a = css::uno::Any(css::uno::Reference< Interface2a >());
-    CPPUNIT_ASSERT(a.getValueType() == cppu::UnoType<Interface2a>::get());
+    CPPUNIT_ASSERT(bool(a.getValueType() == cppu::UnoType<Interface2a>::get()));
     {
         bool b = true;
         CPPUNIT_ASSERT_MESSAGE("bool", !(a >>= b) && b);
@@ -2138,10 +2032,6 @@ void Test::testNull() {
         sal_Int8 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int8", !(a >>= b) && b == 2);
     }
-    {
-        sal_uInt8 b = 2;
-        CPPUNIT_ASSERT_MESSAGE("sal_uInt8", !(a >>= b) && b == 2);
-    }
     {
         sal_Int16 b = 2;
         CPPUNIT_ASSERT_MESSAGE("sal_Int16", !(a >>= b) && b == 2);
@@ -2188,10 +2078,6 @@ void Test::testNull() {
             "css::uno::Type",
             !(a >>= b) && b == cppu::UnoType<OUString>::get());
     }
-    {
-        css::uno::Any b(rtl::OUString("2"));
-        CPPUNIT_ASSERT_MESSAGE("css::uno::Any", (a >>= b) && b == a);
-    }
     {
         css::uno::Sequence< rtl::OUString > b(2);
         CPPUNIT_ASSERT_MESSAGE(
