@@ -21,26 +21,27 @@
 
 #include "IdentityMapping.hxx"
 
-#include <boost/unordered_map.hpp>
-#include <set>
 #include <algorithm>
 #include <cassert>
+#include <set>
+#include <unordered_map>
 
-#include "rtl/ustring.hxx"
-#include "rtl/ustrbuf.hxx"
-#include "osl/module.h"
-#include "osl/diagnose.h"
-#include "osl/mutex.hxx"
-#include "osl/interlck.h"
+#include <rtl/ustring.hxx>
+#include <rtl/ustrbuf.hxx>
+#include <osl/module.h>
+#include <osl/diagnose.h>
+#include <osl/mutex.hxx>
+#include <osl/interlck.h>
+#include <sal/log.hxx>
 
-#include "uno/dispatcher.h"
-#include "uno/mapping.h"
-#include "uno/lbnames.h"
-#include "uno/environment.hxx"
+#include <uno/dispatcher.h>
+#include <uno/mapping.h>
+#include <uno/lbnames.h>
+#include <uno/environment.hxx>
 
-#include "typelib/typedescription.h"
+#include <typelib/typedescription.h>
 
-#include "cppu/EnvDcp.hxx"
+#include <cppu/EnvDcp.hxx>
 #include "cascade_mapping.hxx"
 #include "loadmodule.hxx"
 
@@ -49,9 +50,6 @@ using namespace osl;
 using namespace com::sun::star::uno;
 using ::rtl::OUString;
 using ::rtl::OUStringBuffer;
-using ::rtl::OUStringToOString;
-using ::rtl::OUStringHash;
-using ::rtl::OString;
 
 namespace cppu
 {
@@ -61,16 +59,26 @@ class Mapping
     uno_Mapping * _pMapping;
 
 public:
-    inline explicit Mapping( uno_Mapping * pMapping = 0 );
+    inline explicit Mapping( uno_Mapping * pMapping = nullptr );
     inline Mapping( const Mapping & rMapping );
+    Mapping(Mapping && other): _pMapping(other._pMapping)
+    { other._pMapping = nullptr; }
     inline ~Mapping();
     inline Mapping & SAL_CALL operator = ( uno_Mapping * pMapping );
-    inline Mapping & SAL_CALL operator = ( const Mapping & rMapping )
+    Mapping & SAL_CALL operator = ( const Mapping & rMapping )
         { return operator = ( rMapping._pMapping ); }
-    inline uno_Mapping * SAL_CALL get() const
+    Mapping & operator =(Mapping && other) {
+        if (_pMapping != nullptr) {
+            (*_pMapping->release)(_pMapping);
+        }
+        _pMapping = other._pMapping;
+        other._pMapping = nullptr;
+        return *this;
+    }
+    uno_Mapping * SAL_CALL get() const
         { return _pMapping; }
-    inline bool SAL_CALL is() const
-        { return (_pMapping != 0); }
+    bool SAL_CALL is() const
+        { return (_pMapping != nullptr); }
 };
 
 inline Mapping::Mapping( uno_Mapping * pMapping )
@@ -121,16 +129,16 @@ struct MappingEntry
         {}
 };
 
-struct FctPtrHash : public std::unary_function< uno_Mapping *, size_t >
+struct FctPtrHash
 {
     size_t operator()( uno_Mapping * pKey ) const
         { return reinterpret_cast<size_t>(pKey); }
 };
 
-typedef boost::unordered_map<
-    OUString, MappingEntry *, OUStringHash > t_OUString2Entry;
-typedef boost::unordered_map<
-    uno_Mapping *, MappingEntry *, FctPtrHash, equal_to< uno_Mapping * > > t_Mapping2Entry;
+typedef std::unordered_map<
+    OUString, MappingEntry * > t_OUString2Entry;
+typedef std::unordered_map<
+    uno_Mapping *, MappingEntry *, FctPtrHash > t_Mapping2Entry;
 
 typedef set< uno_getMappingFunc > t_CallbackSet;
 typedef set< OUString > t_OUStringSet;
@@ -151,7 +159,7 @@ struct MappingsData
 
 static MappingsData & getMappingsData()
 {
-    static MappingsData * s_p = 0;
+    static MappingsData * s_p = nullptr;
     if (! s_p)
     {
         MutexGuard aGuard( Mutex::getGlobalMutex() );
@@ -227,18 +235,18 @@ static void SAL_CALL mediate_mapInterface(
         uno_Mediate_Mapping * that = static_cast< uno_Mediate_Mapping * >( pMapping );
         uno_Mapping * pFrom2Uno = that->aFrom2Uno.get();
 
-        uno_Interface * pUnoI = 0;
-        (*pFrom2Uno->mapInterface)( pFrom2Uno, (void **) &pUnoI, pInterface, pInterfaceTypeDescr );
-        if (0 == pUnoI)
+        uno_Interface * pUnoI = nullptr;
+        (*pFrom2Uno->mapInterface)( pFrom2Uno, reinterpret_cast<void **>(&pUnoI), pInterface, pInterfaceTypeDescr );
+        if (nullptr == pUnoI)
         {
             void * pOut = *ppOut;
-            if (0 != pOut)
+            if (nullptr != pOut)
             {
                 uno_ExtEnvironment * pTo = that->aTo.get()->pExtEnv;
-                OSL_ENSURE( 0 != pTo, "### cannot release out interface: leaking!" );
-                if (0 != pTo)
+                OSL_ENSURE( nullptr != pTo, "### cannot release out interface: leaking!" );
+                if (nullptr != pTo)
                     (*pTo->releaseInterface)( pTo, pOut );
-                *ppOut = 0; // set to 0 anyway, because mapping was not successful!
+                *ppOut = nullptr; // set to 0 anyway, because mapping was not successful!
             }
         }
         else
@@ -337,7 +345,7 @@ static uno_ext_getMappingFunc selectMapFunc( const OUString & rBridgeName )
 
 #else
 
-static inline oslModule loadModule( const OUString & rBridgeName )
+static inline bool loadModule(osl::Module & rModule, const OUString & rBridgeName)
 {
     bool bNeg;
     {
@@ -347,16 +355,23 @@ static inline oslModule loadModule( const OUString & rBridgeName )
     bNeg = (iFind != rData.aNegativeLibs.end());
     }
 
-    if (! bNeg)
+    if (!bNeg)
     {
-        oslModule hModule = cppu::detail::loadModule( rBridgeName );
+        bool bModule;
+        try {
+            bModule = cppu::detail::loadModule(rModule, rBridgeName);
+        }
+        catch(...) {
+            // convert throw to return false
+            bModule = false;
+        }
 
-        if (hModule)
-            return hModule;
+        if (bModule)
+            return true;
 
         setNegativeBridge( rBridgeName ); // no load again
     }
-    return 0;
+    return false;
 }
 
 #endif
@@ -390,9 +405,7 @@ static Mapping loadExternalMapping(
 
         if (! fpGetMapFunc)
         {
-#if OSL_DEBUG_LEVEL > 1
-            OSL_TRACE( "Could not find mapfunc for %s", OUStringToOString( aName, RTL_TEXTENCODING_ASCII_US ).getStr());
-#endif
+            SAL_INFO("cppu", "Could not find mapfunc for " << aName);
             return Mapping();
         }
 
@@ -406,34 +419,34 @@ static Mapping loadExternalMapping(
         }
 #else
         // find proper lib
-        oslModule hModule = 0;
+        osl::Module aModule;
+        bool bModule(false);
         OUString aName;
 
         if ( EnvDcp::getTypeName(rFrom.getTypeName()) == UNO_LB_UNO )
-            hModule = loadModule( aName = getBridgeName( rTo, rFrom, rAddPurpose ) );
-        if (! hModule)
-            hModule = loadModule( aName = getBridgeName( rFrom, rTo, rAddPurpose ) );
-        if (! hModule)
-            hModule = loadModule( aName = getBridgeName( rTo, rFrom, rAddPurpose ) );
+            bModule = loadModule( aModule, aName = getBridgeName( rTo, rFrom, rAddPurpose ) );
+        if (!bModule)
+            bModule = loadModule( aModule, aName = getBridgeName( rFrom, rTo, rAddPurpose ) );
+        if (!bModule)
+            bModule = loadModule( aModule, aName = getBridgeName( rTo, rFrom, rAddPurpose ) );
 
-        if (hModule)
+        if (bModule)
         {
-            OUString aSymbolName( UNO_EXT_GETMAPPING );
             uno_ext_getMappingFunc fpGetMapFunc =
-                (uno_ext_getMappingFunc)::osl_getFunctionSymbol(
-                    hModule, aSymbolName.pData );
+                reinterpret_cast<uno_ext_getMappingFunc>(aModule.getSymbol( UNO_EXT_GETMAPPING ));
 
             if (fpGetMapFunc)
             {
                 Mapping aExt;
-                (*fpGetMapFunc)( (uno_Mapping **)&aExt, rFrom.get(), rTo.get() );
+                (*fpGetMapFunc)( reinterpret_cast<uno_Mapping **>(&aExt), rFrom.get(), rTo.get() );
                 OSL_ASSERT( aExt.is() );
                 if (aExt.is())
                 {
+                    aModule.release();
                     return aExt;
                 }
             }
-            ::osl_unloadModule( hModule );
+            aModule.unload();
             setNegativeBridge( aName );
         }
 #endif
@@ -461,10 +474,7 @@ static Mapping getDirectMapping(
             aGuard.clear();
             return loadExternalMapping( rFrom, rTo, rAddPurpose );
         }
-        else
-        {
-            return Mapping( (*iFind).second->pMapping );
-        }
+        return Mapping( (*iFind).second->pMapping );
     }
     return Mapping();
 }
@@ -502,7 +512,7 @@ static Mapping getMediateMapping(
     else
     {
         // get registered uno env
-        ::uno_getEnvironment( (uno_Environment **)&aUno, aUnoEnvTypeName.pData, 0 );
+        ::uno_getEnvironment( reinterpret_cast<uno_Environment **>(&aUno), aUnoEnvTypeName.pData, nullptr );
 
         aUno2To = getDirectMapping( aUno, rTo );
         // : uno <-> to
@@ -515,7 +525,7 @@ static Mapping getMediateMapping(
     {
         // create anonymous uno env
         Environment aAnUno;
-        ::uno_createEnvironment( (uno_Environment **)&aAnUno, aUnoEnvTypeName.pData, 0 );
+        ::uno_createEnvironment( reinterpret_cast<uno_Environment **>(&aAnUno), aUnoEnvTypeName.pData, nullptr );
 
         Mapping aAnUno2Uno( getDirectMapping( aAnUno, aUno, rAddPurpose ) );
         if (! aAnUno2Uno.is())
@@ -556,13 +566,13 @@ void SAL_CALL uno_getMapping(
     rtl_uString * pAddPurpose )
     SAL_THROW_EXTERN_C()
 {
-    assert(ppMapping != 0);
-    assert(pFrom != 0);
-    assert(pTo != 0);
+    assert(ppMapping != nullptr);
+    assert(pFrom != nullptr);
+    assert(pTo != nullptr);
     if (*ppMapping)
     {
         (*(*ppMapping)->release)( *ppMapping );
-        *ppMapping = 0;
+        *ppMapping = nullptr;
     }
 
     Mapping aRet;
@@ -630,16 +640,16 @@ void SAL_CALL uno_getMappingByName(
     if (*ppMapping)
     {
         (*(*ppMapping)->release)( *ppMapping );
-        *ppMapping = 0;
+        *ppMapping = nullptr;
     }
 
-    uno_Environment * pEFrom = 0;
-    uno_getEnvironment( &pEFrom, pFrom, 0 );
+    uno_Environment * pEFrom = nullptr;
+    uno_getEnvironment( &pEFrom, pFrom, nullptr );
     OSL_ENSURE( pEFrom, "### cannot get source environment!" );
     if (pEFrom)
     {
-        uno_Environment * pETo = 0;
-        uno_getEnvironment( &pETo, pTo, 0 );
+        uno_Environment * pETo = nullptr;
+        uno_getEnvironment( &pETo, pTo, nullptr );
         OSL_ENSURE( pETo, "### cannot get target environment!" );
         if (pETo)
         {
@@ -651,7 +661,7 @@ void SAL_CALL uno_getMappingByName(
 }
 
 
-CPPU_DLLPUBLIC void SAL_CALL uno_registerMapping(
+void SAL_CALL uno_registerMapping(
     uno_Mapping ** ppMapping, uno_freeMappingFunc freeMapping,
     uno_Environment * pFrom, uno_Environment * pTo, rtl_uString * pAddPurpose )
     SAL_THROW_EXTERN_C()
@@ -664,10 +674,7 @@ CPPU_DLLPUBLIC void SAL_CALL uno_registerMapping(
     {
         OUString aMappingName(
             getMappingName( pFrom, pTo, pAddPurpose ? OUString(pAddPurpose) : OUString() ) );
-#if OSL_DEBUG_LEVEL > 2
-        OString cstr( OUStringToOString( aMappingName, RTL_TEXTENCODING_ASCII_US ) );
-        OSL_TRACE( "> inserting new mapping: %s", cstr.getStr() );
-#endif
+        SAL_INFO("cppu", "> inserting new mapping: " << aMappingName);
         // count initially 1
         MappingEntry * pEntry = new MappingEntry( *ppMapping, freeMapping, aMappingName );
         rData.aName2Entry[ aMappingName ] = pEntry;
@@ -689,7 +696,7 @@ CPPU_DLLPUBLIC void SAL_CALL uno_registerMapping(
     }
 }
 
-CPPU_DLLPUBLIC void SAL_CALL uno_revokeMapping(
+void SAL_CALL uno_revokeMapping(
     uno_Mapping * pMapping )
     SAL_THROW_EXTERN_C()
 {
@@ -704,17 +711,14 @@ CPPU_DLLPUBLIC void SAL_CALL uno_revokeMapping(
         rData.aMapping2Entry.erase( pEntry->pMapping );
         rData.aName2Entry.erase( pEntry->aMappingName );
         aGuard.clear();
-#if OSL_DEBUG_LEVEL > 2
-        OString cstr( OUStringToOString( pEntry->aMappingName, RTL_TEXTENCODING_ASCII_US  ) );
-        OSL_TRACE( "> revoking mapping %s", cstr.getStr() );
-#endif
+        SAL_INFO("cppu", "> revoking mapping " << pEntry->aMappingName);
         (*pEntry->freeMapping)( pEntry->pMapping );
         delete pEntry;
     }
 }
 
 
-CPPU_DLLPUBLIC void SAL_CALL uno_registerMappingCallback(
+void SAL_CALL uno_registerMappingCallback(
     uno_getMappingFunc pCallback )
     SAL_THROW_EXTERN_C()
 {
@@ -724,7 +728,7 @@ CPPU_DLLPUBLIC void SAL_CALL uno_registerMappingCallback(
     rData.aCallbacks.insert( pCallback );
 }
 
-CPPU_DLLPUBLIC void SAL_CALL uno_revokeMappingCallback(
+void SAL_CALL uno_revokeMappingCallback(
     uno_getMappingFunc pCallback )
     SAL_THROW_EXTERN_C()
 {
