@@ -20,16 +20,17 @@
 
 #include <rtl/bootstrap.hxx>
 
+#include <uno/lbnames.h>
 #include <uno/mapping.hxx>
 
 #include <cppuhelper/factory.hxx>
-#include <cppuhelper/compbase2.hxx>
+#include <cppuhelper/compbase.hxx>
 #include <cppuhelper/component_context.hxx>
 #include <cppuhelper/supportsservice.hxx>
 
 #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <com/sun/star/util/XMacroExpander.hpp>
-#include "com/sun/star/uno/RuntimeException.hpp"
+#include <com/sun/star/uno/RuntimeException.hpp>
 
 #include "macro_expander.hxx"
 #include "paths.hxx"
@@ -48,9 +49,9 @@ using rtl::OUString;
 namespace cppu
 {
 
-Bootstrap const & get_unorc() SAL_THROW(())
+Bootstrap const & get_unorc()
 {
-    static rtlBootstrapHandle s_bstrap = 0;
+    static rtlBootstrapHandle s_bstrap = nullptr;
     if (! s_bstrap)
     {
         OUString iniName(getUnoIniUri());
@@ -67,7 +68,7 @@ Bootstrap const & get_unorc() SAL_THROW(())
             s_bstrap = bstrap;
         }
     }
-    return *(Bootstrap const *)&s_bstrap;
+    return *reinterpret_cast<Bootstrap const *>(&s_bstrap);
 }
 
 }
@@ -111,7 +112,7 @@ inline Sequence< OUString > const & s_get_service_names()
     return theImplNames::get().getNames();
 }
 
-typedef ::cppu::WeakComponentImplHelper2<
+typedef cppu::WeakComponentImplHelper<
     util::XMacroExpander, lang::XServiceInfo > t_uno_impl;
 
 struct mutex_holder
@@ -122,66 +123,52 @@ struct mutex_holder
 class Bootstrap_MacroExpander : public mutex_holder, public t_uno_impl
 {
 protected:
-    virtual void SAL_CALL disposing();
+    virtual void SAL_CALL disposing() override;
 
 public:
-    inline Bootstrap_MacroExpander() SAL_THROW(())
+    Bootstrap_MacroExpander()
         : t_uno_impl( m_mutex )
         {}
-    virtual ~Bootstrap_MacroExpander()
-        SAL_THROW(());
 
     // XMacroExpander impl
-    virtual OUString SAL_CALL expandMacros( OUString const & exp )
-        throw (lang::IllegalArgumentException);
+    virtual OUString SAL_CALL expandMacros( OUString const & exp ) override;
     // XServiceInfo impl
-    virtual OUString SAL_CALL getImplementationName()
-        throw (RuntimeException);
-    virtual sal_Bool SAL_CALL supportsService( OUString const & serviceName )
-        throw (RuntimeException);
-    virtual Sequence< OUString > SAL_CALL getSupportedServiceNames()
-        throw (RuntimeException);
+    virtual OUString SAL_CALL getImplementationName() override;
+    virtual sal_Bool SAL_CALL supportsService( OUString const & serviceName ) override;
+    virtual Sequence< OUString > SAL_CALL getSupportedServiceNames() override;
 };
 
-//__________________________________________________________________________________________________
+
 void Bootstrap_MacroExpander::disposing()
 {}
-//__________________________________________________________________________________________________
-Bootstrap_MacroExpander::~Bootstrap_MacroExpander() SAL_THROW(())
-{}
 
 // XServiceInfo impl
-//__________________________________________________________________________________________________
+
 OUString Bootstrap_MacroExpander::getImplementationName()
-    throw (RuntimeException)
 {
     return s_impl_name();
 }
-//__________________________________________________________________________________________________
+
 sal_Bool Bootstrap_MacroExpander::supportsService( OUString const & serviceName )
-    throw (RuntimeException)
 {
     return cppu::supportsService(this, serviceName);
 }
-//__________________________________________________________________________________________________
+
 Sequence< OUString > Bootstrap_MacroExpander::getSupportedServiceNames()
-    throw (RuntimeException)
 {
     return s_get_service_names();
 }
 
 // XMacroExpander impl
-//__________________________________________________________________________________________________
+
 OUString Bootstrap_MacroExpander::expandMacros( OUString const & exp )
-    throw (lang::IllegalArgumentException)
 {
     return cppuhelper::detail::expandMacros( exp );
 }
 
-//==================================================================================================
+
 Reference< XInterface > SAL_CALL service_create(
     SAL_UNUSED_PARAMETER Reference< XComponentContext > const & )
-    SAL_THROW( (RuntimeException) )
 {
     return static_cast< ::cppu::OWeakObject * >( new Bootstrap_MacroExpander );
 }
@@ -190,7 +177,7 @@ Reference< XInterface > SAL_CALL service_create(
 
 namespace cppuhelper { namespace detail {
 
-Reference< lang::XSingleComponentFactory > create_bootstrap_macro_expander_factory() SAL_THROW(())
+Reference< lang::XSingleComponentFactory > create_bootstrap_macro_expander_factory()
 {
     Reference< lang::XSingleComponentFactory > free(::cppu::createSingleComponentFactory(
                                                         service_create,
@@ -198,13 +185,13 @@ Reference< lang::XSingleComponentFactory > create_bootstrap_macro_expander_facto
                                                         s_get_service_names() ));
 
     uno::Environment curr_env(Environment::getCurrent());
-    uno::Environment target_env(rtl::OUString(CPPU_STRINGIFY(CPPU_ENV)));
+    uno::Environment target_env(CPPU_CURRENT_LANGUAGE_BINDING_NAME);
 
     uno::Mapping target2curr(target_env, curr_env);
 
     return Reference<lang::XSingleComponentFactory>(
-        reinterpret_cast<lang::XSingleComponentFactory *>(
-            target2curr.mapInterface(free.get(), ::getCppuType(&free))),
+        static_cast<lang::XSingleComponentFactory *>(
+            target2curr.mapInterface(free.get(), cppu::UnoType<decltype(free)>::get())),
         SAL_NO_ACQUIRE);
 }
 
