@@ -25,7 +25,6 @@
 #include <cassert>
 
 #include <com/sun/star/uno/DeploymentException.hpp>
-#include <com/sun/star/uno/Reference.hxx>
 #include <com/sun/star/uno/XInterface.hpp>
 #include <osl/file.hxx>
 #include <osl/module.hxx>
@@ -37,6 +36,7 @@
 
 namespace {
 
+#ifndef ANDROID
 rtl::OUString get_this_libpath() {
     static rtl::OUString s_uri;
     if (s_uri.isEmpty()) {
@@ -56,7 +56,7 @@ rtl::OUString get_this_libpath() {
     }
     return s_uri;
 }
-
+#endif
 }
 
 rtl::OUString cppu::getUnoIniUri() {
