@@ -37,51 +37,41 @@ namespace offapp
     using namespace ::com::sun::star::uno;
 
 
-    static const OUString& getConnectionPoolNodeName()
+    static OUString getConnectionPoolNodeName()
     {
-        static OUString s_sNodeName("org.openoffice.Office.DataAccess/ConnectionPool" );
-        return s_sNodeName;
+        return OUString("org.openoffice.Office.DataAccess/ConnectionPool" );
     }
 
 
-    static const OUString& getEnablePoolingNodeName()
+    static OUString getEnablePoolingNodeName()
     {
-        static OUString s_sNodeName("EnablePooling");
-        return s_sNodeName;
+        return OUString("EnablePooling");
     }
 
 
-    static const OUString& getDriverSettingsNodeName()
+    static OUString getDriverSettingsNodeName()
     {
-        static OUString s_sNodeName("DriverSettings");
-        return s_sNodeName;
+        return OUString("DriverSettings");
     }
 
 
-    static const OUString& getDriverNameNodeName()
+    static OUString getDriverNameNodeName()
     {
-        static OUString s_sNodeName("DriverName");
-        return s_sNodeName;
+        return OUString("DriverName");
     }
 
 
-    static const OUString& getEnableNodeName()
+    static OUString getEnableNodeName()
     {
-        static OUString s_sNodeName("Enable");
-        return s_sNodeName;
+        return OUString("Enable");
     }
 
 
-    static const OUString& getTimeoutNodeName()
+    static OUString getTimeoutNodeName()
     {
-        static OUString s_sNodeName("Timeout");
-        return s_sNodeName;
+        return OUString("Timeout");
     }
 
-
-    //= ConnectionPoolConfig
-
-
     void ConnectionPoolConfig::GetOptions(SfxItemSet& _rFillItems)
     {
         // the config node where all pooling relevant info are stored under
@@ -103,7 +93,7 @@ namespace offapp
                 ++aLoopDrivers
             )
         {
-            aSettings.push_back(DriverPooling(*aLoopDrivers, false, 120));
+            aSettings.push_back(DriverPooling(*aLoopDrivers));
         }
 
         // then look for which of them settings are stored in the configuration
@@ -126,12 +116,12 @@ namespace offapp
                     aLookup != aSettings.end();
                     ++aLookup
                 )
-                if (sThisDriverName.equals(aLookup->sName))
+                if (sThisDriverName == aLookup->sName)
                     break;
 
             if (aLookup == aSettings.end())
             {   // do not know the driver - add it
-                aSettings.push_back(DriverPooling(sThisDriverName, false, 120));
+                aSettings.push_back(DriverPooling(sThisDriverName));
 
                 // and the position of the new entry
                 aLookup = aSettings.end();
@@ -151,7 +141,7 @@ namespace offapp
     {
         // the config node where all pooling relevant info are stored under
         OConfigurationTreeRoot aConnectionPoolRoot = OConfigurationTreeRoot::createWithComponentContext(
-            ::comphelper::getProcessComponentContext(), getConnectionPoolNodeName(), -1, OConfigurationTreeRoot::CM_UPDATABLE);
+            ::comphelper::getProcessComponentContext(), getConnectionPoolNodeName());
 
         if (!aConnectionPoolRoot.isValid())
             // already asserted by the OConfigurationTreeRoot
@@ -160,16 +150,16 @@ namespace offapp
         bool bNeedCommit = false;
 
         // the global "enabled" flag
-        SFX_ITEMSET_GET( _rSourceItems, pEnabled, SfxBoolItem, SID_SB_POOLING_ENABLED, true );
+        const SfxBoolItem* pEnabled = _rSourceItems.GetItem<SfxBoolItem>(SID_SB_POOLING_ENABLED);
         if (pEnabled)
         {
-            sal_Bool bEnabled = pEnabled->GetValue();
-            aConnectionPoolRoot.setNodeValue(getEnablePoolingNodeName(), Any(&bEnabled, ::getBooleanCppuType()));
+            bool bEnabled = pEnabled->GetValue();
+            aConnectionPoolRoot.setNodeValue(getEnablePoolingNodeName(), Any(bEnabled));
             bNeedCommit = true;
         }
 
         // the settings for the single drivers
-        SFX_ITEMSET_GET( _rSourceItems, pDriverSettings, DriverPoolingSettingsItem, SID_SB_DRIVER_TIMEOUTS, true );
+        const DriverPoolingSettingsItem* pDriverSettings = _rSourceItems.GetItem<DriverPoolingSettingsItem>(SID_SB_DRIVER_TIMEOUTS);
         if (pDriverSettings)
         {
             OConfigurationNode aDriverSettings = aConnectionPoolRoot.openNode(getDriverSettingsNodeName());
@@ -195,9 +185,9 @@ namespace offapp
                     aThisDriverSettings = aDriverSettings.createNode(aLoop->sName);
 
                 // set the values
-                aThisDriverSettings.setNodeValue(getDriverNameNodeName(), makeAny(sThisDriverName));
-                aThisDriverSettings.setNodeValue(getEnableNodeName(), Any(&aLoop->bEnabled, ::getBooleanCppuType()));
-                aThisDriverSettings.setNodeValue(getTimeoutNodeName(), makeAny(aLoop->nTimeoutSeconds));
+                aThisDriverSettings.setNodeValue(getDriverNameNodeName(), Any(sThisDriverName));
+                aThisDriverSettings.setNodeValue(getEnableNodeName(), Any(aLoop->bEnabled));
+                aThisDriverSettings.setNodeValue(getTimeoutNodeName(), Any(aLoop->nTimeoutSeconds));
             }
             bNeedCommit = true;
         }
@@ -209,5 +199,4 @@ namespace offapp
 }   // namespace offapp
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
