@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "macroass.hxx"
+#include <macroass.hxx>
 
 #include <basic/basmgr.hxx>
 #include <comphelper/string.hxx>
@@ -26,23 +26,23 @@
 #include <svx/dialogs.hrc>
 #include <svtools/svmedit.hxx>
 #include <vcl/idle.hxx>
-#include "cfgutil.hxx"
+#include <cfgutil.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/evntconf.hxx>
 #include <sfx2/objsh.hxx>
-#include "cuires.hrc"
 #include <vcl/fixed.hxx>
-#include "headertablistbox.hxx"
-#include "svtools/svlbitm.hxx"
-#include "svtools/treelistentry.hxx"
+#include <headertablistbox.hxx>
+#include <svtools/svlbitm.hxx>
+#include <svtools/treelistentry.hxx>
+#include <o3tl/make_unique.hxx>
 
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::frame::XFrame;
 
-class _SfxMacroTabPage_Impl
+class SfxMacroTabPage_Impl
 {
 public:
-    _SfxMacroTabPage_Impl();
+    SfxMacroTabPage_Impl();
 
     OUString                               maStaticMacroLBLabel;
     VclPtr<PushButton>                     pAssignPB;
@@ -55,13 +55,12 @@ public:
     VclPtr<VclFrame>                       pMacroFrame;
     VclPtr<SfxConfigFunctionListBox>       pMacroLB;
 
-    bool                            bReadOnly;
     Idle                            maFillGroupIdle;
     bool                            bGotEvents;
     bool m_bDummyActivated; ///< has this tab page already been activated
 };
 
-_SfxMacroTabPage_Impl::_SfxMacroTabPage_Impl()
+SfxMacroTabPage_Impl::SfxMacroTabPage_Impl()
     : pAssignPB(nullptr)
     , pDeletePB(nullptr)
     , pEventLB(nullptr)
@@ -69,7 +68,6 @@ _SfxMacroTabPage_Impl::_SfxMacroTabPage_Impl()
     , pGroupLB(nullptr)
     , pMacroFrame(nullptr)
     , pMacroLB(nullptr)
-    , bReadOnly(false)
     , bGotEvents(false)
     , m_bDummyActivated(false)
 {
@@ -94,7 +92,7 @@ static long nTabs[] =
 
 #define LB_MACROS_ITEMPOS   2
 
-OUString ConvertToUIName_Impl( SvxMacro *pMacro )
+OUString ConvertToUIName_Impl( SvxMacro const *pMacro )
 {
     OUString aName( pMacro->GetMacName() );
     OUString aEntry;
@@ -104,11 +102,7 @@ OUString ConvertToUIName_Impl( SvxMacro *pMacro )
         aEntry = aName.getToken( nCount-1, '.' );
         if ( nCount > 2 )
         {
-            aEntry += "(";
-            aEntry += aName.getToken( 0, '.' );
-            aEntry += ".";
-            aEntry += aName.getToken( nCount-2, '.' );
-            aEntry += ")";
+            aEntry += "(" + aName.getToken( 0, '.' ) + "." + aName.getToken( nCount-2, '.' ) + ")";
         }
         return aEntry;
     }
@@ -116,46 +110,66 @@ OUString ConvertToUIName_Impl( SvxMacro *pMacro )
         return aName;
 }
 
-void _SfxMacroTabPage::EnableButtons()
+void SfxMacroTabPage::EnableButtons()
 {
     // don't do anything as long as the eventbox is empty
     const SvTreeListEntry* pE = mpImpl->pEventLB->GetListBox().FirstSelected();
     if ( pE )
     {
         // get bound macro
-        const SvxMacro* pM = aTbl.Get( (sal_uInt16)reinterpret_cast<sal_uLong>(pE->GetUserData()) );
-        mpImpl->pDeletePB->Enable( nullptr != pM && !mpImpl->bReadOnly );
+        const SvxMacro* pM = aTbl.Get( (SvMacroItemId)reinterpret_cast<sal_uLong>(pE->GetUserData()) );
+        mpImpl->pDeletePB->Enable( nullptr != pM );
 
         OUString sEventMacro = static_cast<const SvLBoxString&>(pE->GetItem( LB_MACROS_ITEMPOS )).GetText();
 
         OUString sScriptURI = mpImpl->pMacroLB->GetSelectedScriptURI();
-        mpImpl->pAssignPB->Enable( !mpImpl->bReadOnly && !sScriptURI.equalsIgnoreAsciiCase( sEventMacro ) );
+        mpImpl->pAssignPB->Enable( !sScriptURI.equalsIgnoreAsciiCase( sEventMacro ) );
     }
     else
         mpImpl->pAssignPB->Enable( false );
 }
 
-_SfxMacroTabPage::_SfxMacroTabPage(vcl::Window* pParent, const SfxItemSet& rAttrSet)
+SfxMacroTabPage::SfxMacroTabPage(vcl::Window* pParent, const Reference< XFrame >& rxDocumentFrame, const SfxItemSet& rAttrSet )
     : SfxTabPage(pParent, "EventAssignPage", "cui/ui/eventassignpage.ui", &rAttrSet)
 {
-    mpImpl = new _SfxMacroTabPage_Impl;
+    mpImpl.reset(new SfxMacroTabPage_Impl);
+
+    mpImpl->maFillGroupIdle.SetInvokeHandler( LINK( this, SfxMacroTabPage, TimeOut_Impl ) );
+    mpImpl->maFillGroupIdle.SetPriority( TaskPriority::HIGHEST );
+    mpImpl->maFillGroupIdle.SetDebugName( "SfxMacroTabPage maFillGroupIdle" );
+
+    mpImpl->sStrEvent = get<FixedText>("eventft")->GetText();
+    mpImpl->sAssignedMacro = get<FixedText>("assignft")->GetText();
+    get(mpImpl->pEventLB , "assignments");
+    get(mpImpl->pAssignPB, "assign");
+    get(mpImpl->pDeletePB, "delete");
+    get(mpImpl->pGroupFrame, "groupframe");
+    get(mpImpl->pGroupLB, "libraries");
+    get(mpImpl->pMacroFrame, "macroframe");
+    mpImpl->maStaticMacroLBLabel = mpImpl->pMacroFrame->get_label();
+    get(mpImpl->pMacroLB, "macros");
+
+    SetFrame( rxDocumentFrame );
+
+    InitAndSetHandler();
+
+    ScriptChanged();
 }
 
-_SfxMacroTabPage::~_SfxMacroTabPage()
+SfxMacroTabPage::~SfxMacroTabPage()
 {
     disposeOnce();
 }
 
-void _SfxMacroTabPage::dispose()
+void SfxMacroTabPage::dispose()
 {
-    DELETEZ( mpImpl );
+    mpImpl.reset();
     SfxTabPage::dispose();
 }
 
-void _SfxMacroTabPage::AddEvent( const OUString & rEventName, sal_uInt16 nEventId )
+void SfxMacroTabPage::AddEvent( const OUString & rEventName, SvMacroItemId nEventId )
 {
-    OUString sTmp( rEventName );
-    sTmp += "\t";
+    OUString sTmp = rEventName + "\t";
 
     // if the table is valid already
     SvxMacro* pM = aTbl.Get( nEventId );
@@ -169,7 +183,7 @@ void _SfxMacroTabPage::AddEvent( const OUString & rEventName, sal_uInt16 nEventI
     pE->SetUserData( reinterpret_cast< void* >( sal::static_int_cast< sal_IntPtr >( nEventId )) );
 }
 
-void _SfxMacroTabPage::ScriptChanged()
+void SfxMacroTabPage::ScriptChanged()
 {
     // get new areas and their functions
     mpImpl->pGroupFrame->Show();
@@ -178,10 +192,10 @@ void _SfxMacroTabPage::ScriptChanged()
     EnableButtons();
 }
 
-bool _SfxMacroTabPage::FillItemSet( SfxItemSet* rSet )
+bool SfxMacroTabPage::FillItemSet( SfxItemSet* rSet )
 {
     SvxMacroItem aItem( GetWhich( aPageRg[0] ) );
-    ((SvxMacroTableDtor&)aItem.GetMacroTable()) = aTbl;
+    const_cast<SvxMacroTableDtor&>(aItem.GetMacroTable()) = aTbl;
 
     const SfxPoolItem* pItem;
     if( SfxItemState::SET != GetItemSet().GetItemState( aItem.Which(), true, &pItem )
@@ -193,17 +207,13 @@ bool _SfxMacroTabPage::FillItemSet( SfxItemSet* rSet )
     return false;
 }
 
-void _SfxMacroTabPage::LaunchFillGroup()
+void SfxMacroTabPage::LaunchFillGroup()
 {
-    if (!mpImpl->maFillGroupIdle.GetIdleHdl().IsSet())
-    {
-        mpImpl->maFillGroupIdle.SetIdleHdl( LINK( this, _SfxMacroTabPage, TimeOut_Impl ) );
-        mpImpl->maFillGroupIdle.SetPriority( SchedulerPriority::HIGHEST );
+    if (! mpImpl->maFillGroupIdle.IsActive() )
         mpImpl->maFillGroupIdle.Start();
-    }
 }
 
-void _SfxMacroTabPage::ActivatePage( const SfxItemSet& )
+void SfxMacroTabPage::ActivatePage( const SfxItemSet& )
 {
     // fdo#57553 lazily init script providers, because it is annoying if done
     // on dialog open (SfxTabDialog::Start_Impl activates all tab pages once!)
@@ -215,7 +225,7 @@ void _SfxMacroTabPage::ActivatePage( const SfxItemSet& )
     LaunchFillGroup();
 }
 
-void _SfxMacroTabPage::PageCreated(const SfxAllItemSet& aSet)
+void SfxMacroTabPage::PageCreated(const SfxAllItemSet& aSet)
 {
     const SfxPoolItem* pEventsItem;
     if( !mpImpl->bGotEvents && SfxItemState::SET == aSet.GetItemState( SID_EVENTCONFIG, true, &pEventsItem ) )
@@ -230,7 +240,7 @@ void _SfxMacroTabPage::PageCreated(const SfxAllItemSet& aSet)
     }
 }
 
-void _SfxMacroTabPage::Reset( const SfxItemSet* rSet )
+void SfxMacroTabPage::Reset( const SfxItemSet* rSet )
 {
     const SfxPoolItem* pItem;
     if( SfxItemState::SET == rSet->GetItemState( GetWhich( aPageRg[0] ), true, &pItem ))
@@ -256,20 +266,18 @@ void _SfxMacroTabPage::Reset( const SfxItemSet* rSet )
         rListBox.SetCurEntry( pE );
 }
 
-bool _SfxMacroTabPage::IsReadOnly() const
+bool SfxMacroTabPage::IsReadOnly() const
 {
-    return mpImpl->bReadOnly;
+    return false;
 }
 
-IMPL_LINK_NOARG_TYPED( _SfxMacroTabPage, SelectEvent_Impl, SvTreeListBox*, void)
+IMPL_LINK_NOARG( SfxMacroTabPage, SelectEvent_Impl, SvTreeListBox*, void)
 {
     SvHeaderTabListBox&     rListBox = mpImpl->pEventLB->GetListBox();
     SvTreeListEntry*            pE = rListBox.FirstSelected();
-    sal_uLong                   nPos;
-    if( !pE || LISTBOX_ENTRY_NOTFOUND ==
-        ( nPos = rListBox.GetModel()->GetAbsPos( pE ) ) )
+    if( !pE || LISTBOX_ENTRY_NOTFOUND == rListBox.GetModel()->GetAbsPos( pE ) )
     {
-        DBG_ASSERT( pE, "wo kommt der leere Eintrag her?" );
+        DBG_ASSERT( pE, "Where does the empty entry come from?" );
         return;
     }
 
@@ -277,7 +285,7 @@ IMPL_LINK_NOARG_TYPED( _SfxMacroTabPage, SelectEvent_Impl, SvTreeListBox*, void)
     EnableButtons();
 }
 
-IMPL_LINK_NOARG_TYPED( _SfxMacroTabPage, SelectGroup_Impl, SvTreeListBox*, void)
+IMPL_LINK_NOARG( SfxMacroTabPage, SelectGroup_Impl, SvTreeListBox*, void)
 {
     mpImpl->pGroupLB->GroupSelected();
     const OUString sScriptURI = mpImpl->pMacroLB->GetSelectedScriptURI();
@@ -289,37 +297,35 @@ IMPL_LINK_NOARG_TYPED( _SfxMacroTabPage, SelectGroup_Impl, SvTreeListBox*, void)
     EnableButtons();
 }
 
-IMPL_LINK_NOARG_TYPED( _SfxMacroTabPage, SelectMacro_Impl, SvTreeListBox*, void)
+IMPL_LINK_NOARG( SfxMacroTabPage, SelectMacro_Impl, SvTreeListBox*, void)
 {
     EnableButtons();
 }
 
-IMPL_LINK_TYPED( _SfxMacroTabPage, AssignDeleteClickHdl_Impl, Button*, pBtn, void )
+IMPL_LINK( SfxMacroTabPage, AssignDeleteClickHdl_Impl, Button*, pBtn, void )
 {
     AssignDeleteHdl(pBtn);
 }
 
-IMPL_LINK_TYPED( _SfxMacroTabPage, AssignDeleteHdl_Impl, SvTreeListBox*, pBtn, bool )
+IMPL_LINK( SfxMacroTabPage, AssignDeleteHdl_Impl, SvTreeListBox*, pBtn, bool )
 {
     return AssignDeleteHdl(pBtn);
 }
 
-bool _SfxMacroTabPage::AssignDeleteHdl(Control* pBtn)
+bool SfxMacroTabPage::AssignDeleteHdl(Control const * pBtn)
 {
     SvHeaderTabListBox& rListBox = mpImpl->pEventLB->GetListBox();
     SvTreeListEntry* pE = rListBox.FirstSelected();
-    sal_uLong nPos;
-    if( !pE || LISTBOX_ENTRY_NOTFOUND ==
-        ( nPos = rListBox.GetModel()->GetAbsPos( pE ) ) )
+    if( !pE || LISTBOX_ENTRY_NOTFOUND == rListBox.GetModel()->GetAbsPos( pE ) )
     {
-        DBG_ASSERT( pE, "wo kommt der leere Eintrag her?" );
+        DBG_ASSERT( pE, "Where does the empty entry come from?" );
         return false;
     }
 
     const bool bAssEnabled = pBtn != mpImpl->pDeletePB && mpImpl->pAssignPB->IsEnabled();
 
     // remove from the table
-    sal_uInt16 nEvent = (sal_uInt16)reinterpret_cast<sal_uLong>(pE->GetUserData());
+    SvMacroItemId nEvent = (SvMacroItemId)reinterpret_cast<sal_uLong>(pE->GetUserData());
     aTbl.Erase( nEvent );
 
     OUString sScriptURI;
@@ -329,18 +335,18 @@ bool _SfxMacroTabPage::AssignDeleteHdl(Control* pBtn)
         if( sScriptURI.startsWith( "vnd.sun.star.script:" ) )
         {
             aTbl.Insert(
-                nEvent, SvxMacro( sScriptURI, OUString( SVX_MACRO_LANGUAGE_SF ) ) );
+                nEvent, SvxMacro( sScriptURI, SVX_MACRO_LANGUAGE_SF ) );
         }
         else
         {
-            OSL_ENSURE( false, "_SfxMacroTabPage::AssignDeleteHdl_Impl: this branch is *not* dead? (out of interest: tell fs, please!)" );
+            OSL_ENSURE( false, "SfxMacroTabPage::AssignDeleteHdl_Impl: this branch is *not* dead? (out of interest: tell fs, please!)" );
             aTbl.Insert(
-                nEvent, SvxMacro( sScriptURI, OUString( SVX_MACRO_LANGUAGE_STARBASIC ) ) );
+                nEvent, SvxMacro( sScriptURI, SVX_MACRO_LANGUAGE_STARBASIC ) );
         }
     }
 
     mpImpl->pEventLB->SetUpdateMode( false );
-    pE->ReplaceItem(std::unique_ptr<SvLBoxString>(new SvLBoxString(pE, 0, sScriptURI)), LB_MACROS_ITEMPOS);
+    pE->ReplaceItem(o3tl::make_unique<SvLBoxString>(sScriptURI), LB_MACROS_ITEMPOS);
     rListBox.GetModel()->InvalidateEntry( pE );
     rListBox.Select( pE );
     rListBox.MakeVisible( pE );
@@ -350,7 +356,7 @@ bool _SfxMacroTabPage::AssignDeleteHdl(Control* pBtn)
     return false;
 }
 
-IMPL_LINK_TYPED( _SfxMacroTabPage, TimeOut_Impl, Idle*,, void )
+IMPL_LINK( SfxMacroTabPage, TimeOut_Impl, Timer*,, void )
 {
     // FillMacroList() can take a long time -> show wait cursor and disable input
     SfxTabDialog* pTabDlg = GetTabDialog();
@@ -360,7 +366,11 @@ IMPL_LINK_TYPED( _SfxMacroTabPage, TimeOut_Impl, Idle*,, void )
         pTabDlg->EnterWait();
         pTabDlg->EnableInput( false );
     }
-    FillMacroList();
+    // fill macro list
+    mpImpl->pGroupLB->Init(
+        comphelper::getProcessComponentContext(),
+        GetFrame(),
+        OUString(), false);
     if ( pTabDlg )
     {
         pTabDlg->EnableInput();
@@ -368,26 +378,26 @@ IMPL_LINK_TYPED( _SfxMacroTabPage, TimeOut_Impl, Idle*,, void )
     }
 }
 
-void _SfxMacroTabPage::InitAndSetHandler()
+void SfxMacroTabPage::InitAndSetHandler()
 {
     SvHeaderTabListBox& rListBox = mpImpl->pEventLB->GetListBox();
     HeaderBar&          rHeaderBar = mpImpl->pEventLB->GetHeaderBar();
-    Link<SvTreeListBox*,bool> aLnk(LINK(this, _SfxMacroTabPage, AssignDeleteHdl_Impl ));
+    Link<SvTreeListBox*,bool> aLnk(LINK(this, SfxMacroTabPage, AssignDeleteHdl_Impl ));
     mpImpl->pMacroLB->SetDoubleClickHdl( aLnk );
-    mpImpl->pDeletePB->SetClickHdl( LINK(this, _SfxMacroTabPage, AssignDeleteClickHdl_Impl ) );
-    mpImpl->pAssignPB->SetClickHdl( LINK(this, _SfxMacroTabPage, AssignDeleteClickHdl_Impl ) );
+    mpImpl->pDeletePB->SetClickHdl( LINK(this, SfxMacroTabPage, AssignDeleteClickHdl_Impl ) );
+    mpImpl->pAssignPB->SetClickHdl( LINK(this, SfxMacroTabPage, AssignDeleteClickHdl_Impl ) );
     rListBox.SetDoubleClickHdl( aLnk );
 
-    rListBox.SetSelectHdl( LINK( this, _SfxMacroTabPage, SelectEvent_Impl ));
-    mpImpl->pGroupLB->SetSelectHdl( LINK( this, _SfxMacroTabPage, SelectGroup_Impl ));
-    mpImpl->pMacroLB->SetSelectHdl( LINK( this, _SfxMacroTabPage, SelectMacro_Impl ));
+    rListBox.SetSelectHdl( LINK( this, SfxMacroTabPage, SelectEvent_Impl ));
+    mpImpl->pGroupLB->SetSelectHdl( LINK( this, SfxMacroTabPage, SelectGroup_Impl ));
+    mpImpl->pMacroLB->SetSelectHdl( LINK( this, SfxMacroTabPage, SelectMacro_Impl ));
 
-    rListBox.SetSelectionMode( SINGLE_SELECTION );
+    rListBox.SetSelectionMode( SelectionMode::Single );
     rListBox.SetTabs( &nTabs[0] );
     Size aSize( nTabs[ 2 ], 0 );
-    rHeaderBar.InsertItem( ITEMID_EVENT, mpImpl->sStrEvent, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
+    rHeaderBar.InsertItem( ITEMID_EVENT, mpImpl->sStrEvent, LogicToPixel( aSize, MapMode( MapUnit::MapAppFont ) ).Width() );
     aSize.Width() = 1764;       // don't know what, so 42^2 is best to use...
-    rHeaderBar.InsertItem( ITMEID_ASSMACRO, mpImpl->sAssignedMacro, LogicToPixel( aSize, MapMode( MAP_APPFONT ) ).Width() );
+    rHeaderBar.InsertItem( ITMEID_ASSMACRO, mpImpl->sAssignedMacro, LogicToPixel( aSize, MapMode( MapUnit::MapAppFont ) ).Width() );
     rListBox.SetSpaceBetweenEntries( 0 );
 
     mpImpl->pEventLB->Show();
@@ -401,16 +411,7 @@ void _SfxMacroTabPage::InitAndSetHandler()
 
 }
 
-void _SfxMacroTabPage::FillMacroList()
-{
-    mpImpl->pGroupLB->Init(
-        css::uno::Reference<
-            css::uno::XComponentContext >(),
-        GetFrame(),
-        OUString(), false);
-}
-
-void _SfxMacroTabPage::FillEvents()
+void SfxMacroTabPage::FillEvents()
 {
     SvHeaderTabListBox& rListBox = mpImpl->pEventLB->GetListBox();
 
@@ -423,45 +424,23 @@ void _SfxMacroTabPage::FillEvents()
         if( pE )
         {
             SvLBoxString&     rLItem = static_cast<SvLBoxString&>( pE->GetItem( LB_MACROS_ITEMPOS ) );
-            DBG_ASSERT( SV_ITEM_ID_LBOXSTRING == rLItem.GetType(), "_SfxMacroTabPage::FillEvents(): no LBoxString" );
+            DBG_ASSERT( SvLBoxItemType::String == rLItem.GetType(), "SfxMacroTabPage::FillEvents(): no LBoxString" );
 
             OUString          sOld( rLItem.GetText() );
             OUString          sNew;
-            sal_uInt16        nEventId = ( sal_uInt16 ) reinterpret_cast<sal_uLong>( pE->GetUserData() );
+            SvMacroItemId     nEventId = (SvMacroItemId) reinterpret_cast<sal_uLong>( pE->GetUserData() );
             if( aTbl.IsKeyValid( nEventId ) )
                 sNew = ConvertToUIName_Impl( aTbl.Get( nEventId ) );
 
             if( sOld != sNew )
             {
-                pE->ReplaceItem(std::unique_ptr<SvLBoxString>(new SvLBoxString(
-                                    pE, 0, sNew)), LB_MACROS_ITEMPOS);
+                pE->ReplaceItem(o3tl::make_unique<SvLBoxString>(sNew), LB_MACROS_ITEMPOS);
                 rListBox.GetModel()->InvalidateEntry( pE );
             }
         }
     }
 }
 
-SfxMacroTabPage::SfxMacroTabPage(vcl::Window* pParent, const Reference< XFrame >& rxDocumentFrame, const SfxItemSet& rSet )
-    : _SfxMacroTabPage( pParent, rSet )
-{
-    mpImpl->sStrEvent = get<FixedText>("eventft")->GetText();
-    mpImpl->sAssignedMacro = get<FixedText>("assignft")->GetText();
-    get(mpImpl->pEventLB , "assignments");
-    get(mpImpl->pAssignPB, "assign");
-    get(mpImpl->pDeletePB, "delete");
-    get(mpImpl->pGroupFrame, "groupframe");
-    get(mpImpl->pGroupLB, "libraries");
-    get(mpImpl->pMacroFrame, "macroframe");
-    mpImpl->maStaticMacroLBLabel = mpImpl->pMacroFrame->get_label();
-    get(mpImpl->pMacroLB, "macros");
-
-    SetFrame( rxDocumentFrame );
-
-    InitAndSetHandler();
-
-    ScriptChanged();
-}
-
 namespace
 {
     VclPtr<SfxMacroTabPage> CreateSfxMacroTabPage( vcl::Window* pParent, const SfxItemSet& rAttrSet )
@@ -480,7 +459,7 @@ SfxMacroAssignDlg::SfxMacroAssignDlg(vcl::Window* pParent,
     : SfxSingleTabDialog(pParent, rSet, "EventAssignDialog",
         "cui/ui/eventassigndialog.ui")
 {
-    SfxMacroTabPage* pPage = CreateSfxMacroTabPage(get_content_area(), rSet);
+    VclPtr<SfxMacroTabPage> pPage = CreateSfxMacroTabPage(get_content_area(), rSet);
     pPage->SetFrame( rxDocumentFrame );
     SetTabPage( pPage );
     pPage->LaunchFillGroup();
