@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <cuires.hrc>
+#include <strings.hrc>
 #include <dialmgr.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/module.hxx>
@@ -44,7 +44,7 @@
 #include <svx/sxmtritm.hxx>
 #include <svx/sxmuitm.hxx>
 
-#include "measure.hxx"
+#include <measure.hxx>
 
 const sal_uInt16 SvxMeasurePage::pRanges[] =
 {
@@ -69,7 +69,7 @@ SvxMeasureDialog::SvxMeasureDialog( vcl::Window* pParent, const SfxItemSet& rInA
     _pPage->Construct();
 
     SetTabPage(_pPage );
-    SetText(CUI_RESSTR(RID_SVXSTR_DIMENSION_LINE));
+    SetText(CuiResId(RID_SVXSTR_DIMENSION_LINE));
 }
 
 /*************************************************************************
@@ -86,7 +86,7 @@ SvxMeasurePage::SvxMeasurePage( vcl::Window* pWindow, const SfxItemSet& rInAttrs
         rOutAttrs               ( rInAttrs ),
         aAttrSet                ( *rInAttrs.GetPool() ),
         pView( nullptr ),
-        eUnit( SFX_MAPUNIT_100TH_MM ),
+        eUnit( MapUnit::Map100thMM ),
         bPositionModified       ( false )
 {
     get(m_pMtrFldLineDist, "MTR_LINE_DIST");
@@ -181,7 +181,7 @@ void SvxMeasurePage::dispose()
 void SvxMeasurePage::Reset( const SfxItemSet* rAttrs )
 {
     SfxItemPool* pPool = rAttrs->GetPool();
-    DBG_ASSERT( pPool, "Wo ist der Pool" );
+    DBG_ASSERT( pPool, "Where is the pool?" );
     eUnit = pPool->GetMetric( SDRATTR_MEASURELINEDIST );
 
     const SfxPoolItem* pItem = GetItem( *rAttrs, SDRATTR_MEASURELINEDIST );
@@ -263,7 +263,7 @@ void SvxMeasurePage::Reset( const SfxItemSet* rAttrs )
     // SdrMeasureBelowRefEdgeItem
     if( rAttrs->GetItemState( SDRATTR_MEASUREBELOWREFEDGE ) != SfxItemState::DONTCARE )
     {
-        m_pTsbBelowRefEdge->SetState( static_cast<const SdrMeasureBelowRefEdgeItem&>( rAttrs->Get( SDRATTR_MEASUREBELOWREFEDGE ) ).
+        m_pTsbBelowRefEdge->SetState( rAttrs->Get( SDRATTR_MEASUREBELOWREFEDGE ).
                         GetValue() ? TRISTATE_TRUE : TRISTATE_FALSE );
         m_pTsbBelowRefEdge->EnableTriState( false );
     }
@@ -292,7 +292,7 @@ void SvxMeasurePage::Reset( const SfxItemSet* rAttrs )
     // Attention: negate !
     if( rAttrs->GetItemState( SDRATTR_MEASURETEXTROTA90 ) != SfxItemState::DONTCARE )
     {
-        m_pTsbParallel->SetState( static_cast<const SdrMeasureTextRota90Item&>( rAttrs->Get( SDRATTR_MEASURETEXTROTA90 ) ).
+        m_pTsbParallel->SetState( rAttrs->Get( SDRATTR_MEASURETEXTROTA90 ).
                         GetValue() ? TRISTATE_FALSE : TRISTATE_TRUE );
         m_pTsbParallel->EnableTriState( false );
     }
@@ -305,7 +305,7 @@ void SvxMeasurePage::Reset( const SfxItemSet* rAttrs )
     // SdrMeasureShowUnitItem
     if( rAttrs->GetItemState( SDRATTR_MEASURESHOWUNIT ) != SfxItemState::DONTCARE )
     {
-        m_pTsbShowUnit->SetState( static_cast<const SdrYesNoItem&>( rAttrs->Get( SDRATTR_MEASURESHOWUNIT ) ).
+        m_pTsbShowUnit->SetState( rAttrs->Get( SDRATTR_MEASURESHOWUNIT ).
                         GetValue() ? TRISTATE_TRUE : TRISTATE_FALSE );
         m_pTsbShowUnit->EnableTriState( false );
     }
@@ -318,8 +318,7 @@ void SvxMeasurePage::Reset( const SfxItemSet* rAttrs )
     // SdrMeasureUnitItem
     if( rAttrs->GetItemState( SDRATTR_MEASUREUNIT ) != SfxItemState::DONTCARE )
     {
-        long nFieldUnit = (long) static_cast<const SdrMeasureUnitItem&>( rAttrs->
-                                    Get( SDRATTR_MEASUREUNIT ) ).GetValue();
+        long nFieldUnit = (long) rAttrs->Get( SDRATTR_MEASUREUNIT ).GetValue();
 
         for( sal_Int32 i = 0; i < m_pLbUnit->GetEntryCount(); ++i )
         {
@@ -339,53 +338,57 @@ void SvxMeasurePage::Reset( const SfxItemSet* rAttrs )
     // Position
     if ( rAttrs->GetItemState( SDRATTR_MEASURETEXTVPOS ) != SfxItemState::DONTCARE )
     {
-        SdrMeasureTextVPos eVPos = (SdrMeasureTextVPos)
-                    static_cast<const SdrMeasureTextVPosItem&>( rAttrs->Get( SDRATTR_MEASURETEXTVPOS ) ).GetValue();
+        css::drawing::MeasureTextVertPos eVPos =
+                    rAttrs->Get( SDRATTR_MEASURETEXTVPOS ).GetValue();
         {
             if ( rAttrs->GetItemState( SDRATTR_MEASURETEXTHPOS ) != SfxItemState::DONTCARE )
             {
                 m_pTsbAutoPosV->EnableTriState( false );
                 m_pTsbAutoPosH->EnableTriState( false );
 
-                SdrMeasureTextHPos eHPos = (SdrMeasureTextHPos)
-                            static_cast<const SdrMeasureTextHPosItem&>( rAttrs->Get( SDRATTR_MEASURETEXTHPOS ) ).GetValue();
-                RECT_POINT eRP = RP_MM;
+                css::drawing::MeasureTextHorzPos eHPos =
+                            rAttrs->Get( SDRATTR_MEASURETEXTHPOS ).GetValue();
+                RectPoint eRP = RectPoint::MM;
                 switch( eVPos )
                 {
-                case SDRMEASURE_ABOVE:
+                case css::drawing::MeasureTextVertPos_EAST:
                     switch( eHPos )
                     {
-                    case SDRMEASURE_TEXTLEFTOUTSIDE:    eRP = RP_LT; break;
-                    case SDRMEASURE_TEXTINSIDE:         eRP = RP_MT; break;
-                    case SDRMEASURE_TEXTRIGHTOUTSIDE:   eRP = RP_RT; break;
-                    case SDRMEASURE_TEXTHAUTO:          eRP = RP_MT; break;
+                    case css::drawing::MeasureTextHorzPos_LEFTOUTSIDE:    eRP = RectPoint::LT; break;
+                    case css::drawing::MeasureTextHorzPos_INSIDE:         eRP = RectPoint::MT; break;
+                    case css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE:   eRP = RectPoint::RT; break;
+                    case css::drawing::MeasureTextHorzPos_AUTO:          eRP = RectPoint::MT; break;
+                    default: break;
                     }
                     break;
-                case SDRMEASURETEXT_VERTICALCENTERED:
+                case css::drawing::MeasureTextVertPos_CENTERED:
                     switch( eHPos )
                     {
-                    case SDRMEASURE_TEXTLEFTOUTSIDE:    eRP = RP_LM; break;
-                    case SDRMEASURE_TEXTINSIDE:         eRP = RP_MM; break;
-                    case SDRMEASURE_TEXTRIGHTOUTSIDE:   eRP = RP_RM; break;
-                    case SDRMEASURE_TEXTHAUTO:          eRP = RP_MM; break;
+                    case css::drawing::MeasureTextHorzPos_LEFTOUTSIDE:    eRP = RectPoint::LM; break;
+                    case css::drawing::MeasureTextHorzPos_INSIDE:         eRP = RectPoint::MM; break;
+                    case css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE:   eRP = RectPoint::RM; break;
+                    case css::drawing::MeasureTextHorzPos_AUTO:          eRP = RectPoint::MM; break;
+                    default: break;
                     }
                     break;
-                case SDRMEASURE_BELOW:
+                case css::drawing::MeasureTextVertPos_WEST:
                     switch( eHPos )
                     {
-                    case SDRMEASURE_TEXTLEFTOUTSIDE:    eRP = RP_LB; break;
-                    case SDRMEASURE_TEXTINSIDE:         eRP = RP_MB; break;
-                    case SDRMEASURE_TEXTRIGHTOUTSIDE:   eRP = RP_RB; break;
-                    case SDRMEASURE_TEXTHAUTO:          eRP = RP_MB; break;
+                    case css::drawing::MeasureTextHorzPos_LEFTOUTSIDE:    eRP = RectPoint::LB; break;
+                    case css::drawing::MeasureTextHorzPos_INSIDE:         eRP = RectPoint::MB; break;
+                    case css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE:   eRP = RectPoint::RB; break;
+                    case css::drawing::MeasureTextHorzPos_AUTO:          eRP = RectPoint::MB; break;
+                    default: break;
                     }
                     break;
-                case SDRMEASURE_TEXTVAUTO:
+                case css::drawing::MeasureTextVertPos_AUTO:
                     switch( eHPos )
                     {
-                    case SDRMEASURE_TEXTLEFTOUTSIDE:    eRP = RP_LM; break;
-                    case SDRMEASURE_TEXTINSIDE:         eRP = RP_MM; break;
-                    case SDRMEASURE_TEXTRIGHTOUTSIDE:   eRP = RP_RM; break;
-                    case SDRMEASURE_TEXTHAUTO:          eRP = RP_MM; break;
+                    case css::drawing::MeasureTextHorzPos_LEFTOUTSIDE:    eRP = RectPoint::LM; break;
+                    case css::drawing::MeasureTextHorzPos_INSIDE:         eRP = RectPoint::MM; break;
+                    case css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE:   eRP = RectPoint::RM; break;
+                    case css::drawing::MeasureTextHorzPos_AUTO:          eRP = RectPoint::MM; break;
+                    default: break;
                     }
                     break;
                  default: ;//prevent warning
@@ -393,13 +396,13 @@ void SvxMeasurePage::Reset( const SfxItemSet* rAttrs )
 
                 CTL_STATE nState = CTL_STATE::NONE;
 
-                if( eHPos == SDRMEASURE_TEXTHAUTO )
+                if (eHPos == css::drawing::MeasureTextHorzPos_AUTO)
                 {
                     m_pTsbAutoPosH->SetState( TRISTATE_TRUE );
                     nState = CTL_STATE::NOHORZ;
                 }
 
-                if( eVPos == SDRMEASURE_TEXTVAUTO )
+                if (eVPos == css::drawing::MeasureTextVertPos_AUTO)
                 {
                     m_pTsbAutoPosV->SetState( TRISTATE_TRUE );
                     nState |= CTL_STATE::NOVERT;
@@ -503,7 +506,7 @@ bool SvxMeasurePage::FillItemSet( SfxItemSet* rAttrs)
         bModified = true;
     }
 
-    sal_Int32 nPos = m_pLbUnit->GetSelectEntryPos();
+    sal_Int32 nPos = m_pLbUnit->GetSelectedEntryPos();
     if( m_pLbUnit->IsValueChangedFromSaved() )
     {
         if( nPos != LISTBOX_ENTRY_NOTFOUND )
@@ -518,42 +521,41 @@ bool SvxMeasurePage::FillItemSet( SfxItemSet* rAttrs)
     if( bPositionModified )
     {
         // Position
-        SdrMeasureTextVPos eVPos, eOldVPos;
-        SdrMeasureTextHPos eHPos, eOldHPos;
+        css::drawing::MeasureTextVertPos eVPos, eOldVPos;
+        css::drawing::MeasureTextHorzPos eHPos, eOldHPos;
 
-        RECT_POINT eRP = m_pCtlPosition->GetActualRP();
+        RectPoint eRP = m_pCtlPosition->GetActualRP();
         switch( eRP )
         {
             default:
-            case RP_LT: eVPos = SDRMEASURE_ABOVE;
-                        eHPos = SDRMEASURE_TEXTLEFTOUTSIDE; break;
-            case RP_LM: eVPos = SDRMEASURETEXT_VERTICALCENTERED;
-                        eHPos = SDRMEASURE_TEXTLEFTOUTSIDE; break;
-            case RP_LB: eVPos = SDRMEASURE_BELOW;
-                        eHPos = SDRMEASURE_TEXTLEFTOUTSIDE; break;
-            case RP_MT: eVPos = SDRMEASURE_ABOVE;
-                        eHPos = SDRMEASURE_TEXTINSIDE; break;
-            case RP_MM: eVPos = SDRMEASURETEXT_VERTICALCENTERED;
-                        eHPos = SDRMEASURE_TEXTINSIDE; break;
-            case RP_MB: eVPos = SDRMEASURE_BELOW;
-                        eHPos = SDRMEASURE_TEXTINSIDE; break;
-            case RP_RT: eVPos = SDRMEASURE_ABOVE;
-                        eHPos = SDRMEASURE_TEXTRIGHTOUTSIDE; break;
-            case RP_RM: eVPos = SDRMEASURETEXT_VERTICALCENTERED;
-                        eHPos = SDRMEASURE_TEXTRIGHTOUTSIDE; break;
-            case RP_RB: eVPos = SDRMEASURE_BELOW;
-                        eHPos = SDRMEASURE_TEXTRIGHTOUTSIDE; break;
+            case RectPoint::LT: eVPos = css::drawing::MeasureTextVertPos_EAST;
+                        eHPos = css::drawing::MeasureTextHorzPos_LEFTOUTSIDE; break;
+            case RectPoint::LM: eVPos = css::drawing::MeasureTextVertPos_CENTERED;
+                        eHPos = css::drawing::MeasureTextHorzPos_LEFTOUTSIDE; break;
+            case RectPoint::LB: eVPos = css::drawing::MeasureTextVertPos_WEST;
+                        eHPos = css::drawing::MeasureTextHorzPos_LEFTOUTSIDE; break;
+            case RectPoint::MT: eVPos = css::drawing::MeasureTextVertPos_EAST;
+                        eHPos = css::drawing::MeasureTextHorzPos_INSIDE; break;
+            case RectPoint::MM: eVPos = css::drawing::MeasureTextVertPos_CENTERED;
+                        eHPos = css::drawing::MeasureTextHorzPos_INSIDE; break;
+            case RectPoint::MB: eVPos = css::drawing::MeasureTextVertPos_WEST;
+                        eHPos = css::drawing::MeasureTextHorzPos_INSIDE; break;
+            case RectPoint::RT: eVPos = css::drawing::MeasureTextVertPos_EAST;
+                        eHPos = css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE; break;
+            case RectPoint::RM: eVPos = css::drawing::MeasureTextVertPos_CENTERED;
+                        eHPos = css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE; break;
+            case RectPoint::RB: eVPos = css::drawing::MeasureTextVertPos_WEST;
+                        eHPos = css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE; break;
         }
-        if( m_pTsbAutoPosH->GetState() == TRISTATE_TRUE )
-            eHPos = SDRMEASURE_TEXTHAUTO;
+        if (m_pTsbAutoPosH->GetState() == TRISTATE_TRUE)
+            eHPos = css::drawing::MeasureTextHorzPos_AUTO;
 
-        if( m_pTsbAutoPosV->GetState() == TRISTATE_TRUE )
-            eVPos = SDRMEASURE_TEXTVAUTO;
+        if (m_pTsbAutoPosV->GetState() == TRISTATE_TRUE)
+            eVPos = css::drawing::MeasureTextVertPos_AUTO;
 
         if ( rAttrs->GetItemState( SDRATTR_MEASURETEXTVPOS ) != SfxItemState::DONTCARE )
         {
-            eOldVPos = (SdrMeasureTextVPos)
-                        static_cast<const SdrMeasureTextVPosItem&>( rOutAttrs.Get( SDRATTR_MEASURETEXTVPOS ) ).GetValue();
+            eOldVPos = rOutAttrs.Get(SDRATTR_MEASURETEXTVPOS).GetValue();
             if( eOldVPos != eVPos )
             {
                 rAttrs->Put( SdrMeasureTextVPosItem( eVPos ) );
@@ -568,8 +570,7 @@ bool SvxMeasurePage::FillItemSet( SfxItemSet* rAttrs)
 
         if ( rAttrs->GetItemState( SDRATTR_MEASURETEXTHPOS ) != SfxItemState::DONTCARE )
         {
-            eOldHPos = (SdrMeasureTextHPos)
-                        static_cast<const SdrMeasureTextHPosItem&>( rOutAttrs.Get( SDRATTR_MEASURETEXTHPOS ) ).GetValue();
+            eOldHPos = rOutAttrs.Get( SDRATTR_MEASURETEXTHPOS ).GetValue();
             if( eOldHPos != eHPos )
             {
                 rAttrs->Put( SdrMeasureTextHPosItem( eHPos ) );
@@ -595,7 +596,7 @@ bool SvxMeasurePage::FillItemSet( SfxItemSet* rAttrs)
 
 void SvxMeasurePage::Construct()
 {
-    DBG_ASSERT( pView, "Keine gueltige View Uebergeben!" );
+    DBG_ASSERT( pView, "No valid View transferred!" );
 
     m_pCtlPreview->pMeasureObj->SetModel( pView->GetModel() );
     m_pCtlPreview->Invalidate();
@@ -607,30 +608,30 @@ VclPtr<SfxTabPage> SvxMeasurePage::Create( vcl::Window* pWindow,
     return VclPtr<SvxMeasurePage>::Create( pWindow, *rAttrs );
 }
 
-void SvxMeasurePage::PointChanged( vcl::Window* pWindow, RECT_POINT /*eRP*/ )
+void SvxMeasurePage::PointChanged( vcl::Window* pWindow, RectPoint /*eRP*/ )
 {
     ChangeAttrHdl_Impl( pWindow );
 }
 
-IMPL_LINK_TYPED( SvxMeasurePage, ClickAutoPosHdl_Impl, Button*, p, void )
+IMPL_LINK( SvxMeasurePage, ClickAutoPosHdl_Impl, Button*, p, void )
 {
     if( m_pTsbAutoPosH->GetState() == TRISTATE_TRUE )
     {
         switch( m_pCtlPosition->GetActualRP() )
         {
-            case RP_LT:
-            case RP_RT:
-                m_pCtlPosition->SetActualRP( RP_MT );
+            case RectPoint::LT:
+            case RectPoint::RT:
+                m_pCtlPosition->SetActualRP( RectPoint::MT );
             break;
 
-            case RP_LM:
-            case RP_RM:
-                m_pCtlPosition->SetActualRP( RP_MM );
+            case RectPoint::LM:
+            case RectPoint::RM:
+                m_pCtlPosition->SetActualRP( RectPoint::MM );
             break;
 
-            case RP_LB:
-            case RP_RB:
-                m_pCtlPosition->SetActualRP( RP_MB );
+            case RectPoint::LB:
+            case RectPoint::RB:
+                m_pCtlPosition->SetActualRP( RectPoint::MB );
             break;
             default: ;//prevent warning
         }
@@ -639,19 +640,19 @@ IMPL_LINK_TYPED( SvxMeasurePage, ClickAutoPosHdl_Impl, Button*, p, void )
     {
         switch( m_pCtlPosition->GetActualRP() )
         {
-            case RP_LT:
-            case RP_LB:
-                m_pCtlPosition->SetActualRP( RP_LM );
+            case RectPoint::LT:
+            case RectPoint::LB:
+                m_pCtlPosition->SetActualRP( RectPoint::LM );
             break;
 
-            case RP_MT:
-            case RP_MB:
-                m_pCtlPosition->SetActualRP( RP_MM );
+            case RectPoint::MT:
+            case RectPoint::MB:
+                m_pCtlPosition->SetActualRP( RectPoint::MM );
             break;
 
-            case RP_RT:
-            case RP_RB:
-                m_pCtlPosition->SetActualRP( RP_RM );
+            case RectPoint::RT:
+            case RectPoint::RB:
+                m_pCtlPosition->SetActualRP( RectPoint::RM );
             break;
             default: ;//prevent warning
         }
@@ -659,19 +660,19 @@ IMPL_LINK_TYPED( SvxMeasurePage, ClickAutoPosHdl_Impl, Button*, p, void )
     ChangeAttrHdl_Impl( p );
 }
 
-IMPL_LINK_TYPED( SvxMeasurePage, ChangeAttrClickHdl_Impl, Button*, p, void )
+IMPL_LINK( SvxMeasurePage, ChangeAttrClickHdl_Impl, Button*, p, void )
 {
     ChangeAttrHdl_Impl(p);
 }
-IMPL_LINK_TYPED( SvxMeasurePage, ChangeAttrListBoxHdl_Impl, ListBox&, rBox, void )
+IMPL_LINK( SvxMeasurePage, ChangeAttrListBoxHdl_Impl, ListBox&, rBox, void )
 {
     ChangeAttrHdl_Impl(&rBox);
 }
-IMPL_LINK_TYPED( SvxMeasurePage, ChangeAttrEditHdl_Impl, Edit&, rBox, void )
+IMPL_LINK( SvxMeasurePage, ChangeAttrEditHdl_Impl, Edit&, rBox, void )
 {
     ChangeAttrHdl_Impl(&rBox);
 }
-void SvxMeasurePage::ChangeAttrHdl_Impl( void* p )
+void SvxMeasurePage::ChangeAttrHdl_Impl( void const * p )
 {
     if( p == m_pMtrFldLineDist )
     {
@@ -733,7 +734,7 @@ void SvxMeasurePage::ChangeAttrHdl_Impl( void* p )
 
     if( p == m_pLbUnit )
     {
-        sal_Int32 nPos = m_pLbUnit->GetSelectEntryPos();
+        sal_Int32 nPos = m_pLbUnit->GetSelectedEntryPos();
         if( nPos != LISTBOX_ENTRY_NOTFOUND )
         {
             sal_uInt16 nFieldUnit = (sal_uInt16)reinterpret_cast<sal_IntPtr>(m_pLbUnit->GetEntryData( nPos ));
@@ -747,44 +748,44 @@ void SvxMeasurePage::ChangeAttrHdl_Impl( void* p )
         bPositionModified = true;
 
         // Position
-        RECT_POINT eRP = m_pCtlPosition->GetActualRP();
-        SdrMeasureTextVPos eVPos;
-        SdrMeasureTextHPos eHPos;
+        RectPoint eRP = m_pCtlPosition->GetActualRP();
+        css::drawing::MeasureTextVertPos eVPos;
+        css::drawing::MeasureTextHorzPos eHPos;
 
         switch( eRP )
         {
             default:
-            case RP_LT: eVPos = SDRMEASURE_ABOVE;
-                        eHPos = SDRMEASURE_TEXTLEFTOUTSIDE; break;
-            case RP_LM: eVPos = SDRMEASURETEXT_VERTICALCENTERED;
-                        eHPos = SDRMEASURE_TEXTLEFTOUTSIDE; break;
-            case RP_LB: eVPos = SDRMEASURE_BELOW;
-                        eHPos = SDRMEASURE_TEXTLEFTOUTSIDE; break;
-            case RP_MT: eVPos = SDRMEASURE_ABOVE;
-                        eHPos = SDRMEASURE_TEXTINSIDE; break;
-            case RP_MM: eVPos = SDRMEASURETEXT_VERTICALCENTERED;
-                        eHPos = SDRMEASURE_TEXTINSIDE; break;
-            case RP_MB: eVPos = SDRMEASURE_BELOW;
-                        eHPos = SDRMEASURE_TEXTINSIDE; break;
-            case RP_RT: eVPos = SDRMEASURE_ABOVE;
-                        eHPos = SDRMEASURE_TEXTRIGHTOUTSIDE; break;
-            case RP_RM: eVPos = SDRMEASURETEXT_VERTICALCENTERED;
-                        eHPos = SDRMEASURE_TEXTRIGHTOUTSIDE; break;
-            case RP_RB: eVPos = SDRMEASURE_BELOW;
-                        eHPos = SDRMEASURE_TEXTRIGHTOUTSIDE; break;
+            case RectPoint::LT: eVPos = css::drawing::MeasureTextVertPos_EAST;
+                        eHPos = css::drawing::MeasureTextHorzPos_LEFTOUTSIDE; break;
+            case RectPoint::LM: eVPos = css::drawing::MeasureTextVertPos_CENTERED;
+                        eHPos = css::drawing::MeasureTextHorzPos_LEFTOUTSIDE; break;
+            case RectPoint::LB: eVPos = css::drawing::MeasureTextVertPos_WEST;
+                        eHPos = css::drawing::MeasureTextHorzPos_LEFTOUTSIDE; break;
+            case RectPoint::MT: eVPos = css::drawing::MeasureTextVertPos_EAST;
+                        eHPos = css::drawing::MeasureTextHorzPos_INSIDE; break;
+            case RectPoint::MM: eVPos = css::drawing::MeasureTextVertPos_CENTERED;
+                        eHPos = css::drawing::MeasureTextHorzPos_INSIDE; break;
+            case RectPoint::MB: eVPos = css::drawing::MeasureTextVertPos_WEST;
+                        eHPos = css::drawing::MeasureTextHorzPos_INSIDE; break;
+            case RectPoint::RT: eVPos = css::drawing::MeasureTextVertPos_EAST;
+                        eHPos = css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE; break;
+            case RectPoint::RM: eVPos = css::drawing::MeasureTextVertPos_CENTERED;
+                        eHPos = css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE; break;
+            case RectPoint::RB: eVPos = css::drawing::MeasureTextVertPos_WEST;
+                        eHPos = css::drawing::MeasureTextHorzPos_RIGHTOUTSIDE; break;
         }
 
         CTL_STATE nState = CTL_STATE::NONE;
 
-        if( m_pTsbAutoPosH->GetState() == TRISTATE_TRUE )
+        if (m_pTsbAutoPosH->GetState() == TRISTATE_TRUE)
         {
-            eHPos = SDRMEASURE_TEXTHAUTO;
+            eHPos = css::drawing::MeasureTextHorzPos_AUTO;
             nState = CTL_STATE::NOHORZ;
         }
 
-        if( m_pTsbAutoPosV->GetState() == TRISTATE_TRUE )
+        if (m_pTsbAutoPosV->GetState() == TRISTATE_TRUE)
         {
-            eVPos = SDRMEASURE_TEXTVAUTO;
+            eVPos = css::drawing::MeasureTextVertPos_AUTO;
             nState |= CTL_STATE::NOVERT;
         }
 
@@ -802,17 +803,16 @@ void SvxMeasurePage::ChangeAttrHdl_Impl( void* p )
 void SvxMeasurePage::FillUnitLB()
 {
     // fill ListBox with metrics
-    SvxStringArray aMetricArr( SVX_RES( RID_SVXSTR_FIELDUNIT_TABLE ) );
 
-    sal_IntPtr nUnit = FUNIT_NONE;
+    FieldUnit nUnit = FUNIT_NONE;
     OUString aStrMetric( m_pFtAutomatic->GetText());
     sal_Int32 nPos = m_pLbUnit->InsertEntry( aStrMetric );
     m_pLbUnit->SetEntryData( nPos, reinterpret_cast<void*>(nUnit) );
 
-    for( sal_uInt32 i = 0; i < aMetricArr.Count(); ++i )
+    for( sal_uInt32 i = 0; i < SvxFieldUnitTable::Count(); ++i )
     {
-        aStrMetric = aMetricArr.GetStringByPos( i );
-        nUnit = aMetricArr.GetValue( i );
+        aStrMetric = SvxFieldUnitTable::GetString(i);
+        nUnit = SvxFieldUnitTable::GetValue(i);
         nPos = m_pLbUnit->InsertEntry( aStrMetric );
         m_pLbUnit->SetEntryData( nPos, reinterpret_cast<void*>(nUnit) );
     }
