@@ -26,13 +26,12 @@
 #include <svx/svdview.hxx>
 #include <svx/dialogs.hrc>
 
-#include <cuires.hrc>
 #include <svx/xtable.hxx>
-#include "svx/globl3d.hxx"
+#include <svx/globl3d.hxx>
 #include <svx/svdmodel.hxx>
-#include "svx/drawitem.hxx"
-#include "cuitabarea.hxx"
-#include "dlgname.hxx"
+#include <svx/drawitem.hxx>
+#include <cuitabarea.hxx>
+#include <dlgname.hxx>
 #include <dialmgr.hxx>
 
 SvxAreaTabDialog::SvxAreaTabDialog
@@ -49,11 +48,6 @@ SvxAreaTabDialog::SvxAreaTabDialog
     , m_nAreaTabPage(0)
     , m_nShadowTabPage(0)
     , m_nTransparenceTabPage(0)
-    , m_nColorTabPage(0)
-    , m_nGradientTabPage(0)
-    , m_nHatchTabPage(0)
-    , m_nBitmapTabPage(0)
-
     , mpDrawModel          ( pModel ),
     mpColorList          ( pModel->GetColorList() ),
     mpNewColorList       ( pModel->GetColorList() ),
@@ -63,15 +57,15 @@ SvxAreaTabDialog::SvxAreaTabDialog
     mpNewHatchingList    ( pModel->GetHatchList() ),
     mpBitmapList         ( pModel->GetBitmapList() ),
     mpNewBitmapList      ( pModel->GetBitmapList() ),
+    mpPatternList        ( pModel->GetPatternList() ),
+    mpNewPatternList     ( pModel->GetPatternList() ),
     mrOutAttrs           ( *pAttr ),
 
     mnColorListState ( ChangeType::NONE ),
     mnBitmapListState ( ChangeType::NONE ),
+    mnPatternListState ( ChangeType::NONE ),
     mnGradientListState ( ChangeType::NONE ),
-    mnHatchingListState ( ChangeType::NONE ),
-    mnPageType( PT_AREA ),
-    mnPos( 0 ),
-    mbAreaTP( false )
+    mnHatchingListState ( ChangeType::NONE )
 {
     m_nAreaTabPage = AddTabPage( "RID_SVXPAGE_AREA", SvxAreaTabPage::Create, nullptr );
 
@@ -85,10 +79,6 @@ SvxAreaTabDialog::SvxAreaTabDialog
     }
 
     m_nTransparenceTabPage = AddTabPage( "RID_SVXPAGE_TRANSPARENCE", SvxTransparenceTabPage::Create,  nullptr);
-    m_nColorTabPage = AddTabPage( "RID_SVXPAGE_COLOR", SvxColorTabPage::Create, nullptr );
-    m_nGradientTabPage = AddTabPage( "RID_SVXPAGE_GRADIENT", SvxGradientTabPage::Create, nullptr );
-    m_nHatchTabPage = AddTabPage( "RID_SVXPAGE_HATCH", SvxHatchTabPage::Create, nullptr );
-    m_nBitmapTabPage = AddTabPage( "RID_SVXPAGE_BITMAP", SvxBitmapTabPage::Create,  nullptr);
 
     SetCurPageId( "RID_SVXPAGE_AREA" );
 
@@ -139,6 +129,16 @@ void SvxAreaTabDialog::SavePalettes()
             mpDrawModel->GetItemPool().Put(aItem,SID_BITMAP_LIST);
         mpBitmapList = mpDrawModel->GetBitmapList();
     }
+    if( mpNewPatternList != mpDrawModel->GetPatternList() )
+    {
+        mpDrawModel->SetPropertyList( static_cast<XPropertyList *>(mpNewPatternList.get()) );
+        SvxPatternListItem aItem( mpNewPatternList, SID_PATTERN_LIST );
+        if( pShell )
+            pShell->PutItem( aItem );
+        else
+            mpDrawModel->GetItemPool().Put(aItem,SID_PATTERN_LIST);
+        mpPatternList = mpDrawModel->GetPatternList();
+    }
 
     // save the tables when they have been changed
 
@@ -179,6 +179,19 @@ void SvxAreaTabDialog::SavePalettes()
         }
     }
 
+    if( mnPatternListState & ChangeType::MODIFIED )
+    {
+        mpPatternList->SetPath( aPath );
+        mpPatternList->Save();
+
+        SvxPatternListItem aItem( mpPatternList, SID_PATTERN_LIST );
+        // ToolBoxControls are informed:
+        if( pShell )
+            pShell->PutItem( aItem );
+        else
+            mpDrawModel->GetItemPool().Put(aItem);
+    }
+
     if( mnGradientListState & ChangeType::MODIFIED )
     {
         mpGradientList->SetPath( aPath );
@@ -196,9 +209,6 @@ void SvxAreaTabDialog::SavePalettes()
 
     if (mnColorListState & ChangeType::MODIFIED && mpColorList.is())
     {
-        mpColorList->SetPath( aPath );
-        mpColorList->Save();
-
         SvxColorListItem aItem( mpColorList, SID_COLOR_TABLE );
         // ToolBoxControls are informed:
         if ( pShell )
@@ -210,23 +220,19 @@ void SvxAreaTabDialog::SavePalettes()
     }
 }
 
-
 short SvxAreaTabDialog::Ok()
 {
     SavePalettes();
-
     // RET_OK is returned, if at least one
     // TabPage returns sal_True in FillItemSet().
     // This happens by default at the moment.
-    return( SfxTabDialog::Ok() );
+    return SfxTabDialog::Ok();
 }
 
 
-
-IMPL_LINK_NOARG_TYPED(SvxAreaTabDialog, CancelHdlImpl, Button*, void)
+IMPL_LINK_NOARG(SvxAreaTabDialog, CancelHdlImpl, Button*, void)
 {
     SavePalettes();
-
     EndDialog();
 }
 
@@ -238,76 +244,23 @@ void SvxAreaTabDialog::PageCreated( sal_uInt16 nId, SfxTabPage &rPage )
             static_cast<SvxAreaTabPage&>(rPage).SetGradientList( mpGradientList );
             static_cast<SvxAreaTabPage&>(rPage).SetHatchingList( mpHatchingList );
             static_cast<SvxAreaTabPage&>(rPage).SetBitmapList( mpBitmapList );
-            static_cast<SvxAreaTabPage&>(rPage).SetPageType( mnPageType );
-            static_cast<SvxAreaTabPage&>(rPage).SetDlgType( 0 );
-            static_cast<SvxAreaTabPage&>(rPage).SetPos( mnPos );
-            static_cast<SvxAreaTabPage&>(rPage).SetAreaTP( &mbAreaTP );
+            static_cast<SvxAreaTabPage&>(rPage).SetPatternList( mpPatternList );
             static_cast<SvxAreaTabPage&>(rPage).SetGrdChgd( &mnGradientListState );
             static_cast<SvxAreaTabPage&>(rPage).SetHtchChgd( &mnHatchingListState );
             static_cast<SvxAreaTabPage&>(rPage).SetBmpChgd( &mnBitmapListState );
+            static_cast<SvxAreaTabPage&>(rPage).SetPtrnChgd( &mnPatternListState );
             static_cast<SvxAreaTabPage&>(rPage).SetColorChgd( &mnColorListState );
-            static_cast<SvxAreaTabPage&>(rPage).Construct();
             // ActivatePge() is not called the first time
             static_cast<SvxAreaTabPage&>(rPage).ActivatePage( mrOutAttrs );
     }
     else if (nId == m_nShadowTabPage)
     {
             static_cast<SvxShadowTabPage&>(rPage).SetColorList( mpColorList );
-            static_cast<SvxShadowTabPage&>(rPage).SetPageType( mnPageType );
-            static_cast<SvxShadowTabPage&>(rPage).SetDlgType( 0 );
-            static_cast<SvxShadowTabPage&>(rPage).SetAreaTP( &mbAreaTP );
             static_cast<SvxShadowTabPage&>(rPage).SetColorChgd( &mnColorListState );
-            static_cast<SvxShadowTabPage&>(rPage).Construct();
-    }
-    else if (nId == m_nGradientTabPage)
-    {
-            static_cast<SvxGradientTabPage&>(rPage).SetColorList( mpColorList );
-            static_cast<SvxGradientTabPage&>(rPage).SetGradientList( mpGradientList );
-            static_cast<SvxGradientTabPage&>(rPage).SetPageType( &mnPageType );
-            static_cast<SvxGradientTabPage&>(rPage).SetDlgType( 0 );
-            static_cast<SvxGradientTabPage&>(rPage).SetPos( &mnPos );
-            static_cast<SvxGradientTabPage&>(rPage).SetAreaTP( &mbAreaTP );
-            static_cast<SvxGradientTabPage&>(rPage).SetGrdChgd( &mnGradientListState );
-            static_cast<SvxGradientTabPage&>(rPage).SetColorChgd( &mnColorListState );
-            static_cast<SvxGradientTabPage&>(rPage).Construct();
-    }
-    else if (nId == m_nHatchTabPage)
-    {
-            static_cast<SvxHatchTabPage&>(rPage).SetColorList( mpColorList );
-            static_cast<SvxHatchTabPage&>(rPage).SetHatchingList( mpHatchingList );
-            static_cast<SvxHatchTabPage&>(rPage).SetPageType( &mnPageType );
-            static_cast<SvxHatchTabPage&>(rPage).SetDlgType( 0 );
-            static_cast<SvxHatchTabPage&>(rPage).SetPos( &mnPos );
-            static_cast<SvxHatchTabPage&>(rPage).SetAreaTP( &mbAreaTP );
-            static_cast<SvxHatchTabPage&>(rPage).SetHtchChgd( &mnHatchingListState );
-            static_cast<SvxHatchTabPage&>(rPage).SetColorChgd( &mnColorListState );
-            static_cast<SvxHatchTabPage&>(rPage).Construct();
-    }
-    else if (nId == m_nBitmapTabPage)
-    {
-            static_cast<SvxBitmapTabPage&>(rPage).SetColorList( mpColorList );
-            static_cast<SvxBitmapTabPage&>(rPage).SetBitmapList( mpBitmapList );
-            static_cast<SvxBitmapTabPage&>(rPage).SetPageType( &mnPageType );
-            static_cast<SvxBitmapTabPage&>(rPage).SetDlgType( 0 );
-            static_cast<SvxBitmapTabPage&>(rPage).SetPos( &mnPos );
-            static_cast<SvxBitmapTabPage&>(rPage).SetAreaTP( &mbAreaTP );
-            static_cast<SvxBitmapTabPage&>(rPage).SetBmpChgd( &mnBitmapListState );
-            static_cast<SvxBitmapTabPage&>(rPage).SetColorChgd( &mnColorListState );
-            static_cast<SvxBitmapTabPage&>(rPage).Construct();
-    }
-    else if (nId == m_nColorTabPage)
-    {
-            static_cast<SvxColorTabPage&>(rPage).SetColorList( mpColorList );
-            static_cast<SvxColorTabPage&>(rPage).SetPageType( &mnPageType );
-            static_cast<SvxColorTabPage&>(rPage).SetDlgType( 0 );
-            static_cast<SvxColorTabPage&>(rPage).SetPos( &mnPos );
-            static_cast<SvxColorTabPage&>(rPage).SetAreaTP( &mbAreaTP );
-            static_cast<SvxColorTabPage&>(rPage).SetColorChgd( &mnColorListState );
-            static_cast<SvxColorTabPage&>(rPage).Construct();
     }
     else if (nId == m_nTransparenceTabPage)
     {
-            static_cast<SvxTransparenceTabPage&>(rPage).SetPageType( mnPageType );
+            static_cast<SvxTransparenceTabPage&>(rPage).SetPageType( PageType::Area );
             static_cast<SvxTransparenceTabPage&>(rPage).SetDlgType( 0 );
     }
 }
