@@ -17,9 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include "KeySet.hxx"
-#include "core_resource.hxx"
-#include "core_resource.hrc"
+#include <core_resource.hxx>
+#include <strings.hrc>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/sdbc/XDatabaseMetaData.hpp>
 #include <com/sun/star/sdbc/ColumnValue.hpp>
@@ -28,8 +29,8 @@
 #include <com/sun/star/sdbc/XGeneratedResultSet.hpp>
 #include <com/sun/star/sdbc/XColumnLocate.hpp>
 #include <com/sun/star/container/XIndexAccess.hpp>
-#include "dbastrings.hrc"
-#include "apitools.hxx"
+#include <stringconstants.hxx>
+#include <apitools.hxx>
 #include <com/sun/star/sdbcx/XKeysSupplier.hpp>
 #include <com/sun/star/sdb/XSingleSelectQueryComposer.hpp>
 #include <com/sun/star/sdbcx/XIndexesSupplier.hpp>
@@ -43,9 +44,8 @@
 #include <string.h>
 #include <com/sun/star/io/XInputStream.hpp>
 #include <com/sun/star/sdbcx/XTablesSupplier.hpp>
-#include "querycomposer.hxx"
-#include "composertools.hxx"
-#include <tools/debug.hxx>
+#include <querycomposer.hxx>
+#include <composertools.hxx>
 #include "PrivateRow.hxx"
 
 using namespace dbaccess;
@@ -67,7 +67,7 @@ using std::vector;
 
 namespace
 {
-    void lcl_fillIndexColumns(const Reference<XIndexAccess>& _xIndexes, ::std::vector< Reference<XNameAccess> >& _rAllIndexColumns)
+    void lcl_fillIndexColumns(const Reference<XIndexAccess>& _xIndexes, std::vector< Reference<XNameAccess> >& _rAllIndexColumns)
     {
         if ( _xIndexes.is() )
         {
@@ -93,7 +93,7 @@ namespace
         }
         catch(const Exception&)
         {
-            r = NULL;
+            r = nullptr;
         }
         catch(...)
         {
@@ -151,7 +151,7 @@ void OKeySet::findTableColumnsMatching_throw(   const Any& i_aTable,
                                                 const OUString& i_rUpdateTableName,
                                                 const Reference<XDatabaseMetaData>& i_xMeta,
                                                 const Reference<XNameAccess>& i_xQueryColumns,
-                                                ::std::unique_ptr<SelectColumnsMetaData>& o_pKeyColumnNames)
+                                                std::unique_ptr<SelectColumnsMetaData> const & o_pKeyColumnNames)
 {
     // first ask the database itself for the best columns which can be used
     Sequence< OUString> aBestColumnNames;
@@ -190,7 +190,7 @@ void OKeySet::findTableColumnsMatching_throw(   const Any& i_aTable,
         xTableProp->getPropertyValue( PROPERTY_CATALOGNAME )>>= sCatalog;
         xTableProp->getPropertyValue( PROPERTY_SCHEMANAME ) >>= sSchema;
         xTableProp->getPropertyValue( PROPERTY_NAME )       >>= sTable;
-        sUpdateTableName = dbtools::composeTableName( i_xMeta, sCatalog, sSchema, sTable, false, ::dbtools::eInDataManipulation );
+        sUpdateTableName = dbtools::composeTableName( i_xMeta, sCatalog, sSchema, sTable, false, ::dbtools::EComposeRule::InDataManipulation );
     }
 
     ::dbaccess::getColumnPositions(i_xQueryColumns,aBestColumnNames,sUpdateTableName,(*o_pKeyColumnNames),true);
@@ -221,12 +221,11 @@ namespace
 {
     void appendOneKeyColumnClause( const OUString &tblName, const OUString &colName, const connectivity::ORowSetValue &_rValue, OUStringBuffer &o_buf )
     {
-        static const char s_sDot[] = ".";
         OUString fullName;
         if (tblName.isEmpty())
             fullName = colName;
         else
-            fullName = tblName + s_sDot + colName;
+            fullName = tblName + "." + colName;
         if ( _rValue.isNull() )
         {
             o_buf.append(fullName + " IS NULL ");
@@ -265,7 +264,7 @@ OUStringBuffer OKeySet::createKeyFilter()
     {
         if ( ! aFilter.isEmpty() )
             aFilter.append(aAnd);
-        appendOneKeyColumnClause(::dbtools::quoteTableName(xMeta, aPosIter->second.sTableName, ::dbtools::eInDataManipulation),
+        appendOneKeyColumnClause(::dbtools::quoteTableName(xMeta, aPosIter->second.sTableName, ::dbtools::EComposeRule::InDataManipulation),
                                  ::dbtools::quoteName(aQuote, aPosIter->second.sRealName),
                                  *aIter++,
                                  aFilter);
@@ -275,7 +274,7 @@ OUStringBuffer OKeySet::createKeyFilter()
     {
         if ( ! aFilter.isEmpty() )
             aFilter.append(aAnd);
-        appendOneKeyColumnClause(::dbtools::quoteTableName(xMeta, aPosIter->second.sTableName, ::dbtools::eInDataManipulation),
+        appendOneKeyColumnClause(::dbtools::quoteTableName(xMeta, aPosIter->second.sTableName, ::dbtools::EComposeRule::InDataManipulation),
                                  ::dbtools::quoteName(aQuote, aPosIter->second.sRealName),
                                  *aIter++,
                                  aFilter);
@@ -311,7 +310,7 @@ void OKeySet::construct(const Reference< XResultSet>& _xDriverSet, const OUStrin
             {
                 connectivity::OSQLTable xSelColSup(xSelectTables->getByName(*pIter),uno::UNO_QUERY);
                 Reference<XPropertySet> xProp(xSelColSup,uno::UNO_QUERY);
-                OUString sSelectTableName = ::dbtools::composeTableName( xMeta, xProp, ::dbtools::eInDataManipulation, false, false, false );
+                OUString sSelectTableName = ::dbtools::composeTableName( xMeta, xProp, ::dbtools::EComposeRule::InDataManipulation, false );
 
                 ::dbaccess::getColumnPositions(xQueryColumns, xSelColSup->getColumns()->getElementNames(), sSelectTableName, (*m_pForeignColumnNames), true);
 
@@ -323,8 +322,8 @@ void OKeySet::construct(const Reference< XResultSet>& _xDriverSet, const OUStrin
 
     // the first row is empty because it's now easier for us to distinguish when we are beforefirst or first
     // without extra variable to be set
-    OKeySetValue keySetValue(nullptr,::std::pair<sal_Int32,Reference<XRow> >(0,Reference<XRow>()));
-    m_aKeyMap.insert(OKeySetMatrix::value_type(0, keySetValue));
+    OKeySetValue keySetValue(nullptr,std::pair<sal_Int32,Reference<XRow> >(0,Reference<XRow>()));
+    m_aKeyMap.emplace(0, keySetValue);
     m_aKeyIter = m_aKeyMap.begin();
 }
 
@@ -333,8 +332,8 @@ void OKeySet::reset(const Reference< XResultSet>& _xDriverSet)
     OCacheSet::construct(_xDriverSet, m_sRowSetFilter);
     m_bRowCountFinal = false;
     m_aKeyMap.clear();
-    OKeySetValue keySetValue(nullptr,::std::pair<sal_Int32,Reference<XRow> >(0,Reference<XRow>()));
-    m_aKeyMap.insert(OKeySetMatrix::value_type(0,keySetValue));
+    OKeySetValue keySetValue(nullptr,std::pair<sal_Int32,Reference<XRow> >(0,Reference<XRow>()));
+    m_aKeyMap.emplace(0,keySetValue);
     m_aKeyIter = m_aKeyMap.begin();
 }
 
@@ -348,13 +347,13 @@ void OKeySet::ensureStatement( )
     const connectivity::ORowVector< ORowSetValue >::Vector::const_iterator aEnd  = m_aKeyIter->second.first->get().end();
     for( ; aIter != aEnd; ++aIter )
         FilterColumnsNULL.push_back(aIter->isNull());
-    vStatements_t::iterator pNewStatement(m_vStatements.find(FilterColumnsNULL));
+    vStatements_t::const_iterator pNewStatement(m_vStatements.find(FilterColumnsNULL));
     if(pNewStatement == m_vStatements.end())
     {
         // no: make a new one
         makeNewStatement();
-        std::pair< vStatements_t::iterator, bool > insert_result
-            (m_vStatements.insert(vStatements_t::value_type(FilterColumnsNULL, m_xStatement)));
+        std::pair< vStatements_t::const_iterator, bool > insert_result
+            (m_vStatements.emplace( FilterColumnsNULL, m_xStatement));
         (void) insert_result; // WaE: unused variable
         assert(insert_result.second);
     }
@@ -414,14 +413,14 @@ void OKeySet::invalidateRow()
     ::comphelper::disposeComponent(m_xSet);
 }
 
-Any SAL_CALL OKeySet::getBookmark() throw(SQLException, RuntimeException)
+Any SAL_CALL OKeySet::getBookmark()
 {
     OSL_ENSURE(m_aKeyIter != m_aKeyMap.end() && m_aKeyIter != m_aKeyMap.begin(),
         "getBookmark is only possible when we stand on a valid row!");
     return makeAny(m_aKeyIter->first);
 }
 
-bool SAL_CALL OKeySet::moveToBookmark( const Any& bookmark ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::moveToBookmark( const Any& bookmark )
 {
     m_bInserted = m_bUpdated = m_bDeleted = false;
     m_aKeyIter = m_aKeyMap.find(::comphelper::getINT32(bookmark));
@@ -429,7 +428,7 @@ bool SAL_CALL OKeySet::moveToBookmark( const Any& bookmark ) throw(SQLException,
     return m_aKeyIter != m_aKeyMap.end();
 }
 
-sal_Int32 SAL_CALL OKeySet::compareBookmarks( const Any& _first, const Any& _second ) throw(SQLException, RuntimeException)
+sal_Int32 SAL_CALL OKeySet::compareBookmarks( const Any& _first, const Any& _second )
 {
     sal_Int32 nFirst = 0, nSecond = 0;
     _first >>= nFirst;
@@ -438,18 +437,18 @@ sal_Int32 SAL_CALL OKeySet::compareBookmarks( const Any& _first, const Any& _sec
     return (nFirst != nSecond) ? CompareBookmark::NOT_EQUAL : CompareBookmark::EQUAL;
 }
 
-bool SAL_CALL OKeySet::hasOrderedBookmarks(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::hasOrderedBookmarks(  )
 {
     return true;
 }
 
-sal_Int32 SAL_CALL OKeySet::hashBookmark( const Any& bookmark ) throw(SQLException, RuntimeException)
+sal_Int32 SAL_CALL OKeySet::hashBookmark( const Any& bookmark )
 {
     return ::comphelper::getINT32(bookmark);
 }
 
 
-void SAL_CALL OKeySet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetRow& _rOriginalRow,const connectivity::OSQLTable& _xTable  ) throw(SQLException, RuntimeException, std::exception)
+void SAL_CALL OKeySet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetRow& _rOriginalRow,const connectivity::OSQLTable& _xTable  )
 {
     Reference<XPropertySet> xSet(_xTable,UNO_QUERY);
     fillTableName(xSet);
@@ -472,11 +471,11 @@ void SAL_CALL OKeySet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetRow
     if ( xIndexSup.is() )
         xIndexes.set(xIndexSup->getIndexes(),UNO_QUERY);
 
-    ::std::vector< Reference<XNameAccess> > aAllIndexColumns;
+    std::vector< Reference<XNameAccess> > aAllIndexColumns;
     lcl_fillIndexColumns(xIndexes,aAllIndexColumns);
 
     OUStringBuffer sKeyCondition,sIndexCondition;
-    ::std::vector<sal_Int32> aIndexColumnPositions;
+    std::vector<sal_Int32> aIndexColumnPositions;
 
     const sal_Int32 nOldLength = aSql.getLength();
     sal_Int32 i = 1;
@@ -496,8 +495,8 @@ void SAL_CALL OKeySet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetRow
         }
         else
         {
-            ::std::vector< Reference<XNameAccess> >::const_iterator aIndexEnd = aAllIndexColumns.end();
-            for( ::std::vector< Reference<XNameAccess> >::const_iterator aIndexIter = aAllIndexColumns.begin();
+            std::vector< Reference<XNameAccess> >::const_iterator aIndexEnd = aAllIndexColumns.end();
+            for( std::vector< Reference<XNameAccess> >::const_iterator aIndexIter = aAllIndexColumns.begin();
                 aIndexIter != aIndexEnd;++aIndexIter)
             {
                 if((*aIndexIter)->hasByName(aIter->first))
@@ -526,7 +525,7 @@ void SAL_CALL OKeySet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetRow
         aSql.setLength(aSql.getLength()-1);
     }
     else
-        ::dbtools::throwSQLException( DBACORE_RESSTRING( RID_STR_NO_VALUE_CHANGED ), SQL_GENERAL_ERROR, m_xConnection );
+        ::dbtools::throwSQLException( DBA_RES( RID_STR_NO_VALUE_CHANGED ), StandardSQLState::GENERAL_ERROR, m_xConnection );
 
     if(!sKeyCondition.isEmpty() || !sIndexCondition.isEmpty())
     {
@@ -546,13 +545,13 @@ void SAL_CALL OKeySet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetRow
         aSql.setLength(aSql.getLength()-5); // remove the last AND
     }
     else
-        ::dbtools::throwSQLException( DBACORE_RESSTRING( RID_STR_NO_CONDITION_FOR_PK ), SQL_GENERAL_ERROR, m_xConnection );
+        ::dbtools::throwSQLException( DBA_RES( RID_STR_NO_CONDITION_FOR_PK ), StandardSQLState::GENERAL_ERROR, m_xConnection );
 
     // now create end execute the prepared statement
     executeUpdate(_rInsertRow ,_rOriginalRow,aSql.makeStringAndClear(),"",aIndexColumnPositions);
 }
 
-void OKeySet::executeUpdate(const ORowSetRow& _rInsertRow ,const ORowSetRow& _rOriginalRow,const OUString& i_sSQL,const OUString& i_sTableName,const ::std::vector<sal_Int32>& _aIndexColumnPositions)
+void OKeySet::executeUpdate(const ORowSetRow& _rInsertRow ,const ORowSetRow& _rOriginalRow,const OUString& i_sSQL,const OUString& i_sTableName,const std::vector<sal_Int32>& _aIndexColumnPositions)
 {
     // now create end execute the prepared statement
     Reference< XPreparedStatement > xPrep(m_xConnection->prepareStatement(i_sSQL));
@@ -574,7 +573,7 @@ void OKeySet::executeUpdate(const ORowSetRow& _rInsertRow ,const ORowSetRow& _rO
             {
                 if ( bRefetch )
                 {
-                    bRefetch = ::std::find(m_aFilterColumns.begin(),m_aFilterColumns.end(),aIter->second.sRealName) == m_aFilterColumns.end();
+                    bRefetch = std::find(m_aFilterColumns.begin(),m_aFilterColumns.end(),aIter->second.sRealName) == m_aFilterColumns.end();
                 }
                 impl_convertValue_throw(_rInsertRow,aIter->second);
                 (_rInsertRow->get())[nPos].setSigned((_rOriginalRow->get())[nPos].isSigned());
@@ -596,8 +595,8 @@ void OKeySet::executeUpdate(const ORowSetRow& _rInsertRow ,const ORowSetRow& _rO
     if ( !_aIndexColumnPositions.empty() )
     {
         // now we have to set the index values
-        ::std::vector<sal_Int32>::const_iterator aIdxColIter = _aIndexColumnPositions.begin();
-        ::std::vector<sal_Int32>::const_iterator aIdxColEnd = _aIndexColumnPositions.end();
+        std::vector<sal_Int32>::const_iterator aIdxColIter = _aIndexColumnPositions.begin();
+        std::vector<sal_Int32>::const_iterator aIdxColEnd = _aIndexColumnPositions.end();
         j = 0;
         aIter = m_pColumnNames->begin();
         for(;aIdxColIter != aIdxColEnd;++aIdxColIter,++i,++j,++aIter)
@@ -618,7 +617,7 @@ void OKeySet::executeUpdate(const ORowSetRow& _rInsertRow ,const ORowSetRow& _rO
     }
 }
 
-void SAL_CALL OKeySet::insertRow( const ORowSetRow& _rInsertRow,const connectivity::OSQLTable& _xTable ) throw(SQLException, RuntimeException, std::exception)
+void SAL_CALL OKeySet::insertRow( const ORowSetRow& _rInsertRow,const connectivity::OSQLTable& _xTable )
 {
     Reference<XPropertySet> xSet(_xTable,UNO_QUERY);
     fillTableName(xSet);
@@ -627,9 +626,7 @@ void SAL_CALL OKeySet::insertRow( const ORowSetRow& _rInsertRow,const connectivi
 
     // set values and column names
     OUStringBuffer aValues(" VALUES ( ");
-    static const char aPara[] = "?,";
     OUString aQuote = getIdentifierQuoteString();
-    static const char aComma[] = ",";
 
     SelectColumnsMetaData::const_iterator aIter = m_pColumnNames->begin();
     SelectColumnsMetaData::const_iterator aEnd = m_pColumnNames->end();
@@ -642,15 +639,15 @@ void SAL_CALL OKeySet::insertRow( const ORowSetRow& _rInsertRow,const connectivi
         {
             if ( bRefetch )
             {
-                bRefetch = ::std::find(m_aFilterColumns.begin(),m_aFilterColumns.end(),aIter->second.sRealName) == m_aFilterColumns.end();
+                bRefetch = std::find(m_aFilterColumns.begin(),m_aFilterColumns.end(),aIter->second.sRealName) == m_aFilterColumns.end();
             }
-            aSql.append(::dbtools::quoteName( aQuote,aIter->second.sRealName) + aComma);
-            aValues.append(aPara);
+            aSql.append(::dbtools::quoteName( aQuote,aIter->second.sRealName) + ",");
+            aValues.append("?,");
             bModified = true;
         }
     }
     if ( !bModified )
-        ::dbtools::throwSQLException( DBACORE_RESSTRING( RID_STR_NO_VALUE_CHANGED ), SQL_GENERAL_ERROR, m_xConnection );
+        ::dbtools::throwSQLException( DBA_RES( RID_STR_NO_VALUE_CHANGED ), StandardSQLState::GENERAL_ERROR, m_xConnection );
 
     aSql[aSql.getLength() - 1] = ')';
     aValues[aValues.getLength() - 1] = ')';
@@ -720,11 +717,11 @@ void OKeySet::executeInsert( const ORowSetRow& _rInsertRow,const OUString& i_sSQ
                     Reference< XResultSetMetaDataSupplier > xMdSup(xRes,UNO_QUERY);
                     Reference< XResultSetMetaData > xMd = xMdSup->getMetaData();
                     sal_Int32 nColumnCount = xMd->getColumnCount();
-                    ::std::vector< OUString >::iterator aAutoIter = m_aAutoColumns.begin();
-                    ::std::vector< OUString >::iterator aAutoEnd = m_aAutoColumns.end();
+                    std::vector< OUString >::const_iterator aAutoIter = m_aAutoColumns.begin();
+                    std::vector< OUString >::const_iterator aAutoEnd = m_aAutoColumns.end();
                     for (sal_Int32 i = 1;aAutoIter !=  aAutoEnd && i <= nColumnCount; ++aAutoIter,++i)
                     {
-                        SelectColumnsMetaData::iterator aFind = m_pKeyColumnNames->find(*aAutoIter);
+                        SelectColumnsMetaData::const_iterator aFind = m_pKeyColumnNames->find(*aAutoIter);
                         if ( aFind != m_pKeyColumnNames->end() )
                             (_rInsertRow->get())[aFind->second.nPosition].fill(i, aFind->second.nType, xRow);
                     }
@@ -748,18 +745,15 @@ void OKeySet::executeInsert( const ORowSetRow& _rInsertRow,const OUString& i_sSQ
         const OUString sQuote = getIdentifierQuoteString();
         OUString sMaxStmt;
         aEnd = m_pKeyColumnNames->end();
-        ::std::vector< OUString >::iterator aAutoIter = m_aAutoColumns.begin();
-        ::std::vector< OUString >::iterator aAutoEnd = m_aAutoColumns.end();
+        std::vector< OUString >::const_iterator aAutoIter = m_aAutoColumns.begin();
+        std::vector< OUString >::const_iterator aAutoEnd = m_aAutoColumns.end();
         for (;aAutoIter !=  aAutoEnd; ++aAutoIter)
         {
             // we will only fetch values which are keycolumns
-            SelectColumnsMetaData::iterator aFind = m_pKeyColumnNames->find(*aAutoIter);
+            SelectColumnsMetaData::const_iterator aFind = m_pKeyColumnNames->find(*aAutoIter);
             if ( aFind != aEnd )
             {
-                sMaxStmt += sMax;
-                sMaxStmt += ::dbtools::quoteName( sQuote,aFind->second.sRealName
-);
-                sMaxStmt += sMaxEnd;
+                sMaxStmt += sMax + ::dbtools::quoteName( sQuote,aFind->second.sRealName) + sMaxEnd;
             }
         }
 
@@ -768,7 +762,7 @@ void OKeySet::executeInsert( const ORowSetRow& _rInsertRow,const OUString& i_sSQ
             sMaxStmt = sMaxStmt.replaceAt(sMaxStmt.getLength()-1,1," ");
             OUString sStmt = "SELECT " + sMaxStmt + "FROM ";
             OUString sCatalog,sSchema,sTable;
-            ::dbtools::qualifiedNameComponents(m_xConnection->getMetaData(),m_sUpdateTableName,sCatalog,sSchema,sTable,::dbtools::eInDataManipulation);
+            ::dbtools::qualifiedNameComponents(m_xConnection->getMetaData(),m_sUpdateTableName,sCatalog,sSchema,sTable,::dbtools::EComposeRule::InDataManipulation);
             sStmt += ::dbtools::composeTableNameForSelect( m_xConnection, sCatalog, sSchema, sTable );
             try
             {
@@ -782,7 +776,7 @@ void OKeySet::executeInsert( const ORowSetRow& _rInsertRow,const OUString& i_sSQ
                     for (sal_Int32 i=1;aAutoIter != aAutoEnd; ++aAutoIter,++i)
                     {
                         // we will only fetch values which are keycolumns
-                        SelectColumnsMetaData::iterator aFind = m_pKeyColumnNames->find(*aAutoIter);
+                        SelectColumnsMetaData::const_iterator aFind = m_pKeyColumnNames->find(*aAutoIter);
                         if ( aFind != aEnd )
                             (_rInsertRow->get())[aFind->second.nPosition].fill(i, aFind->second.nType, xRow);
                     }
@@ -797,12 +791,12 @@ void OKeySet::executeInsert( const ORowSetRow& _rInsertRow,const OUString& i_sSQ
     }
     if ( m_bInserted )
     {
-        OKeySetMatrix::iterator aKeyIter = m_aKeyMap.end();
+        OKeySetMatrix::const_iterator aKeyIter = m_aKeyMap.end();
         --aKeyIter;
         ORowSetRow aKeyRow = new connectivity::ORowVector< ORowSetValue >(m_pKeyColumnNames->size());
         copyRowValue(_rInsertRow,aKeyRow,aKeyIter->first + 1);
 
-        m_aKeyIter = m_aKeyMap.insert(OKeySetMatrix::value_type(aKeyIter->first + 1,OKeySetValue(aKeyRow,::std::pair<sal_Int32,Reference<XRow> >(1,Reference<XRow>())))).first;
+        m_aKeyIter = m_aKeyMap.emplace( aKeyIter->first + 1, OKeySetValue(aKeyRow,std::pair<sal_Int32,Reference<XRow> >(1,Reference<XRow>())) ).first;
         // now we set the bookmark for this row
         (_rInsertRow->get())[0] = makeAny((sal_Int32)m_aKeyIter->first);
         tryRefetch(_rInsertRow,bRefetch);
@@ -828,7 +822,7 @@ void OKeySet::tryRefetch(const ORowSetRow& _rInsertRow,bool bRefetch)
     }
 }
 
-void OKeySet::copyRowValue(const ORowSetRow& _rInsertRow,ORowSetRow& _rKeyRow,sal_Int32 i_nBookmark)
+void OKeySet::copyRowValue(const ORowSetRow& _rInsertRow, ORowSetRow const & _rKeyRow, sal_Int32 i_nBookmark)
 {
     connectivity::ORowVector< ORowSetValue >::Vector::iterator aIter = _rKeyRow->get().begin();
 
@@ -867,7 +861,7 @@ void OKeySet::copyRowValue(const ORowSetRow& _rInsertRow,ORowSetRow& _rKeyRow,sa
     }
 }
 
-void SAL_CALL OKeySet::deleteRow(const ORowSetRow& _rDeleteRow,const connectivity::OSQLTable& _xTable   ) throw(SQLException, RuntimeException)
+void SAL_CALL OKeySet::deleteRow(const ORowSetRow& _rDeleteRow,const connectivity::OSQLTable& _xTable   )
 {
     Reference<XPropertySet> xSet(_xTable,UNO_QUERY);
     fillTableName(xSet);
@@ -887,11 +881,11 @@ void SAL_CALL OKeySet::deleteRow(const ORowSetRow& _rDeleteRow,const connectivit
         xIndexes.set(xIndexSup->getIndexes(),UNO_QUERY);
 
     //  Reference<XColumnsSupplier>
-    ::std::vector< Reference<XNameAccess> > aAllIndexColumns;
+    std::vector< Reference<XNameAccess> > aAllIndexColumns;
     lcl_fillIndexColumns(xIndexes,aAllIndexColumns);
 
     OUStringBuffer sIndexCondition;
-    ::std::vector<sal_Int32> aIndexColumnPositions;
+    std::vector<sal_Int32> aIndexColumnPositions;
     SelectColumnsMetaData::const_iterator aIter = m_pColumnNames->begin();
     SelectColumnsMetaData::const_iterator aEnd = m_pColumnNames->end();
 
@@ -912,8 +906,8 @@ void SAL_CALL OKeySet::deleteRow(const ORowSetRow& _rDeleteRow,const connectivit
         }
         else
         {
-            ::std::vector< Reference<XNameAccess> >::const_iterator aIndexEnd = aAllIndexColumns.end();
-            for( ::std::vector< Reference<XNameAccess> >::const_iterator aIndexIter = aAllIndexColumns.begin();
+            std::vector< Reference<XNameAccess> >::const_iterator aIndexEnd = aAllIndexColumns.end();
+            for( std::vector< Reference<XNameAccess> >::const_iterator aIndexIter = aAllIndexColumns.begin();
                     aIndexIter != aIndexEnd;++aIndexIter)
             {
                 if((*aIndexIter)->hasByName(aIter->first))
@@ -949,8 +943,8 @@ void SAL_CALL OKeySet::deleteRow(const ORowSetRow& _rDeleteRow,const connectivit
     }
 
     // now we have to set the index values
-    ::std::vector<sal_Int32>::iterator aIdxColIter = aIndexColumnPositions.begin();
-    ::std::vector<sal_Int32>::iterator aIdxColEnd = aIndexColumnPositions.end();
+    std::vector<sal_Int32>::const_iterator aIdxColIter = aIndexColumnPositions.begin();
+    std::vector<sal_Int32>::const_iterator aIdxColEnd = aIndexColumnPositions.end();
     aIter = m_pColumnNames->begin();
     for(;aIdxColIter != aIdxColEnd;++aIdxColIter,++i,++aIter)
     {
@@ -1009,7 +1003,7 @@ Reference<XNameAccess> OKeySet::getKeyColumns() const
     return xKeyColumns;
 }
 
-bool SAL_CALL OKeySet::next(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::next()
 {
     m_bInserted = m_bUpdated = m_bDeleted = false;
 
@@ -1037,24 +1031,24 @@ bool SAL_CALL OKeySet::next(  ) throw(SQLException, RuntimeException)
     return !isAfterLast();
 }
 
-bool SAL_CALL OKeySet::isBeforeFirst(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::isBeforeFirst(  )
 {
     return m_aKeyIter == m_aKeyMap.begin();
 }
 
-bool SAL_CALL OKeySet::isAfterLast(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::isAfterLast(  )
 {
     return  m_bRowCountFinal && m_aKeyIter == m_aKeyMap.end();
 }
 
-void SAL_CALL OKeySet::beforeFirst(  ) throw(SQLException, RuntimeException)
+void SAL_CALL OKeySet::beforeFirst(  )
 {
     m_bInserted = m_bUpdated = m_bDeleted = false;
     m_aKeyIter = m_aKeyMap.begin();
     invalidateRow();
 }
 
-void SAL_CALL OKeySet::afterLast(  ) throw(SQLException, RuntimeException)
+void SAL_CALL OKeySet::afterLast(  )
 {
     m_bInserted = m_bUpdated = m_bDeleted = false;
     fillAllRows();
@@ -1062,7 +1056,7 @@ void SAL_CALL OKeySet::afterLast(  ) throw(SQLException, RuntimeException)
     invalidateRow();
 }
 
-bool SAL_CALL OKeySet::first(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::first()
 {
     m_bInserted = m_bUpdated = m_bDeleted = false;
     m_aKeyIter = m_aKeyMap.begin();
@@ -1080,7 +1074,7 @@ bool SAL_CALL OKeySet::first(  ) throw(SQLException, RuntimeException)
     return m_aKeyIter != m_aKeyMap.end() && m_aKeyIter != m_aKeyMap.begin();
 }
 
-bool SAL_CALL OKeySet::last(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::last(  )
 {
     return last_checked(true);
 }
@@ -1099,15 +1093,15 @@ bool OKeySet::last_checked( bool /* i_bFetchRow */ )
     return m_aKeyIter != m_aKeyMap.end() && m_aKeyIter != m_aKeyMap.begin();
 }
 
-sal_Int32 SAL_CALL OKeySet::getRow(  ) throw(SQLException, RuntimeException)
+sal_Int32 SAL_CALL OKeySet::getRow(  )
 {
     OSL_ENSURE(!isAfterLast(),"getRow is not allowed when afterlast record!");
     OSL_ENSURE(!isBeforeFirst(),"getRow is not allowed when beforefirst record!");
 
-    return ::std::distance(m_aKeyMap.begin(),m_aKeyIter);
+    return std::distance(m_aKeyMap.begin(),m_aKeyIter);
 }
 
-bool SAL_CALL OKeySet::absolute( sal_Int32 row ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::absolute( sal_Int32 row )
 {
     return absolute_checked(row,true);
 }
@@ -1182,12 +1176,12 @@ bool OKeySet::previous_checked( bool /* i_bFetchRow */ )
     return m_aKeyIter != m_aKeyMap.begin();
 }
 
-bool SAL_CALL OKeySet::previous(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::previous(  )
 {
     return previous_checked(true);
 }
 
-bool OKeySet::doTryRefetch_throw()  throw(SQLException, RuntimeException)
+bool OKeySet::doTryRefetch_throw()
 {
     ensureStatement( );
     // we just reassign the base members
@@ -1198,7 +1192,7 @@ bool OKeySet::doTryRefetch_throw()  throw(SQLException, RuntimeException)
     sal_Int32 nPos=1;
     connectivity::ORowVector< ORowSetValue >::Vector::const_iterator aParaIter;
     connectivity::ORowVector< ORowSetValue >::Vector::const_iterator aParaEnd;
-    OUpdatedParameter::iterator aUpdateFind = m_aUpdatedParameter.find(m_aKeyIter->first);
+    OUpdatedParameter::const_iterator aUpdateFind = m_aUpdatedParameter.find(m_aKeyIter->first);
     if ( aUpdateFind == m_aUpdatedParameter.end() )
     {
         aParaIter = m_aParameterValueForCache->get().begin();
@@ -1231,7 +1225,7 @@ bool OKeySet::doTryRefetch_throw()  throw(SQLException, RuntimeException)
     return m_xSet->next();
 }
 
-void SAL_CALL OKeySet::refreshRow() throw(SQLException, RuntimeException)
+void SAL_CALL OKeySet::refreshRow()
 {
     invalidateRow();
 
@@ -1248,7 +1242,7 @@ void SAL_CALL OKeySet::refreshRow() throw(SQLException, RuntimeException)
     if ( !bOK )
     {
         // This row has disappeared; remove it.
-        OKeySetMatrix::iterator aTemp = m_aKeyIter;
+        OKeySetMatrix::const_iterator aTemp = m_aKeyIter;
         // use *next* row
         ++m_aKeyIter;
         m_aKeyMap.erase(aTemp);
@@ -1317,7 +1311,7 @@ bool OKeySet::fetchRow()
             const SelectColumnDescription& rColDesc = aPosIter->second;
             aIter->fill(rColDesc.nPosition, rColDesc.nType, m_xRow);
         }
-        m_aKeyIter = m_aKeyMap.insert(OKeySetMatrix::value_type(m_aKeyMap.rbegin()->first+1,OKeySetValue(aKeyRow,::std::pair<sal_Int32,Reference<XRow> >(0,Reference<XRow>())))).first;
+        m_aKeyIter = m_aKeyMap.emplace( m_aKeyMap.rbegin()->first+1,OKeySetValue(aKeyRow,std::pair<sal_Int32,Reference<XRow> >(0,Reference<XRow>())) ).first;
     }
     else
         m_bRowCountFinal = true;
@@ -1339,7 +1333,7 @@ bool OKeySet::fillAllRows()
 }
 
 // XRow
-sal_Bool SAL_CALL OKeySet::wasNull(  ) throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OKeySet::wasNull(  )
 {
     if ( ! m_xRow.is() )
         throwGenericSQLException("Must call getFOO() for some FOO before wasNull()", *this);
@@ -1348,7 +1342,7 @@ sal_Bool SAL_CALL OKeySet::wasNull(  ) throw(SQLException, RuntimeException, std
     return m_xRow->wasNull();
 }
 
-inline void OKeySet::ensureRowForData( ) throw(SQLException, RuntimeException)
+inline void OKeySet::ensureRowForData( )
 {
     if (! m_xRow.is() )
         refreshRow();
@@ -1358,131 +1352,131 @@ inline void OKeySet::ensureRowForData( ) throw(SQLException, RuntimeException)
     OSL_ENSURE(m_xRow.is(),"m_xRow is null! I've called throwSQLException but execution continued?");
 }
 
-OUString SAL_CALL OKeySet::getString( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+OUString SAL_CALL OKeySet::getString( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getString(columnIndex);
 }
 
-sal_Bool SAL_CALL OKeySet::getBoolean( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OKeySet::getBoolean( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getBoolean(columnIndex);
 }
 
-sal_Int8 SAL_CALL OKeySet::getByte( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+sal_Int8 SAL_CALL OKeySet::getByte( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getByte(columnIndex);
 }
 
-sal_Int16 SAL_CALL OKeySet::getShort( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+sal_Int16 SAL_CALL OKeySet::getShort( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getShort(columnIndex);
 }
 
-sal_Int32 SAL_CALL OKeySet::getInt( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+sal_Int32 SAL_CALL OKeySet::getInt( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getInt(columnIndex);
 }
 
-sal_Int64 SAL_CALL OKeySet::getLong( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+sal_Int64 SAL_CALL OKeySet::getLong( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getLong(columnIndex);
 }
 
-float SAL_CALL OKeySet::getFloat( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+float SAL_CALL OKeySet::getFloat( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getFloat(columnIndex);
 }
 
-double SAL_CALL OKeySet::getDouble( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+double SAL_CALL OKeySet::getDouble( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getDouble(columnIndex);
 }
 
-Sequence< sal_Int8 > SAL_CALL OKeySet::getBytes( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+Sequence< sal_Int8 > SAL_CALL OKeySet::getBytes( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getBytes(columnIndex);
 }
 
-css::util::Date SAL_CALL OKeySet::getDate( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+css::util::Date SAL_CALL OKeySet::getDate( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getDate(columnIndex);
 }
 
-css::util::Time SAL_CALL OKeySet::getTime( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+css::util::Time SAL_CALL OKeySet::getTime( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getTime(columnIndex);
 }
 
-css::util::DateTime SAL_CALL OKeySet::getTimestamp( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+css::util::DateTime SAL_CALL OKeySet::getTimestamp( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getTimestamp(columnIndex);
 }
 
-Reference< css::io::XInputStream > SAL_CALL OKeySet::getBinaryStream( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+Reference< css::io::XInputStream > SAL_CALL OKeySet::getBinaryStream( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getBinaryStream(columnIndex);
 }
 
-Reference< css::io::XInputStream > SAL_CALL OKeySet::getCharacterStream( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+Reference< css::io::XInputStream > SAL_CALL OKeySet::getCharacterStream( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getCharacterStream(columnIndex);
 }
 
-Any SAL_CALL OKeySet::getObject( sal_Int32 columnIndex, const Reference< css::container::XNameAccess >& typeMap ) throw(SQLException, RuntimeException, std::exception)
+Any SAL_CALL OKeySet::getObject( sal_Int32 columnIndex, const Reference< css::container::XNameAccess >& typeMap )
 {
     ensureRowForData();
     return m_xRow->getObject(columnIndex,typeMap);
 }
 
-Reference< XRef > SAL_CALL OKeySet::getRef( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+Reference< XRef > SAL_CALL OKeySet::getRef( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getRef(columnIndex);
 }
 
-Reference< XBlob > SAL_CALL OKeySet::getBlob( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+Reference< XBlob > SAL_CALL OKeySet::getBlob( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getBlob(columnIndex);
 }
 
-Reference< XClob > SAL_CALL OKeySet::getClob( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+Reference< XClob > SAL_CALL OKeySet::getClob( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getClob(columnIndex);
 }
 
-Reference< XArray > SAL_CALL OKeySet::getArray( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+Reference< XArray > SAL_CALL OKeySet::getArray( sal_Int32 columnIndex )
 {
     ensureRowForData();
     return m_xRow->getArray(columnIndex);
 }
 
-bool SAL_CALL OKeySet::rowUpdated(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::rowUpdated(  )
 {
     return m_aKeyIter != m_aKeyMap.begin() && m_aKeyIter != m_aKeyMap.end() && m_aKeyIter->second.second.first == 2;
 }
 
-bool SAL_CALL OKeySet::rowInserted(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::rowInserted(  )
 {
     return m_aKeyIter != m_aKeyMap.begin() && m_aKeyIter != m_aKeyMap.end() && m_aKeyIter->second.second.first == 1;
 }
 
-bool SAL_CALL OKeySet::rowDeleted(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OKeySet::rowDeleted(  )
 {
     bool bDeleted = m_bDeleted;
     m_bDeleted = false;
@@ -1566,7 +1560,7 @@ void OKeySet::impl_convertValue_throw(const ORowSetRow& _rInsertRow,const Select
                 sal_Int32 nIndex = sValue.indexOf('.');
                 if ( nIndex != -1 )
                 {
-                    aValue = sValue.copy(0,::std::min(sValue.getLength(),nIndex + (i_aMetaData.nScale > 0 ? i_aMetaData.nScale + 1 : 0)));
+                    aValue = sValue.copy(0,std::min(sValue.getLength(),nIndex + (i_aMetaData.nScale > 0 ? i_aMetaData.nScale + 1 : 0)));
                 }
             }
             break;
