@@ -17,9 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <resultset.hxx>
-#include "dbastrings.hrc"
-#include "apitools.hxx"
+#include "resultset.hxx"
+#include <stringconstants.hxx>
+#include <apitools.hxx>
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <com/sun/star/sdbc/ResultSetType.hpp>
 #include <cppuhelper/supportsservice.hxx>
@@ -30,7 +30,7 @@
 #include <comphelper/types.hxx>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
-#include <datacolumn.hxx>
+#include "datacolumn.hxx"
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <connectivity/dbexception.hxx>
 #include <connectivity/dbtools.hxx>
@@ -61,7 +61,7 @@ OResultSet::OResultSet(const css::uno::Reference< css::sdbc::XResultSet >& _xRes
            ,m_nResultSetConcurrency(0)
            ,m_bIsBookmarkable(false)
 {
-    m_pColumns = new OColumns(*this, m_aMutex, _bCaseSensitive, ::std::vector< OUString>(), nullptr,nullptr);
+    m_pColumns = new OColumns(*this, m_aMutex, _bCaseSensitive, std::vector< OUString>(), nullptr,nullptr);
 
     try
     {
@@ -82,7 +82,7 @@ OResultSet::OResultSet(const css::uno::Reference< css::sdbc::XResultSet >& _xRes
             {
                 m_bIsBookmarkable = ::comphelper::getBOOL(xSet->getPropertyValue(PROPERTY_ISBOOKMARKABLE));
                 OSL_ENSURE( !m_bIsBookmarkable || Reference< XRowLocate >(m_xDelegatorResultSet, UNO_QUERY).is(),
-                    "OResultSet::OResultSet: aggregate is inconsistent in it's bookmarkable attribute!" );
+                    "OResultSet::OResultSet: aggregate is inconsistent in its bookmarkable attribute!" );
                 m_bIsBookmarkable = m_bIsBookmarkable && Reference< XRowLocate >(m_xDelegatorResultSet, UNO_QUERY).is();
             }
         }
@@ -101,7 +101,7 @@ OResultSet::~OResultSet()
 }
 
 // css::lang::XTypeProvider
-Sequence< Type > OResultSet::getTypes() throw (RuntimeException, std::exception)
+Sequence< Type > OResultSet::getTypes()
 {
     OTypeCollection aTypes(cppu::UnoType<XPropertySet>::get(),
                            OResultSetBase::getTypes());
@@ -109,13 +109,13 @@ Sequence< Type > OResultSet::getTypes() throw (RuntimeException, std::exception)
     return aTypes.getTypes();
 }
 
-Sequence< sal_Int8 > OResultSet::getImplementationId() throw (RuntimeException, std::exception)
+Sequence< sal_Int8 > OResultSet::getImplementationId()
 {
     return css::uno::Sequence<sal_Int8>();
 }
 
 // css::uno::XInterface
-Any OResultSet::queryInterface( const Type & rType ) throw (RuntimeException, std::exception)
+Any OResultSet::queryInterface( const Type & rType )
 {
     Any aIface = OResultSetBase::queryInterface( rType );
     if (!aIface.hasValue())
@@ -158,7 +158,7 @@ void OResultSet::disposing()
 }
 
 // XCloseable
-void OResultSet::close() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::close()
 {
     {
         MutexGuard aGuard( m_aMutex );
@@ -168,17 +168,17 @@ void OResultSet::close() throw( SQLException, RuntimeException, std::exception )
 }
 
 // XServiceInfo
-OUString OResultSet::getImplementationName(  ) throw(RuntimeException, std::exception)
+OUString OResultSet::getImplementationName(  )
 {
     return OUString("com.sun.star.sdb.OResultSet");
 }
 
-sal_Bool OResultSet::supportsService( const OUString& _rServiceName ) throw (RuntimeException, std::exception)
+sal_Bool OResultSet::supportsService( const OUString& _rServiceName )
 {
     return cppu::supportsService(this, _rServiceName);
 }
 
-Sequence< OUString > OResultSet::getSupportedServiceNames(  ) throw (RuntimeException, std::exception)
+Sequence< OUString > OResultSet::getSupportedServiceNames(  )
 {
     Sequence< OUString > aSNS( 2 );
     aSNS[0] = SERVICE_SDBC_RESULTSET;
@@ -187,7 +187,7 @@ Sequence< OUString > OResultSet::getSupportedServiceNames(  ) throw (RuntimeExce
 }
 
 // css::beans::XPropertySet
-Reference< XPropertySetInfo > OResultSet::getPropertySetInfo() throw (RuntimeException, std::exception)
+Reference< XPropertySetInfo > OResultSet::getPropertySetInfo()
 {
     return createPropertySetInfo( getInfoHelper() ) ;
 }
@@ -211,15 +211,15 @@ Reference< XPropertySetInfo > OResultSet::getPropertySetInfo() throw (RuntimeExc
     return *getArrayHelper();
 }
 
-sal_Bool OResultSet::convertFastPropertyValue(Any & rConvertedValue, Any & rOldValue, sal_Int32 nHandle, const Any& rValue ) throw( IllegalArgumentException  )
+sal_Bool OResultSet::convertFastPropertyValue(Any & rConvertedValue, Any & rOldValue, sal_Int32 nHandle, const Any& rValue )
 {
     // be lazy ...
     rConvertedValue = rValue;
     getFastPropertyValue( rOldValue, nHandle );
-    return sal_True;
+    return true;
 }
 
-void OResultSet::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const Any& rValue ) throw (Exception, std::exception)
+void OResultSet::setFastPropertyValue_NoBroadcast( sal_Int32 nHandle, const Any& rValue )
 {
     // set it for the driver result set
     Reference< XPropertySet > xSet(m_xDelegatorResultSet, UNO_QUERY);
@@ -242,8 +242,7 @@ void OResultSet::getFastPropertyValue( Any& rValue, sal_Int32 nHandle ) const
     {
         case PROPERTY_ID_ISBOOKMARKABLE:
         {
-            sal_Bool bVal = m_bIsBookmarkable;
-            rValue.setValue(&bVal, cppu::UnoType<bool>::get());
+            rValue <<= m_bIsBookmarkable;
         }   break;
         default:
         {
@@ -261,14 +260,14 @@ void OResultSet::getFastPropertyValue( Any& rValue, sal_Int32 nHandle ) const
 }
 
 // XWarningsSupplier
-Any OResultSet::getWarnings() throw( SQLException, RuntimeException, std::exception )
+Any OResultSet::getWarnings()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
     return m_aWarnings.getWarnings();
 }
 
-void OResultSet::clearWarnings() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::clearWarnings()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -276,7 +275,7 @@ void OResultSet::clearWarnings() throw( SQLException, RuntimeException, std::exc
 }
 
 // css::sdbc::XResultSetMetaDataSupplier
-Reference< XResultSetMetaData > OResultSet::getMetaData() throw( SQLException, RuntimeException, std::exception )
+Reference< XResultSetMetaData > OResultSet::getMetaData()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -285,7 +284,7 @@ Reference< XResultSetMetaData > OResultSet::getMetaData() throw( SQLException, R
 }
 
 // css::sdbc::XColumnLocate
-sal_Int32 OResultSet::findColumn(const OUString& columnName) throw( SQLException, RuntimeException, std::exception )
+sal_Int32 OResultSet::findColumn(const OUString& columnName)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -295,7 +294,7 @@ sal_Int32 OResultSet::findColumn(const OUString& columnName) throw( SQLException
 
 namespace
 {
-    static Reference< XDatabaseMetaData > lcl_getDBMetaDataFromStatement_nothrow( const Reference< XInterface >& _rxStatement )
+    Reference< XDatabaseMetaData > lcl_getDBMetaDataFromStatement_nothrow( const Reference< XInterface >& _rxStatement )
     {
         Reference< XDatabaseMetaData > xDBMetaData;
         try
@@ -319,7 +318,7 @@ namespace
 }
 
 // css::sdbcx::XColumnsSupplier
-Reference< css::container::XNameAccess > OResultSet::getColumns() throw( RuntimeException, std::exception )
+Reference< css::container::XNameAccess > OResultSet::getColumns()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -367,15 +366,12 @@ Reference< css::container::XNameAccess > OResultSet::getColumns() throw( Runtime
             const Sequence< OUString > aNames( xColNames->getElementNames() );
             SAL_WARN_IF( aNames.getLength() != nColCount, "dbaccess",
                 "OResultSet::getColumns: invalid column count!" );
-            for (   const OUString* pName = aNames.getConstArray();
-                    pName != aNames.getConstArray() + aNames.getLength();
-                    ++pName
-                )
+            for (  auto const & name : aNames )
             {
-                Reference< XPropertySet > xColProps( xColNames->getByName( *pName ), UNO_QUERY_THROW );
+                Reference< XPropertySet > xColProps( xColNames->getByName( name ), UNO_QUERY_THROW );
                 OUString sName;
                 OSL_VERIFY( xColProps->getPropertyValue( PROPERTY_NAME ) >>= sName );
-                SAL_WARN_IF( sName != *pName, "dbaccess", "OResultSet::getColumns: invalid column name!" );
+                SAL_WARN_IF( sName != name, "dbaccess", "OResultSet::getColumns: invalid column name!" );
             }
 
         }
@@ -389,7 +385,7 @@ Reference< css::container::XNameAccess > OResultSet::getColumns() throw( Runtime
 }
 
 // css::sdbc::XRow
-sal_Bool OResultSet::wasNull() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::wasNull()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -397,7 +393,7 @@ sal_Bool OResultSet::wasNull() throw( SQLException, RuntimeException, std::excep
     return m_xDelegatorRow->wasNull();
 }
 
-OUString OResultSet::getString(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+OUString OResultSet::getString(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -405,7 +401,7 @@ OUString OResultSet::getString(sal_Int32 columnIndex) throw( SQLException, Runti
     return m_xDelegatorRow->getString(columnIndex);
 }
 
-sal_Bool OResultSet::getBoolean(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::getBoolean(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -413,7 +409,7 @@ sal_Bool OResultSet::getBoolean(sal_Int32 columnIndex) throw( SQLException, Runt
     return m_xDelegatorRow->getBoolean(columnIndex);
 }
 
-sal_Int8 OResultSet::getByte(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+sal_Int8 OResultSet::getByte(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -421,7 +417,7 @@ sal_Int8 OResultSet::getByte(sal_Int32 columnIndex) throw( SQLException, Runtime
     return m_xDelegatorRow->getByte(columnIndex);
 }
 
-sal_Int16 OResultSet::getShort(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+sal_Int16 OResultSet::getShort(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -429,7 +425,7 @@ sal_Int16 OResultSet::getShort(sal_Int32 columnIndex) throw( SQLException, Runti
     return m_xDelegatorRow->getShort(columnIndex);
 }
 
-sal_Int32 OResultSet::getInt(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+sal_Int32 OResultSet::getInt(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -437,7 +433,7 @@ sal_Int32 OResultSet::getInt(sal_Int32 columnIndex) throw( SQLException, Runtime
     return m_xDelegatorRow->getInt(columnIndex);
 }
 
-sal_Int64 OResultSet::getLong(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+sal_Int64 OResultSet::getLong(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -445,7 +441,7 @@ sal_Int64 OResultSet::getLong(sal_Int32 columnIndex) throw( SQLException, Runtim
     return m_xDelegatorRow->getLong(columnIndex);
 }
 
-float OResultSet::getFloat(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+float OResultSet::getFloat(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -453,7 +449,7 @@ float OResultSet::getFloat(sal_Int32 columnIndex) throw( SQLException, RuntimeEx
     return m_xDelegatorRow->getFloat(columnIndex);
 }
 
-double OResultSet::getDouble(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+double OResultSet::getDouble(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -461,7 +457,7 @@ double OResultSet::getDouble(sal_Int32 columnIndex) throw( SQLException, Runtime
     return m_xDelegatorRow->getDouble(columnIndex);
 }
 
-Sequence< sal_Int8 > OResultSet::getBytes(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+Sequence< sal_Int8 > OResultSet::getBytes(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -469,7 +465,7 @@ Sequence< sal_Int8 > OResultSet::getBytes(sal_Int32 columnIndex) throw( SQLExcep
     return m_xDelegatorRow->getBytes(columnIndex);
 }
 
-css::util::Date OResultSet::getDate(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+css::util::Date OResultSet::getDate(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -477,7 +473,7 @@ css::util::Date OResultSet::getDate(sal_Int32 columnIndex) throw( SQLException,
     return m_xDelegatorRow->getDate(columnIndex);
 }
 
-css::util::Time OResultSet::getTime(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+css::util::Time OResultSet::getTime(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -485,7 +481,7 @@ css::util::Time OResultSet::getTime(sal_Int32 columnIndex) throw( SQLException,
     return m_xDelegatorRow->getTime(columnIndex);
 }
 
-css::util::DateTime OResultSet::getTimestamp(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+css::util::DateTime OResultSet::getTimestamp(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -493,7 +489,7 @@ css::util::DateTime OResultSet::getTimestamp(sal_Int32 columnIndex) throw( SQLEx
     return m_xDelegatorRow->getTimestamp(columnIndex);
 }
 
-Reference< css::io::XInputStream >  OResultSet::getBinaryStream(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+Reference< css::io::XInputStream >  OResultSet::getBinaryStream(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -501,7 +497,7 @@ Reference< css::io::XInputStream >  OResultSet::getBinaryStream(sal_Int32 column
     return m_xDelegatorRow->getBinaryStream(columnIndex);
 }
 
-Reference< css::io::XInputStream >  OResultSet::getCharacterStream(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+Reference< css::io::XInputStream >  OResultSet::getCharacterStream(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -509,7 +505,7 @@ Reference< css::io::XInputStream >  OResultSet::getCharacterStream(sal_Int32 col
     return m_xDelegatorRow->getCharacterStream(columnIndex);
 }
 
-Any OResultSet::getObject(sal_Int32 columnIndex, const Reference< css::container::XNameAccess > & typeMap) throw( SQLException, RuntimeException, std::exception )
+Any OResultSet::getObject(sal_Int32 columnIndex, const Reference< css::container::XNameAccess > & typeMap)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -517,7 +513,7 @@ Any OResultSet::getObject(sal_Int32 columnIndex, const Reference< css::container
     return m_xDelegatorRow->getObject(columnIndex, typeMap);
 }
 
-Reference< XRef >  OResultSet::getRef(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+Reference< XRef >  OResultSet::getRef(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -525,7 +521,7 @@ Reference< XRef >  OResultSet::getRef(sal_Int32 columnIndex) throw( SQLException
     return m_xDelegatorRow->getRef(columnIndex);
 }
 
-Reference< XBlob >  OResultSet::getBlob(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+Reference< XBlob >  OResultSet::getBlob(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -533,7 +529,7 @@ Reference< XBlob >  OResultSet::getBlob(sal_Int32 columnIndex) throw( SQLExcepti
     return m_xDelegatorRow->getBlob(columnIndex);
 }
 
-Reference< XClob >  OResultSet::getClob(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+Reference< XClob >  OResultSet::getClob(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -541,7 +537,7 @@ Reference< XClob >  OResultSet::getClob(sal_Int32 columnIndex) throw( SQLExcepti
     return m_xDelegatorRow->getClob(columnIndex);
 }
 
-Reference< XArray >  OResultSet::getArray(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+Reference< XArray >  OResultSet::getArray(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -550,7 +546,7 @@ Reference< XArray >  OResultSet::getArray(sal_Int32 columnIndex) throw( SQLExcep
 }
 
 // css::sdbc::XRowUpdate
-void OResultSet::updateNull(sal_Int32 columnIndex) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateNull(sal_Int32 columnIndex)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -560,7 +556,7 @@ void OResultSet::updateNull(sal_Int32 columnIndex) throw( SQLException, RuntimeE
     m_xDelegatorRowUpdate->updateNull(columnIndex);
 }
 
-void OResultSet::updateBoolean(sal_Int32 columnIndex, sal_Bool x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateBoolean(sal_Int32 columnIndex, sal_Bool x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -570,7 +566,7 @@ void OResultSet::updateBoolean(sal_Int32 columnIndex, sal_Bool x) throw( SQLExce
     m_xDelegatorRowUpdate->updateBoolean(columnIndex, x);
 }
 
-void OResultSet::updateByte(sal_Int32 columnIndex, sal_Int8 x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateByte(sal_Int32 columnIndex, sal_Int8 x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -580,7 +576,7 @@ void OResultSet::updateByte(sal_Int32 columnIndex, sal_Int8 x) throw( SQLExcepti
     m_xDelegatorRowUpdate->updateByte(columnIndex, x);
 }
 
-void OResultSet::updateShort(sal_Int32 columnIndex, sal_Int16 x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateShort(sal_Int32 columnIndex, sal_Int16 x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -590,7 +586,7 @@ void OResultSet::updateShort(sal_Int32 columnIndex, sal_Int16 x) throw( SQLExcep
     m_xDelegatorRowUpdate->updateShort(columnIndex, x);
 }
 
-void OResultSet::updateInt(sal_Int32 columnIndex, sal_Int32 x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateInt(sal_Int32 columnIndex, sal_Int32 x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -600,7 +596,7 @@ void OResultSet::updateInt(sal_Int32 columnIndex, sal_Int32 x) throw( SQLExcepti
     m_xDelegatorRowUpdate->updateInt(columnIndex, x);
 }
 
-void OResultSet::updateLong(sal_Int32 columnIndex, sal_Int64 x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateLong(sal_Int32 columnIndex, sal_Int64 x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -610,7 +606,7 @@ void OResultSet::updateLong(sal_Int32 columnIndex, sal_Int64 x) throw( SQLExcept
     m_xDelegatorRowUpdate->updateLong(columnIndex, x);
 }
 
-void OResultSet::updateFloat(sal_Int32 columnIndex, float x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateFloat(sal_Int32 columnIndex, float x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -620,7 +616,7 @@ void OResultSet::updateFloat(sal_Int32 columnIndex, float x) throw( SQLException
     m_xDelegatorRowUpdate->updateFloat(columnIndex, x);
 }
 
-void OResultSet::updateDouble(sal_Int32 columnIndex, double x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateDouble(sal_Int32 columnIndex, double x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -630,7 +626,7 @@ void OResultSet::updateDouble(sal_Int32 columnIndex, double x) throw( SQLExcepti
     m_xDelegatorRowUpdate->updateDouble(columnIndex, x);
 }
 
-void OResultSet::updateString(sal_Int32 columnIndex, const OUString& x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateString(sal_Int32 columnIndex, const OUString& x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -640,7 +636,7 @@ void OResultSet::updateString(sal_Int32 columnIndex, const OUString& x) throw( S
     m_xDelegatorRowUpdate->updateString(columnIndex, x);
 }
 
-void OResultSet::updateBytes(sal_Int32 columnIndex, const Sequence< sal_Int8 >& x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateBytes(sal_Int32 columnIndex, const Sequence< sal_Int8 >& x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -650,7 +646,7 @@ void OResultSet::updateBytes(sal_Int32 columnIndex, const Sequence< sal_Int8 >&
     m_xDelegatorRowUpdate->updateBytes(columnIndex, x);
 }
 
-void OResultSet::updateDate(sal_Int32 columnIndex, const css::util::Date& x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateDate(sal_Int32 columnIndex, const css::util::Date& x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -660,7 +656,7 @@ void OResultSet::updateDate(sal_Int32 columnIndex, const css::util::Date& x) thr
     m_xDelegatorRowUpdate->updateDate(columnIndex, x);
 }
 
-void OResultSet::updateTime(sal_Int32 columnIndex, const css::util::Time& x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateTime(sal_Int32 columnIndex, const css::util::Time& x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -670,7 +666,7 @@ void OResultSet::updateTime(sal_Int32 columnIndex, const css::util::Time& x) thr
     m_xDelegatorRowUpdate->updateTime(columnIndex, x);
 }
 
-void OResultSet::updateTimestamp(sal_Int32 columnIndex, const css::util::DateTime& x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateTimestamp(sal_Int32 columnIndex, const css::util::DateTime& x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -680,7 +676,7 @@ void OResultSet::updateTimestamp(sal_Int32 columnIndex, const css::util::DateTim
     m_xDelegatorRowUpdate->updateTimestamp(columnIndex, x);
 }
 
-void OResultSet::updateBinaryStream(sal_Int32 columnIndex, const Reference< css::io::XInputStream > & x, sal_Int32 length) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateBinaryStream(sal_Int32 columnIndex, const Reference< css::io::XInputStream > & x, sal_Int32 length)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -690,7 +686,7 @@ void OResultSet::updateBinaryStream(sal_Int32 columnIndex, const Reference< css:
     m_xDelegatorRowUpdate->updateBinaryStream(columnIndex, x, length);
 }
 
-void OResultSet::updateCharacterStream(sal_Int32 columnIndex, const Reference< css::io::XInputStream > & x, sal_Int32 length) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateCharacterStream(sal_Int32 columnIndex, const Reference< css::io::XInputStream > & x, sal_Int32 length)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -700,7 +696,7 @@ void OResultSet::updateCharacterStream(sal_Int32 columnIndex, const Reference< c
     m_xDelegatorRowUpdate->updateCharacterStream(columnIndex, x, length);
 }
 
-void OResultSet::updateNumericObject(sal_Int32 columnIndex, const Any& x, sal_Int32 scale) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateNumericObject(sal_Int32 columnIndex, const Any& x, sal_Int32 scale)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -710,7 +706,7 @@ void OResultSet::updateNumericObject(sal_Int32 columnIndex, const Any& x, sal_In
     m_xDelegatorRowUpdate->updateNumericObject(columnIndex, x, scale);
 }
 
-void OResultSet::updateObject(sal_Int32 columnIndex, const Any& x) throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateObject(sal_Int32 columnIndex, const Any& x)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -721,7 +717,7 @@ void OResultSet::updateObject(sal_Int32 columnIndex, const Any& x) throw( SQLExc
 }
 
 // css::sdbc::XResultSet
-sal_Bool OResultSet::next() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::next()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -729,7 +725,7 @@ sal_Bool OResultSet::next() throw( SQLException, RuntimeException, std::exceptio
     return m_xDelegatorResultSet->next();
 }
 
-sal_Bool OResultSet::isBeforeFirst() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::isBeforeFirst()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -737,7 +733,7 @@ sal_Bool OResultSet::isBeforeFirst() throw( SQLException, RuntimeException, std:
     return m_xDelegatorResultSet->isBeforeFirst();
 }
 
-sal_Bool OResultSet::isAfterLast() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::isAfterLast()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -745,7 +741,7 @@ sal_Bool OResultSet::isAfterLast() throw( SQLException, RuntimeException, std::e
     return m_xDelegatorResultSet->isAfterLast();
 }
 
-sal_Bool OResultSet::isFirst() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::isFirst()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -753,7 +749,7 @@ sal_Bool OResultSet::isFirst() throw( SQLException, RuntimeException, std::excep
     return m_xDelegatorResultSet->isFirst();
 }
 
-sal_Bool OResultSet::isLast() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::isLast()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -761,7 +757,7 @@ sal_Bool OResultSet::isLast() throw( SQLException, RuntimeException, std::except
     return m_xDelegatorResultSet->isLast();
 }
 
-void OResultSet::beforeFirst() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::beforeFirst()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -769,7 +765,7 @@ void OResultSet::beforeFirst() throw( SQLException, RuntimeException, std::excep
     m_xDelegatorResultSet->beforeFirst();
 }
 
-void OResultSet::afterLast() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::afterLast()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -777,7 +773,7 @@ void OResultSet::afterLast() throw( SQLException, RuntimeException, std::excepti
     m_xDelegatorResultSet->afterLast();
 }
 
-sal_Bool OResultSet::first() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::first()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -785,7 +781,7 @@ sal_Bool OResultSet::first() throw( SQLException, RuntimeException, std::excepti
     return m_xDelegatorResultSet->first();
 }
 
-sal_Bool OResultSet::last() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::last()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -793,7 +789,7 @@ sal_Bool OResultSet::last() throw( SQLException, RuntimeException, std::exceptio
     return m_xDelegatorResultSet->last();
 }
 
-sal_Int32 OResultSet::getRow() throw( SQLException, RuntimeException, std::exception )
+sal_Int32 OResultSet::getRow()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -801,7 +797,7 @@ sal_Int32 OResultSet::getRow() throw( SQLException, RuntimeException, std::excep
     return m_xDelegatorResultSet->getRow();
 }
 
-sal_Bool OResultSet::absolute(sal_Int32 row) throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::absolute(sal_Int32 row)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -809,7 +805,7 @@ sal_Bool OResultSet::absolute(sal_Int32 row) throw( SQLException, RuntimeExcepti
     return m_xDelegatorResultSet->absolute(row);
 }
 
-sal_Bool OResultSet::relative(sal_Int32 rows) throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::relative(sal_Int32 rows)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -817,7 +813,7 @@ sal_Bool OResultSet::relative(sal_Int32 rows) throw( SQLException, RuntimeExcept
     return m_xDelegatorResultSet->relative(rows);
 }
 
-sal_Bool OResultSet::previous() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::previous()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -825,7 +821,7 @@ sal_Bool OResultSet::previous() throw( SQLException, RuntimeException, std::exce
     return m_xDelegatorResultSet->previous();
 }
 
-void OResultSet::refreshRow() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::refreshRow()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -833,7 +829,7 @@ void OResultSet::refreshRow() throw( SQLException, RuntimeException, std::except
     m_xDelegatorResultSet->refreshRow();
 }
 
-sal_Bool OResultSet::rowUpdated() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::rowUpdated()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -841,7 +837,7 @@ sal_Bool OResultSet::rowUpdated() throw( SQLException, RuntimeException, std::ex
     return m_xDelegatorResultSet->rowUpdated();
 }
 
-sal_Bool OResultSet::rowInserted() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::rowInserted()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -849,7 +845,7 @@ sal_Bool OResultSet::rowInserted() throw( SQLException, RuntimeException, std::e
     return m_xDelegatorResultSet->rowInserted();
 }
 
-sal_Bool OResultSet::rowDeleted() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::rowDeleted()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -857,7 +853,7 @@ sal_Bool OResultSet::rowDeleted() throw( SQLException, RuntimeException, std::ex
     return m_xDelegatorResultSet->rowDeleted();
 }
 
-Reference< XInterface > OResultSet::getStatement() throw( SQLException, RuntimeException, std::exception )
+Reference< XInterface > OResultSet::getStatement()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -866,7 +862,7 @@ Reference< XInterface > OResultSet::getStatement() throw( SQLException, RuntimeE
 }
 
 // css::sdbcx::XRowLocate
-Any OResultSet::getBookmark() throw( SQLException, RuntimeException, std::exception )
+Any OResultSet::getBookmark()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -876,7 +872,7 @@ Any OResultSet::getBookmark() throw( SQLException, RuntimeException, std::except
     return Reference< XRowLocate >(m_xDelegatorResultSet, UNO_QUERY)->getBookmark();
 }
 
-sal_Bool OResultSet::moveToBookmark(const Any& bookmark) throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::moveToBookmark(const Any& bookmark)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -886,7 +882,7 @@ sal_Bool OResultSet::moveToBookmark(const Any& bookmark) throw( SQLException, Ru
     return Reference< XRowLocate >(m_xDelegatorResultSet, UNO_QUERY)->moveToBookmark(bookmark);
 }
 
-sal_Bool OResultSet::moveRelativeToBookmark(const Any& bookmark, sal_Int32 rows) throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::moveRelativeToBookmark(const Any& bookmark, sal_Int32 rows)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -896,7 +892,7 @@ sal_Bool OResultSet::moveRelativeToBookmark(const Any& bookmark, sal_Int32 rows)
     return Reference< XRowLocate >(m_xDelegatorResultSet, UNO_QUERY)->moveRelativeToBookmark(bookmark, rows);
 }
 
-sal_Int32 OResultSet::compareBookmarks(const Any& _first, const Any& _second) throw( SQLException, RuntimeException, std::exception )
+sal_Int32 OResultSet::compareBookmarks(const Any& _first, const Any& _second)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -906,7 +902,7 @@ sal_Int32 OResultSet::compareBookmarks(const Any& _first, const Any& _second) th
     return Reference< XRowLocate >(m_xDelegatorResultSet, UNO_QUERY)->compareBookmarks(_first, _second);
 }
 
-sal_Bool OResultSet::hasOrderedBookmarks() throw( SQLException, RuntimeException, std::exception )
+sal_Bool OResultSet::hasOrderedBookmarks()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -916,7 +912,7 @@ sal_Bool OResultSet::hasOrderedBookmarks() throw( SQLException, RuntimeException
     return Reference< XRowLocate >(m_xDelegatorResultSet, UNO_QUERY)->hasOrderedBookmarks();
 }
 
-sal_Int32 OResultSet::hashBookmark(const Any& bookmark) throw( SQLException, RuntimeException, std::exception )
+sal_Int32 OResultSet::hashBookmark(const Any& bookmark)
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -927,7 +923,7 @@ sal_Int32 OResultSet::hashBookmark(const Any& bookmark) throw( SQLException, Run
 }
 
 // css::sdbc::XResultSetUpdate
-void OResultSet::insertRow() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::insertRow()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -937,7 +933,7 @@ void OResultSet::insertRow() throw( SQLException, RuntimeException, std::excepti
     m_xDelegatorResultSetUpdate->insertRow();
 }
 
-void OResultSet::updateRow() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::updateRow()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -947,7 +943,7 @@ void OResultSet::updateRow() throw( SQLException, RuntimeException, std::excepti
     m_xDelegatorResultSetUpdate->updateRow();
 }
 
-void OResultSet::deleteRow() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::deleteRow()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -957,7 +953,7 @@ void OResultSet::deleteRow() throw( SQLException, RuntimeException, std::excepti
     m_xDelegatorResultSetUpdate->deleteRow();
 }
 
-void OResultSet::cancelRowUpdates() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::cancelRowUpdates()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -967,7 +963,7 @@ void OResultSet::cancelRowUpdates() throw( SQLException, RuntimeException, std::
     m_xDelegatorResultSetUpdate->cancelRowUpdates();
 }
 
-void OResultSet::moveToInsertRow() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::moveToInsertRow()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -977,7 +973,7 @@ void OResultSet::moveToInsertRow() throw( SQLException, RuntimeException, std::e
     m_xDelegatorResultSetUpdate->moveToInsertRow();
 }
 
-void OResultSet::moveToCurrentRow() throw( SQLException, RuntimeException, std::exception )
+void OResultSet::moveToCurrentRow()
 {
     MutexGuard aGuard(m_aMutex);
     ::connectivity::checkDisposed(OResultSetBase::rBHelper.bDisposed);
@@ -992,13 +988,13 @@ void OResultSet::checkReadOnly() const
     if  (   ( m_nResultSetConcurrency == ResultSetConcurrency::READ_ONLY )
         ||  !m_xDelegatorResultSetUpdate.is()
         )
-        throwSQLException( "The result set is read-only.", SQL_GENERAL_ERROR, *const_cast< OResultSet* >( this ) );
+        throwSQLException( "The result set is read-only.", StandardSQLState::GENERAL_ERROR, *const_cast< OResultSet* >( this ) );
 }
 
 void OResultSet::checkBookmarkable() const
 {
     if ( !m_bIsBookmarkable )
-        throwSQLException( "The result set does not have bookmark support.", SQL_GENERAL_ERROR, *const_cast< OResultSet* >( this ) );
+        throwSQLException( "The result set does not have bookmark support.", StandardSQLState::GENERAL_ERROR, *const_cast< OResultSet* >( this ) );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
