@@ -26,7 +26,6 @@ namespace sdbtools
 
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::sdbc::XConnection;
-    using ::com::sun::star::sdbc::SQLException;
     using ::com::sun::star::uno::RuntimeException;
     using ::com::sun::star::uno::XComponentContext;
 
@@ -41,7 +40,7 @@ namespace sdbtools
     {
     }
 
-    sal_Bool SAL_CALL DataSourceMetaData::supportsQueriesInFrom(  ) throw (RuntimeException, SQLException, std::exception)
+    sal_Bool SAL_CALL DataSourceMetaData::supportsQueriesInFrom(  )
     {
         EntryGuard aGuard( *this );
         ::dbtools::DatabaseMetaData aMeta( getConnection() );
