@@ -25,8 +25,7 @@
 #include <comphelper/namedvaluecollection.hxx>
 #include <sfx2/app.hxx>
 #include <dbaccess/IController.hxx>
-#include "UITools.hxx"
-#include <sfx2/sfx.hrc>
+#include <UITools.hxx>
 #include <svtools/acceleratorexecute.hxx>
 #include <svtools/imgdef.hxx>
 #include <tools/diagnose_ex.h>
