@@ -17,8 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sbagrid.hrc"
-#include "uiservices.hxx"
+#include <sbagrid.hrc>
+#include <core_resource.hxx>
+#include <helpids.h>
+#include <uiservices.hxx>
 
 #include <sot/exchange.hxx>
 #include <svx/svxids.hrc>
@@ -27,9 +29,9 @@
 #include <svx/dbaexchange.hxx>
 #include <com/sun/star/ui/dialogs/XExecutableDialog.hpp>
 
-#include "sbagrid.hxx"
-#include "dlgattr.hxx"
-#include "dlgsize.hxx"
+#include <sbagrid.hxx>
+#include <dlgattr.hxx>
+#include <dlgsize.hxx>
 #include <com/sun/star/form/XLoadable.hpp>
 #include <com/sun/star/form/ControlFontDialog.hpp>
 #include <com/sun/star/sdb/CommandType.hpp>
@@ -69,18 +71,19 @@
 #include <com/sun/star/sdbcx/XTablesSupplier.hpp>
 #include <com/sun/star/sdbc/DataType.hpp>
 #include <vcl/msgbox.hxx>
-#include "dbu_brw.hrc"
-#include "browserids.hxx"
-#include "dbustrings.hrc"
-#include "dbu_reghelper.hxx"
-#include "dbexchange.hxx"
-#include "TableRowExchange.hxx"
-#include "TableRow.hxx"
-#include "FieldDescriptions.hxx"
+#include <browserids.hxx>
+#include <stringconstants.hxx>
+#include <strings.hrc>
+#include <strings.hxx>
+#include <dbu_reghelper.hxx>
+#include <dbexchange.hxx>
+#include <TableRowExchange.hxx>
+#include <TableRow.hxx>
+#include <FieldDescriptions.hxx>
 #include <svtools/stringtransfer.hxx>
 #include <vcl/stdtext.hxx>
-#include "UITools.hxx"
-#include "TokenWriter.hxx"
+#include <UITools.hxx>
+#include <TokenWriter.hxx>
 #include <osl/diagnose.h>
 #include <algorithm>
 
@@ -107,7 +110,7 @@ extern "C" void SAL_CALL createRegistryInfo_SbaXGridControl()
     static OMultiInstanceAutoRegistration< SbaXGridControl > aAutoRegistration;
 }
 
-css::uno::Sequence<OUString> SAL_CALL SbaXGridControl::getSupportedServiceNames() throw(std::exception)
+css::uno::Sequence<OUString> SAL_CALL SbaXGridControl::getSupportedServiceNames()
 {
     return getSupportedServiceNames_Static();
 }
@@ -119,17 +122,17 @@ Reference< XInterface > SAL_CALL SbaXGridControl::Create(const Reference<XMultiS
 
 // SbaXGridControl
 
-OUString SAL_CALL SbaXGridControl::getImplementationName() throw(std::exception)
+OUString SAL_CALL SbaXGridControl::getImplementationName()
 {
     return getImplementationName_Static();
 }
 
-OUString SbaXGridControl::getImplementationName_Static() throw( RuntimeException )
+OUString SbaXGridControl::getImplementationName_Static()
 {
     return OUString("com.sun.star.comp.dbu.SbaXGridControl");
 }
 
-Sequence< OUString> SbaXGridControl::getSupportedServiceNames_Static() throw( RuntimeException )
+Sequence< OUString> SbaXGridControl::getSupportedServiceNames_Static()
 {
     Sequence< OUString> aSupported(3);
     aSupported[0] = "com.sun.star.form.control.InteractionGridControl";
@@ -171,13 +174,13 @@ FmXGridPeer* SbaXGridControl::imp_CreatePeer(vcl::Window* pParent)
     return pReturn;
 }
 
-Any SAL_CALL SbaXGridControl::queryInterface(const Type& _rType) throw (RuntimeException, std::exception)
+Any SAL_CALL SbaXGridControl::queryInterface(const Type& _rType)
 {
     Any aRet = FmXGridControl::queryInterface(_rType);
     return aRet.hasValue() ? aRet : ::cppu::queryInterface(_rType,static_cast<css::frame::XDispatch*>(this));
 }
 
-Sequence< Type > SAL_CALL SbaXGridControl::getTypes(  ) throw (RuntimeException, std::exception)
+Sequence< Type > SAL_CALL SbaXGridControl::getTypes(  )
 {
     Sequence< Type > aTypes = FmXGridControl::getTypes();
 
@@ -188,12 +191,12 @@ Sequence< Type > SAL_CALL SbaXGridControl::getTypes(  ) throw (RuntimeException,
     return aTypes;
 }
 
-Sequence< sal_Int8 > SAL_CALL SbaXGridControl::getImplementationId(  ) throw (RuntimeException, std::exception)
+Sequence< sal_Int8 > SAL_CALL SbaXGridControl::getImplementationId(  )
 {
     return css::uno::Sequence<sal_Int8>();
 }
 
-void SAL_CALL SbaXGridControl::createPeer(const Reference< css::awt::XToolkit > & rToolkit, const Reference< css::awt::XWindowPeer > & rParentPeer) throw( RuntimeException, std::exception )
+void SAL_CALL SbaXGridControl::createPeer(const Reference< css::awt::XToolkit > & rToolkit, const Reference< css::awt::XWindowPeer > & rParentPeer)
 {
     FmXGridControl::createPeer(rToolkit, rParentPeer);
 
@@ -203,70 +206,68 @@ void SAL_CALL SbaXGridControl::createPeer(const Reference< css::awt::XToolkit >
     // TODO: why the hell this whole class does not use any mutex?
 
         Reference< css::frame::XDispatch >  xDisp(getPeer(), UNO_QUERY);
-        for (   StatusMultiplexerArray::iterator aIter = m_aStatusMultiplexer.begin();
+        for (   StatusMultiplexerArray::const_iterator aIter = m_aStatusMultiplexer.begin();
                 aIter != m_aStatusMultiplexer.end();
                 ++aIter)
         {
-            if ((*aIter).second && (*aIter).second->getLength())
-                xDisp->addStatusListener((*aIter).second, (*aIter).first);
+            if ((*aIter).second.is() && (*aIter).second->getLength())
+                xDisp->addStatusListener((*aIter).second.get(), (*aIter).first);
         }
 }
 
-void SAL_CALL SbaXGridControl::dispatch(const css::util::URL& aURL, const Sequence< PropertyValue >& aArgs) throw( RuntimeException, std::exception )
+void SAL_CALL SbaXGridControl::dispatch(const css::util::URL& aURL, const Sequence< PropertyValue >& aArgs)
 {
     Reference< css::frame::XDispatch >  xDisp(getPeer(), UNO_QUERY);
     if (xDisp.is())
         xDisp->dispatch(aURL, aArgs);
 }
 
-void SAL_CALL SbaXGridControl::addStatusListener( const Reference< XStatusListener > & _rxListener, const URL& _rURL ) throw( RuntimeException, std::exception )
+void SAL_CALL SbaXGridControl::addStatusListener( const Reference< XStatusListener > & _rxListener, const URL& _rURL )
 {
     ::osl::MutexGuard aGuard( GetMutex() );
     if ( _rxListener.is() )
     {
-        SbaXStatusMultiplexer*& pMultiplexer = m_aStatusMultiplexer[ _rURL ];
-        if ( !pMultiplexer )
+        rtl::Reference<SbaXStatusMultiplexer>& xMultiplexer = m_aStatusMultiplexer[ _rURL ];
+        if ( !xMultiplexer.is() )
         {
-            pMultiplexer = new SbaXStatusMultiplexer( *this, GetMutex() );
-            pMultiplexer->acquire();
+            xMultiplexer = new SbaXStatusMultiplexer( *this, GetMutex() );
         }
 
-        pMultiplexer->addInterface( _rxListener );
+        xMultiplexer->addInterface( _rxListener );
         if ( getPeer().is() )
         {
-            if ( 1 == pMultiplexer->getLength() )
+            if ( 1 == xMultiplexer->getLength() )
             {   // the first external listener for this URL
                 Reference< XDispatch >  xDisp( getPeer(), UNO_QUERY );
-                xDisp->addStatusListener( pMultiplexer, _rURL );
+                xDisp->addStatusListener( xMultiplexer.get(), _rURL );
             }
             else
             {   // already have other listeners for this URL
-                _rxListener->statusChanged( pMultiplexer->getLastEvent() );
+                _rxListener->statusChanged( xMultiplexer->getLastEvent() );
             }
         }
     }
 }
 
-void SAL_CALL SbaXGridControl::removeStatusListener(const Reference< css::frame::XStatusListener > & _rxListener, const css::util::URL& _rURL) throw( RuntimeException, std::exception )
+void SAL_CALL SbaXGridControl::removeStatusListener(const Reference< css::frame::XStatusListener > & _rxListener, const css::util::URL& _rURL)
 {
     ::osl::MutexGuard aGuard( GetMutex() );
 
-    SbaXStatusMultiplexer*& pMultiplexer = m_aStatusMultiplexer[_rURL];
-    if (!pMultiplexer)
+    rtl::Reference<SbaXStatusMultiplexer>& xMultiplexer = m_aStatusMultiplexer[_rURL];
+    if (!xMultiplexer.is())
     {
-        pMultiplexer = new SbaXStatusMultiplexer(*this,GetMutex());
-        pMultiplexer->acquire();
+        xMultiplexer = new SbaXStatusMultiplexer(*this,GetMutex());
     }
 
-    if (getPeer().is() && pMultiplexer->getLength() == 1)
+    if (getPeer().is() && xMultiplexer->getLength() == 1)
     {
         Reference< css::frame::XDispatch >  xDisp(getPeer(), UNO_QUERY);
-        xDisp->removeStatusListener(pMultiplexer, _rURL);
+        xDisp->removeStatusListener(xMultiplexer.get(), _rURL);
     }
-    pMultiplexer->removeInterface( _rxListener );
+    xMultiplexer->removeInterface( _rxListener );
 }
 
-void SAL_CALL SbaXGridControl::dispose() throw( RuntimeException, std::exception )
+void SAL_CALL SbaXGridControl::dispose()
 {
     SolarMutexGuard aGuard;
 
@@ -277,11 +278,10 @@ void SAL_CALL SbaXGridControl::dispose() throw( RuntimeException, std::exception
             aIter != m_aStatusMultiplexer.end();
             ++aIter)
     {
-        if ((*aIter).second)
+        if ((*aIter).second.is())
         {
             (*aIter).second->disposeAndClear(aEvt);
-            (*aIter).second->release();
-            (*aIter).second = nullptr;
+            (*aIter).second.clear();
         }
     }
     StatusMultiplexerArray().swap(m_aStatusMultiplexer);
@@ -300,7 +300,7 @@ SbaXGridPeer::~SbaXGridPeer()
 {
 }
 
-void SAL_CALL SbaXGridPeer::dispose() throw( RuntimeException, std::exception )
+void SAL_CALL SbaXGridPeer::dispose()
 {
     EventObject aEvt(*this);
 
@@ -324,7 +324,7 @@ void SbaXGridPeer::NotifyStatusChanged(const css::util::URL& _rUrl, const Refere
     if ( m_aDispatchStates.end() != aURLStatePos )
         aEvt.State <<= aURLStatePos->second;
     else
-        aEvt.State <<= sal_False;
+        aEvt.State <<= false;
 
     if (xControl.is())
         xControl->statusChanged(aEvt);
@@ -341,7 +341,7 @@ void SbaXGridPeer::NotifyStatusChanged(const css::util::URL& _rUrl, const Refere
     }
 }
 
-Any SAL_CALL SbaXGridPeer::queryInterface(const Type& _rType) throw (RuntimeException, std::exception)
+Any SAL_CALL SbaXGridPeer::queryInterface(const Type& _rType)
 {
     Any aRet = ::cppu::queryInterface(_rType,static_cast<css::frame::XDispatch*>(this));
     if(aRet.hasValue())
@@ -349,7 +349,7 @@ Any SAL_CALL SbaXGridPeer::queryInterface(const Type& _rType) throw (RuntimeExce
     return FmXGridPeer::queryInterface(_rType);
 }
 
-Reference< css::frame::XDispatch >  SAL_CALL SbaXGridPeer::queryDispatch(const css::util::URL& aURL, const OUString& aTargetFrameName, sal_Int32 nSearchFlags) throw( RuntimeException, std::exception )
+Reference< css::frame::XDispatch >  SAL_CALL SbaXGridPeer::queryDispatch(const css::util::URL& aURL, const OUString& aTargetFrameName, sal_Int32 nSearchFlags)
 {
     if  (   ( aURL.Complete == ".uno:GridSlots/BrowserAttribs" ) || ( aURL.Complete == ".uno:GridSlots/RowHeight" )
         ||  ( aURL.Complete == ".uno:GridSlots/ColumnAttribs" )  || ( aURL.Complete == ".uno:GridSlots/ColumnWidth" )
@@ -361,7 +361,7 @@ Reference< css::frame::XDispatch >  SAL_CALL SbaXGridPeer::queryDispatch(const c
     return FmXGridPeer::queryDispatch(aURL, aTargetFrameName, nSearchFlags);
 }
 
-IMPL_LINK_NOARG_TYPED( SbaXGridPeer, OnDispatchEvent, void*, void )
+IMPL_LINK_NOARG( SbaXGridPeer, OnDispatchEvent, void*, void )
 {
     VclPtr< SbaGridControl > pGrid = GetAs< SbaGridControl >();
     if ( pGrid )    // if this fails, we were disposing before arriving here
@@ -396,7 +396,7 @@ SbaXGridPeer::DispatchType SbaXGridPeer::classifyDispatchURL( const URL& _rURL )
     return eURLType;
 }
 
-void SAL_CALL SbaXGridPeer::dispatch(const URL& aURL, const Sequence< PropertyValue >& aArgs) throw( RuntimeException, std::exception )
+void SAL_CALL SbaXGridPeer::dispatch(const URL& aURL, const Sequence< PropertyValue >& aArgs)
 {
     VclPtr< SbaGridControl > pGrid = GetAs< SbaGridControl >();
     if (!pGrid)
@@ -452,7 +452,7 @@ void SAL_CALL SbaXGridPeer::dispatch(const URL& aURL, const Sequence< PropertyVa
     if ( dtUnknown != eURLType )
     {
         // notify any status listeners that the dialog is now active (well, about to be active)
-        MapDispatchToBool::iterator aThisURLState = m_aDispatchStates.insert( MapDispatchToBool::value_type( eURLType, sal_True ) ).first;
+        MapDispatchToBool::const_iterator aThisURLState = m_aDispatchStates.emplace( eURLType, true ).first;
         NotifyStatusChanged( aURL, nullptr );
 
         // execute the dialog
@@ -494,7 +494,7 @@ void SAL_CALL SbaXGridPeer::dispatch(const URL& aURL, const Sequence< PropertyVa
     }
 }
 
-void SAL_CALL SbaXGridPeer::addStatusListener(const Reference< css::frame::XStatusListener > & xControl, const css::util::URL& aURL) throw( RuntimeException, std::exception )
+void SAL_CALL SbaXGridPeer::addStatusListener(const Reference< css::frame::XStatusListener > & xControl, const css::util::URL& aURL)
 {
     ::cppu::OInterfaceContainerHelper* pCont = m_aStatusListeners.getContainer(aURL);
     if (!pCont)
@@ -504,7 +504,7 @@ void SAL_CALL SbaXGridPeer::addStatusListener(const Reference< css::frame::XStat
     NotifyStatusChanged(aURL, xControl);
 }
 
-void SAL_CALL SbaXGridPeer::removeStatusListener(const Reference< css::frame::XStatusListener > & xControl, const css::util::URL& aURL) throw( RuntimeException, std::exception )
+void SAL_CALL SbaXGridPeer::removeStatusListener(const Reference< css::frame::XStatusListener > & xControl, const css::util::URL& aURL)
 {
     ::cppu::OInterfaceContainerHelper* pCont = m_aStatusListeners.getContainer(aURL);
     if ( pCont )
@@ -521,7 +521,7 @@ const Sequence< sal_Int8 > & SbaXGridPeer::getUnoTunnelId()
     return theSbaXGridPeerUnoTunnelId::get().getSeq();
 }
 
-Sequence< Type > SAL_CALL SbaXGridPeer::getTypes() throw (RuntimeException, std::exception)
+Sequence< Type > SAL_CALL SbaXGridPeer::getTypes()
 {
     Sequence< Type > aTypes = FmXGridPeer::getTypes();
     sal_Int32 nOldLen = aTypes.getLength();
@@ -532,7 +532,7 @@ Sequence< Type > SAL_CALL SbaXGridPeer::getTypes() throw (RuntimeException, std:
 }
 
 // return implementation specific data
-sal_Int64 SAL_CALL SbaXGridPeer::getSomething( const Sequence< sal_Int8 > & rId ) throw(css::uno::RuntimeException, std::exception)
+sal_Int64 SAL_CALL SbaXGridPeer::getSomething( const Sequence< sal_Int8 > & rId )
 {
     if( rId.getLength() == 16 && 0 == memcmp( getUnoTunnelId().getConstArray(),  rId.getConstArray(), 16 ) )
         return reinterpret_cast< sal_Int64 >( this );
@@ -556,16 +556,27 @@ VclPtr<FmGridControl> SbaXGridPeer::imp_CreateControl(vcl::Window* pParent, WinB
 
 // SbaGridHeader
 
-SbaGridHeader::SbaGridHeader(BrowseBox* pParent, WinBits nWinBits)
-    :FmGridHeader(pParent, nWinBits)
+SbaGridHeader::SbaGridHeader(BrowseBox* pParent)
+    :FmGridHeader(pParent, WB_STDHEADERBAR | WB_DRAG)
     ,DragSourceHelper(this)
 {
 }
 
+SbaGridHeader::~SbaGridHeader()
+{
+    disposeOnce();
+}
+
+void SbaGridHeader::dispose()
+{
+    DragSourceHelper::dispose();
+    FmGridHeader::dispose();
+}
+
 void SbaGridHeader::StartDrag( sal_Int8 _nAction, const Point& _rPosPixel )
 {
     SolarMutexGuard aGuard;
-        // in the new DnD API, the solar mutex is not locked when StartDrag get's called
+        // in the new DnD API, the solar mutex is not locked when StartDrag is called
 
     ImplStartColumnDrag( _nAction, _rPosPixel );
 }
@@ -576,27 +587,27 @@ void SbaGridHeader::MouseButtonDown( const MouseEvent& _rMEvt )
         if (_rMEvt.GetClicks() != 2)
         {
             // the base class will start a column move here, which we don't want to allow
-            // (at the moment. If we store relative positions with the columns, we can allow column moves ....)
+            // (at the moment. If we store relative positions with the columns, we can allow column moves...)
 
         }
 
     FmGridHeader::MouseButtonDown(_rMEvt);
 }
 
-bool SbaGridHeader::ImplStartColumnDrag(sal_Int8 _nAction, const Point& _rMousePos)
+void SbaGridHeader::ImplStartColumnDrag(sal_Int8 _nAction, const Point& _rMousePos)
 {
     sal_uInt16 nId = GetItemId(_rMousePos);
     bool bResizingCol = false;
     if (HEADERBAR_ITEM_NOTFOUND != nId)
     {
-        Rectangle aColRect = GetItemRect(nId);
+        tools::Rectangle aColRect = GetItemRect(nId);
         aColRect.Left() += nId ? 3 : 0; // the handle col (nId == 0) does not have a left margin for resizing
         aColRect.Right() -= 3;
         bResizingCol = !aColRect.IsInside(_rMousePos);
     }
     if (!bResizingCol)
     {
-        // force the base class to end it's drag mode
+        // force the base class to end its drag mode
         EndTracking(TrackingEventFlags::Cancel | TrackingEventFlags::End);
 
         // because we have 3d-buttons the select handler is called from MouseButtonUp, but StartDrag
@@ -610,10 +621,7 @@ bool SbaGridHeader::ImplStartColumnDrag(sal_Int8 _nAction, const Point& _rMouseP
                     _rMousePos.Y() - GetSizePixel().Height()
                 )
             );
-        return true;
     }
-
-    return false;
 }
 
 void SbaGridHeader::PreExecuteColumnContextMenu(sal_uInt16 nColId, PopupMenu& rMenu)
@@ -625,16 +633,16 @@ void SbaGridHeader::PreExecuteColumnContextMenu(sal_uInt16 nColId, PopupMenu& rM
 
     if (bDBIsReadOnly)
     {
-        rMenu.EnableItem(SID_FM_HIDECOL, false);
-        PopupMenu* pShowColsMenu = rMenu.GetPopupMenu(SID_FM_SHOWCOLS);
+        rMenu.EnableItem(rMenu.GetItemId("hide"), false);
+        PopupMenu* pShowColsMenu = rMenu.GetPopupMenu(rMenu.GetItemId("show"));
         if (pShowColsMenu)
         {
             // at most 16 items which mean "show column <name>"
             for (sal_uInt16 i=1; i<16; ++i)
                 pShowColsMenu->EnableItem(i, false);
             // "show cols/more..." and "show cols/all"
-            pShowColsMenu->EnableItem(SID_FM_SHOWCOLS_MORE, false);
-            pShowColsMenu->EnableItem(SID_FM_SHOWALLCOLS, false);
+            pShowColsMenu->EnableItem(pShowColsMenu->GetItemId("more"), false);
+            pShowColsMenu->EnableItem(pShowColsMenu->GetItemId("all"), false);
         }
     }
 
@@ -642,7 +650,6 @@ void SbaGridHeader::PreExecuteColumnContextMenu(sal_uInt16 nColId, PopupMenu& rM
     bool bColAttrs = (nColId != (sal_uInt16)-1) && (nColId != 0);
     if ( bColAttrs && !bDBIsReadOnly)
     {
-        PopupMenu aNewItems(ModuleRes(RID_SBA_GRID_COLCTXMENU));
         sal_uInt16 nPos = 0;
         sal_uInt16 nModelPos = static_cast<SbaGridControl*>(GetParent())->GetModelColumnPos(nColId);
         Reference< XPropertySet >  xField = static_cast<SbaGridControl*>(GetParent())->getField(nModelPos);
@@ -661,14 +668,14 @@ void SbaGridHeader::PreExecuteColumnContextMenu(sal_uInt16 nColId, PopupMenu& rM
             case DataType::REF:
                 break;
             default:
-                rMenu.InsertItem(ID_BROWSER_COLATTRSET, aNewItems.GetItemText(ID_BROWSER_COLATTRSET), MenuItemBits::NONE, OString(), nPos++);
-                rMenu.SetHelpId(ID_BROWSER_COLATTRSET, aNewItems.GetHelpId(ID_BROWSER_COLATTRSET));
+                rMenu.InsertItem(ID_BROWSER_COLATTRSET, DBA_RES(RID_STR_COLUMN_FORMAT), MenuItemBits::NONE, OString(), nPos++);
+                rMenu.SetHelpId(ID_BROWSER_COLATTRSET, HID_BROWSER_COLUMNFORMAT);
                 rMenu.InsertSeparator(OString(), nPos++);
             }
         }
 
-        rMenu.InsertItem(ID_BROWSER_COLWIDTH, aNewItems.GetItemText(ID_BROWSER_COLWIDTH), MenuItemBits::NONE, OString(), nPos++);
-        rMenu.SetHelpId(ID_BROWSER_COLWIDTH, aNewItems.GetHelpId(ID_BROWSER_COLWIDTH));
+        rMenu.InsertItem(ID_BROWSER_COLWIDTH, DBA_RES(RID_STR_COLUMN_WIDTH), MenuItemBits::NONE, OString(), nPos++);
+        rMenu.SetHelpId(ID_BROWSER_COLWIDTH, HID_BROWSER_COLUMNWIDTH);
         rMenu.InsertSeparator(OString(), nPos++);
     }
 }
@@ -691,11 +698,10 @@ void SbaGridHeader::PostExecuteColumnContextMenu(sal_uInt16 nColId, const PopupM
 
                 if(!xField.is())
                     break;
-                ::std::vector< std::shared_ptr<OTableRow> > vClipboardList;
+                std::vector< std::shared_ptr<OTableRow> > vClipboardList;
                 // send it to the clipboard
-                vClipboardList.push_back(std::shared_ptr<OTableRow>(new OTableRow(xField)));
-                OTableRowExchange* pData = new OTableRowExchange(vClipboardList);
-                Reference< css::datatransfer::XTransferable> xRef = pData;
+                vClipboardList.push_back(std::make_shared<OTableRow>(xField));
+                rtl::Reference<OTableRowExchange> pData = new OTableRowExchange(vClipboardList);
                 pData->CopyToClipboard(GetParent());
             }
             break;
@@ -705,7 +711,7 @@ void SbaGridHeader::PostExecuteColumnContextMenu(sal_uInt16 nColId, const PopupM
 }
 
 // SbaGridControl
-SbaGridControl::SbaGridControl(Reference< XComponentContext > _rM,
+SbaGridControl::SbaGridControl(Reference< XComponentContext > const & _rM,
                                vcl::Window* pParent, FmXGridPeer* _pPeer, WinBits nBits)
     :FmGridControl(_rM,pParent, _pPeer, nBits)
     ,m_pMasterListener(nullptr)
@@ -743,24 +749,21 @@ void SbaGridControl::PreExecuteRowContextMenu(sal_uInt16 nRow, PopupMenu& rMenu)
 {
     FmGridControl::PreExecuteRowContextMenu(nRow, rMenu);
 
-    PopupMenu aNewItems(ModuleRes(RID_SBA_GRID_ROWCTXMENU));
     sal_uInt16 nPos = 0;
 
     if (!IsReadOnlyDB())
     {
-        rMenu.InsertItem(ID_BROWSER_TABLEATTR, aNewItems.GetItemText(ID_BROWSER_TABLEATTR), MenuItemBits::NONE, OString(), nPos++);
-        rMenu.SetHelpId(ID_BROWSER_TABLEATTR, aNewItems.GetHelpId(ID_BROWSER_TABLEATTR));
+        rMenu.InsertItem(ID_BROWSER_TABLEATTR, DBA_RES(RID_STR_TABLE_FORMAT), MenuItemBits::NONE, OString(), nPos++);
+        rMenu.SetHelpId(ID_BROWSER_TABLEATTR, HID_BROWSER_TABLEFORMAT);
 
-        rMenu.InsertItem(ID_BROWSER_ROWHEIGHT, aNewItems.GetItemText(ID_BROWSER_ROWHEIGHT), MenuItemBits::NONE, OString(), nPos++);
-        rMenu.SetHelpId(ID_BROWSER_ROWHEIGHT, aNewItems.GetHelpId(ID_BROWSER_ROWHEIGHT));
+        rMenu.InsertItem(ID_BROWSER_ROWHEIGHT, DBA_RES(RID_STR_ROW_HEIGHT), MenuItemBits::NONE, OString(), nPos++);
+        rMenu.SetHelpId(ID_BROWSER_ROWHEIGHT, HID_BROWSER_ROWHEIGHT);
         rMenu.InsertSeparator(OString(), nPos++);
     }
 
     if ( GetSelectRowCount() > 0 )
     {
-        rMenu.InsertItem(ID_BROWSER_COPY, aNewItems.GetItemText(SID_COPY), MenuItemBits::NONE, OString(), nPos++);
-        rMenu.SetHelpId(ID_BROWSER_COPY, aNewItems.GetHelpId(SID_COPY));
-
+        rMenu.InsertItem(ID_BROWSER_COPY, DBA_RES(RID_STR_COPY), MenuItemBits::NONE, OString(), nPos++);
         rMenu.InsertSeparator(OString(), nPos++);
     }
 }
@@ -917,11 +920,6 @@ void SbaGridControl::Select()
         m_pMasterListener->SelectionChanged();
 }
 
-void SbaGridControl::CursorMoved()
-{
-    FmGridControl::CursorMoved();
-}
-
 void SbaGridControl::ActivateCell(long nRow, sal_uInt16 nCol, bool bSetCellFocus /*= sal_True*/ )
 {
     FmGridControl::ActivateCell(nRow, nCol, bSetCellFocus);
@@ -948,18 +946,6 @@ void SbaGridControl::onColumnChange()
         m_pMasterListener->ColumnChanged();
 }
 
-void SbaGridControl::BeforeDrop()
-{
-    if (m_pMasterListener)
-        m_pMasterListener->BeforeDrop();
-}
-
-void SbaGridControl::AfterDrop()
-{
-    if (m_pMasterListener)
-        m_pMasterListener->AfterDrop();
-}
-
 Reference< XPropertySet >  SbaGridControl::getField(sal_uInt16 nModelPos)
 {
     Reference< XPropertySet >  xEmptyReturn;
@@ -978,7 +964,7 @@ Reference< XPropertySet >  SbaGridControl::getField(sal_uInt16 nModelPos)
     }
     catch (const Exception& e)
     {
-        SAL_WARN("dbaccess", "SbaGridControl::getField Exception occurred: " << e.Message);
+        SAL_WARN("dbaccess", "SbaGridControl::getField Exception occurred: " << e);
     }
 
     return xEmptyReturn;
@@ -996,7 +982,7 @@ bool SbaGridControl::IsReadOnlyDB() const
         if (xColumns.is())
         {
             Reference< XRowSet >  xDataSource(xColumns->getParent(), UNO_QUERY);
-            ::dbtools::ensureRowSetConnection( xDataSource, getContext(), false ); // NOT SURE ABOUT FALSE
+            ::dbtools::ensureRowSetConnection( xDataSource, getContext() );
             Reference< XChild >  xConn(::dbtools::getConnection(xDataSource),UNO_QUERY);
             if (xConn.is())
             {
@@ -1013,7 +999,7 @@ bool SbaGridControl::IsReadOnlyDB() const
     }
     catch (const Exception& e)
     {
-        SAL_WARN("dbaccess", "SbaGridControl::IsReadOnlyDB Exception occurred: " << e.Message);
+        SAL_WARN("dbaccess", "SbaGridControl::IsReadOnlyDB Exception occurred: " << e);
     }
 
     return bDBIsReadOnly;
@@ -1037,7 +1023,7 @@ void SbaGridControl::MouseButtonDown( const BrowserMouseEvent& rMEvt)
 void SbaGridControl::StartDrag( sal_Int8 _nAction, const Point& _rPosPixel )
 {
     SolarMutexGuard aGuard;
-        // in the new DnD API, the solar mutex is not locked when StartDrag get's called
+        // in the new DnD API, the solar mutex is not locked when StartDrag is called
 
     bool bHandled = false;
 
@@ -1057,7 +1043,7 @@ void SbaGridControl::StartDrag( sal_Int8 _nAction, const Point& _rPosPixel )
         // so the row contains data which has no counter part within the data source
 
         long nCorrectRowCount = GetRowCount();
-        if (GetOptions() & OPT_INSERT)
+        if (GetOptions() & DbGridControlOptions::Insert)
             --nCorrectRowCount; // there is a empty row for inserting records
         if (bCurrentRowVirtual)
             --nCorrectRowCount;
@@ -1091,7 +1077,7 @@ void SbaGridControl::StartDrag( sal_Int8 _nAction, const Point& _rPosPixel )
                 SelectAll();
 
             getMouseEvent().Clear();
-            DoRowDrag((sal_Int16)nRow);
+            implTransferSelectedRows((sal_Int16)nRow, false);
 
             bHandled = true;
         }
@@ -1127,11 +1113,6 @@ void SbaGridControl::StartDrag( sal_Int8 _nAction, const Point& _rPosPixel )
         FmGridControl::StartDrag(_nAction, _rPosPixel);
 }
 
-void SbaGridControl::Command(const CommandEvent& rEvt)
-{
-    FmGridControl::Command(rEvt);
-}
-
 void SbaGridControl::DoColumnDrag(sal_uInt16 nColumnPos)
 {
     Reference< XPropertySet >  xDataSource(getDataSource(), UNO_QUERY);
@@ -1163,8 +1144,7 @@ void SbaGridControl::DoColumnDrag(sal_uInt16 nColumnPos)
     if (sField.isEmpty())
         return;
 
-    OColumnTransferable* pDataTransfer = new OColumnTransferable(xDataSource, sField, xAffectedField, xActiveConnection, ColumnTransferFormatFlags::FIELD_DESCRIPTOR | ColumnTransferFormatFlags::COLUMN_DESCRIPTOR);
-    Reference< XTransferable > xEnsureDelete = pDataTransfer;
+    rtl::Reference<OColumnTransferable> pDataTransfer = new OColumnTransferable(xDataSource, sField, xAffectedField, xActiveConnection, ColumnTransferFormatFlags::FIELD_DESCRIPTOR | ColumnTransferFormatFlags::COLUMN_DESCRIPTOR);
     pDataTransfer->StartDrag(this, DND_ACTION_COPY | DND_ACTION_LINK);
 }
 
@@ -1174,11 +1154,6 @@ void SbaGridControl::CopySelectedRowsToClipboard()
     implTransferSelectedRows( (sal_Int16)FirstSelectedRow(), true );
 }
 
-void SbaGridControl::DoRowDrag( sal_Int16 nRowPos )
-{
-    implTransferSelectedRows( nRowPos, false );
-}
-
 void SbaGridControl::implTransferSelectedRows( sal_Int16 nRowPos, bool _bTrueIfClipboardFalseIfDrag )
 {
     Reference< XPropertySet > xForm( getDataSource(), UNO_QUERY );
@@ -1201,12 +1176,10 @@ void SbaGridControl::implTransferSelectedRows( sal_Int16 nRowPos, bool _bTrueIfC
         bSelectionBookmarks = true;
     }
 
-    Reference< XResultSet> xRowSetClone;
     try
     {
-        ODataClipboard* pTransfer = new ODataClipboard( xForm, aSelectedRows, bSelectionBookmarks, getContext() );
+        rtl::Reference<ODataClipboard> pTransfer = new ODataClipboard( xForm, aSelectedRows, bSelectionBookmarks, getContext() );
 
-        Reference< XTransferable > xEnsureDelete = pTransfer;
         if ( _bTrueIfClipboardFalseIfDrag )
             pTransfer->CopyToClipboard( this );
         else
@@ -1244,9 +1217,9 @@ void SbaGridControl::DoFieldDrag(sal_uInt16 nColumnPos, sal_Int16 nRowPos)
 }
 
 /// unary_function Functor object for class ZZ returntype is void
-    struct SbaGridControlPrec : ::std::unary_function<DataFlavorExVector::value_type,bool>
+    struct SbaGridControlPrec
     {
-        inline bool operator()(const DataFlavorExVector::value_type& _aType)
+        bool operator()(const DataFlavorExVector::value_type& _aType)
         {
             switch (_aType.mnSotId)
             {
@@ -1270,15 +1243,15 @@ sal_Int8 SbaGridControl::AcceptDrop( const BrowserAcceptDropEvent& rEvt )
     if ( IsDropFormatSupported( SotClipboardFormatId::STRING ) ) do
     {   // odd construction, but spares us a lot of (explicit ;) goto's
 
-        if (!GetEmptyRow().Is())
+        if (!GetEmptyRow().is())
             // without an empty row we're not in update mode
             break;
 
         long    nRow = GetRowAtYPosPixel(rEvt.maPosPixel.Y(), false);
-        sal_uInt16  nCol = GetColumnAtXPosPixel(rEvt.maPosPixel.X(), false);
+        sal_uInt16  nCol = GetColumnAtXPosPixel(rEvt.maPosPixel.X());
 
         long nCorrectRowCount = GetRowCount();
-        if (GetOptions() & OPT_INSERT)
+        if (GetOptions() & DbGridControlOptions::Insert)
             --nCorrectRowCount; // there is a empty row for inserting records
         if (IsCurrentAppending())
             --nCorrectRowCount; // the current data record doesn't really exist, we are appending a new one
@@ -1287,17 +1260,17 @@ sal_Int8 SbaGridControl::AcceptDrop( const BrowserAcceptDropEvent& rEvt )
             // no valid cell under the mouse cursor
             break;
 
-        Rectangle aRect = GetCellRect(nRow, nCol, false);
+        tools::Rectangle aRect = GetCellRect(nRow, nCol, false);
         if (!aRect.IsInside(rEvt.maPosPixel))
             // not dropped within a cell (a cell isn't as wide as the column - the are small spaces)
             break;
 
-        if ((IsModified() || (GetCurrentRow().Is() && GetCurrentRow()->IsModified())) && (GetCurrentPos() != nRow))
+        if ((IsModified() || (GetCurrentRow().is() && GetCurrentRow()->IsModified())) && (GetCurrentPos() != nRow))
             // there is a current and modified row or cell and he text is to be dropped into another one
             break;
 
         CellControllerRef xCurrentController = Controller();
-        if (xCurrentController.Is() && xCurrentController->IsModified() && ((nRow != GetCurRow()) || (nCol != GetCurColumnId())))
+        if (xCurrentController.is() && xCurrentController->IsModified() && ((nRow != GetCurRow()) || (nCol != GetCurColumnId())))
             // the current controller is modified and the user wants to drop in another cell -> no chance
             // (when leaving the modified cell a error may occur - this is deadly while dragging)
             break;
@@ -1312,9 +1285,8 @@ sal_Int8 SbaGridControl::AcceptDrop( const BrowserAcceptDropEvent& rEvt )
             if (::comphelper::getBOOL(xField->getPropertyValue(PROPERTY_ISREADONLY)))
                 break;
         }
-        catch (const Exception& e )
+        catch (const Exception& )
         {
-            (void)e; // make compiler happy
             // assume RO
             break;
         }
@@ -1345,10 +1317,10 @@ sal_Int8 SbaGridControl::AcceptDrop( const BrowserAcceptDropEvent& rEvt )
 
     } while (false);
 
-    if(nAction != DND_ACTION_COPY && GetEmptyRow().Is())
+    if(nAction != DND_ACTION_COPY && GetEmptyRow().is())
     {
         const DataFlavorExVector& _rFlavors = GetDataFlavors();
-        if(::std::any_of(_rFlavors.begin(),_rFlavors.end(),SbaGridControlPrec()))
+        if(std::any_of(_rFlavors.begin(),_rFlavors.end(),SbaGridControlPrec()))
             nAction = DND_ACTION_COPY;
     }
 
@@ -1369,10 +1341,10 @@ sal_Int8 SbaGridControl::ExecuteDrop( const BrowserExecuteDropEvent& rEvt )
     if ( IsDropFormatSupported( SotClipboardFormatId::STRING ) )
     {
         long    nRow = GetRowAtYPosPixel(rEvt.maPosPixel.Y(), false);
-        sal_uInt16  nCol = GetColumnAtXPosPixel(rEvt.maPosPixel.X(), false);
+        sal_uInt16  nCol = GetColumnAtXPosPixel(rEvt.maPosPixel.X());
 
         long nCorrectRowCount = GetRowCount();
-        if (GetOptions() & OPT_INSERT)
+        if (GetOptions() & DbGridControlOptions::Insert)
             --nCorrectRowCount; // there is a empty row for inserting records
         if (IsCurrentAppending())
             --nCorrectRowCount; // the current data record doesn't really exist, we are appending a new one
@@ -1388,7 +1360,7 @@ sal_Int8 SbaGridControl::ExecuteDrop( const BrowserExecuteDropEvent& rEvt )
             ActivateCell();
 
         CellControllerRef xCurrentController = Controller();
-        if (!xCurrentController.Is() || nullptr == dynamic_cast< const EditCellController* >(xCurrentController.get()))
+        if (!xCurrentController.is() || nullptr == dynamic_cast< const EditCellController* >(xCurrentController.get()))
             return DND_ACTION_NONE;
         Edit& rEdit = static_cast<Edit&>(xCurrentController->GetWindow());
 
@@ -1406,10 +1378,10 @@ sal_Int8 SbaGridControl::ExecuteDrop( const BrowserExecuteDropEvent& rEvt )
         return DND_ACTION_COPY;
     }
 
-    if(GetEmptyRow().Is())
+    if(GetEmptyRow().is())
     {
         const DataFlavorExVector& _rFlavors = GetDataFlavors();
-        if( ::std::any_of(_rFlavors.begin(),_rFlavors.end(), SbaGridControlPrec()) )
+        if( std::any_of(_rFlavors.begin(),_rFlavors.end(), SbaGridControlPrec()) )
         {
             TransferableDataHelper aDropped( rEvt.maDropEvent.Transferable );
             m_aDataDescriptor = ODataAccessObjectTransferable::extractObjectDescriptor(aDropped);
@@ -1428,14 +1400,13 @@ Reference< XPropertySet >  SbaGridControl::getDataSource() const
     Reference< XPropertySet >  xReturn;
 
     Reference< XChild >  xColumns(GetPeer()->getColumns(), UNO_QUERY);
-    Reference< XPropertySet >  xDataSource;
     if (xColumns.is())
         xReturn.set(xColumns->getParent(), UNO_QUERY);
 
     return xReturn;
 }
 
-IMPL_LINK_NOARG_TYPED(SbaGridControl, AsynchDropEvent, void*, void)
+IMPL_LINK_NOARG(SbaGridControl, AsynchDropEvent, void*, void)
 {
     m_nAsyncDropEvent = nullptr;
 
@@ -1445,32 +1416,35 @@ IMPL_LINK_NOARG_TYPED(SbaGridControl, AsynchDropEvent, void*, void)
         bool bCountFinal = false;
         xDataSource->getPropertyValue(PROPERTY_ISROWCOUNTFINAL) >>= bCountFinal;
         if ( !bCountFinal )
-            setDataSource(nullptr); // dettach from grid control
+            setDataSource(nullptr); // detach from grid control
         Reference< XResultSetUpdate > xResultSetUpdate(xDataSource,UNO_QUERY);
-        ODatabaseImportExport* pImExport = new ORowSetImportExport(this,xResultSetUpdate,m_aDataDescriptor, getContext());
-        Reference<XEventListener> xHolder = pImExport;
+        rtl::Reference<ODatabaseImportExport> pImExport = new ORowSetImportExport(this,xResultSetUpdate,m_aDataDescriptor, getContext());
         Hide();
         try
         {
             pImExport->initialize(m_aDataDescriptor);
-            BeforeDrop();
+            if (m_pMasterListener)
+                m_pMasterListener->BeforeDrop();
             if(!pImExport->Read())
             {
-                OUString sError = OUString(ModuleRes(STR_NO_COLUMNNAME_MATCHING));
+                OUString sError = DBA_RES(STR_NO_COLUMNNAME_MATCHING);
                 throwGenericSQLException(sError,nullptr);
             }
-            AfterDrop();
+            if (m_pMasterListener)
+                m_pMasterListener->AfterDrop();
             Show();
         }
         catch(const SQLException& e)
         {
-            AfterDrop();
+            if (m_pMasterListener)
+                m_pMasterListener->AfterDrop();
             Show();
             ::dbaui::showError( ::dbtools::SQLExceptionInfo(e), this, getContext() );
         }
         catch(const Exception& )
         {
-            AfterDrop();
+            if (m_pMasterListener)
+                m_pMasterListener->AfterDrop();
             Show();
             DBG_UNHANDLED_EXCEPTION();
         }
@@ -1486,16 +1460,11 @@ OUString SbaGridControl::GetAccessibleObjectDescription( ::svt::AccessibleBrowse
     if ( ::svt::BBTYPE_BROWSEBOX == eObjType )
     {
         SolarMutexGuard aGuard;
-        sRet = OUString(ModuleRes(STR_DATASOURCE_GRIDCONTROL_DESC));
+        sRet = DBA_RES(STR_DATASOURCE_GRIDCONTROL_DESC);
     }
     else
         sRet = FmGridControl::GetAccessibleObjectDescription( eObjType,_nPosition);
     return sRet;
 }
 
-void SbaGridControl::DeleteSelectedRows()
-{
-    FmGridControl::DeleteSelectedRows();
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
