@@ -17,15 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <core_resource.hxx>
 #include "adminpages.hxx"
 #include "DbAdminImpl.hxx"
-#include "dbu_dlg.hrc"
+#include <dbu_dlg.hxx>
+#include <strings.hrc>
 #include "DriverSettings.hxx"
-#include "dsitems.hxx"
-#include "propertysetitem.hxx"
-#include "UITools.hxx"
+#include <dsitems.hxx>
+#include <propertysetitem.hxx>
+#include <UITools.hxx>
 #include "UserAdmin.hxx"
-#include "UserAdminDlg.hxx"
+#include <UserAdminDlg.hxx>
 
 #include <comphelper/processfactory.hxx>
 #include <connectivity/dbmetadata.hxx>
@@ -101,8 +103,8 @@ namespace dbaui
             ::dbtools::DatabaseMetaData aMetaData( createConnection().first );
             if ( !aMetaData.supportsUserAdministration( getORB() ) )
             {
-                OUString sError(ModuleRes(STR_USERADMIN_NOT_AVAILABLE));
-                throw SQLException(sError,nullptr,OUString("S1000") ,0,Any());
+                OUString sError(DBA_RES(STR_USERADMIN_NOT_AVAILABLE));
+                throw SQLException(sError, nullptr, "S1000", 0, Any());
             }
         }
         catch(const SQLException&)
@@ -139,14 +141,14 @@ namespace dbaui
     {
         return m_pItemSet;
     }
-    ::std::pair< Reference<XConnection>,sal_Bool> OUserAdminDlg::createConnection()
+    std::pair< Reference<XConnection>,sal_Bool> OUserAdminDlg::createConnection()
     {
         if ( !m_xConnection.is() )
         {
             m_xConnection = m_pImpl->createConnection().first;
             m_bOwnConnection = m_xConnection.is();
         }
-        return ::std::pair< Reference<XConnection>,sal_Bool> (m_xConnection,false);
+        return std::pair< Reference<XConnection>,sal_Bool> (m_xConnection,false);
     }
     Reference< XComponentContext > OUserAdminDlg::getORB() const
     {
@@ -168,10 +170,7 @@ namespace dbaui
     {
         SetText(_sTitle);
     }
-    void OUserAdminDlg::enableConfirmSettings( bool _bEnable )
-    {
-        (void)_bEnable;
-    }
+    void OUserAdminDlg::enableConfirmSettings( bool ) {}
     void OUserAdminDlg::saveDatasource()
     {
         PrepareLeaveCurrentPage();
