@@ -17,32 +17,30 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "dlgattr.hxx"
+#include <dlgattr.hxx>
 
 #include <sfx2/tabdlg.hxx>
 
 #include <svx/numinf.hxx>
 
 #include <svx/dialogs.hrc>
-#include "dbu_dlg.hrc"
+#include <dbu_dlg.hxx>
 #include <svl/itemset.hxx>
 #include <svl/zforlist.hxx>
 #include <svx/svxids.hrc>
 #include <svx/flagsdef.hxx>
 #include <svl/intitem.hxx>
-#include "moduledbu.hxx"
+#include <core_resource.hxx>
 using namespace dbaui;
 
 
 SbaSbAttrDlg::SbaSbAttrDlg(vcl::Window* pParent, const SfxItemSet* pCellAttrs,
-    SvNumberFormatter* pFormatter, bool bHasFormat, bool bRow)
+    SvNumberFormatter* pFormatter, bool bHasFormat)
     : SfxTabDialog(pParent, "FieldDialog", "dbaccess/ui/fielddialog.ui", pCellAttrs)
     , m_nNumberFormatId(0)
 {
     pNumberInfoItem = new SvxNumberInfoItem( pFormatter, 0 );
 
-    if (bRow)
-        SetText(get<FixedText>("alttitle")->GetText());
     if (bHasFormat)
         m_nNumberFormatId = AddTabPage("format", RID_SVXPAGE_NUMBERFORMAT);
     else
@@ -66,7 +64,7 @@ void SbaSbAttrDlg::PageCreated( sal_uInt16 nPageId, SfxTabPage& rTabPage )
     SfxAllItemSet aSet(*(GetInputSetImpl()->GetPool()));
     if (nPageId == m_nNumberFormatId)
     {
-        aSet.Put (SvxNumberInfoItem( pNumberInfoItem->GetNumberFormatter(), (const sal_uInt16)SID_ATTR_NUMBERFORMAT_INFO));
+        aSet.Put (SvxNumberInfoItem( pNumberInfoItem->GetNumberFormatter(), (sal_uInt16)SID_ATTR_NUMBERFORMAT_INFO));
         rTabPage.PageCreated(aSet);
     }
 }
