@@ -17,10 +17,12 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "indexfieldscontrol.hxx"
-#include "dbu_dlg.hrc"
+#include <core_resource.hxx>
+#include <indexfieldscontrol.hxx>
+#include <dbu_dlg.hxx>
+#include <strings.hrc>
 #include <osl/diagnose.h>
-#include "dbaccess_helpid.hrc"
+#include <helpids.h>
 #include <vcl/settings.hxx>
 #include <vcl/builderfactory.hxx>
 
@@ -72,14 +74,12 @@ namespace dbaui
         , m_aSeekRow(m_aFields.end())
         , m_pSortingCell(nullptr)
         , m_pFieldNameCell(nullptr)
-        , m_nMaxColumnsInIndex(0)
         , m_bAddIndexAppendix(false)
     {
     }
 
-    VCL_BUILDER_DECL_FACTORY(DbaIndexFieldsControl)
+    extern "C" SAL_DLLPUBLIC_EXPORT void SAL_CALL makeDbaIndexFieldsControl(VclPtr<vcl::Window> & rRet, VclPtr<vcl::Window> & pParent, VclBuilder::stringmap &)
     {
-        (void)rMap;
         rRet = VclPtr<IndexFieldsControl>::Create(pParent, WB_BORDER | WB_NOTABSTOP);
     }
 
@@ -113,7 +113,7 @@ namespace dbaui
         return true;
     }
 
-    void IndexFieldsControl::PaintCell( OutputDevice& _rDev, const Rectangle& _rRect, sal_uInt16 _nColumnId ) const
+    void IndexFieldsControl::PaintCell( OutputDevice& _rDev, const tools::Rectangle& _rRect, sal_uInt16 _nColumnId ) const
     {
         Point aPos(_rRect.TopLeft());
         aPos.X() += 1;
@@ -190,9 +190,8 @@ namespace dbaui
         return EditBrowseBox::GetTotalCellWidth(_nRow, _nColId);
     }
 
-    void IndexFieldsControl::Init(const Sequence< OUString >& _rAvailableFields, sal_Int32 _nMaxColumnsInIndex,bool _bAddIndexAppendix)
+    void IndexFieldsControl::Init(const Sequence< OUString >& _rAvailableFields, bool _bAddIndexAppendix)
     {
-        m_nMaxColumnsInIndex = _nMaxColumnsInIndex;
         m_bAddIndexAppendix = _bAddIndexAppendix;
 
         RemoveColumns();
@@ -202,11 +201,11 @@ namespace dbaui
 
         if ( m_bAddIndexAppendix )
         {
-            m_sAscendingText = ModuleRes(STR_ORDER_ASCENDING);
-            m_sDescendingText = ModuleRes(STR_ORDER_DESCENDING);
+            m_sAscendingText = DBA_RES(STR_ORDER_ASCENDING);
+            m_sDescendingText = DBA_RES(STR_ORDER_DESCENDING);
 
             // the "sort order" column
-            OUString sColumnName = ModuleRes(STR_TAB_INDEX_SORTORDER);
+            OUString sColumnName = DBA_RES(STR_TAB_INDEX_SORTORDER);
             // the width of the order column is the maximum widths of the texts used
             // (the title of the column)
             sal_Int32 nSortOrderColumnWidth = GetTextWidth(sColumnName);
@@ -231,7 +230,7 @@ namespace dbaui
         nFieldNameWidth -= aSystemStyle.GetScrollBarSize();
         nFieldNameWidth -= 8;
         // the "field name" column
-        OUString sColumnName = ModuleRes(STR_TAB_INDEX_FIELD);
+        OUString sColumnName = DBA_RES(STR_TAB_INDEX_FIELD);
         InsertDataColumn(COLUMN_ID_FIELDNAME, sColumnName, nFieldNameWidth, HeaderBarItemBits::STDSTYLE, 0);
 
         // create the cell controllers
@@ -293,7 +292,7 @@ namespace dbaui
         {
             case COLUMN_ID_FIELDNAME:
             {
-                OUString sFieldSelected = m_pFieldNameCell->GetSelectEntry();
+                OUString sFieldSelected = m_pFieldNameCell->GetSelectedEntry();
                 bool bEmptySelected = sFieldSelected.isEmpty();
                 if (isNewField())
                 {
@@ -339,7 +338,7 @@ namespace dbaui
             {
                 OSL_ENSURE(!isNewField(), "IndexFieldsControl::SaveModified: why the hell ...!!!");
                 // selected entry
-                sal_Int32 nPos = m_pSortingCell->GetSelectEntryPos();
+                sal_Int32 nPos = m_pSortingCell->GetSelectedEntryPos();
                 OSL_ENSURE(LISTBOX_ENTRY_NOTFOUND != nPos, "IndexFieldsControl::SaveModified: how did you get this selection??");
                 // adjust the sort flag in the index field description
                 OIndexField& rCurrentField = m_aFields[GetCurRow()];
@@ -385,7 +384,7 @@ namespace dbaui
         {   // a field has been selected
             if (GetCurRow() >= GetRowCount() - 2)
             {   // and we're in one of the last two rows
-                OUString sSelectedEntry = m_pFieldNameCell->GetSelectEntry();
+                OUString sSelectedEntry = m_pFieldNameCell->GetSelectedEntry();
                 sal_Int32 nCurrentRow = GetCurRow();
                 sal_Int32 rowCount = GetRowCount();
 
@@ -394,7 +393,7 @@ namespace dbaui
                 if (!sSelectedEntry.isEmpty() && (nCurrentRow == rowCount - 1) /*&& (!m_nMaxColumnsInIndex || rowCount < m_nMaxColumnsInIndex )*/ )
                 {   // in the last row, an non-empty string has been selected
                     // -> insert a new row
-                    m_aFields.push_back(OIndexField());
+                    m_aFields.emplace_back();
                     RowInserted(GetRowCount());
                     Invalidate(GetRowRectPixel(nCurrentRow));
                 }
