@@ -17,8 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "DExport.hxx"
-#include "moduledbu.hxx"
+#include <DExport.hxx>
+#include <core_resource.hxx>
 
 #include <com/sun/star/sdbcx/XTablesSupplier.hpp>
 #include <com/sun/star/sdbcx/XDataDescriptorFactory.hpp>
@@ -33,26 +33,27 @@
 #include <com/sun/star/uno/XComponentContext.hpp>
 #include <com/sun/star/util/NumberFormat.hpp>
 #include <com/sun/star/util/XNumberFormatTypes.hpp>
-#include "dbustrings.hrc"
-#include "dbu_misc.hrc"
+#include <stringconstants.hxx>
+#include <strings.hrc>
+#include <strings.hxx>
 #include <connectivity/dbconversion.hxx>
 #include <osl/thread.h>
 #include <sfx2/sfxhtml.hxx>
 #include <svl/numuno.hxx>
 #include <connectivity/dbtools.hxx>
 #include <comphelper/extract.hxx>
-#include "TypeInfo.hxx"
-#include "FieldDescriptions.hxx"
-#include "UITools.hxx"
+#include <TypeInfo.hxx>
+#include <FieldDescriptions.hxx>
+#include <UITools.hxx>
 #include <unotools/configmgr.hxx>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
 #include <tools/contnr.hxx>
 #include <i18nlangtag/mslangid.hxx>
 #include <com/sun/star/awt/FontDescriptor.hpp>
-#include "WCopyTable.hxx"
-#include "WExtendPages.hxx"
-#include "WCPage.hxx"
+#include <WCopyTable.hxx>
+#include <WExtendPages.hxx>
+#include <WCPage.hxx>
 #include <unotools/syslocale.hxx>
 #include <svl/zforlist.hxx>
 #include <connectivity/dbexception.hxx>
@@ -60,7 +61,7 @@
 #include <com/sun/star/sdbc/SQLWarning.hpp>
 #include <com/sun/star/sdb/SQLContext.hpp>
 #include <com/sun/star/sdb/application/CopyTableOperation.hpp>
-#include "sqlmessage.hxx"
+#include <sqlmessage.hxx>
 #include "UpdateHelperImpl.hxx"
 #include <vcl/msgbox.hxx>
 #include <cppuhelper/exc_hlp.hxx>
@@ -100,7 +101,6 @@ ODatabaseExport::ODatabaseExport(sal_Int32 nRows,
     ,m_nColumnPos(0)
     ,m_nRows(1)
     ,m_nRowCount(0)
-    ,m_nDefToken( osl_getThreadTextEncoding() )
     ,m_bError(false)
     ,m_bInTbl(false)
     ,m_bHead(true)
@@ -139,8 +139,6 @@ ODatabaseExport::ODatabaseExport(sal_Int32 nRows,
 ODatabaseExport::ODatabaseExport(const SharedConnection& _rxConnection,
                                  const Reference< XNumberFormatter >& _rxNumberF,
                                  const Reference< css::uno::XComponentContext >& _rxContext,
-                                 const TColumnVector* pList,
-                                 const OTypeInfoMap* _pInfoMap,
                                  SvStream& _rInputStream)
     :m_aDestColumns(_rxConnection->getMetaData().is() && _rxConnection->getMetaData()->supportsMixedCaseQuotedIdentifiers())
     ,m_xConnection(_rxConnection)
@@ -154,7 +152,6 @@ ODatabaseExport::ODatabaseExport(const SharedConnection& _rxConnection,
     ,m_nColumnPos(0)
     ,m_nRows(1)
     ,m_nRowCount(0)
-    ,m_nDefToken( osl_getThreadTextEncoding() )
     ,m_bError(false)
     ,m_bInTbl(false)
     ,m_bHead(true)
@@ -182,8 +179,8 @@ ODatabaseExport::ODatabaseExport(const SharedConnection& _rxConnection,
     if(xSet.is())
     {
         ::connectivity::ORowSetValue aValue;
-        ::std::vector<sal_Int32> aTypes;
-        ::std::vector<sal_Bool> aNullable;
+        std::vector<sal_Int32> aTypes;
+        std::vector<sal_Bool> aNullable;
         Reference<XResultSetMetaData> xResultSetMetaData = Reference<XResultSetMetaDataSupplier>(xSet,UNO_QUERY_THROW)->getMetaData();
         Reference<XRow> xRow(xSet,UNO_QUERY_THROW);
         while(xSet->next())
@@ -238,13 +235,13 @@ ODatabaseExport::ODatabaseExport(const SharedConnection& _rxConnection,
                 m_pTypeInfo->bNullable      = (sal_Int32)aValue == ColumnValue::NULLABLE;
                 ++nPos;
                 aValue.fill(nPos,aTypes[nPos],aNullable[nPos],xRow);
-                m_pTypeInfo->bCaseSensitive = aValue;
+                // bCaseSensitive
                 ++nPos;
                 aValue.fill(nPos,aTypes[nPos],aNullable[nPos],xRow);
                 m_pTypeInfo->nSearchType    = aValue;
                 ++nPos;
                 aValue.fill(nPos,aTypes[nPos],aNullable[nPos],xRow);
-                m_pTypeInfo->bUnsigned      = aValue;
+                // bUnsigned
                 ++nPos;
                 aValue.fill(nPos,aTypes[nPos],aNullable[nPos],xRow);
                 m_pTypeInfo->bCurrency      = aValue;
@@ -279,7 +276,6 @@ ODatabaseExport::ODatabaseExport(const SharedConnection& _rxConnection,
     }
     if ( !m_pTypeInfo )
         m_pTypeInfo = std::make_shared<OTypeInfo>();
-    SetColumnTypes(pList,_pInfoMap);
 }
 
 ODatabaseExport::~ODatabaseExport()
@@ -302,9 +298,9 @@ void ODatabaseExport::insertValueIntoColumn()
         if(pField)
         {
             sal_Int32 nNewPos = m_bIsAutoIncrement ? m_nColumnPos+1 : m_nColumnPos;
-            OSL_ENSURE((nNewPos) < static_cast<sal_Int32>(m_vColumns.size()),"m_vColumns: Illegal index for vector");
+            OSL_ENSURE(nNewPos < static_cast<sal_Int32>(m_vColumns.size()),"m_vColumns: Illegal index for vector");
 
-            if ( (nNewPos) < static_cast<sal_Int32>(m_vColumns.size() ) )
+            if ( nNewPos < static_cast<sal_Int32>(m_vColumns.size() ) )
             {
                 sal_Int32 nPos = m_vColumns[nNewPos].first;
                 if ( nPos != COLUMN_POSITION_NOT_FOUND )
@@ -316,7 +312,7 @@ void ODatabaseExport::insertValueIntoColumn()
                         OSL_ENSURE((nNewPos) < static_cast<sal_Int32>(m_vColumnTypes.size()),"Illegal index for vector");
                         if (m_vColumnTypes[nNewPos] != DataType::VARCHAR && m_vColumnTypes[nNewPos] != DataType::CHAR && m_vColumnTypes[nNewPos] != DataType::LONGVARCHAR )
                         {
-                            SAL_INFO("dbaccess", "ODatabaseExport::insertValueIntoColumn != DataType::VARCHAR" );
+                            SAL_INFO("dbaccess.ui", "ODatabaseExport::insertValueIntoColumn != DataType::VARCHAR" );
                             ensureFormatter();
                             sal_Int32 nNumberFormat = 0;
                             double fOutNumber = 0.0;
@@ -521,7 +517,7 @@ sal_Int16 ODatabaseExport::CheckString(const OUString& aCheckToken, sal_Int16 _n
                 case NumberFormat::TEXT:
                 case NumberFormat::UNDEFINED:
                 case NumberFormat::LOGICAL:
-                    nNumberFormat = NumberFormat::TEXT; // Text "uberschreibt alles
+                    nNumberFormat = NumberFormat::TEXT; // Text overwrites everything
                     break;
                 case NumberFormat::DATETIME:
                     switch(_nOldNumberFormat)
@@ -546,7 +542,7 @@ sal_Int16 ODatabaseExport::CheckString(const OUString& aCheckToken, sal_Int16 _n
     }
     catch(Exception&)
     {
-        nNumberFormat = NumberFormat::TEXT; // Text "uberschreibt alles
+        nNumberFormat = NumberFormat::TEXT; // Text overwrites everything
     }
 
     return nNumberFormat;
@@ -561,7 +557,7 @@ void ODatabaseExport::SetColumnTypes(const TColumnVector* _pList,const OTypeInfo
         Reference< XNumberFormats >         xFormats = xSupplier->getNumberFormats();
         TColumnVector::const_iterator aIter = _pList->begin();
         TColumnVector::const_iterator aEnd = _pList->end();
-        for(sal_Int32 i= 0;aIter != aEnd && (i) < static_cast<sal_Int32>(m_vNumberFormat.size()) && (i) < static_cast<sal_Int32>(m_vColumnSize.size()) ;++aIter,++i)
+        for(sal_Int32 i= 0;aIter != aEnd && i < static_cast<sal_Int32>(m_vNumberFormat.size()) && i < static_cast<sal_Int32>(m_vColumnSize.size()) ;++aIter,++i)
         {
             sal_Int32 nDataType;
             sal_Int32 nLength(0),nScale(0);
@@ -608,8 +604,8 @@ void ODatabaseExport::SetColumnTypes(const TColumnVector* _pList,const OTypeInfo
             if(aFind != _pInfoMap->end())
             {
                 (*aIter)->second->SetType(aFind->second);
-                (*aIter)->second->SetPrecision(::std::min<sal_Int32>(aFind->second->nPrecision,nLength));
-                (*aIter)->second->SetScale(::std::min<sal_Int32>(aFind->second->nMaximumScale,nScale));
+                (*aIter)->second->SetPrecision(std::min<sal_Int32>(aFind->second->nPrecision,nLength));
+                (*aIter)->second->SetScale(std::min<sal_Int32>(aFind->second->nMaximumScale,nScale));
 
                 sal_Int32 nFormatKey = ::dbtools::getDefaultNumberFormat( nDataType,
                                     (*aIter)->second->GetScale(),
@@ -632,7 +628,7 @@ void ODatabaseExport::CreateDefaultColumn(const OUString& _rColumnName)
         aAlias = ::dbtools::convertName2SQLName(_rColumnName,xDestMetaData->getExtraNameCharacters());
 
     if(nMaxNameLen && aAlias.getLength() > nMaxNameLen)
-        aAlias = aAlias.copy(0, ::std::min<sal_Int32>( nMaxNameLen-1, aAlias.getLength() ) );
+        aAlias = aAlias.copy(0, std::min<sal_Int32>( nMaxNameLen-1, aAlias.getLength() ) );
 
     OUString sName(aAlias);
     if(m_aDestColumns.find(sName) != m_aDestColumns.end())
@@ -645,7 +641,7 @@ void ODatabaseExport::CreateDefaultColumn(const OUString& _rColumnName)
                   + OUString::number(++nPos);
             if(nMaxNameLen && sName.getLength() > nMaxNameLen)
             {
-                aAlias = aAlias.copy(0,::std::min<sal_Int32>( nMaxNameLen-nCount, aAlias.getLength() ));
+                aAlias = aAlias.copy(0,std::min<sal_Int32>( nMaxNameLen-nCount, aAlias.getLength() ));
                 sName = aAlias
                       + OUString::number(nPos);
                 ++nCount;
@@ -657,7 +653,7 @@ void ODatabaseExport::CreateDefaultColumn(const OUString& _rColumnName)
     OFieldDescription* pField = new OFieldDescription();
     pField->SetType(m_pTypeInfo);
     pField->SetName(aAlias);
-    pField->SetPrecision(::std::min<sal_Int32>((sal_Int32)255,m_pTypeInfo->nPrecision));
+    pField->SetPrecision(std::min<sal_Int32>((sal_Int32)255,m_pTypeInfo->nPrecision));
     pField->SetScale(0);
     pField->SetIsNullable(ColumnValue::NULLABLE);
     pField->SetAutoIncrement(false);
@@ -671,7 +667,7 @@ void ODatabaseExport::CreateDefaultColumn(const OUString& _rColumnName)
         m_aDestColumns.erase(aFind);
     }
 
-    m_vDestVector.push_back(m_aDestColumns.insert(TColumns::value_type(aAlias,pField)).first);
+    m_vDestVector.emplace_back(m_aDestColumns.emplace(aAlias,pField).first);
 }
 
 bool ODatabaseExport::createRowSet()
@@ -751,8 +747,8 @@ void ODatabaseExport::showErrorDialog(const css::sdbc::SQLException& e)
     {
         OUString aMsg = e.Message
                       + "\n"
-                      + OUString(ModuleRes( STR_QRY_CONTINUE ));
-        ScopedVclPtrInstance< OSQLWarningBox > aBox( nullptr, aMsg, WB_YES_NO | WB_DEF_NO );
+                      + DBA_RES( STR_QRY_CONTINUE );
+        ScopedVclPtrInstance< OSQLWarningBox > aBox( nullptr, aMsg, MessBoxStyle::YesNo | MessBoxStyle::DefaultNo );
 
         if (aBox->Execute() == RET_YES)
             m_bDontAskAgain = true;
@@ -766,8 +762,8 @@ void ODatabaseExport::adjustFormat()
     if ( !m_sTextToken.isEmpty() )
     {
         sal_Int32 nNewPos = m_bIsAutoIncrement ? m_nColumnPos+1 : m_nColumnPos;
-        OSL_ENSURE((nNewPos) < static_cast<sal_Int32>(m_vColumns.size()),"Illegal index for vector");
-        if ( (nNewPos) < static_cast<sal_Int32>(m_vColumns.size()) )
+        OSL_ENSURE(nNewPos < static_cast<sal_Int32>(m_vColumns.size()),"Illegal index for vector");
+        if ( nNewPos < static_cast<sal_Int32>(m_vColumns.size()) )
         {
             sal_Int32 nColPos = m_vColumns[nNewPos].first;
             if( nColPos != sal::static_int_cast< long >(CONTAINER_ENTRY_NOTFOUND))
@@ -776,7 +772,7 @@ void ODatabaseExport::adjustFormat()
                 OSL_ENSURE((nColPos) < static_cast<sal_Int32>(m_vNumberFormat.size()),"m_vFormatKey: Illegal index for vector");
                 OSL_ENSURE((nColPos) < static_cast<sal_Int32>(m_vColumnSize.size()),"m_vColumnSize: Illegal index for vector");
                 m_vNumberFormat[nColPos] = CheckString(m_sTextToken,m_vNumberFormat[nColPos]);
-                m_vColumnSize[nColPos] = ::std::max<sal_Int32>((sal_Int32)m_vColumnSize[nColPos], m_sTextToken.getLength());
+                m_vColumnSize[nColPos] = std::max<sal_Int32>((sal_Int32)m_vColumnSize[nColPos], m_sTextToken.getLength());
             }
         }
         eraseTokens();
@@ -807,7 +803,7 @@ Reference< XPreparedStatement > ODatabaseExport::createPreparedStatment( const R
                                                        ,const Reference<XPropertySet>& _xDestTable
                                                        ,const TPositions& _rvColumns)
 {
-    OUString sComposedTableName = ::dbtools::composeTableName( _xMetaData, _xDestTable, ::dbtools::EComposeRule::InDataManipulation, false, false, true );
+    OUString sComposedTableName = ::dbtools::composeTableName( _xMetaData, _xDestTable, ::dbtools::EComposeRule::InDataManipulation, true );
 
     OUString aSql = "INSERT INTO "
                   + sComposedTableName
@@ -829,11 +825,11 @@ Reference< XPreparedStatement > ODatabaseExport::createPreparedStatment( const R
         return Reference< XPreparedStatement > ();
     }
     const OUString* pIter = aDestColumnNames.getConstArray();
-    ::std::vector< OUString> aInsertList;
+    std::vector< OUString> aInsertList;
     aInsertList.resize(aDestColumnNames.getLength()+1);
     for(size_t j=0; j < aInsertList.size(); ++j)
     {
-        ODatabaseExport::TPositions::const_iterator aFind = ::std::find_if(_rvColumns.begin(),_rvColumns.end(),
+        ODatabaseExport::TPositions::const_iterator aFind = std::find_if(_rvColumns.begin(),_rvColumns.end(),
             [j] (const ODatabaseExport::TPositions::value_type& tPos)
                 { return tPos.second == (sal_Int32)(j+1); });
         if ( _rvColumns.end() != aFind && aFind->second != sal::static_int_cast< long >(CONTAINER_ENTRY_NOTFOUND) && aFind->first != sal::static_int_cast< long >(CONTAINER_ENTRY_NOTFOUND) )
@@ -844,8 +840,8 @@ Reference< XPreparedStatement > ODatabaseExport::createPreparedStatment( const R
     }
 
     // create the sql string
-    ::std::vector< OUString>::const_iterator aInsertEnd = aInsertList.end();
-    for (::std::vector< OUString>::const_iterator aInsertIter = aInsertList.begin(); aInsertIter != aInsertEnd; ++aInsertIter)
+    std::vector< OUString>::const_iterator aInsertEnd = aInsertList.end();
+    for (std::vector< OUString>::const_iterator aInsertIter = aInsertList.begin(); aInsertIter != aInsertEnd; ++aInsertIter)
     {
         if ( !aInsertIter->isEmpty() )
         {
