@@ -17,18 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "linkeddocuments.hxx"
+#include <core_resource.hxx>
+#include <linkeddocuments.hxx>
 #include <osl/diagnose.h>
 #include <tools/diagnose_ex.h>
 #include <unotools/confignode.hxx>
-#include "dbustrings.hrc"
+#include <stringconstants.hxx>
 #include <comphelper/classids.hxx>
 #include <comphelper/namedvaluecollection.hxx>
 #include <com/sun/star/lang/XSingleServiceFactory.hpp>
-#include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/frame/XComponentLoader.hpp>
 #include <com/sun/star/util/URL.hpp>
-#include <com/sun/star/frame/FrameSearchFlag.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/ucb/XCommandProcessor.hpp>
 #include <com/sun/star/ucb/OpenCommandArgument.hpp>
@@ -38,11 +37,11 @@
 #include <comphelper/types.hxx>
 #include <vcl/msgbox.hxx>
 #include <ucbhelper/content.hxx>
-#include "dbu_misc.hrc"
+#include <strings.hrc>
+#include <strings.hxx>
 #include <svl/filenotation.hxx>
-#include "browserids.hxx"
+#include <browserids.hxx>
 #include <sfx2/new.hxx>
-#include "moduledbu.hxx"
 #include <sfx2/app.hxx>
 #include <basic/sbx.hxx>
 #include <basic/sbuno.hxx>
@@ -56,7 +55,7 @@
 #include <connectivity/dbtools.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <com/sun/star/io/WrongFormatException.hpp>
-#include "com/sun/star/sdb/RowSetVetoException.hpp"
+#include <com/sun/star/sdb/RowSetVetoException.hpp>
 
 namespace dbaui
 {
@@ -139,7 +138,7 @@ namespace dbaui
 
             case E_OPEN_FOR_MAIL:
                 aArguments.put( "Hidden", true );
-                // fall through
+                SAL_FALLTHROUGH;
 
             case E_OPEN_DESIGN:
                 sOpenMode = "openDesign";
@@ -152,23 +151,17 @@ namespace dbaui
         aArguments.put( "OpenMode", sOpenMode );
 
         aArguments.put( OUString(PROPERTY_ACTIVE_CONNECTION), m_xConnection );
-        try
-        {
-            Reference<XHierarchicalNameContainer> xHier(m_xDocumentContainer,UNO_QUERY);
-            if ( xHier.is() && xHier->hasByHierarchicalName(_rLinkName) )
-            {
-                _xDefinition.set(xHier->getByHierarchicalName(_rLinkName),UNO_QUERY);
-            }
 
-            aArguments.merge( _rAdditionalArgs, true );
-
-            xRet = xComponentLoader->loadComponentFromURL( _rLinkName, OUString(), 0, aArguments.getPropertyValues() );
-        }
-        catch(const Exception&)
+        Reference<XHierarchicalNameContainer> xHier(m_xDocumentContainer,UNO_QUERY);
+        if ( xHier.is() && xHier->hasByHierarchicalName(_rLinkName) )
         {
-            throw;
+            _xDefinition.set(xHier->getByHierarchicalName(_rLinkName),UNO_QUERY);
         }
 
+        aArguments.merge( _rAdditionalArgs, true );
+
+        xRet = xComponentLoader->loadComponentFromURL( _rLinkName, OUString(), 0, aArguments.getPropertyValues() );
+
         return xRet;
     }
     void OLinkedDocumentsAccess::impl_newWithPilot( const char* _pWizardService,
@@ -321,7 +314,7 @@ namespace dbaui
             xRet = impl_open( _rLinkName, _xDefinition, _eOpenMode, _rAdditionalArgs );
             if ( !xRet.is() )
             {
-                OUString sMessage = ModuleRes(STR_COULDNOTOPEN_LINKEDDOC);
+                OUString sMessage = DBA_RES(STR_COULDNOTOPEN_LINKEDDOC);
                 sMessage = sMessage.replaceFirst("$file$",_rLinkName);
 
                 css::sdbc::SQLException aSQLException;
@@ -338,11 +331,11 @@ namespace dbaui
             aInfo = dbtools::SQLExceptionInfo(aSQLException);
 
             // more like a hack, insert an empty message
-            OUString sText( ModuleRes( RID_STR_EXTENSION_NOT_PRESENT ) );
+            OUString sText( DBA_RES( RID_STR_EXTENSION_NOT_PRESENT ) );
             sText = sText.replaceFirst("$file$",_rLinkName);
             aInfo.prepend(sText);
 
-            OUString sMessage = ModuleRes(STR_COULDNOTOPEN_LINKEDDOC);
+            OUString sMessage = DBA_RES(STR_COULDNOTOPEN_LINKEDDOC);
             sMessage = sMessage.replaceFirst("$file$",_rLinkName);
             aInfo.prepend(sMessage);
         }
@@ -360,7 +353,7 @@ namespace dbaui
                 // more like a hack, insert an empty message
                 aInfo.prepend(" \n");
 
-                OUString sMessage = ModuleRes(STR_COULDNOTOPEN_LINKEDDOC);
+                OUString sMessage = DBA_RES(STR_COULDNOTOPEN_LINKEDDOC);
                 sMessage = sMessage.replaceFirst("$file$",_rLinkName);
                 aInfo.prepend(sMessage);
             }
