@@ -19,16 +19,16 @@
 
 #include <sal/config.h>
 
-#include "uiservices.hxx"
+#include <uiservices.hxx>
 #include "unoDirectSql.hxx"
-#include "dbu_reghelper.hxx"
+#include <dbu_reghelper.hxx>
 #include <com/sun/star/sdbcx/XColumnsSupplier.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/connection/XConnection.hpp>
 #include <com/sun/star/container/XNamed.hpp>
-#include "directsql.hxx"
-#include "dbustrings.hrc"
-#include "datasourceconnector.hxx"
+#include <directsql.hxx>
+#include <stringconstants.hxx>
+#include <datasourceconnector.hxx>
 #include <tools/diagnose_ex.h>
 #include <comphelper/processfactory.hxx>
 
@@ -61,7 +61,6 @@ namespace dbaui
     }
 
     css::uno::Sequence<sal_Int8> ODirectSQLDialog::getImplementationId()
-        throw (css::uno::RuntimeException, std::exception)
     {
         return css::uno::Sequence<sal_Int8>();
     }
