@@ -29,15 +29,19 @@
 #include <signal.h>
 #endif
 
-#include "app.hxx"
-#include "desktop.hrc"
+#include <app.hxx>
+#include <dp_shared.hxx>
+#include <strings.hrc>
 #include "cmdlineargs.hxx"
 #include "cmdlinehelp.hxx"
 #include "dispatchwatcher.hxx"
-#include "lockfile.hxx"
+#include <lockfile.hxx>
 #include "userinstall.hxx"
 #include "desktopcontext.hxx"
-#include "migration.hxx"
+#include <migration.hxx>
+#if HAVE_FEATURE_UPDATE_MAR
+#include "updater.hxx"
+#endif
 
 #include <o3tl/runtimetooustring.hxx>
 #include <svl/languageoptions.hxx>
@@ -46,7 +50,6 @@
 #include <com/sun/star/frame/theAutoRecovery.hpp>
 #include <com/sun/star/frame/theGlobalEventBroadcaster.hpp>
 #include <com/sun/star/frame/SessionListener.hpp>
-#include <com/sun/star/frame/XSessionManagerListener.hpp>
 #include <com/sun/star/frame/XSynchronousDispatch.hpp>
 #include <com/sun/star/document/CorruptedFilterConfigurationException.hpp>
 #include <com/sun/star/configuration/CorruptedConfigurationException.hpp>
@@ -56,12 +59,10 @@
 #include <com/sun/star/system/SystemShellExecuteFlags.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
 #include <com/sun/star/frame/StartModule.hpp>
-#include <com/sun/star/frame/XComponentLoader.hpp>
 #include <com/sun/star/view/XPrintable.hpp>
 #include <com/sun/star/awt/XTopWindow.hpp>
 #include <com/sun/star/util/URLTransformer.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
-#include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/lang/ServiceNotRegisteredException.hpp>
 #include <com/sun/star/configuration/MissingBootstrapFileException.hpp>
 #include <com/sun/star/configuration/InvalidBootstrapFileException.hpp>
@@ -74,8 +75,9 @@
 #include <com/sun/star/document/XDocumentEventListener.hpp>
 #include <com/sun/star/ui/theUIElementFactoryManager.hpp>
 #include <com/sun/star/ui/theWindowStateConfiguration.hpp>
-#include <com/sun/star/frame/thePopupMenuControllerFactory.hpp>
 #include <com/sun/star/office/Quickstart.hpp>
+#include <com/sun/star/system/XSystemShellExecute.hpp>
+#include <com/sun/star/system/SystemShellExecute.hpp>
 
 #include <desktop/exithelper.h>
 #include <sal/log.hxx>
@@ -91,6 +93,7 @@
 #include <unotools/localfilehelper.hxx>
 #include <officecfg/Office/Common.hxx>
 #include <officecfg/Office/Recovery.hxx>
+#include <officecfg/Office/Update.hxx>
 #include <officecfg/Setup.hxx>
 #include <osl/file.hxx>
 #include <osl/process.h>
@@ -102,7 +105,7 @@
 #include <vcl/help.hxx>
 #include <vcl/layout.hxx>
 #include <vcl/settings.hxx>
-#include <sfx2/sfx.hrc>
+#include <sfx2/sfxsids.hrc>
 #include <sfx2/app.hxx>
 #include <sfx2/safemode.hxx>
 #include <svl/itemset.hxx>
@@ -146,7 +149,7 @@
 #define GETPID getpid
 #endif
 
-#include "strings.hxx"
+#include <strings.hxx>
 
 using namespace ::com::sun::star::awt;
 using namespace ::com::sun::star::uno;
@@ -162,8 +165,6 @@ using namespace ::com::sun::star::ui;
 using namespace ::com::sun::star::ui::dialogs;
 using namespace ::com::sun::star::container;
 
-ResMgr* desktop::Desktop::pResMgr = nullptr;
-
 namespace desktop
 {
 
@@ -289,7 +290,7 @@ bool shouldLaunchQuickstart()
     if (!bQuickstart)
     {
         const SfxPoolItem* pItem=nullptr;
-        SfxItemSet aQLSet(SfxGetpApp()->GetPool(), SID_ATTR_QUICKLAUNCHER, SID_ATTR_QUICKLAUNCHER);
+        SfxItemSet aQLSet(SfxGetpApp()->GetPool(), svl::Items<SID_ATTR_QUICKLAUNCHER, SID_ATTR_QUICKLAUNCHER>{});
         SfxGetpApp()->GetOptions(aQLSet);
         SfxItemState eState = aQLSet.GetItemState(SID_ATTR_QUICKLAUNCHER, false, &pItem);
         if (SfxItemState::SET == eState)
@@ -305,7 +306,7 @@ void SetRestartState() {
         officecfg::Setup::Office::OfficeRestartInProgress::set(true, batch);
         batch->commit();
     } catch (css::uno::Exception & e) {
-        SAL_WARN("desktop.app", "ignoring Exception \"" << e.Message << "\"");
+        SAL_WARN("desktop.app", "ignoring " << e);
     }
 }
 
@@ -324,95 +325,31 @@ void DoRestartActionsIfNecessary(bool quickstart) {
             }
         } catch (css::uno::Exception & e) {
             SAL_WARN(
-                "desktop.app", "ignoring Exception \"" << e.Message << "\"");
+                "desktop.app", "ignoring " << e);
         }
     }
 }
 
 }
 
-
-ResMgr* Desktop::GetDesktopResManager()
-{
-    if ( !Desktop::pResMgr )
-    {
-        // Create desktop resource manager and bootstrap process
-        // was successful. Use default way to get language specific message.
-        if ( Application::IsInExecute() )
-            Desktop::pResMgr = ResMgr::CreateResMgr("dkt");
-
-        if ( !Desktop::pResMgr )
-        {
-            // Use VCL to get the correct language specific message as we
-            // are in the bootstrap process and not able to get the installed
-            // language!!
-            OUString aUILocaleString = langselect::getEmergencyLocale();
-            LanguageTag aLanguageTag( aUILocaleString);
-            //! ResMgr may modify the Locale for fallback!
-            Desktop::pResMgr = ResMgr::SearchCreateResMgr( "dkt", aLanguageTag);
-        }
-    }
-
-    return Desktop::pResMgr;
-}
-
 namespace {
 
 
-// Get a message string securely. There is a fallback string if the resource
-// is not available.
-
-OUString GetMsgString(
-    sal_uInt16 nId, const OUString& aFallbackMsg,
-    bool bAlwaysUseFallbackMsg = false )
+OUString MakeStartupErrorMessage(OUString const & aErrorMessage)
 {
-    if ( !bAlwaysUseFallbackMsg )
-    {
-        ResMgr* resMgr = Desktop::GetDesktopResManager();
-        if ( resMgr )
-            return ResId(nId, *resMgr);
-    }
-    return aFallbackMsg;
-}
-
-OUString MakeStartupErrorMessage(
-    OUString const & aErrorMessage, bool bAlwaysUseFallbackMsg = false )
-{
-    OUStringBuffer    aDiagnosticMessage( 100 );
-
-    aDiagnosticMessage.append(
-        GetMsgString(
-            STR_BOOTSTRAP_ERR_CANNOT_START, "The program cannot be started.",
-            bAlwaysUseFallbackMsg ) );
-
-    aDiagnosticMessage.append( "\n" );
-
-    aDiagnosticMessage.append( aErrorMessage );
-
-    return aDiagnosticMessage.makeStringAndClear();
+    return DpResId(STR_BOOTSTRAP_ERR_CANNOT_START) + "\n" + aErrorMessage;
 }
 
 OUString MakeStartupConfigAccessErrorMessage( OUString const & aInternalErrMsg )
 {
-    OUStringBuffer aDiagnosticMessage( 200 );
-
-    ResMgr* pResMgr = Desktop::GetDesktopResManager();
-    if ( pResMgr )
-        aDiagnosticMessage.append( ResId(STR_BOOTSTRAP_ERR_CFG_DATAACCESS, *pResMgr) );
-    else
-        aDiagnosticMessage.append( "The program cannot be started." );
-
+    OUString aDiagnosticMessage = DpResId(STR_BOOTSTRAP_ERR_CFG_DATAACCESS);
     if ( !aInternalErrMsg.isEmpty() )
     {
-        aDiagnosticMessage.append( "\n\n" );
-        if ( pResMgr )
-            aDiagnosticMessage.append( ResId(STR_INTERNAL_ERRMSG, *pResMgr) );
-        else
-            aDiagnosticMessage.append( "The following internal error has occurred:\n\n" );
-        aDiagnosticMessage.append( aInternalErrMsg );
+        aDiagnosticMessage += "\n\n"
+                           + DpResId(STR_INTERNAL_ERRMSG)
+                           + aInternalErrMsg;
     }
-
-    return aDiagnosticMessage.makeStringAndClear();
+    return aDiagnosticMessage;
 }
 
 
@@ -423,7 +360,7 @@ OUString MakeStartupConfigAccessErrorMessage( OUString const & aInternalErrMsg )
 // On the other side we must make sure that no further actions will be possible within
 // the current office process ! No pipe requests, no menu/toolbar/shortcut actions
 // are allowed. Otherwise we will force a "crash inside a crash".
-// Thats why we have to use a special native message box here which does not use yield :-)
+// That's why we have to use a special native message box here which does not use yield :-)
 
 void FatalError(const OUString& sMessage)
 {
@@ -437,11 +374,8 @@ void FatalError(const OUString& sMessage)
             sProductKey = sProductKey.copy( nLastIndex+1 );
     }
 
-    OUStringBuffer sTitle (128);
-    sTitle.append      (sProductKey     );
-    sTitle.append (" - Fatal Error");
-
-    Application::ShowNativeErrorBox (sTitle.makeStringAndClear (), sMessage);
+    OUString sTitle = sProductKey + " - Fatal Error";
+    Application::ShowNativeErrorBox (sTitle, sMessage);
     _exit(EXITHELPER_FATAL_ERROR);
 }
 
@@ -729,8 +663,7 @@ OUString    Desktop::CreateErrorMsgString(
         /// the shared installation directory could not be located
         case ::utl::Bootstrap::MISSING_INSTALL_DIRECTORY:
         {
-            aMsg = GetMsgString( STR_BOOTSTRAP_ERR_PATH_INVALID,
-                        "The installation path is not available." );
+            aMsg = DpResId(STR_BOOTSTRAP_ERR_PATH_INVALID);
             bFileInfo = false;
         }
         break;
@@ -738,8 +671,7 @@ OUString    Desktop::CreateErrorMsgString(
         /// the bootstrap INI file could not be found or read
         case ::utl::Bootstrap::MISSING_BOOTSTRAP_FILE:
         {
-            aMsg = GetMsgString( STR_BOOTSTRAP_ERR_FILE_MISSING,
-                        "The configuration file \"$1\" is missing." );
+            aMsg = DpResId(STR_BOOTSTRAP_ERR_FILE_MISSING);
         }
         break;
 
@@ -748,40 +680,35 @@ OUString    Desktop::CreateErrorMsgString(
          case ::utl::Bootstrap::MISSING_BOOTSTRAP_FILE_ENTRY:
          case ::utl::Bootstrap::INVALID_BOOTSTRAP_FILE_ENTRY:
         {
-            aMsg = GetMsgString( STR_BOOTSTRAP_ERR_FILE_CORRUPT,
-                        "The configuration file \"$1\" is corrupt." );
+            aMsg = DpResId(STR_BOOTSTRAP_ERR_FILE_CORRUPT);
         }
         break;
 
         /// the version locator INI file could not be found or read
         case ::utl::Bootstrap::MISSING_VERSION_FILE:
         {
-            aMsg = GetMsgString( STR_BOOTSTRAP_ERR_FILE_MISSING,
-                        "The configuration file \"$1\" is missing." );
+            aMsg = DpResId(STR_BOOTSTRAP_ERR_FILE_MISSING);
         }
         break;
 
         /// the version locator INI has no entry for this version
-         case ::utl::Bootstrap::MISSING_VERSION_FILE_ENTRY:
+        case ::utl::Bootstrap::MISSING_VERSION_FILE_ENTRY:
         {
-            aMsg = GetMsgString( STR_BOOTSTRAP_ERR_NO_SUPPORT,
-                        "The main configuration file \"$1\" does not support the current version." );
+            aMsg = DpResId(STR_BOOTSTRAP_ERR_NO_SUPPORT);
         }
         break;
 
         /// the user installation directory does not exist
-           case ::utl::Bootstrap::MISSING_USER_DIRECTORY:
+        case ::utl::Bootstrap::MISSING_USER_DIRECTORY:
         {
-            aMsg = GetMsgString( STR_BOOTSTRAP_ERR_DIR_MISSING,
-                        "The configuration directory \"$1\" is missing." );
+            aMsg = DpResId(STR_BOOTSTRAP_ERR_DIR_MISSING);
         }
         break;
 
         /// some bootstrap data was invalid in unexpected ways
         case ::utl::Bootstrap::INVALID_BOOTSTRAP_DATA:
         {
-            aMsg = GetMsgString( STR_BOOTSTRAP_ERR_INTERNAL,
-                        "An internal failure occurred." );
+            aMsg = DpResId(STR_BOOTSTRAP_ERR_INTERNAL);
             bFileInfo = false;
         }
         break;
@@ -890,10 +817,7 @@ void Desktop::HandleBootstrapErrors(
         // Currently we are not able to display a message box with a service manager due to this limitations inside VCL.
 
         // When UNO is not properly initialized, all kinds of things can fail
-        // and cause the process to crash (e.g., a call to GetMsgString may
-        // crash when somewhere deep within that call Any::operator <= is used
-        // with a PropertyValue, and no binary UNO type description for
-        // PropertyValue is available).  To give the user a hint even if
+        // and cause the process to crash. To give the user a hint even if
         // generating and displaying a message box below crashes, print a
         // hard-coded message on stderr first:
         std::cerr
@@ -910,40 +834,18 @@ void Desktop::HandleBootstrapErrors(
         }
 
         // First sentence. We cannot bootstrap office further!
-        OUString            aMessage;
-        OUStringBuffer        aDiagnosticMessage( 100 );
-
-        OUString aErrorMsg;
-
-        if ( aBootstrapError == BE_UNO_SERVICEMANAGER )
-            aErrorMsg = "The service manager is not available.";
-        else
-            aErrorMsg = GetMsgString( STR_BOOTSTRAP_ERR_NO_CFG_SERVICE,
-                            "The configuration service is not available." );
-
-        aDiagnosticMessage.append( aErrorMsg );
-        aDiagnosticMessage.append( "\n" );
+        OUString aDiagnosticMessage = DpResId(STR_BOOTSTRAP_ERR_NO_CFG_SERVICE) + "\n";
         if ( !aErrorMessage.isEmpty() )
         {
-            aDiagnosticMessage.append( "(\"" );
-            aDiagnosticMessage.append( aErrorMessage );
-            aDiagnosticMessage.append( "\")\n" );
+            aDiagnosticMessage += "(\"" + aErrorMessage + "\")\n";
         }
 
         // Due to the fact the we haven't a backup applicat.rdb file anymore it is not possible to
         // repair the installation with the setup executable besides the office executable. Now
         // we have to ask the user to start the setup on CD/installation directory manually!!
-        OUString aStartSetupManually( GetMsgString(
-            STR_ASK_START_SETUP_MANUALLY,
-            "Start setup application to repair the installation from CD, or the folder containing the installation packages.",
-            aBootstrapError == BE_UNO_SERVICEMANAGER ) );
+        aDiagnosticMessage += DpResId(STR_ASK_START_SETUP_MANUALLY);
 
-        aDiagnosticMessage.append( aStartSetupManually );
-        aMessage = MakeStartupErrorMessage(
-            aDiagnosticMessage.makeStringAndClear(),
-            aBootstrapError == BE_UNO_SERVICEMANAGER );
-
-        FatalError( aMessage);
+        FatalError(MakeStartupErrorMessage(aDiagnosticMessage));
     }
     else if ( aBootstrapError == BE_OFFICECONFIG_BROKEN )
     {
@@ -955,11 +857,7 @@ void Desktop::HandleBootstrapErrors(
         // enter safe mode, too
         sfx2::SafeMode::putFlag();
 
-        OUString msg(
-            GetMsgString(
-            STR_CONFIG_ERR_ACCESS_GENERAL,
-            ("A general error occurred while accessing your central"
-            " configuration. SafeMode is initiated.")));
+        OUString msg(DpResId(STR_CONFIG_ERR_ACCESS_GENERAL));
         if (!aErrorMessage.isEmpty()) {
             msg += "\n(\"" + aErrorMessage + "\")";
         }
@@ -967,59 +865,31 @@ void Desktop::HandleBootstrapErrors(
     }
     else if ( aBootstrapError == BE_USERINSTALL_FAILED )
     {
-        OUString aMessage;
-        OUStringBuffer aDiagnosticMessage( 100 );
-        OUString aErrorMsg;
-        aErrorMsg = GetMsgString( STR_BOOTSTRAP_ERR_USERINSTALL_FAILED,
-            "User installation could not be completed" );
-        aDiagnosticMessage.append( aErrorMsg );
-        aMessage = MakeStartupErrorMessage( aDiagnosticMessage.makeStringAndClear() );
-        FatalError(aMessage);
+        OUString aDiagnosticMessage = DpResId(STR_BOOTSTRAP_ERR_USERINSTALL_FAILED);
+        FatalError(MakeStartupErrorMessage(aDiagnosticMessage));
     }
     else if ( aBootstrapError == BE_LANGUAGE_MISSING )
     {
-        OUString aMessage;
-        OUStringBuffer aDiagnosticMessage( 100 );
-        OUString aErrorMsg;
-        aErrorMsg = GetMsgString(
-            //@@@ FIXME: should use an own resource string => #i36213#
-            STR_BOOTSTRAP_ERR_LANGUAGE_MISSING,
-            "Language could not be determined." );
-        aDiagnosticMessage.append( aErrorMsg );
-        aMessage = MakeStartupErrorMessage(
-            aDiagnosticMessage.makeStringAndClear() );
-        FatalError(aMessage);
+        OUString aDiagnosticMessage = DpResId(STR_BOOTSTRAP_ERR_LANGUAGE_MISSING);
+        FatalError(MakeStartupErrorMessage(aDiagnosticMessage));
     }
     else if (( aBootstrapError == BE_USERINSTALL_NOTENOUGHDISKSPACE ) ||
              ( aBootstrapError == BE_USERINSTALL_NOWRITEACCESS      ))
     {
-        OUString       aUserInstallationURL;
-        OUString       aUserInstallationPath;
-        OUString       aMessage;
-        OUString       aErrorMsg;
-        OUStringBuffer aDiagnosticMessage( 100 );
-
+        OUString aUserInstallationURL;
+        OUString aUserInstallationPath;
         utl::Bootstrap::locateUserInstallation( aUserInstallationURL );
-
-        if ( aBootstrapError == BE_USERINSTALL_NOTENOUGHDISKSPACE )
-            aErrorMsg = GetMsgString(
-                STR_BOOSTRAP_ERR_NOTENOUGHDISKSPACE,
-                "User installation could not be completed due to insufficient free disk space." );
-        else
-            aErrorMsg = GetMsgString(
-                STR_BOOSTRAP_ERR_NOACCESSRIGHTS,
-                "User installation could not be processed due to missing access rights." );
-
         osl::File::getSystemPathFromFileURL( aUserInstallationURL, aUserInstallationPath );
 
-        aDiagnosticMessage.append( aErrorMsg );
-        aDiagnosticMessage.append( aUserInstallationPath );
-        aMessage = MakeStartupErrorMessage(
-            aDiagnosticMessage.makeStringAndClear() );
-        FatalError(aMessage);
-    }
+        OUString aDiagnosticMessage;
+        if ( aBootstrapError == BE_USERINSTALL_NOTENOUGHDISKSPACE )
+            aDiagnosticMessage = DpResId(STR_BOOSTRAP_ERR_NOTENOUGHDISKSPACE);
+        else
+            aDiagnosticMessage = DpResId(STR_BOOSTRAP_ERR_NOACCESSRIGHTS);
+        aDiagnosticMessage += aUserInstallationPath;
 
-    return;
+        FatalError(MakeStartupErrorMessage(aDiagnosticMessage));
+    }
 }
 
 
@@ -1112,6 +982,15 @@ void impl_checkRecoveryState(bool& bCrashed           ,
     bSessionDataExists = elements && session;
 }
 
+Reference< css::frame::XSynchronousDispatch > g_xRecoveryUI;
+
+template <class Ref>
+struct RefClearGuard
+{
+    Ref& m_Ref;
+    RefClearGuard(Ref& ref) : m_Ref(ref) {}
+    ~RefClearGuard() { m_Ref.clear(); }
+};
 
 /*  @short  start the recovery wizard.
 
@@ -1126,12 +1005,13 @@ bool impl_callRecoveryUI(bool bEmergencySave     ,
 
     css::uno::Reference< css::uno::XComponentContext > xContext = ::comphelper::getProcessComponentContext();
 
-    Reference< css::frame::XSynchronousDispatch > xRecoveryUI(
+    g_xRecoveryUI.set(
         xContext->getServiceManager()->createInstanceWithContext("com.sun.star.comp.svx.RecoveryUI", xContext),
         css::uno::UNO_QUERY_THROW);
+    RefClearGuard<Reference< css::frame::XSynchronousDispatch >> refClearGuard(g_xRecoveryUI);
 
     Reference< css::util::XURLTransformer > xURLParser =
-        css::util::URLTransformer::create(::comphelper::getProcessComponentContext());
+        css::util::URLTransformer::create(xContext);
 
     css::util::URL aURL;
     if (bEmergencySave)
@@ -1143,6 +1023,24 @@ bool impl_callRecoveryUI(bool bEmergencySave     ,
 
     xURLParser->parseStrict(aURL);
 
+    css::uno::Any aRet = g_xRecoveryUI->dispatchWithReturnValue(aURL, css::uno::Sequence< css::beans::PropertyValue >());
+    bool bRet = false;
+    aRet >>= bRet;
+    return bRet;
+}
+
+bool impl_bringToFrontRecoveryUI()
+{
+    Reference< css::frame::XSynchronousDispatch > xRecoveryUI(g_xRecoveryUI);
+    if (!xRecoveryUI.is())
+        return false;
+
+    css::util::URL aURL;
+    aURL.Complete = "vnd.sun.star.autorecovery:/doBringToFront";
+    Reference< css::util::XURLTransformer > xURLParser =
+        css::util::URLTransformer::create(::comphelper::getProcessComponentContext());
+    xURLParser->parseStrict(aURL);
+
     css::uno::Any aRet = xRecoveryUI->dispatchWithReturnValue(aURL, css::uno::Sequence< css::beans::PropertyValue >());
     bool bRet = false;
     aRet >>= bRet;
@@ -1158,8 +1056,7 @@ void restartOnMac(bool passArguments) {
     RequestHandler::Disable();
 #if HAVE_FEATURE_MACOSX_SANDBOX
     (void) passArguments; // avoid warnings
-    ResMgr *resMgr = Desktop::GetDesktopResManager();
-    OUString aMessage = ResId(STR_LO_MUST_BE_RESTARTED, *resMgr);
+    OUString aMessage = DpResId(STR_LO_MUST_BE_RESTARTED);
 
     MessageDialog aRestartBox(NULL, aMessage);
     aRestartBox.Execute();
@@ -1232,6 +1129,20 @@ void restartOnMac(bool passArguments) {
 #endif
 }
 
+#if HAVE_FEATURE_UPDATE_MAR
+bool isTimeForUpdateCheck()
+{
+    sal_uInt64 nLastUpdate = officecfg::Office::Update::Update::LastUpdateTime::get();
+    sal_uInt64 nNow = tools::Time::GetSystemTicks();
+
+    sal_uInt64 n7DayInMS = 1000 * 60 * 60 * 12 * 1; // 12 hours in ms
+    if (nNow - n7DayInMS >= nLastUpdate)
+        return true;
+
+    return false;
+}
+#endif
+
 }
 
 void Desktop::Exception(ExceptionCategory nCategory)
@@ -1243,8 +1154,7 @@ void Desktop::Exception(ExceptionCategory nCategory)
     Application::SetSystemWindowMode( nOldMode & ~SystemWindowFlags::NOAUTOMODE );
     if ( bInException )
     {
-        OUString aDoubleExceptionString;
-        Application::Abort( aDoubleExceptionString );
+        Application::Abort( OUString() );
     }
 
     bInException = true;
@@ -1274,8 +1184,7 @@ void Desktop::Exception(ExceptionCategory nCategory)
     {
         case ExceptionCategory::ResourceNotLoaded:
         {
-            OUString aResExceptionString;
-            Application::Abort( aResExceptionString );
+            Application::Abort( OUString() );
             break;
         }
 
@@ -1328,23 +1237,6 @@ struct ExecuteGlobals
 
 static ExecuteGlobals* pExecGlobals = nullptr;
 
-
-//This just calls Execute() for all normal uses of LibreOffice, but for
-//ui-testing if built with afl-clang-fast++ then on exit it will pseudo-restart
-//(up to 100 times)
-void Desktop::DoExecute()
-{
-#if !defined(__AFL_HAVE_MANUAL_CONTROL)
-    Execute();
-#else
-    while (__AFL_LOOP(1000))
-    {
-        Execute();
-        OpenDefault();
-    }
-#endif
-}
-
 int Desktop::Main()
 {
     pExecGlobals = new ExecuteGlobals();
@@ -1387,7 +1279,7 @@ int Desktop::Main()
     }
 #endif
 
-    ResMgr::SetReadStringHook( ReplaceStringHookProc );
+    Translate::SetReadStringHook(ReplaceStringHookProc);
 
     // Startup screen
     OpenSplashScreen();
@@ -1425,13 +1317,18 @@ int Desktop::Main()
 #if HAVE_FEATURE_DESKTOP
         // check user installation directory for lockfile so we can be sure
         // there is no other instance using our data files from a remote host
-        m_xLockfile.reset(new Lockfile);
 
-        if ( !rCmdLineArgs.IsHeadless() && !rCmdLineArgs.IsInvisible() &&
-             !rCmdLineArgs.IsNoLockcheck() && !m_xLockfile->check( Lockfile_execWarning ))
+        bool bMustLockProfile = ( getenv( "SAL_NOLOCK_PROFILE" ) == nullptr );
+        if ( bMustLockProfile )
         {
-            // Lockfile exists, and user clicked 'no'
-            return EXIT_FAILURE;
+            m_xLockfile.reset(new Lockfile);
+
+            if ( !rCmdLineArgs.IsHeadless() && !rCmdLineArgs.IsInvisible() &&
+                 !rCmdLineArgs.IsNoLockcheck() && !m_xLockfile->check( Lockfile_execWarning ))
+            {
+                // Lockfile exists, and user clicked 'no'
+                return EXIT_FAILURE;
+            }
         }
 
         // check if accessibility is enabled but not working and allow to quit
@@ -1450,6 +1347,84 @@ int Desktop::Main()
         if ( !InitializeConfiguration() )
             return EXIT_FAILURE;
 
+#if HAVE_FEATURE_UPDATE_MAR
+        const char* pUpdaterTestEnable = std::getenv("LIBO_UPDATER_TEST_ENABLE");
+        if (pUpdaterTestEnable || officecfg::Office::Update::Update::Enabled::get())
+        {
+            // check if we just updated
+            const char* pUpdaterRunning = std::getenv("LIBO_UPDATER_TEST_RUNNING");
+            bool bUpdateRunning = officecfg::Office::Update::Update::UpdateRunning::get() || pUpdaterRunning;
+            if (bUpdateRunning)
+            {
+                OUString aSeeAlso = officecfg::Office::Update::Update::SeeAlso::get();
+                OUString aOldBuildID = officecfg::Office::Update::Update::OldBuildID::get();
+
+                OUString aBuildID = Updater::getBuildID();
+                if (aOldBuildID == aBuildID)
+                {
+                    Updater::log("Old and new Build ID are the same. No Updating took place.");
+                }
+                else
+                {
+                    if (!aSeeAlso.isEmpty())
+                    {
+                        SAL_INFO("desktop.updater", "See also: " << aSeeAlso);
+                                Reference< css::system::XSystemShellExecute > xSystemShell(
+                        SystemShellExecute::create(::comphelper::getProcessComponentContext()) );
+
+                        xSystemShell->execute( aSeeAlso, OUString(), SystemShellExecuteFlags::URIS_ONLY );
+                    }
+                }
+
+                // reset all the configuration values,
+                // all values need to be read before this code
+                std::shared_ptr< comphelper::ConfigurationChanges > batch(
+                        comphelper::ConfigurationChanges::create());
+                officecfg::Office::Update::Update::UpdateRunning::set(false, batch);
+                officecfg::Office::Update::Update::SeeAlso::set(OUString(), batch);
+                officecfg::Office::Update::Update::OldBuildID::set(OUString(), batch);
+                batch->commit();
+
+                Updater::removeUpdateFiles();
+            }
+
+            osl::DirectoryItem aUpdateFile;
+            osl::DirectoryItem::get(Updater::getUpdateFileURL(), aUpdateFile);
+
+            const char* pUpdaterTestUpdate = std::getenv("LIBO_UPDATER_TEST_UPDATE");
+            const char* pForcedUpdateCheck = std::getenv("LIBO_UPDATER_TEST_UPDATE_CHECK");
+            if (pUpdaterTestUpdate || aUpdateFile.is())
+            {
+                OUString aBuildID("${$BRAND_BASE_DIR/" LIBO_ETC_FOLDER "/" SAL_CONFIGFILE("version") ":buildid}");
+                rtl::Bootstrap::expandMacros(aBuildID);
+                std::shared_ptr< comphelper::ConfigurationChanges > batch(
+                        comphelper::ConfigurationChanges::create());
+                officecfg::Office::Update::Update::OldBuildID::set(aBuildID, batch);
+                officecfg::Office::Update::Update::UpdateRunning::set(true, batch);
+                batch->commit();
+
+                // make sure the change is written to the configuration before we start the update
+                css::uno::Reference<css::util::XFlushable> xFlushable(css::configuration::theDefaultProvider::get(xContext), UNO_QUERY);;
+                xFlushable->flush();
+                // avoid the old oosplash staying around
+                CloseSplashScreen();
+                bool bSuccess = update();
+                if (bSuccess)
+                    return EXIT_SUCCESS;
+            }
+            else if (isTimeForUpdateCheck() || pForcedUpdateCheck)
+            {
+                sal_uInt64 nNow = tools::Time::GetSystemTicks();
+                Updater::log("Update Check Time: " + OUString::number(nNow));
+                std::shared_ptr< comphelper::ConfigurationChanges > batch(
+                        comphelper::ConfigurationChanges::create());
+                officecfg::Office::Update::Update::LastUpdateTime::set(nNow, batch);
+                batch->commit();
+                m_aUpdateThread = std::thread(update_checker);
+            }
+        }
+#endif
+
         SetSplashScreenProgress(30);
 
         // create title string
@@ -1457,9 +1432,8 @@ int Desktop::Main()
 
 #ifdef DBG_UTIL
         //include buildid in non product builds
-        OUString aDefault("development");
         aTitle += " [";
-        aTitle += utl::Bootstrap::getBuildIdData(aDefault);
+        aTitle += utl::Bootstrap::getBuildIdData("development");
         aTitle += "]";
 #endif
 
@@ -1535,7 +1509,7 @@ int Desktop::Main()
                 }
                 else
                 {
-                    SAL_WARN("desktop.app", "cannot open pidfile " << pidfile.getURL() << osl::FileBase::RC(rc));
+                    SAL_WARN("desktop.app", "cannot open pidfile " << pidfile.getURL() << rc);
                 }
             }
             else
@@ -1592,7 +1566,6 @@ int Desktop::Main()
     if ( !pExecGlobals->bRestartRequested )
     {
         Application::SetFilterHdl( LINK( this, Desktop, ImplInitFilterHdl ) );
-        bool bTerminateRequested = false;
 
         // Preload function depends on an initialized sfx application!
         SetSplashScreenProgress(75);
@@ -1602,7 +1575,7 @@ int Desktop::Main()
 
         SetSplashScreenProgress(80);
 
-        if ( !bTerminateRequested && !rCmdLineArgs.IsInvisible() &&
+        if ( !rCmdLineArgs.IsInvisible() &&
              !rCmdLineArgs.IsNoQuickstart() )
             InitializeQuickstartMode( xContext );
 
@@ -1622,6 +1595,15 @@ int Desktop::Main()
         CheckOpenCLCompute(xDesktop);
 #endif
 
+        // In headless mode, reap the process started by fire_glxtest_process() early in soffice_main
+        // (desktop/source/app/sofficemain.cxx), in a code block that needs to be covered by the same
+        // #if condition as this code block:
+#if defined( UNX ) && !defined MACOSX && !defined IOS && !defined ANDROID && !defined(LIBO_HEADLESS) && HAVE_FEATURE_OPENGL
+        if (rCmdLineArgs.IsHeadless()) {
+            reap_glxtest_process();
+        }
+#endif
+
         // Release solar mutex just before we wait for our client to connect
         {
             SolarMutexReleaser aReleaser;
@@ -1655,7 +1637,7 @@ int Desktop::Main()
                 // if this run of the office is triggered by restart, some additional actions should be done
                 DoRestartActionsIfNecessary( !rCmdLineArgs.IsInvisible() && !rCmdLineArgs.IsNoQuickstart() );
 
-                DoExecute();
+                Execute();
             }
         }
         catch(const css::document::CorruptedFilterConfigurationException& exFilterCfg)
@@ -1699,6 +1681,9 @@ int Desktop::doShutdown()
     if( ! pExecGlobals )
         return EXIT_SUCCESS;
 
+    if (m_aUpdateThread.joinable())
+        m_aUpdateThread.join();
+
     pExecGlobals->bRestartRequested = pExecGlobals->bRestartRequested ||
         OfficeRestartManager::get(comphelper::getProcessComponentContext())->
         isRestartRequested(true);
@@ -1712,8 +1697,6 @@ int Desktop::doShutdown()
         pExecGlobals->xGlobalBroadcaster->documentEventOccured(aEvent);
     }
 
-    delete pResMgr;
-    pResMgr = nullptr;
     // Restore old value
     const CommandLineArgs& rCmdLineArgs = GetCommandLineArgs();
     if ( rCmdLineArgs.IsHeadless() || rCmdLineArgs.IsEventTesting() )
@@ -1989,8 +1972,7 @@ IMPL_LINK_NOARG(Desktop, OpenClients_Impl, void*, void)
         if (pExitPostStartup && *pExitPostStartup)
             new ExitTimer();
     } catch (const css::uno::Exception &e) {
-        OUString a( "UNO exception during client open:\n"  );
-        Application::Abort( a + e.Message );
+        Application::Abort( "UNO exception during client open: " + e.Message );
     }
 }
 
@@ -2005,40 +1987,33 @@ void Desktop::OpenClients()
 
     if (!rArgs.IsQuickstart())
     {
-        bool bShowHelp = false;
-        OUStringBuffer aHelpURLBuffer;
+        OUString aHelpModule;
         if (rArgs.IsHelpWriter()) {
-            bShowHelp = true;
-            aHelpURLBuffer.append("vnd.sun.star.help://swriter/start");
+            aHelpModule = "swriter";
         } else if (rArgs.IsHelpCalc()) {
-            bShowHelp = true;
-            aHelpURLBuffer.append("vnd.sun.star.help://scalc/start");
+            aHelpModule = "scalc";
         } else if (rArgs.IsHelpDraw()) {
-            bShowHelp = true;
-            aHelpURLBuffer.append("vnd.sun.star.help://sdraw/start");
+            aHelpModule = "sdraw";
         } else if (rArgs.IsHelpImpress()) {
-            bShowHelp = true;
-            aHelpURLBuffer.append("vnd.sun.star.help://simpress/start");
+            aHelpModule = "simpress";
         } else if (rArgs.IsHelpBase()) {
-            bShowHelp = true;
-            aHelpURLBuffer.append("vnd.sun.star.help://sdatabase/start");
+            aHelpModule = "sdatabase";
         } else if (rArgs.IsHelpBasic()) {
-            bShowHelp = true;
-            aHelpURLBuffer.append("vnd.sun.star.help://sbasic/start");
+            aHelpModule = "sbasic";
         } else if (rArgs.IsHelpMath()) {
-            bShowHelp = true;
-            aHelpURLBuffer.append("vnd.sun.star.help://smath/start");
+            aHelpModule = "smath";
         }
-        if (bShowHelp) {
-            aHelpURLBuffer.append("?Language=");
-            aHelpURLBuffer.append(utl::ConfigManager::getLocale());
+        if (!aHelpModule.isEmpty()) {
+            OUString aHelpURL = "vnd.sun.star.help://"
+                              + aHelpModule
+                              + "/start?Language="
+                              + utl::ConfigManager::getLocale();
 #if defined UNX
-            aHelpURLBuffer.append("&System=UNX");
+            aHelpURL += "&System=UNX";
 #elif defined WNT
-            aHelpURLBuffer.append("&System=WIN");
+            aHelpURL += "&System=WIN";
 #endif
-            Application::GetHelp()->Start(
-                aHelpURLBuffer.makeStringAndClear(), nullptr);
+            Application::GetHelp()->Start(aHelpURL, nullptr);
             return;
         }
     }
@@ -2079,7 +2054,7 @@ void Desktop::OpenClients()
         }
         catch(const css::uno::Exception& e)
         {
-            SAL_WARN( "desktop.app", "Could not disable AutoRecovery." << e.Message);
+            SAL_WARN( "desktop.app", "Could not disable AutoRecovery." << e);
         }
     }
     else
@@ -2093,8 +2068,8 @@ void Desktop::OpenClients()
 
         if ( !bDisableRecovery &&
             (
-                ( bExistsRecoveryData ) || // => crash with files    => recovery
-                ( bCrashed            )    // => crash without files => error report
+                bExistsRecoveryData || // => crash with files    => recovery
+                bCrashed               // => crash without files => error report
             )
            )
         {
@@ -2106,7 +2081,7 @@ void Desktop::OpenClients()
             }
             catch(const css::uno::Exception& e)
             {
-                SAL_WARN( "desktop.app", "Error during recovery" << e.Message);
+                SAL_WARN( "desktop.app", "Error during recovery" << e);
             }
         }
         else if (bExistsRecoveryData && bDisableRecovery && !rArgs.HasModuleParam())
@@ -2123,7 +2098,7 @@ void Desktop::OpenClients()
         }
         catch(const css::uno::Exception& e)
         {
-            SAL_WARN( "desktop.app", "Registration of session listener failed" << e.Message);
+            SAL_WARN( "desktop.app", "Registration of session listener failed" << e);
         }
 
         if ( !bExistsRecoveryData && xSessionListener.is() )
@@ -2135,7 +2110,7 @@ void Desktop::OpenClients()
             }
             catch(const css::uno::Exception& e)
             {
-                SAL_WARN( "desktop.app", "Error in session management" << e.Message);
+                SAL_WARN( "desktop.app", "Error in session management" << e);
             }
         }
     }
@@ -2159,8 +2134,10 @@ void Desktop::OpenClients()
     aRequest.aConversionList = rArgs.GetConversionList();
     aRequest.aConversionParams = rArgs.GetConversionParams();
     aRequest.aConversionOut = rArgs.GetConversionOut();
+    aRequest.aImageConversionType = rArgs.GetImageConversionType();
     aRequest.aInFilter = rArgs.GetInFilter();
     aRequest.bTextCat = rArgs.IsTextCat();
+    aRequest.bScriptCat = rArgs.IsScriptCat();
 
     if ( !aRequest.aOpenList.empty() ||
          !aRequest.aViewList.empty() ||
@@ -2192,12 +2169,8 @@ void Desktop::OpenClients()
         {
             aRequest.aPrintList.clear();
             aRequest.aPrintToList.clear();
-            ResMgr* pDtResMgr = GetDesktopResManager();
-            if( pDtResMgr )
-            {
-                ScopedVclPtrInstance< MessageDialog > aBox(nullptr, ResId(STR_ERR_PRINTDISABLED, *pDtResMgr));
-                aBox->Execute();
-            }
+            ScopedVclPtrInstance< MessageDialog > aBox(nullptr, DpResId(STR_ERR_PRINTDISABLED));
+            aBox->Execute();
         }
 
         // Process request
@@ -2338,7 +2311,7 @@ void Desktop::HandleAppEvent( const ApplicationEvent& rAppEvent )
         createAcceptor(rAppEvent.GetStringData());
         break;
     case ApplicationEvent::Type::Appear:
-        if ( !GetCommandLineArgs().IsInvisible() )
+        if ( !GetCommandLineArgs().IsInvisible() && !impl_bringToFrontRecoveryUI() )
         {
             Reference< css::uno::XComponentContext > xContext = ::comphelper::getProcessComponentContext();
 
@@ -2514,9 +2487,8 @@ void Desktop::OpenSplashScreen()
         if ( rCmdLine.HasSplashPipe() )
             aSplashService = "com.sun.star.office.PipeSplashScreen";
 
-        bool bVisible = true;
         Sequence< Any > aSeq( 2 );
-        aSeq[0] <<= bVisible;
+        aSeq[0] <<= true; // bVisible
         aSeq[1] <<= aAppName;
         css::uno::Reference< css::uno::XComponentContext > xContext = ::comphelper::getProcessComponentContext();
         m_rSplashScreen.set(
@@ -2588,12 +2560,12 @@ void Desktop::ShowBackingComponent(Desktop * progress)
         xContainerWindow = xBackingFrame->getContainerWindow();
     if (xContainerWindow.is())
     {
-        // set the WB_EXT_DOCUMENT style. Normally, this is done by the TaskCreator service when a "_blank"
+        // set the WindowExtendedStyle::Document style. Normally, this is done by the TaskCreator service when a "_blank"
         // frame/window is created. Since we do not use the TaskCreator here, we need to mimic its behavior,
         // otherwise documents loaded into this frame will later on miss functionality depending on the style.
         VclPtr<vcl::Window> pContainerWindow = VCLUnoHelper::GetWindow( xContainerWindow );
         SAL_WARN_IF( !pContainerWindow, "desktop.app", "Desktop::Main: no implementation access to the frame's container window!" );
-        pContainerWindow->SetExtendedStyle( pContainerWindow->GetExtendedStyle() | WB_EXT_DOCUMENT );
+        pContainerWindow->SetExtendedStyle( pContainerWindow->GetExtendedStyle() | WindowExtendedStyle::Document );
         if (progress != nullptr)
         {
             progress->SetSplashScreenProgress(75);
@@ -2628,12 +2600,12 @@ void Desktop::CheckFirstRun( )
 
 #ifdef _WIN32
         // Check if Quickstarter should be started (on Windows only)
-        TCHAR szValue[8192];
+        WCHAR szValue[8192];
         DWORD nValueSize = sizeof(szValue);
         HKEY hKey;
-        if ( ERROR_SUCCESS == RegOpenKey( HKEY_LOCAL_MACHINE,  "Software\\LibreOffice", &hKey ) )
+        if ( ERROR_SUCCESS == RegOpenKeyW( HKEY_LOCAL_MACHINE, L"Software\\LibreOffice", &hKey ) )
         {
-            if ( ERROR_SUCCESS == RegQueryValueEx( hKey, TEXT("RunQuickstartAtFirstStart"), nullptr, nullptr, reinterpret_cast<LPBYTE>(szValue), &nValueSize ) )
+            if ( ERROR_SUCCESS == RegQueryValueExW( hKey, L"RunQuickstartAtFirstStart", nullptr, nullptr, reinterpret_cast<LPBYTE>(szValue), &nValueSize ) )
             {
                 css::uno::Reference< css::uno::XComponentContext > xContext = ::comphelper::getProcessComponentContext();
                 css::office::Quickstart::createAutoStart(xContext, true/*Quickstart*/, true/*bAutostart*/);
