@@ -22,10 +22,10 @@
 
 #include <config_vclplug.h>
 
-#include "app.hxx"
+#include <app.hxx>
+#include <dp_shared.hxx>
 #include "cmdlineargs.hxx"
-#include "desktopresid.hxx"
-#include "desktop.hrc"
+#include <strings.hrc>
 #include <com/sun/star/registry/XSimpleRegistry.hpp>
 #include <com/sun/star/lang/XComponent.hpp>
 #include <com/sun/star/lang/XInitialization.hpp>
@@ -45,14 +45,13 @@
 #include <rtl/bootstrap.hxx>
 #include <sal/log.hxx>
 
-#include <tools/rcid.h>
-
 #include <rtl/instance.hxx>
 #include <comphelper/processfactory.hxx>
 #include <unotools/ucbhelper.hxx>
 #include <unotools/tempfile.hxx>
 #include <vcl/svapp.hxx>
 #include <unotools/pathoptions.hxx>
+#include <sfx2/safemode.hxx>
 #include <map>
 
 using namespace desktop;
@@ -66,7 +65,6 @@ namespace desktop
 {
 
 
-
 static void configureUcb()
 {
     // For backwards compatibility, in case some code still uses plain
@@ -153,13 +151,13 @@ void Desktop::createAcceptor(const OUString& aAcceptString)
             try
             {
                 rAcceptor->initialize( aSeq );
-                rMap.insert(AcceptorMap::value_type(aAcceptString, rAcceptor));
+                rMap.emplace(aAcceptString, rAcceptor);
             }
             catch (const css::uno::Exception& e)
             {
                 // no error handling needed...
                 // acceptor just won't come up
-                SAL_WARN( "desktop.app", "Acceptor could not be created: " << e.Message);
+                SAL_WARN( "desktop.app", "Acceptor could not be created: " << e);
             }
         }
         else
@@ -176,7 +174,7 @@ class enable
     Sequence<Any> m_aSeq;
     public:
     enable() : m_aSeq(1) {
-        m_aSeq[0] <<= sal_True;
+        m_aSeq[0] <<= true;
     }
     void operator() (const AcceptorMap::value_type& val) {
         if (val.second.is()) {
@@ -185,7 +183,8 @@ class enable
     }
 };
 
-void Desktop::enableAcceptors()
+// enable acceptors
+IMPL_STATIC_LINK_NOARG(Desktop, EnableAcceptors_Impl, void*, void)
 {
     if (!bAccept)
     {
@@ -237,13 +236,7 @@ void Desktop::CreateTemporaryDirectory()
     {
         // Catch runtime exception here: We have to add language dependent info
         // to the exception message. Fallback solution uses hard coded string.
-        OUString aMsg;
-        DesktopResId aResId( STR_BOOTSTRAP_ERR_NO_PATHSET_SERVICE );
-        aResId.SetRT( RSC_STRING );
-        if ( aResId.GetResMgr()->IsAvailable( aResId ))
-            aMsg = OUString( aResId );
-        else
-            aMsg = "The path manager is not available.\n";
+        OUString aMsg = DpResId(STR_BOOTSTRAP_ERR_NO_PATHSET_SERVICE);
         e.Message = aMsg + e.Message;
         throw;
     }
