@@ -20,19 +20,22 @@
 #include <vcl/svapp.hxx>
 #include <vcl/msgbox.hxx>
 
-#include <osl/mutex.hxx>
-
 #include <toolkit/helper/vclunohelper.hxx>
 
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/configuration/theDefaultProvider.hpp>
+#include <com/sun/star/deployment/DeploymentException.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
+#include <com/sun/star/frame/TerminationVetoException.hpp>
+#include <com/sun/star/ucb/CommandAbortedException.hpp>
+#include <com/sun/star/ucb/CommandFailedException.hpp>
+#include <comphelper/propertysequence.hxx>
 
 #include "dp_gui_dialog2.hxx"
 #include "dp_gui_extensioncmdqueue.hxx"
 #include "dp_gui_theextmgr.hxx"
-#include "dp_identifier.hxx"
-#include "dp_update.hxx"
+#include <dp_identifier.hxx>
+#include <dp_update.hxx>
 
 #define USER_PACKAGE_MANAGER    "user"
 #define SHARED_PACKAGE_MANAGER  "shared"
@@ -42,7 +45,6 @@ using namespace ::com::sun::star;
 namespace dp_gui {
 
 
-
 ::rtl::Reference< TheExtensionManager > TheExtensionManager::s_ExtMgr;
 
 
@@ -55,30 +57,30 @@ TheExtensionManager::TheExtensionManager( const uno::Reference< awt::XWindow > &
     m_xParent( xParent ),
     m_pExtMgrDialog( nullptr ),
     m_pUpdReqDialog( nullptr ),
-    m_pExecuteCmdQueue( nullptr )
+    m_pExecuteCmdQueue( nullptr ),
+    m_bModified(false)
 {
     m_xExtensionManager = deployment::ExtensionManager::get( xContext );
     m_xExtensionManager->addModifyListener( this );
 
     uno::Reference< lang::XMultiServiceFactory > xConfig(
         configuration::theDefaultProvider::get(xContext));
-    uno::Any args[1];
-    beans::PropertyValue aValue( OUString("nodepath"), 0, uno::Any( OUString("/org.openoffice.Office.OptionsDialog/Nodes") ),
-                                 beans::PropertyState_DIRECT_VALUE );
-    args[0] <<= aValue;
+    uno::Sequence<uno::Any> args(comphelper::InitAnyPropertySequence(
+    {
+        {"nodepath", uno::Any(OUString("/org.openoffice.Office.OptionsDialog/Nodes"))}
+    }));
     m_xNameAccessNodes.set(
-        xConfig->createInstanceWithArguments( "com.sun.star.configuration.ConfigurationAccess",
-                                              uno::Sequence< uno::Any >( args, 1 )),
+        xConfig->createInstanceWithArguments( "com.sun.star.configuration.ConfigurationAccess", args),
         uno::UNO_QUERY_THROW);
 
     // get the 'get more extensions here' url
+    uno::Sequence<uno::Any> args2(comphelper::InitAnyPropertySequence(
+    {
+        {"nodepath", uno::Any(OUString("/org.openoffice.Office.ExtensionManager/ExtensionRepositories"))}
+    }));
     uno::Reference< container::XNameAccess > xNameAccessRepositories;
-    beans::PropertyValue aValue2( OUString("nodepath"), 0, uno::Any( OUString("/org.openoffice.Office.ExtensionManager/ExtensionRepositories") ),
-                                  beans::PropertyState_DIRECT_VALUE );
-    args[0] <<= aValue2;
     xNameAccessRepositories.set(
-        xConfig->createInstanceWithArguments( "com.sun.star.configuration.ConfigurationAccess",
-                                              uno::Sequence< uno::Any >( args, 1 )),
+        xConfig->createInstanceWithArguments( "com.sun.star.configuration.ConfigurationAccess", args2),
         uno::UNO_QUERY_THROW);
     try
     {   //throws css::container::NoSuchElementException, css::lang::WrappedTargetException
@@ -189,7 +191,7 @@ bool TheExtensionManager::isVisible()
 }
 
 
-bool TheExtensionManager::checkUpdates( bool /* bShowUpdateOnly */, bool /*bParentVisible*/ )
+void TheExtensionManager::checkUpdates()
 {
     std::vector< uno::Reference< deployment::XPackage >  > vEntries;
     uno::Sequence< uno::Sequence< uno::Reference< deployment::XPackage > > > xAllPackages;
@@ -198,11 +200,11 @@ bool TheExtensionManager::checkUpdates( bool /* bShowUpdateOnly */, bool /*bPare
         xAllPackages = m_xExtensionManager->getAllExtensions( uno::Reference< task::XAbortChannel >(),
                                                               uno::Reference< ucb::XCommandEnvironment >() );
     } catch ( const deployment::DeploymentException & ) {
-        return false;
+        return;
     } catch ( const ucb::CommandFailedException & ) {
-        return false;
+        return;
     } catch ( const ucb::CommandAbortedException & ) {
-        return false;
+        return;
     } catch ( const lang::IllegalArgumentException & e ) {
         throw uno::RuntimeException( e.Message, e.Context );
     }
@@ -218,7 +220,6 @@ bool TheExtensionManager::checkUpdates( bool /* bShowUpdateOnly */, bool /*bPare
     }
 
     m_pExecuteCmdQueue->checkForUpdates( vEntries );
-    return true;
 }
 
 
@@ -341,8 +342,7 @@ PackageState TheExtensionManager::getPackageState( const uno::Reference< deploym
         throw;
     }
     catch (const uno::Exception & exc) {
-        (void) exc;
-        OSL_FAIL( OUStringToOString( exc.Message, RTL_TEXTENCODING_UTF8 ).getStr() );
+        SAL_WARN( "desktop", exc );
         return NOT_AVAILABLE;
     }
 }
@@ -378,7 +378,7 @@ bool TheExtensionManager::supportsOptions( const uno::Reference< deployment::XPa
     for ( int i = 0; i < seqNames.getLength(); i++ )
     {
         uno::Any anyNode = m_xNameAccessNodes->getByName( seqNames[i] );
-        //If we have a node then then it must contain the set of leaves. This is part of OptionsDialog.xcs
+        //If we have a node then it must contain the set of leaves. This is part of OptionsDialog.xcs
         uno::Reference< XInterface> xIntNode = anyNode.get< uno::Reference< XInterface > >();
         uno::Reference< container::XNameAccess > xNode( xIntNode, uno::UNO_QUERY_THROW );
 
@@ -413,7 +413,6 @@ bool TheExtensionManager::supportsOptions( const uno::Reference< deployment::XPa
 
 // XEventListener
 void TheExtensionManager::disposing( lang::EventObject const & rEvt )
-    throw ( uno::RuntimeException, std::exception )
 {
     bool shutDown = (rEvt.Source == m_xDesktop);
 
@@ -438,7 +437,6 @@ void TheExtensionManager::disposing( lang::EventObject const & rEvt )
 
 // XTerminateListener
 void TheExtensionManager::queryTermination( ::lang::EventObject const & )
-    throw ( frame::TerminationVetoException, uno::RuntimeException, std::exception )
 {
     DialogHelper *pDialogHelper = getDialogHelper();
 
@@ -460,7 +458,6 @@ void TheExtensionManager::queryTermination( ::lang::EventObject const & )
 
 
 void TheExtensionManager::notifyTermination( ::lang::EventObject const & rEvt )
-    throw ( uno::RuntimeException, std::exception )
 {
     disposing( rEvt );
 }
@@ -468,8 +465,8 @@ void TheExtensionManager::notifyTermination( ::lang::EventObject const & rEvt )
 
 // XModifyListener
 void TheExtensionManager::modified( ::lang::EventObject const & /*rEvt*/ )
-    throw ( uno::RuntimeException, std::exception )
 {
+    m_bModified = true;
     getDialogHelper()->prepareChecking();
     createPackageList();
     getDialogHelper()->checkEntries();
