@@ -82,11 +82,10 @@
 #include <salhelper/thread.hxx>
 #include <svtools/svlbitm.hxx>
 #include <svtools/treelistbox.hxx>
-#include <svtools/controldims.hrc>
+#include <svtools/controldims.hxx>
 #include <svx/checklbx.hxx>
 #include <tools/gen.hxx>
 #include <tools/link.hxx>
-#include <tools/resid.hxx>
 #include <tools/solar.h>
 #include <unotools/configmgr.hxx>
 #include <vcl/button.hxx>
@@ -95,22 +94,22 @@
 #include <vcl/image.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/svapp.hxx>
-#include <osl/mutex.hxx>
 
 #include <comphelper/processfactory.hxx>
 
-#include "dp_dependencies.hxx"
-#include "dp_descriptioninfoset.hxx"
-#include "dp_identifier.hxx"
-#include "dp_version.hxx"
-#include "dp_misc.h"
-#include "dp_update.hxx"
+#include <dp_dependencies.hxx>
+#include <dp_descriptioninfoset.hxx>
+#include <dp_identifier.hxx>
+#include <dp_version.hxx>
+#include <dp_misc.h>
+#include <dp_update.hxx>
 
 #include "dp_gui.h"
-#include "dp_gui.hrc"
+#include <strings.hrc>
+#include <bitmaps.hlst>
 #include "dp_gui_updatedata.hxx"
 #include "dp_gui_updatedialog.hxx"
-#include "dp_gui_shared.hxx"
+#include <dp_shared.hxx>
 
 class KeyEvent;
 class MouseEvent;
@@ -149,20 +148,18 @@ struct UpdateDialog::DisabledUpdate {
     uno::Sequence< OUString > unsatisfiedDependencies;
     // We also want to show release notes and publisher for disabled updates
     css::uno::Reference< css::xml::dom::XNode > aUpdateInfo;
-    sal_uInt16                m_nID;
 };
 
 struct UpdateDialog::SpecificError {
     OUString name;
     OUString message;
-    sal_uInt16 m_nID;
 };
 
 
 struct UpdateDialog::IgnoredUpdate {
     OUString sExtensionID;
     OUString sVersion;
-    bool          bRemoved;
+    bool     bRemoved;
 
     IgnoredUpdate( const OUString &rExtensionID, const OUString &rVersion );
 };
@@ -217,8 +214,8 @@ private:
         dp_gui::UpdateData & out_data) const;
 
     bool update(
-        UpdateDialog::DisabledUpdate & du,
-        dp_gui::UpdateData & data) const;
+        UpdateDialog::DisabledUpdate const & du,
+        dp_gui::UpdateData const & data) const;
 
     uno::Reference< uno::XComponentContext > m_context;
     UpdateDialog & m_dialog;
@@ -227,7 +224,6 @@ private:
     uno::Reference< task::XInteractionHandler > m_xInteractionHdl;
 
     // guarded by Application::GetSolarMutex():
-    uno::Reference< task::XAbortChannel > m_abort;
     bool m_stop;
 };
 
@@ -253,15 +249,10 @@ UpdateDialog::Thread::Thread(
 }
 
 void UpdateDialog::Thread::stop() {
-    uno::Reference< task::XAbortChannel > abort;
     {
         SolarMutexGuard g;
-        abort = m_abort;
         m_stop = true;
     }
-    if (abort.is()) {
-        abort->sendAbort();
-    }
     m_updateInformation->cancel();
 }
 
@@ -334,7 +325,6 @@ void UpdateDialog::Thread::execute()
         dp_misc::UPDATE_SOURCE sourceShared = dp_misc::isUpdateSharedExtension(
             bSharedReadOnly, sVersionShared, sVersionBundled, sOnlineVersion);
 
-        uno::Reference<deployment::XPackage> updateSource;
         if (sourceUser != dp_misc::UPDATE_SOURCE_NONE)
         {
             if (sourceUser == dp_misc::UPDATE_SOURCE_SHARED)
@@ -452,8 +442,8 @@ void UpdateDialog::Thread::prepareUpdateData(
 }
 
 bool UpdateDialog::Thread::update(
-    UpdateDialog::DisabledUpdate & du,
-    dp_gui::UpdateData & data) const
+    UpdateDialog::DisabledUpdate const & du,
+    dp_gui::UpdateData const & data) const
 {
     bool ret = false;
     if (du.unsatisfiedDependencies.getLength() == 0)
@@ -482,22 +472,21 @@ UpdateDialog::UpdateDialog(
     std::vector< dp_gui::UpdateData > * updateData):
     ModalDialog(parent, "UpdateDialog", "desktop/ui/updatedialog.ui"),
     m_context(context),
-    m_none(DPGUI_RESSTR(RID_DLG_UPDATE_NONE)),
-    m_noInstallable(DPGUI_RESSTR(RID_DLG_UPDATE_NOINSTALLABLE)),
-    m_failure(DPGUI_RESSTR(RID_DLG_UPDATE_FAILURE)),
-    m_unknownError(DPGUI_RESSTR(RID_DLG_UPDATE_UNKNOWNERROR)),
-    m_noDescription(DPGUI_RESSTR(RID_DLG_UPDATE_NODESCRIPTION)),
-    m_noInstall(DPGUI_RESSTR(RID_DLG_UPDATE_NOINSTALL)),
-    m_noDependency(DPGUI_RESSTR(RID_DLG_UPDATE_NODEPENDENCY)),
-    m_noDependencyCurVer(DPGUI_RESSTR(RID_DLG_UPDATE_NODEPENDENCY_CUR_VER)),
-    m_browserbased(DPGUI_RESSTR(RID_DLG_UPDATE_BROWSERBASED)),
-    m_version(DPGUI_RESSTR(RID_DLG_UPDATE_VERSION)),
-    m_ignoredUpdate(DPGUI_RESSTR(RID_DLG_UPDATE_IGNORED_UPDATE)),
+    m_none(DpResId(RID_DLG_UPDATE_NONE)),
+    m_noInstallable(DpResId(RID_DLG_UPDATE_NOINSTALLABLE)),
+    m_failure(DpResId(RID_DLG_UPDATE_FAILURE)),
+    m_unknownError(DpResId(RID_DLG_UPDATE_UNKNOWNERROR)),
+    m_noDescription(DpResId(RID_DLG_UPDATE_NODESCRIPTION)),
+    m_noInstall(DpResId(RID_DLG_UPDATE_NOINSTALL)),
+    m_noDependency(DpResId(RID_DLG_UPDATE_NODEPENDENCY)),
+    m_noDependencyCurVer(DpResId(RID_DLG_UPDATE_NODEPENDENCY_CUR_VER)),
+    m_browserbased(DpResId(RID_DLG_UPDATE_BROWSERBASED)),
+    m_version(DpResId(RID_DLG_UPDATE_VERSION)),
+    m_ignoredUpdate(DpResId(RID_DLG_UPDATE_IGNORED_UPDATE)),
     m_updateData(*updateData),
     m_thread(
         new UpdateDialog::Thread(
             context, *this, vExtensionList)),
-    m_nLastID(1),
     m_bModified( false )
     // TODO: check!
 //    ,
@@ -508,7 +497,7 @@ UpdateDialog::UpdateDialog(
     get(m_pUpdate, "UPDATE_LABEL");
     get(m_pContainer, "UPDATES_CONTAINER");
     m_pUpdates = VclPtr<UpdateDialog::CheckListBox>::Create(m_pContainer, *this);
-    Size aSize(LogicToPixel(Size(240, 51), MapUnit::MapAppFont));
+    Size aSize(LogicToPixel(Size(240, 51), MapMode(MapUnit::MapAppFont)));
     m_pUpdates->set_width_request(aSize.Width());
     m_pUpdates->set_height_request(aSize.Height());
     m_pUpdates->Show();
@@ -519,7 +508,7 @@ UpdateDialog::UpdateDialog(
     get(m_pReleaseNotesLabel, "RELEASE_NOTES_LABEL");
     get(m_pReleaseNotesLink, "RELEASE_NOTES_LINK");
     get(m_pDescriptions, "DESCRIPTIONS");
-    aSize = LogicToPixel(Size(240, 59), MapUnit::MapAppFont);
+    aSize = LogicToPixel(Size(240, 59), MapMode(MapUnit::MapAppFont));
     m_pDescriptions->set_width_request(aSize.Width());
     m_pDescriptions->set_height_request(aSize.Height());
     get(m_pOk, "INSTALL");
@@ -598,12 +587,12 @@ short UpdateDialog::Execute() {
 
 UpdateDialog::CheckListBox::CheckListBox( vcl::Window* pParent, UpdateDialog & dialog):
     SvxCheckListBox( pParent, WinBits(WB_BORDER) ),
-    m_ignoreUpdate( DPGUI_RESSTR( RID_DLG_UPDATE_IGNORE ) ),
-    m_ignoreAllUpdates( DPGUI_RESSTR( RID_DLG_UPDATE_IGNORE_ALL ) ),
-    m_enableUpdate( DPGUI_RESSTR( RID_DLG_UPDATE_ENABLE ) ),
+    m_ignoreUpdate( DpResId( RID_DLG_UPDATE_IGNORE ) ),
+    m_ignoreAllUpdates( DpResId( RID_DLG_UPDATE_IGNORE_ALL ) ),
+    m_enableUpdate( DpResId( RID_DLG_UPDATE_ENABLE ) ),
     m_dialog(dialog)
 {
-    SetNormalStaticImage(Image(DpGuiResId(RID_DLG_UPDATE_NORMALALERT)));
+    SetNormalStaticImage(Image(BitmapEx(RID_DLG_UPDATE_NORMALALERT)));
 }
 
 sal_uInt16 UpdateDialog::CheckListBox::getItemCount() const {
@@ -647,7 +636,7 @@ void UpdateDialog::CheckListBox::handlePopupMenu( const Point &rPos )
 
     if ( pData )
     {
-        sal_uLong nEntryPos = GetSelectEntryPos();
+        sal_uLong nEntryPos = GetSelectedEntryPos();
         UpdateDialog::Index * p = static_cast< UpdateDialog::Index * >( GetEntryData( nEntryPos ) );
 
         if ( ( p->m_eKind == ENABLED_UPDATE ) || ( p->m_eKind == DISABLED_UPDATE ) )
@@ -723,14 +712,11 @@ void UpdateDialog::addAdditional( UpdateDialog::Index * index, SvLBoxButtonKind
 
 
 void UpdateDialog::addEnabledUpdate( OUString const & name,
-                                     dp_gui::UpdateData & data )
+                                     dp_gui::UpdateData const & data )
 {
     sal_uInt16 nIndex = sal::static_int_cast< sal_uInt16 >( m_enabledUpdates.size() );
     UpdateDialog::Index *pEntry = new UpdateDialog::Index( ENABLED_UPDATE, nIndex, name );
 
-    data.m_nID = m_nLastID;
-    m_nLastID += 1;
-
     m_enabledUpdates.push_back( data );
     m_ListboxEntries.push_back( pEntry );
 
@@ -749,14 +735,11 @@ void UpdateDialog::addEnabledUpdate( OUString const & name,
 }
 
 
-void UpdateDialog::addDisabledUpdate( UpdateDialog::DisabledUpdate & data )
+void UpdateDialog::addDisabledUpdate( UpdateDialog::DisabledUpdate const & data )
 {
     sal_uInt16 nIndex = sal::static_int_cast< sal_uInt16 >( m_disabledUpdates.size() );
     UpdateDialog::Index *pEntry = new UpdateDialog::Index( DISABLED_UPDATE, nIndex, data.name );
 
-    data.m_nID = m_nLastID;
-    m_nLastID += 1;
-
     m_disabledUpdates.push_back( data );
     m_ListboxEntries.push_back( pEntry );
 
@@ -765,14 +748,11 @@ void UpdateDialog::addDisabledUpdate( UpdateDialog::DisabledUpdate & data )
 }
 
 
-void UpdateDialog::addSpecificError( UpdateDialog::SpecificError & data )
+void UpdateDialog::addSpecificError( UpdateDialog::SpecificError const & data )
 {
     sal_uInt16 nIndex = sal::static_int_cast< sal_uInt16 >( m_specificErrors.size() );
     UpdateDialog::Index *pEntry = new UpdateDialog::Index( SPECIFIC_ERROR, nIndex, data.name );
 
-    data.m_nID = m_nLastID;
-    m_nLastID += 1;
-
     m_specificErrors.push_back( data );
     m_ListboxEntries.push_back( pEntry );
 
@@ -806,7 +786,7 @@ void UpdateDialog::enableOk() {
 
 // *********************************************************************************
 void UpdateDialog::createNotifyJob( bool bPrepareOnly,
-    uno::Sequence< uno::Sequence< OUString > > &rItemList )
+    uno::Sequence< uno::Sequence< OUString > > const &rItemList )
 {
     if ( !dp_misc::office_is_running() )
         return;
@@ -820,10 +800,10 @@ void UpdateDialog::createNotifyJob( bool bPrepareOnly,
 
         beans::PropertyValue aProperty;
         aProperty.Name  = "nodepath";
-        aProperty.Value = uno::makeAny( OUString("org.openoffice.Office.Addons/AddonUI/OfficeHelp/UpdateCheckJob") );
+        aProperty.Value <<= OUString("org.openoffice.Office.Addons/AddonUI/OfficeHelp/UpdateCheckJob");
 
         uno::Sequence< uno::Any > aArgumentList( 1 );
-        aArgumentList[0] = uno::makeAny( aProperty );
+        aArgumentList[0] <<= aProperty;
 
         uno::Reference< container::XNameAccess > xNameAccess(
             xConfigProvider->createInstanceWithArguments(
@@ -847,10 +827,10 @@ void UpdateDialog::createNotifyJob( bool bPrepareOnly,
         {
             uno::Sequence< beans::PropertyValue > aPropList(2);
             aProperty.Name  = "updateList";
-            aProperty.Value = uno::makeAny( rItemList );
+            aProperty.Value <<= rItemList;
             aPropList[0] = aProperty;
             aProperty.Name  = "prepareOnly";
-            aProperty.Value = uno::makeAny( bPrepareOnly );
+            aProperty.Value <<= bPrepareOnly;
             aPropList[1] = aProperty;
 
             xDispatch->dispatch(aURL, aPropList );
@@ -1084,7 +1064,7 @@ bool UpdateDialog::isIgnoredUpdate( UpdateDialog::Index * index )
 }
 
 
-void UpdateDialog::setIgnoredUpdate( UpdateDialog::Index *pIndex, bool bIgnore, bool bIgnoreAll )
+void UpdateDialog::setIgnoredUpdate( UpdateDialog::Index const *pIndex, bool bIgnore, bool bIgnoreAll )
 {
     OUString aExtensionID;
     OUString aVersion;
@@ -1135,7 +1115,7 @@ IMPL_LINK_NOARG(UpdateDialog, selectionHandler, SvTreeListBox*, void)
 {
     OUStringBuffer b;
     UpdateDialog::Index const * p = static_cast< UpdateDialog::Index const * >(
-        m_pUpdates->GetSelectEntryData());
+        m_pUpdates->GetSelectedEntryData());
     clearDescription();
 
     if ( p != nullptr )
@@ -1275,7 +1255,7 @@ IMPL_LINK_NOARG(UpdateDialog, okHandler, Button*, void)
 {
     //If users are going to update a shared extension then we need
     //to warn them
-    typedef ::std::vector<UpdateData>::const_iterator CIT;
+    typedef std::vector<UpdateData>::const_iterator CIT;
     for (CIT i = m_enabledUpdates.begin(); i < m_enabledUpdates.end(); ++i)
     {
         OSL_ASSERT(i->aInstalledPackage.is());
