@@ -23,16 +23,17 @@
 #include <rtl/bootstrap.hxx>
 #include <cppuhelper/exc_hlp.hxx>
 #include <osl/file.hxx>
+#include <com/sun/star/deployment/DeploymentException.hpp>
 #include <com/sun/star/uno/XComponentContext.hpp>
 #include <com/sun/star/xml/dom/DocumentBuilder.hpp>
 #include <com/sun/star/xml/xpath/XPathAPI.hpp>
 #include <com/sun/star/io/XActiveDataSource.hpp>
 #include <com/sun/star/io/XActiveDataControl.hpp>
-#include "dp_ucb.h"
-#include "dp_misc.h"
+#include <dp_ucb.h>
+#include <dp_misc.h>
 #include <ucbhelper/content.hxx>
 #include <xmlscript/xml_helper.hxx>
-#include "dp_backenddb.hxx"
+#include <dp_backenddb.hxx>
 
 
 using namespace ::com::sun::star::uno;
@@ -52,7 +53,7 @@ BackendDb::BackendDb(
 void BackendDb::save()
 {
     const Reference<css::io::XActiveDataSource> xDataSource(m_doc,css::uno::UNO_QUERY_THROW);
-    ::rtl::ByteSequence bytes;
+    std::vector<sal_Int8> bytes;
     xDataSource->setOutputStream(::xmlscript::createOutputStream(&bytes));
     const Reference<css::io::XActiveDataControl> xDataControl(m_doc,css::uno::UNO_QUERY_THROW);
     xDataControl->start();
@@ -63,7 +64,7 @@ void BackendDb::save()
     ucbDb.writeStream(xData, true /*replace existing*/);
 }
 
-css::uno::Reference<css::xml::dom::XDocument> BackendDb::getDocument()
+css::uno::Reference<css::xml::dom::XDocument> const & BackendDb::getDocument()
 {
     if (!m_doc.is())
     {
@@ -106,7 +107,7 @@ css::uno::Reference<css::xml::dom::XDocument> BackendDb::getDocument()
     return m_doc;
 }
 
-Reference<css::xml::xpath::XXPathAPI> BackendDb::getXPathAPI()
+Reference<css::xml::xpath::XXPathAPI> const & BackendDb::getXPathAPI()
 {
     if (!m_xpathApi.is())
     {
@@ -265,7 +266,7 @@ Reference<css::xml::dom::XNode> BackendDb::getKeyElement(
 
 //Only writes the data if there is at least one entry
 void BackendDb::writeVectorOfPair(
-    ::std::vector< ::std::pair< OUString, OUString > > const & vecPairs,
+    std::vector< std::pair< OUString, OUString > > const & vecPairs,
     OUString const & sVectorTagName,
     OUString const & sPairTagName,
     OUString const & sFirstTagName,
@@ -287,8 +288,7 @@ void BackendDb::writeVectorOfPair(
         xParent->appendChild(
             Reference<css::xml::dom::XNode>(
                 vectorNode, css::uno::UNO_QUERY_THROW));
-        typedef ::std::vector< ::std::pair< OUString, OUString > >::const_iterator CIT;
-        for (CIT i = vecPairs.begin(); i != vecPairs.end(); ++i)
+        for (auto const& vecPair : vecPairs)
         {
             const Reference<css::xml::dom::XElement> pairNode(
                 doc->createElementNS(sNameSpace, sPrefix + sPairTagName));
@@ -305,7 +305,7 @@ void BackendDb::writeVectorOfPair(
                     firstNode, css::uno::UNO_QUERY_THROW));
 
             const Reference<css::xml::dom::XText> firstTextNode(
-                doc->createTextNode( i->first));
+                doc->createTextNode( vecPair.first));
 
             firstNode->appendChild(
                 Reference<css::xml::dom::XNode>(
@@ -319,7 +319,7 @@ void BackendDb::writeVectorOfPair(
                     secondNode, css::uno::UNO_QUERY_THROW));
 
             const Reference<css::xml::dom::XText> secondTextNode(
-                doc->createTextNode( i->second));
+                doc->createTextNode( vecPair.second));
 
             secondNode->appendChild(
                 Reference<css::xml::dom::XNode>(
@@ -335,7 +335,7 @@ void BackendDb::writeVectorOfPair(
     }
 }
 
-::std::vector< ::std::pair< OUString, OUString > >
+std::vector< std::pair< OUString, OUString > >
 BackendDb::readVectorOfPair(
     Reference<css::xml::dom::XNode> const & parent,
     OUString const & sListTagName,
@@ -353,7 +353,7 @@ BackendDb::readVectorOfPair(
         const Reference<css::xml::dom::XNodeList> listPairs =
             xpathApi->selectNodeList(parent, sExprPairs);
 
-        ::std::vector< ::std::pair< OUString, OUString > > retVector;
+        std::vector< std::pair< OUString, OUString > > retVector;
         sal_Int32 length = listPairs->getLength();
         for (sal_Int32 i = 0; i < length; i++)
         {
@@ -367,8 +367,8 @@ BackendDb::readVectorOfPair(
                 xpathApi->selectSingleNode(aPair, sExprSecond);
             OSL_ASSERT(first.is() && second.is());
 
-            retVector.push_back(::std::make_pair(
-                                    first->getNodeValue(), second->getNodeValue()));
+            retVector.emplace_back(
+                                    first->getNodeValue(), second->getNodeValue());
         }
         return retVector;
     }
@@ -383,7 +383,7 @@ BackendDb::readVectorOfPair(
 
 //Only writes the data if there is at least one entry
 void BackendDb::writeSimpleList(
-    ::std::list< OUString> const & list,
+    std::deque< OUString> const & list,
     OUString const & sListTagName,
     OUString const & sMemberTagName,
     Reference<css::xml::dom::XNode> const & xParent)
@@ -403,8 +403,7 @@ void BackendDb::writeSimpleList(
             Reference<css::xml::dom::XNode>(
                 listNode, css::uno::UNO_QUERY_THROW));
 
-        typedef ::std::list<OUString>::const_iterator ITC_ITEMS;
-        for (ITC_ITEMS i = list.begin(); i != list.end(); ++i)
+        for (auto const& elem : list)
         {
             const Reference<css::xml::dom::XNode> memberNode(
                 doc->createElementNS(sNameSpace, sPrefix + sMemberTagName), css::uno::UNO_QUERY_THROW);
@@ -412,7 +411,7 @@ void BackendDb::writeSimpleList(
             listNode->appendChild(memberNode);
 
             const Reference<css::xml::dom::XNode> textNode(
-                doc->createTextNode( *i), css::uno::UNO_QUERY_THROW);
+                doc->createTextNode(elem), css::uno::UNO_QUERY_THROW);
 
             memberNode->appendChild(textNode);
         }
@@ -458,9 +457,7 @@ void BackendDb::writeSimpleElement(
 
 }
 
-/** The key elements have an url attribute and are always children of the root
-    element.
-*/
+/// The key elements have an url attribute and are always children of the root element.
 Reference<css::xml::dom::XNode> BackendDb::writeKeyElement(
     OUString const & url)
 {
@@ -473,7 +470,7 @@ Reference<css::xml::dom::XNode> BackendDb::writeKeyElement(
         const Reference<css::xml::dom::XNode> root = doc->getFirstChild();
 
         //Check if there are an entry with the same url. This can be the case if the
-        //the status of an XPackage is ambiguous. In this case a call to activateExtension
+        //status of an XPackage is ambiguous. In this case a call to activateExtension
         //(dp_extensionmanager.cxx), will register the package again. See also
         //Package::processPackage_impl in dp_backend.cxx.
         //A package can become
@@ -533,7 +530,7 @@ OUString BackendDb::readSimpleElement(
 }
 
 
-::std::list< OUString> BackendDb::readList(
+std::deque< OUString> BackendDb::readList(
     Reference<css::xml::dom::XNode> const & parent,
     OUString const & sListTagName,
     OUString const & sMemberTagName)
@@ -548,7 +545,7 @@ OUString BackendDb::readSimpleElement(
         const Reference<css::xml::dom::XNodeList> list =
             xpathApi->selectNodeList(parent, sExprList);
 
-        ::std::list<OUString > retList;
+        std::deque<OUString > retList;
         sal_Int32 length = list->getLength();
         for (sal_Int32 i = 0; i < length; i++)
         {
@@ -566,12 +563,12 @@ OUString BackendDb::readSimpleElement(
     }
 }
 
-::std::list<OUString> BackendDb::getOneChildFromAllEntries(
+std::vector<OUString> BackendDb::getOneChildFromAllEntries(
     OUString const & name)
 {
     try
     {
-        ::std::list<OUString> listRet;
+        std::vector<OUString> listRet;
         Reference<css::xml::dom::XDocument> doc = getDocument();
         Reference<css::xml::dom::XNode> root = doc->getFirstChild();
 
