@@ -19,42 +19,43 @@
 
 #include <sal/config.h>
 
-#include <boost/noncopyable.hpp>
 #include <com/sun/star/graphic/XPrimitive2DRenderer.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <cppuhelper/implbase2.hxx>
 #include <cppuhelper/supportsservice.hxx>
+#include <comphelper/sequence.hxx>
 #include <com/sun/star/xml/sax/XParser.hpp>
 #include <com/sun/star/xml/sax/InputSource.hpp>
 #include <comphelper/processfactory.hxx>
 #include <drawinglayer/geometry/viewinformation2d.hxx>
 #include <basegfx/numeric/ftools.hxx>
 #include <vcl/bitmapex.hxx>
-#include <drawinglayer/tools/converters.hxx>
 #include <vcl/canvastools.hxx>
 #include <com/sun/star/geometry/RealRectangle2D.hpp>
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
 #include <drawinglayer/primitive2d/transformprimitive2d.hxx>
 
-#include <xprimitive2drenderer.hxx>
+#include <converters.hxx>
+
+#include "xprimitive2drenderer.hxx"
 
 using namespace ::com::sun::star;
 
 
-
 namespace drawinglayer
 {
     namespace unorenderer
     {
         class XPrimitive2DRenderer:
             public cppu::WeakAggImplHelper2<
-                css::graphic::XPrimitive2DRenderer, css::lang::XServiceInfo>,
-            private boost::noncopyable
+                css::graphic::XPrimitive2DRenderer, css::lang::XServiceInfo>
         {
         public:
             XPrimitive2DRenderer();
-            virtual ~XPrimitive2DRenderer();
+
+            XPrimitive2DRenderer(const XPrimitive2DRenderer&) = delete;
+            const XPrimitive2DRenderer& operator=(const XPrimitive2DRenderer&) = delete;
 
             // XPrimitive2DRenderer
             virtual uno::Reference< rendering::XBitmap > SAL_CALL rasterize(
@@ -63,12 +64,12 @@ namespace drawinglayer
                 ::sal_uInt32 DPI_X,
                 ::sal_uInt32 DPI_Y,
                 const css::geometry::RealRectangle2D& Range,
-                ::sal_uInt32 MaximumQuadraticPixels) throw (uno::RuntimeException, std::exception) override;
+                ::sal_uInt32 MaximumQuadraticPixels) override;
 
             // XServiceInfo
-            virtual OUString SAL_CALL getImplementationName() throw(uno::RuntimeException, std::exception) override;
-            virtual sal_Bool SAL_CALL supportsService(const OUString&) throw(uno::RuntimeException, std::exception) override;
-            virtual uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() throw(uno::RuntimeException, std::exception) override;
+            virtual OUString SAL_CALL getImplementationName() override;
+            virtual sal_Bool SAL_CALL supportsService(const OUString&) override;
+            virtual uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() override;
         };
     } // end of namespace unorenderer
 } // end of namespace drawinglayer
@@ -98,7 +99,6 @@ namespace drawinglayer
 } // end of namespace drawinglayer
 
 
-
 namespace drawinglayer
 {
     namespace unorenderer
@@ -107,21 +107,17 @@ namespace drawinglayer
         {
         }
 
-        XPrimitive2DRenderer::~XPrimitive2DRenderer()
-        {
-        }
-
         uno::Reference< rendering::XBitmap > XPrimitive2DRenderer::rasterize(
-            const uno::Sequence< uno::Reference< graphic::XPrimitive2D > >& Primitive2DSequence,
+            const uno::Sequence< uno::Reference< graphic::XPrimitive2D > >& aPrimitive2DSequence,
             const uno::Sequence< beans::PropertyValue >& aViewInformationSequence,
             ::sal_uInt32 DPI_X,
             ::sal_uInt32 DPI_Y,
             const css::geometry::RealRectangle2D& Range,
-            ::sal_uInt32 MaximumQuadraticPixels) throw (uno::RuntimeException, std::exception)
+            ::sal_uInt32 MaximumQuadraticPixels)
         {
             uno::Reference< rendering::XBitmap > XBitmap;
 
-            if(Primitive2DSequence.hasElements())
+            if(aPrimitive2DSequence.hasElements())
             {
                 const basegfx::B2DRange aRange(Range.X1, Range.Y1, Range.X2, Range.Y2);
                 const double fWidth(aRange.getWidth());
@@ -150,7 +146,7 @@ namespace drawinglayer
                     const sal_uInt32 nDiscreteHeight(basegfx::fround((fHeight * fFactor100th_mmToInch) * DPI_Y));
 
                     basegfx::B2DHomMatrix aEmbedding(
-                        basegfx::tools::createTranslateB2DHomMatrix(
+                        basegfx::utils::createTranslateB2DHomMatrix(
                             -aRange.getMinX(),
                             -aRange.getMinY()));
 
@@ -161,11 +157,11 @@ namespace drawinglayer
                     const primitive2d::Primitive2DReference xEmbedRef(
                         new primitive2d::TransformPrimitive2D(
                             aEmbedding,
-                            Primitive2DSequence));
-                    const primitive2d::Primitive2DSequence xEmbedSeq(&xEmbedRef, 1);
+                            comphelper::sequenceToContainer<primitive2d::Primitive2DContainer>(aPrimitive2DSequence)));
+                    const primitive2d::Primitive2DContainer xEmbedSeq { xEmbedRef };
 
                     BitmapEx aBitmapEx(
-                        tools::convertToBitmapEx(
+                        convertToBitmapEx(
                             xEmbedSeq,
                             aViewInformation2D,
                             nDiscreteWidth,
@@ -174,11 +170,9 @@ namespace drawinglayer
 
                     if(!aBitmapEx.IsEmpty())
                     {
-                        const uno::Reference< rendering::XGraphicDevice > xGraphicDevice;
-
-                        aBitmapEx.SetPrefMapMode(MapMode(MAP_100TH_MM));
+                        aBitmapEx.SetPrefMapMode(MapMode(MapUnit::Map100thMM));
                         aBitmapEx.SetPrefSize(Size(basegfx::fround(fWidth), basegfx::fround(fHeight)));
-                        XBitmap = vcl::unotools::xBitmapFromBitmapEx(xGraphicDevice, aBitmapEx);
+                        XBitmap = vcl::unotools::xBitmapFromBitmapEx(aBitmapEx);
                     }
                 }
             }
@@ -186,17 +180,17 @@ namespace drawinglayer
             return XBitmap;
         }
 
-        OUString SAL_CALL XPrimitive2DRenderer::getImplementationName() throw(uno::RuntimeException, std::exception)
+        OUString SAL_CALL XPrimitive2DRenderer::getImplementationName()
         {
             return(XPrimitive2DRenderer_getImplementationName());
         }
 
-        sal_Bool SAL_CALL XPrimitive2DRenderer::supportsService(const OUString& rServiceName) throw(uno::RuntimeException, std::exception)
+        sal_Bool SAL_CALL XPrimitive2DRenderer::supportsService(const OUString& rServiceName)
         {
             return cppu::supportsService(this, rServiceName);
         }
 
-        uno::Sequence< OUString > SAL_CALL XPrimitive2DRenderer::getSupportedServiceNames() throw(uno::RuntimeException, std::exception)
+        uno::Sequence< OUString > SAL_CALL XPrimitive2DRenderer::getSupportedServiceNames()
         {
             return XPrimitive2DRenderer_getSupportedServiceNames();
         }
