@@ -18,7 +18,7 @@
  */
 
 #include <drawinglayer/primitive2d/polygonprimitive2d.hxx>
-#include <basegfx/tools/canvastools.hxx>
+#include <basegfx/utils/canvastools.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
 #include <drawinglayer/primitive2d/polypolygonprimitive2d.hxx>
@@ -91,7 +91,7 @@ namespace drawinglayer
 {
     namespace primitive2d
     {
-        Primitive2DContainer PolygonMarkerPrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& rViewInformation) const
+        void PolygonMarkerPrimitive2D::create2DDecomposition(Primitive2DContainer& rContainer, const geometry::ViewInformation2D& rViewInformation) const
         {
             // calculate logic DashLength
             const basegfx::B2DVector aDashVector(rViewInformation.getInverseObjectToViewTransformation() * basegfx::B2DVector(getDiscreteDashLength(), 0.0));
@@ -100,26 +100,20 @@ namespace drawinglayer
             if(fLogicDashLength > 0.0 && !getRGBColorA().equal(getRGBColorB()))
             {
                 // apply dashing; get line and gap snippets
-                ::std::vector< double > aDash;
+                std::vector< double > aDash;
                 basegfx::B2DPolyPolygon aDashedPolyPolyA;
                 basegfx::B2DPolyPolygon aDashedPolyPolyB;
 
                 aDash.push_back(fLogicDashLength);
                 aDash.push_back(fLogicDashLength);
-                basegfx::tools::applyLineDashing(getB2DPolygon(), aDash, &aDashedPolyPolyA, &aDashedPolyPolyB, 2.0 * fLogicDashLength);
+                basegfx::utils::applyLineDashing(getB2DPolygon(), aDash, &aDashedPolyPolyA, &aDashedPolyPolyB, 2.0 * fLogicDashLength);
 
-                // prepare return value
-                Primitive2DContainer aRetval(2);
-
-                aRetval[0] = Primitive2DReference(new PolyPolygonHairlinePrimitive2D(aDashedPolyPolyA, getRGBColorA()));
-                aRetval[1] = Primitive2DReference(new PolyPolygonHairlinePrimitive2D(aDashedPolyPolyB, getRGBColorB()));
-
-                return aRetval;
+                rContainer.push_back(new PolyPolygonHairlinePrimitive2D(aDashedPolyPolyA, getRGBColorA()));
+                rContainer.push_back(new PolyPolygonHairlinePrimitive2D(aDashedPolyPolyB, getRGBColorB()));
             }
             else
             {
-                const Primitive2DReference xRef(new PolygonHairlinePrimitive2D(getB2DPolygon(), getRGBColorA()));
-                return Primitive2DContainer { xRef };
+                rContainer.push_back(new PolygonHairlinePrimitive2D(getB2DPolygon(), getRGBColorA()));
             }
         }
 
@@ -174,7 +168,7 @@ namespace drawinglayer
             return aRetval;
         }
 
-        Primitive2DContainer PolygonMarkerPrimitive2D::get2DDecomposition(const geometry::ViewInformation2D& rViewInformation) const
+        void PolygonMarkerPrimitive2D::get2DDecomposition(Primitive2DDecompositionVisitor& rVisitor, const geometry::ViewInformation2D& rViewInformation) const
         {
             ::osl::MutexGuard aGuard( m_aMutex );
             bool bNeedNewDecomposition(false);
@@ -201,7 +195,7 @@ namespace drawinglayer
             }
 
             // use parent implementation
-            return BufferedDecompositionPrimitive2D::get2DDecomposition(rViewInformation);
+            BufferedDecompositionPrimitive2D::get2DDecomposition(rVisitor, rViewInformation);
         }
 
         // provide unique ID
@@ -212,22 +206,19 @@ namespace drawinglayer
 
 namespace drawinglayer
 {
-    namespace tools
+    double getRandomColorRange()
     {
-        double getRandomColorRange()
-        {
-            return comphelper::rng::uniform_real_distribution(0.0, nextafter(1.0, DBL_MAX));
-        }
+        return comphelper::rng::uniform_real_distribution(0.0, nextafter(1.0, DBL_MAX));
     }
 
     namespace primitive2d
     {
-        Primitive2DContainer PolygonStrokePrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
+        void PolygonStrokePrimitive2D::create2DDecomposition(Primitive2DContainer& rContainer, const geometry::ViewInformation2D& /*rViewInformation*/) const
         {
             if(getB2DPolygon().count())
             {
                 // #i102241# try to simplify before usage
-                const basegfx::B2DPolygon aB2DPolygon(basegfx::tools::simplifyCurveSegments(getB2DPolygon()));
+                const basegfx::B2DPolygon aB2DPolygon(basegfx::utils::simplifyCurveSegments(getB2DPolygon()));
                 basegfx::B2DPolyPolygon aHairLinePolyPolygon;
 
                 if(getStrokeAttribute().isDefault() || 0.0 == getStrokeAttribute().getFullDotDashLen())
@@ -238,7 +229,7 @@ namespace drawinglayer
                 else
                 {
                     // apply LineStyle
-                    basegfx::tools::applyLineDashing(
+                    basegfx::utils::applyLineDashing(
                         aB2DPolygon, getStrokeAttribute().getDotDashArray(),
                         &aHairLinePolyPolygon, nullptr, getStrokeAttribute().getFullDotDashLen());
                 }
@@ -254,10 +245,10 @@ namespace drawinglayer
                     basegfx::B2DPolyPolygon aAreaPolyPolygon;
                     const double fMiterMinimumAngle(getLineAttribute().getMiterMinimumAngle());
 
-                    for(sal_uInt32 a(0L); a < nCount; a++)
+                    for(sal_uInt32 a(0); a < nCount; a++)
                     {
                         // New version of createAreaGeometry; now creates bezier polygons
-                        aAreaPolyPolygon.append(basegfx::tools::createAreaGeometry(
+                        aAreaPolyPolygon.append(basegfx::utils::createAreaGeometry(
                             aHairLinePolyPolygon.getB2DPolygon(a),
                             fHalfLineWidth,
                             aLineJoin,
@@ -267,11 +258,8 @@ namespace drawinglayer
                             fMiterMinimumAngle));
                     }
 
-                    // prepare return value
-                    Primitive2DContainer aRetval(aAreaPolyPolygon.count());
-
                     // create primitive
-                    for(sal_uInt32 b(0L); b < aAreaPolyPolygon.count(); b++)
+                    for(sal_uInt32 b(0); b < aAreaPolyPolygon.count(); b++)
                     {
                         // put into single polyPolygon primitives to make clear that this is NOT meant
                         // to be painted as a single tools::PolyPolygon (XORed as fill rule). Alternatively, a
@@ -279,29 +267,19 @@ namespace drawinglayer
                         const basegfx::B2DPolyPolygon aNewPolyPolygon(aAreaPolyPolygon.getB2DPolygon(b));
                         static bool bTestByUsingRandomColor(false);
                         const basegfx::BColor aColor(bTestByUsingRandomColor
-                            ? basegfx::BColor(tools::getRandomColorRange(), tools::getRandomColorRange(), tools::getRandomColorRange())
+                            ? basegfx::BColor(getRandomColorRange(), getRandomColorRange(), getRandomColorRange())
                             : getLineAttribute().getColor());
-                        const Primitive2DReference xRef(new PolyPolygonColorPrimitive2D(aNewPolyPolygon, aColor));
-                        aRetval[b] = xRef;
+                        rContainer.push_back(new PolyPolygonColorPrimitive2D(aNewPolyPolygon, aColor));
                     }
-
-                    return aRetval;
                 }
                 else
                 {
-                    // prepare return value
-                    const Primitive2DReference xRef(
+                    rContainer.push_back(
                         new PolyPolygonHairlinePrimitive2D(
                             aHairLinePolyPolygon,
                             getLineAttribute().getColor()));
-
-                    return Primitive2DContainer { xRef };
                 }
             }
-            else
-            {
-                return Primitive2DContainer();
-            }
         }
 
         PolygonStrokePrimitive2D::PolygonStrokePrimitive2D(
@@ -364,10 +342,16 @@ namespace drawinglayer
                     bUseDecomposition = true;
                 }
 
-                if(bUseDecomposition)
+                if (bUseDecomposition)
                 {
                     // get correct range by using the decomposition fallback, reasons see above cases
+
+                    // ofz#947 to optimize calculating the range, turn any slow dashes into a solid line
+                    // when just calculating bounds
+                    attribute::StrokeAttribute aOrigStrokeAttribute = maStrokeAttribute;
+                    const_cast<PolygonStrokePrimitive2D*>(this)->maStrokeAttribute = attribute::StrokeAttribute();
                     aRetval = BufferedDecompositionPrimitive2D::getB2DRange(rViewInformation);
+                    const_cast<PolygonStrokePrimitive2D*>(this)->maStrokeAttribute = aOrigStrokeAttribute;
                 }
                 else
                 {
@@ -410,10 +394,8 @@ namespace drawinglayer
 {
     namespace primitive2d
     {
-        Primitive2DContainer PolygonWavePrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
+        void PolygonWavePrimitive2D::create2DDecomposition(Primitive2DContainer& rContainer, const geometry::ViewInformation2D& /*rViewInformation*/) const
         {
-            Primitive2DContainer aRetval;
-
             if(getB2DPolygon().count())
             {
                 const bool bHasWidth(!basegfx::fTools::equalZero(getWaveWidth()));
@@ -422,19 +404,15 @@ namespace drawinglayer
                 if(bHasWidth && bHasHeight)
                 {
                     // create waveline curve
-                    const basegfx::B2DPolygon aWaveline(basegfx::tools::createWaveline(getB2DPolygon(), getWaveWidth(), getWaveHeight()));
-                    const Primitive2DReference xRef(new PolygonStrokePrimitive2D(aWaveline, getLineAttribute(), getStrokeAttribute()));
-                    aRetval = Primitive2DContainer { xRef };
+                    const basegfx::B2DPolygon aWaveline(basegfx::utils::createWaveline(getB2DPolygon(), getWaveWidth(), getWaveHeight()));
+                    rContainer.push_back(new PolygonStrokePrimitive2D(aWaveline, getLineAttribute(), getStrokeAttribute()));
                 }
                 else
                 {
                     // flat waveline, decompose to simple line primitive
-                    const Primitive2DReference xRef(new PolygonStrokePrimitive2D(getB2DPolygon(), getLineAttribute(), getStrokeAttribute()));
-                    aRetval = Primitive2DContainer { xRef };
+                    rContainer.push_back(new PolygonStrokePrimitive2D(getB2DPolygon(), getLineAttribute(), getStrokeAttribute()));
                 }
             }
-
-            return aRetval;
         }
 
         PolygonWavePrimitive2D::PolygonWavePrimitive2D(
@@ -522,7 +500,7 @@ namespace drawinglayer
 {
     namespace primitive2d
     {
-        Primitive2DContainer PolygonStrokeArrowPrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
+        void PolygonStrokeArrowPrimitive2D::create2DDecomposition(Primitive2DContainer& rContainer, const geometry::ViewInformation2D& /*rViewInformation*/) const
         {
             // copy local polygon, it may be changed
             basegfx::B2DPolygon aLocalPolygon(getB2DPolygon());
@@ -533,7 +511,7 @@ namespace drawinglayer
             if(!aLocalPolygon.isClosed() && aLocalPolygon.count() > 1)
             {
                 // apply arrows
-                const double fPolyLength(basegfx::tools::getLength(aLocalPolygon));
+                const double fPolyLength(basegfx::utils::getLength(aLocalPolygon));
                 double fStart(0.0);
                 double fEnd(0.0);
                 double fStartOverlap(0.0);
@@ -542,7 +520,7 @@ namespace drawinglayer
                 if(!getStart().isDefault() && getStart().isActive())
                 {
                     // create start arrow primitive and consume
-                    aArrowA = basegfx::tools::createAreaGeometryForLineStartEnd(
+                    aArrowA = basegfx::utils::createAreaGeometryForLineStartEnd(
                         aLocalPolygon, getStart().getB2DPolyPolygon(), true, getStart().getWidth(),
                         fPolyLength, getStart().isCentered() ? 0.5 : 0.0, &fStart);
 
@@ -554,7 +532,7 @@ namespace drawinglayer
                 if(!getEnd().isDefault() && getEnd().isActive())
                 {
                     // create end arrow primitive and consume
-                    aArrowB = basegfx::tools::createAreaGeometryForLineStartEnd(
+                    aArrowB = basegfx::utils::createAreaGeometryForLineStartEnd(
                         aLocalPolygon, getEnd().getB2DPolyPolygon(), false, getEnd().getWidth(),
                         fPolyLength, getEnd().isCentered() ? 0.5 : 0.0, &fEnd);
 
@@ -565,37 +543,28 @@ namespace drawinglayer
                 if(0.0 != fStart || 0.0 != fEnd)
                 {
                     // build new poly, consume something from old poly
-                    aLocalPolygon = basegfx::tools::getSnippetAbsolute(aLocalPolygon, fStart-fStartOverlap, fPolyLength - fEnd + fEndOverlap, fPolyLength);
+                    aLocalPolygon = basegfx::utils::getSnippetAbsolute(aLocalPolygon, fStart-fStartOverlap, fPolyLength - fEnd + fEndOverlap, fPolyLength);
                 }
             }
 
-            // prepare return value
-            Primitive2DContainer aRetval(1L + (aArrowA.count() ? 1L : 0L) + (aArrowB.count() ? 1L : 0L));
-            sal_uInt32 nInd(0L);
-
             // add shaft
-            const Primitive2DReference xRefShaft(new
+            rContainer.push_back(new
                 PolygonStrokePrimitive2D(
                     aLocalPolygon, getLineAttribute(), getStrokeAttribute()));
-            aRetval[nInd++] = xRefShaft;
 
             if(aArrowA.count())
             {
-                const Primitive2DReference xRefA(
+                rContainer.push_back(
                     new PolyPolygonColorPrimitive2D(
                         aArrowA, getLineAttribute().getColor()));
-                aRetval[nInd++] = xRefA;
             }
 
             if(aArrowB.count())
             {
-                const Primitive2DReference xRefB(
+                rContainer.push_back(
                     new PolyPolygonColorPrimitive2D(
                         aArrowB, getLineAttribute().getColor()));
-                aRetval[nInd++] = xRefB;
             }
-
-            return aRetval;
         }
 
         PolygonStrokeArrowPrimitive2D::PolygonStrokeArrowPrimitive2D(
@@ -636,8 +605,6 @@ namespace drawinglayer
 
         basegfx::B2DRange PolygonStrokeArrowPrimitive2D::getB2DRange(const geometry::ViewInformation2D& rViewInformation) const
         {
-            basegfx::B2DRange aRetval;
-
             if(getStart().isActive() || getEnd().isActive())
             {
                 // use decomposition when line start/end is used
