@@ -31,11 +31,9 @@
 #include <drawinglayer/primitive3d/drawinglayer_primitivetypes3d.hxx>
 
 
-
 using namespace com::sun::star;
 
 
-
 namespace drawinglayer
 {
     namespace processor3d
@@ -53,8 +51,8 @@ namespace drawinglayer
                     const primitive3d::ShadowPrimitive3D& rPrimitive = static_cast< const primitive3d::ShadowPrimitive3D& >(rCandidate);
 
                     // set new target
-                    primitive2d::Primitive2DVector aNewSubList;
-                    primitive2d::Primitive2DVector* pLastTargetSequence = mpPrimitive2DSequence;
+                    primitive2d::Primitive2DContainer aNewSubList;
+                    primitive2d::Primitive2DContainer* pLastTargetSequence = mpPrimitive2DSequence;
                     mpPrimitive2DSequence = &aNewSubList;
 
                     // activate convert
@@ -78,13 +76,13 @@ namespace drawinglayer
                     primitive2d::BasePrimitive2D* pNew = new primitive2d::ShadowPrimitive2D(
                         rPrimitive.getShadowTransform(),
                         rPrimitive.getShadowColor(),
-                        primitive2d::Primitive2DVectorToPrimitive2DSequence(aNewSubList));
+                        aNewSubList);
 
                     if(basegfx::fTools::more(rPrimitive.getShadowTransparence(), 0.0))
                     {
                         // create simpleTransparencePrimitive, add created primitives
                         const primitive2d::Primitive2DReference xRef(pNew);
-                        const primitive2d::Primitive2DSequence aNewTransPrimitiveVector(&xRef, 1);
+                        const primitive2d::Primitive2DContainer aNewTransPrimitiveVector { xRef };
 
                         pNew = new primitive2d::UnifiedTransparencePrimitive2D(
                             aNewTransPrimitiveVector,
@@ -149,7 +147,7 @@ namespace drawinglayer
                         }
                         else
                         {
-                            a2DHairline = basegfx::tools::createB2DPolygonFromB3DPolygon(rPrimitive.getB3DPolygon(), getViewInformation3D().getObjectToView());
+                            a2DHairline = basegfx::utils::createB2DPolygonFromB3DPolygon(rPrimitive.getB3DPolygon(), getViewInformation3D().getObjectToView());
                         }
 
                         if(a2DHairline.count())
@@ -158,7 +156,7 @@ namespace drawinglayer
                             mpPrimitive2DSequence->push_back(
                                 new primitive2d::PolygonHairlinePrimitive2D(
                                     a2DHairline,
-                                    maPrimitiveColor));
+                                    basegfx::BColor()));
                         }
                     }
                     break;
@@ -180,7 +178,7 @@ namespace drawinglayer
                         }
                         else
                         {
-                            a2DFill = basegfx::tools::createB2DPolyPolygonFromB3DPolyPolygon(rPrimitive.getB3DPolyPolygon(), getViewInformation3D().getObjectToView());
+                            a2DFill = basegfx::utils::createB2DPolyPolygonFromB3DPolyPolygon(rPrimitive.getB3DPolyPolygon(), getViewInformation3D().getObjectToView());
                         }
 
                         if(a2DFill.count())
@@ -189,7 +187,7 @@ namespace drawinglayer
                             mpPrimitive2DSequence->push_back(
                                 new primitive2d::PolyPolygonColorPrimitive2D(
                                     a2DFill,
-                                    maPrimitiveColor));
+                                    basegfx::BColor()));
                         }
                     }
                     break;
@@ -219,7 +217,6 @@ namespace drawinglayer
             maShadowPlaneNormal(),
             maPlanePoint(),
             mfLightPlaneScalar(0.0),
-            maPrimitiveColor(),
             mbShadowProjectionIsValid(false),
             mbConvert(false),
             mbUseProjection(false)
@@ -253,17 +250,13 @@ namespace drawinglayer
         {
             OSL_ENSURE(0 == maPrimitive2DSequence.size(),
                 "OOps, someone used Shadow3DExtractingProcessor, but did not fetch the results (!)");
-            for(size_t a(0); a < maPrimitive2DSequence.size(); a++)
-            {
-                delete maPrimitive2DSequence[a];
-            }
         }
 
         basegfx::B2DPolygon Shadow3DExtractingProcessor::impDoShadowProjection(const basegfx::B3DPolygon& rSource)
         {
             basegfx::B2DPolygon aRetval;
 
-            for(sal_uInt32 a(0L); a < rSource.count(); a++)
+            for(sal_uInt32 a(0); a < rSource.count(); a++)
             {
                 // get point, transform to eye coordinate system
                 basegfx::B3DPoint aCandidate(rSource.getB3DPoint(a));
@@ -278,7 +271,7 @@ namespace drawinglayer
                 aCandidate += maLightNormal * fCut;
 
                 // transform to view, use 2d coordinates
-                aCandidate *= getEyeToView();
+                aCandidate *= maEyeToView;
                 aRetval.append(basegfx::B2DPoint(aCandidate.getX(), aCandidate.getY()));
             }
 
@@ -292,7 +285,7 @@ namespace drawinglayer
         {
             basegfx::B2DPolyPolygon aRetval;
 
-            for(sal_uInt32 a(0L); a < rSource.count(); a++)
+            for(sal_uInt32 a(0); a < rSource.count(); a++)
             {
                 aRetval.append(impDoShadowProjection(rSource.getB3DPolygon(a)));
             }
@@ -300,9 +293,9 @@ namespace drawinglayer
             return aRetval;
         }
 
-        const primitive2d::Primitive2DSequence Shadow3DExtractingProcessor::getPrimitive2DSequence() const
+        const primitive2d::Primitive2DContainer& Shadow3DExtractingProcessor::getPrimitive2DSequence() const
         {
-            return Primitive2DVectorToPrimitive2DSequence(maPrimitive2DSequence);
+            return maPrimitive2DSequence;
         }
 
     } // end of namespace processor3d
