@@ -23,7 +23,7 @@
 #include <vcl/msgbox.hxx>
 #include <vcl/svapp.hxx>
 
-#include <impedit.hxx>
+#include "impedit.hxx"
 #include <editeng/editview.hxx>
 #include <editeng/editeng.hxx>
 #include <edtspell.hxx>
@@ -40,15 +40,14 @@ using namespace com::sun::star::beans;
 using namespace com::sun::star::linguistic2;
 
 
-EditSpellWrapper::EditSpellWrapper( Window* _pWin,
-        Reference< XSpellChecker1 >  &xChecker,
-        bool bIsStart, bool bIsAllRight, EditView* pView ) :
-    SvxSpellWrapper( _pWin, xChecker, bIsStart, bIsAllRight )
+EditSpellWrapper::EditSpellWrapper( vcl::Window* _pWin,
+        bool bIsStart, EditView* pView ) :
+    SvxSpellWrapper( _pWin, bIsStart, false/*bIsAllRight*/ )
 {
     SAL_WARN_IF( !pView, "editeng", "One view has to be abandoned!" );
     // Keep IgnoreList, delete ReplaceList...
-    if (SvxGetChangeAllList().is())
-        SvxGetChangeAllList()->clear();
+    if (LinguMgr::GetChangeAllList().is())
+        LinguMgr::GetChangeAllList()->clear();
     pEditView = pView;
 }
 
@@ -58,7 +57,7 @@ void EditSpellWrapper::SpellStart( SvxSpellArea eArea )
     ImpEditEngine* pImpEE = pEditView->GetImpEditEngine();
     SpellInfo* pSpellInfo = pImpEE->GetSpellInfo();
 
-    if ( eArea == SVX_SPELL_BODY_START )
+    if ( eArea == SvxSpellArea::BodyStart )
     {
         // Is called when
         // a) Spell-Forward has arrived at the end and should restart at the top
@@ -77,7 +76,7 @@ void EditSpellWrapper::SpellStart( SvxSpellArea eArea )
                     pEE->GetEditDoc().GetStartPaM() );
         }
     }
-    else if ( eArea == SVX_SPELL_BODY_END )
+    else if ( eArea == SvxSpellArea::BodyEnd )
     {
         // Is called when
         // a) Spell-Forward is launched
@@ -96,7 +95,7 @@ void EditSpellWrapper::SpellStart( SvxSpellArea eArea )
                     pEE->GetEditDoc().GetEndPaM() );
         }
     }
-    else if ( eArea == SVX_SPELL_BODY )
+    else if ( eArea == SvxSpellArea::Body )
     {
         ;   // Is handled by the App through SpellNextDocument
     }
@@ -106,24 +105,17 @@ void EditSpellWrapper::SpellStart( SvxSpellArea eArea )
     }
 }
 
-sal_Bool EditSpellWrapper::SpellContinue()
+void EditSpellWrapper::SpellContinue()
 {
     SetLast( pEditView->GetImpEditEngine()->ImpSpell( pEditView ) );
-    return GetLast().is();
 }
 
-void EditSpellWrapper::SpellEnd()
-{
-    // Base class will show language errors...
-    SvxSpellWrapper::SpellEnd();
-}
-
-sal_Bool EditSpellWrapper::HasOtherCnt()
+bool EditSpellWrapper::HasOtherCnt()
 {
     return false;
 }
 
-sal_Bool EditSpellWrapper::SpellMore()
+bool EditSpellWrapper::SpellMore()
 {
     EditEngine* pEE = pEditView->GetEditEngine();
     ImpEditEngine* pImpEE = pEditView->GetImpEditEngine();
@@ -134,7 +126,7 @@ sal_Bool EditSpellWrapper::SpellMore()
         bMore = pEE->SpellNextDocument();
         if ( bMore )
         {
-            // The text has been entered into the engine, when backwords then
+            // The text has been entered into the engine, when backwards then
             // it must be behind the selection.
             pEditView->GetImpEditView()->SetEditSelection(
                         pEE->GetEditDoc().GetStartPaM() );
@@ -143,44 +135,13 @@ sal_Bool EditSpellWrapper::SpellMore()
     return bMore;
 }
 
-void EditSpellWrapper::ScrollArea()
-{
-    // No further action needed ...
-    // Except for, that the area is to be scrolled in the center, and not stand
-    // still anywhere.
-}
-
-void EditSpellWrapper::ReplaceAll( const OUString &rNewText,
-            sal_Int16 )
+void EditSpellWrapper::ReplaceAll( const OUString &rNewText )
 {
     // Is called when the word is in ReplaceList of the spell checker
     pEditView->InsertText( rNewText );
     CheckSpellTo();
 }
 
-void EditSpellWrapper::ChangeWord( const OUString& rNewWord,
-            const sal_uInt16 )
-{
-    // Will be called when Word Button Change
-    // or internally by me ChangeAll
-
-    // If there is a dot Punkt after the word, this dot will be stripped away.
-    // If '"' => PreStripped.
-    OUString aNewWord( rNewWord );
-    pEditView->InsertText( aNewWord );
-    CheckSpellTo();
-}
-
-void EditSpellWrapper::ChangeThesWord( const OUString& rNewWord )
-{
-    pEditView->InsertText( rNewWord );
-    CheckSpellTo();
-}
-
-void EditSpellWrapper::AutoCorrect( const OUString&, const OUString& )
-{
-}
-
 void EditSpellWrapper::CheckSpellTo()
 {
     ImpEditEngine* pImpEE = pEditView->GetImpEditEngine();
@@ -200,18 +161,6 @@ size_t WrongList::Valid = std::numeric_limits<size_t>::max();
 
 WrongList::WrongList() : mnInvalidStart(0), mnInvalidEnd(Valid) {}
 
-WrongList::WrongList(const WrongList& r) :
-    maRanges(r.maRanges),
-    mnInvalidStart(r.mnInvalidStart),
-    mnInvalidEnd(r.mnInvalidEnd) {}
-
-WrongList::~WrongList() {}
-
-const std::vector<editeng::MisspellRange>& WrongList::GetRanges() const
-{
-    return maRanges;
-}
-
 void WrongList::SetRanges( const std::vector<editeng::MisspellRange>& rRanges )
 {
     maRanges = rRanges;
@@ -306,7 +255,6 @@ void WrongList::TextInserted( size_t nPos, size_t nLength, bool bPosIsSep )
         }
         SAL_WARN_IF(bRefIsValid && rWrong.mnStart >= rWrong.mnEnd, "editeng",
                 "TextInserted, editeng::MisspellRange: Start >= End?!");
-        (void)bRefIsValid;
     }
 
     SAL_WARN_IF(DbgIsBuggy(), "editeng", "InsertWrong: WrongList broken!");
@@ -317,7 +265,7 @@ void WrongList::TextDeleted( size_t nPos, size_t nLength )
     size_t nEndPos = nPos + nLength;
     if (IsValid())
     {
-        sal_uInt16 nNewInvalidStart = nPos ? nPos - 1 : 0;
+        const size_t nNewInvalidStart = nPos ? nPos - 1 : 0;
         mnInvalidStart = nNewInvalidStart;
         mnInvalidEnd = nNewInvalidStart + 1;
     }
@@ -433,7 +381,7 @@ void WrongList::ClearWrongs( size_t nStart, size_t nEnd,
             {
                 i->mnStart = nEnd;
                 // Blanks?
-                while (i->mnStart < pNode->Len() &&
+                while (i->mnStart < (size_t)pNode->Len() &&
                        (pNode->GetChar(i->mnStart) == ' ' ||
                         pNode->IsFeature(i->mnStart)))
                 {
@@ -480,7 +428,7 @@ void WrongList::InsertWrong( size_t nStart, size_t nEnd )
     if (nPos != maRanges.end())
         maRanges.insert(nPos, editeng::MisspellRange(nStart, nEnd));
     else
-        maRanges.push_back(editeng::MisspellRange(nStart, nEnd));
+        maRanges.emplace_back(nStart, nEnd);
 
     SAL_WARN_IF(DbgIsBuggy(), "editeng", "InsertWrong: WrongList broken!");
 }
@@ -499,7 +447,7 @@ WrongList* WrongList::Clone() const
 // #i102062#
 bool WrongList::operator==(const WrongList& rCompare) const
 {
-    // cleck direct members
+    // check direct members
     if(GetInvalidStart() != rCompare.GetInvalidStart()
         || GetInvalidEnd() != rCompare.GetInvalidEnd()
         || maRanges.size() != rCompare.maRanges.size())
@@ -576,10 +524,9 @@ bool WrongList::DbgIsBuggy() const
     return bError;
 }
 
-//////////////////////////////////////////////////////////////////////
 
 EdtAutoCorrDoc::EdtAutoCorrDoc(
-    EditEngine* pE, ContentNode* pN, sal_uInt16 nCrsr, sal_Unicode cIns) :
+    EditEngine* pE, ContentNode* pN, sal_Int32 nCrsr, sal_Unicode cIns) :
     mpEditEngine(pE),
     pCurNode(pN),
     nCursor(nCrsr),
@@ -589,10 +536,10 @@ EdtAutoCorrDoc::EdtAutoCorrDoc(
 EdtAutoCorrDoc::~EdtAutoCorrDoc()
 {
     if ( bUndoAction )
-        mpEditEngine->UndoActionEnd( EDITUNDO_INSERT );
+        mpEditEngine->UndoActionEnd();
 }
 
-sal_Bool EdtAutoCorrDoc::Delete( sal_uInt16 nStt, sal_uInt16 nEnd )
+bool EdtAutoCorrDoc::Delete(sal_Int32 nStt, sal_Int32 nEnd)
 {
     EditSelection aSel( EditPaM( pCurNode, nStt ), EditPaM( pCurNode, nEnd ) );
     mpEditEngine->DeleteSelection(aSel);
@@ -603,7 +550,7 @@ sal_Bool EdtAutoCorrDoc::Delete( sal_uInt16 nStt, sal_uInt16 nEnd )
     return true;
 }
 
-sal_Bool EdtAutoCorrDoc::Insert( sal_uInt16 nPos, const OUString& rTxt )
+bool EdtAutoCorrDoc::Insert(sal_Int32 nPos, const OUString& rTxt)
 {
     EditSelection aSel = EditPaM( pCurNode, nPos );
     mpEditEngine->InsertText(aSel, rTxt);
@@ -618,15 +565,15 @@ sal_Bool EdtAutoCorrDoc::Insert( sal_uInt16 nPos, const OUString& rTxt )
     return true;
 }
 
-sal_Bool EdtAutoCorrDoc::Replace( sal_uInt16 nPos, const OUString& rTxt )
+bool EdtAutoCorrDoc::Replace(sal_Int32 nPos, const OUString& rTxt)
 {
     return ReplaceRange( nPos, rTxt.getLength(), rTxt );
 }
 
-sal_Bool EdtAutoCorrDoc::ReplaceRange( xub_StrLen nPos, xub_StrLen nSourceLength, const OUString& rTxt )
+bool EdtAutoCorrDoc::ReplaceRange(sal_Int32 nPos, sal_Int32 nSourceLength, const OUString& rTxt)
 {
     // Actually a Replace introduce => corresponds to UNDO
-    sal_uInt16 nEnd = nPos+nSourceLength;
+    sal_Int32 nEnd = nPos+nSourceLength;
     if ( nEnd > pCurNode->Len() )
         nEnd = pCurNode->Len();
 
@@ -646,8 +593,8 @@ sal_Bool EdtAutoCorrDoc::ReplaceRange( xub_StrLen nPos, xub_StrLen nSourceLength
     return true;
 }
 
-sal_Bool EdtAutoCorrDoc::SetAttr( sal_uInt16 nStt, sal_uInt16 nEnd,
-            sal_uInt16 nSlotId, SfxPoolItem& rItem )
+void EdtAutoCorrDoc::SetAttr(sal_Int32 nStt, sal_Int32 nEnd,
+            sal_uInt16 nSlotId, SfxPoolItem& rItem)
 {
     SfxItemPool* pPool = &mpEditEngine->GetEditDoc().GetItemPool();
     while ( pPool->GetSecondaryPool() &&
@@ -666,14 +613,13 @@ sal_Bool EdtAutoCorrDoc::SetAttr( sal_uInt16 nStt, sal_uInt16 nEnd,
 
         EditSelection aSel( EditPaM( pCurNode, nStt ), EditPaM( pCurNode, nEnd ) );
         aSel.Max().SetIndex( nEnd );    // ???
-        mpEditEngine->SetAttribs( aSel, aSet, ATTRSPECIAL_EDGE );
+        mpEditEngine->SetAttribs( aSel, aSet, SetAttribsMode::Edge );
         bAllowUndoAction = false;
     }
-    return true;
 }
 
-sal_Bool EdtAutoCorrDoc::SetINetAttr( sal_uInt16 nStt, sal_uInt16 nEnd,
-            const OUString& rURL )
+bool EdtAutoCorrDoc::SetINetAttr(sal_Int32 nStt, sal_Int32 nEnd,
+            const OUString& rURL)
 {
     // Turn the Text into a command field ...
     EditSelection aSel( EditPaM( pCurNode, nStt ), EditPaM( pCurNode, nEnd ) );
@@ -682,7 +628,7 @@ sal_Bool EdtAutoCorrDoc::SetINetAttr( sal_uInt16 nStt, sal_uInt16 nEnd,
     SAL_WARN_IF(nCursor < nEnd, "editeng",
             "Cursor in the heart of the action?!");
     nCursor -= ( nEnd-nStt );
-    SvxFieldItem aField( SvxURLField( rURL, aText, SVXURLFORMAT_REPR ),
+    SvxFieldItem aField( SvxURLField( rURL, aText, SvxURLFormat::Repr ),
                                       EE_FEATURE_FIELD  );
     mpEditEngine->InsertField(aSel, aField);
     nCursor++;
@@ -702,19 +648,17 @@ OUString const* EdtAutoCorrDoc::GetPrevPara(bool const)
     sal_Int32 nPos = rNodes.GetPos( pCurNode );
 
     // Special case: Bullet => Paragraph start => simply return NULL...
-    const SfxBoolItem& rBulletState = (const SfxBoolItem&)
-            mpEditEngine->GetParaAttrib( nPos, EE_PARA_BULLETSTATE );
-    bool bBullet = rBulletState.GetValue() ? true : false;
-    if ( !bBullet && (mpEditEngine->GetControlWord() & EE_CNTRL_OUTLINER) )
+    const SfxBoolItem& rBulletState = mpEditEngine->GetParaAttrib( nPos, EE_PARA_BULLETSTATE );
+    bool bBullet = rBulletState.GetValue();
+    if ( !bBullet && (mpEditEngine->GetControlWord() & EEControlBits::OUTLINER) )
     {
         // The Outliner has still a Bullet at Level 0.
-        const SfxInt16Item& rLevel = (const SfxInt16Item&)
-                mpEditEngine->GetParaAttrib( nPos, EE_PARA_OUTLLEVEL );
+        const SfxInt16Item& rLevel = mpEditEngine->GetParaAttrib( nPos, EE_PARA_OUTLLEVEL );
         if ( rLevel.GetValue() == 0 )
             bBullet = true;
     }
     if ( bBullet )
-        return 0;
+        return nullptr;
 
     for ( sal_Int32 n = nPos; n; )
     {
@@ -723,7 +667,7 @@ OUString const* EdtAutoCorrDoc::GetPrevPara(bool const)
         if ( pNode->Len() )
             return & pNode->GetString();
     }
-    return 0;
+    return nullptr;
 
 }
 
@@ -746,9 +690,13 @@ bool EdtAutoCorrDoc::ChgAutoCorrWord( sal_Int32& rSttPos,
             pCurNode->GetString(), rSttPos, nEndPos, *this, aLanguageTag);
     if( pFnd && pFnd->IsTextOnly() )
     {
+
+        // replace also last colon of keywords surrounded by colons (for example, ":name:")
+        bool replaceLastChar = pFnd->GetShort()[0] == ':' && pFnd->GetShort().endsWith(":");
+
         // then replace
         EditSelection aSel( EditPaM( pCurNode, rSttPos ),
-                            EditPaM( pCurNode, nEndPos ) );
+                            EditPaM( pCurNode, nEndPos + (replaceLastChar ? 1 : 0) ));
         aSel = mpEditEngine->DeleteSelection(aSel);
         SAL_WARN_IF(nCursor < nEndPos, "editeng",
                 "Cursor in the heart of the action?!");
@@ -763,7 +711,7 @@ bool EdtAutoCorrDoc::ChgAutoCorrWord( sal_Int32& rSttPos,
     return bRet;
 }
 
-LanguageType EdtAutoCorrDoc::GetLanguage( sal_uInt16 nPos, sal_Bool ) const
+LanguageType EdtAutoCorrDoc::GetLanguage( sal_Int32 nPos ) const
 {
     return mpEditEngine->GetLanguage( EditPaM( pCurNode, nPos+1 ) );
 }
