@@ -17,8 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <com/sun/star/xml/AttributeData.hpp>
 #include <com/sun/star/lang/XUnoTunnel.hpp>
+#include <o3tl/any.hxx>
+#include <o3tl/make_unique.hxx>
 #include <xmloff/xmlcnimp.hxx>
 #include <xmloff/unoatrcn.hxx>
 #include <editeng/xmlcnitm.hxx>
@@ -29,48 +32,38 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::xml;
 
 
-TYPEINIT1(SvXMLAttrContainerItem, SfxPoolItem);
-
 SvXMLAttrContainerItem::SvXMLAttrContainerItem( sal_uInt16 _nWhich ) :
-    SfxPoolItem( _nWhich )
+    SfxPoolItem( _nWhich ),
+    pImpl( new SvXMLAttrContainerData )
 {
-    pImpl = new SvXMLAttrContainerData;
 }
 
 SvXMLAttrContainerItem::SvXMLAttrContainerItem(
                                         const SvXMLAttrContainerItem& rItem ) :
-    SfxPoolItem( rItem )
+    SfxPoolItem( rItem ),
+    pImpl( new SvXMLAttrContainerData( *rItem.pImpl ) )
 {
-    pImpl = new SvXMLAttrContainerData( *rItem.pImpl );
 }
 
 SvXMLAttrContainerItem::~SvXMLAttrContainerItem()
 {
-    delete pImpl;
 }
 
-int SvXMLAttrContainerItem::operator==( const SfxPoolItem& rItem ) const
+bool SvXMLAttrContainerItem::operator==( const SfxPoolItem& rItem ) const
 {
-    DBG_ASSERT( rItem.ISA(SvXMLAttrContainerItem),
+    DBG_ASSERT( dynamic_cast< const SvXMLAttrContainerItem* >(&rItem) !=  nullptr,
                "SvXMLAttrContainerItem::operator ==(): Bad type");
-    return *pImpl == *((const SvXMLAttrContainerItem&)rItem).pImpl;
+    return *pImpl.get() == *static_cast<const SvXMLAttrContainerItem&>(rItem).pImpl.get();
 }
 
-int SvXMLAttrContainerItem::Compare( const SfxPoolItem &/*rWith*/ ) const
-{
-    DBG_ASSERT( !this, "not yet implemented" );
-
-    return 0;
-}
-
-SfxItemPresentation SvXMLAttrContainerItem::GetPresentation(
+bool SvXMLAttrContainerItem::GetPresentation(
                     SfxItemPresentation /*ePresentation*/,
-                    SfxMapUnit /*eCoreMetric*/,
-                    SfxMapUnit /*ePresentationMetric*/,
+                    MapUnit /*eCoreMetric*/,
+                    MapUnit /*ePresentationMetric*/,
                     OUString & /*rText*/,
-                    const IntlWrapper * /*pIntlWrapper*/ ) const
+                    const IntlWrapper& /*rIntlWrapper*/ ) const
 {
-    return SFX_ITEM_PRESENTATION_NONE;
+    return false;
 }
 
 sal_uInt16 SvXMLAttrContainerItem::GetVersion( sal_uInt16 /*nFileFormatVersion*/ ) const
@@ -79,48 +72,41 @@ sal_uInt16 SvXMLAttrContainerItem::GetVersion( sal_uInt16 /*nFileFormatVersion*/
     return USHRT_MAX;
 }
 
-bool SvXMLAttrContainerItem::QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 /*nMemberId*/ ) const
+bool SvXMLAttrContainerItem::QueryValue( css::uno::Any& rVal, sal_uInt8 /*nMemberId*/ ) const
 {
     Reference<XNameContainer> xContainer =
-        new SvUnoAttributeContainer( new SvXMLAttrContainerData( *pImpl ) );
+        new SvUnoAttributeContainer( o3tl::make_unique<SvXMLAttrContainerData>( *pImpl.get() ) );
 
-    rVal.setValue( &xContainer, ::getCppuType((Reference<XNameContainer>*)0) );
+    rVal <<= xContainer;
     return true;
 }
 
-bool SvXMLAttrContainerItem::PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 /*nMemberId*/ )
+bool SvXMLAttrContainerItem::PutValue( const css::uno::Any& rVal, sal_uInt8 /*nMemberId*/ )
 {
-    Reference<XInterface> xRef;
-    SvUnoAttributeContainer* pContainer = NULL;
+    SvUnoAttributeContainer* pContainer = nullptr;
 
-    if( rVal.getValue() != NULL && rVal.getValueType().getTypeClass() == TypeClass_INTERFACE )
-    {
-        xRef = *(Reference<XInterface>*)rVal.getValue();
-        Reference<XUnoTunnel> xTunnel(xRef, UNO_QUERY);
-        if( xTunnel.is() )
-            pContainer = (SvUnoAttributeContainer*)(sal_uLong)xTunnel->getSomething(SvUnoAttributeContainer::getUnoTunnelId());
-    }
+    Reference<XUnoTunnel> xTunnel(rVal, UNO_QUERY);
+    if( xTunnel.is() )
+        pContainer = reinterpret_cast<SvUnoAttributeContainer*>((sal_uLong)xTunnel->getSomething(SvUnoAttributeContainer::getUnoTunnelId()));
 
     if( pContainer )
     {
-        delete pImpl;
-        pImpl = new SvXMLAttrContainerData( * pContainer->GetContainerImpl() );
+        pImpl.reset( new SvXMLAttrContainerData( * pContainer->GetContainerImpl() ) );
     }
     else
     {
-        std::auto_ptr<SvXMLAttrContainerData> pNewImpl(new SvXMLAttrContainerData);
+        std::unique_ptr<SvXMLAttrContainerData> pNewImpl(new SvXMLAttrContainerData);
 
         try
         {
-            Reference<XNameContainer> xContainer( xRef, UNO_QUERY );
+            Reference<XNameContainer> xContainer( rVal, UNO_QUERY );
             if( !xContainer.is() )
-                return sal_False;
+                return false;
 
             const Sequence< OUString > aNameSequence( xContainer->getElementNames() );
             const OUString* pNames = aNameSequence.getConstArray();
             const sal_Int32 nCount = aNameSequence.getLength();
             Any aAny;
-            AttributeData* pData;
             sal_Int32 nAttr;
 
             for( nAttr = 0; nAttr < nCount; nAttr++ )
@@ -128,10 +114,10 @@ bool SvXMLAttrContainerItem::PutValue( const com::sun::star::uno::Any& rVal, sal
                 const OUString aName( *pNames++ );
 
                 aAny = xContainer->getByName( aName );
-                if( aAny.getValue() == NULL || aAny.getValueType() != ::getCppuType((AttributeData*)0) )
-                    return sal_False;
+                auto pData = o3tl::tryAccess<AttributeData>(aAny);
+                if( !pData )
+                    return false;
 
-                pData = (AttributeData*)aAny.getValue();
                 sal_Int32 pos = aName.indexOf( ':' );
                 if( pos != -1 )
                 {
@@ -157,7 +143,7 @@ bool SvXMLAttrContainerItem::PutValue( const com::sun::star::uno::Any& rVal, sal
             }
 
             if( nAttr == nCount )
-                pImpl = pNewImpl.release();
+                pImpl = std::move(pNewImpl);
             else
                 return false;
         }
@@ -170,13 +156,13 @@ bool SvXMLAttrContainerItem::PutValue( const com::sun::star::uno::Any& rVal, sal
 }
 
 
-sal_Bool SvXMLAttrContainerItem::AddAttr( const OUString& rLName,
+bool SvXMLAttrContainerItem::AddAttr( const OUString& rLName,
                                         const OUString& rValue )
 {
     return pImpl->AddAttr( rLName, rValue );
 }
 
-sal_Bool SvXMLAttrContainerItem::AddAttr( const OUString& rPrefix,
+bool SvXMLAttrContainerItem::AddAttr( const OUString& rPrefix,
           const OUString& rNamespace, const OUString& rLName,
           const OUString& rValue )
 {
