@@ -22,7 +22,10 @@
 #include <cppuhelper/factory.hxx>
 
 #include "xolefactory.hxx"
+
+#if defined(_WIN32)
 #include "xdialogcreator.hxx"
+#endif
 
 using namespace ::com::sun::star;
 
@@ -33,25 +36,25 @@ SAL_DLLPUBLIC_EXPORT void * SAL_CALL emboleobj_component_getFactory(
     const sal_Char * pImplName, void * pServiceManager,
     SAL_UNUSED_PARAMETER void * /*pRegistryKey*/ )
 {
-    void * pRet = 0;
+    void * pRet = nullptr;
 
     OUString aImplName( OUString::createFromAscii( pImplName ) );
     uno::Reference< lang::XSingleServiceFactory > xFactory;
 
     if ( pServiceManager )
     {
-        if ( aImplName.equals( OleEmbeddedObjectFactory::impl_staticGetImplementationName() ) )
+        if ( aImplName == OleEmbeddedObjectFactory::impl_staticGetImplementationName() )
         {
-            xFactory= ::cppu::createOneInstanceFactory( reinterpret_cast< lang::XMultiServiceFactory*>( pServiceManager ),
+            xFactory= ::cppu::createOneInstanceFactory( static_cast< lang::XMultiServiceFactory*>( pServiceManager ),
                                                 OleEmbeddedObjectFactory::impl_staticGetImplementationName(),
                                                 OleEmbeddedObjectFactory::impl_staticCreateSelfInstance,
                                                 OleEmbeddedObjectFactory::impl_staticGetSupportedServiceNames() );
         }
-#ifdef WNT
-        // the following service makes sence only on windows
+#ifdef _WIN32
+        // the following service makes sense only on windows
         else if ( aImplName.equals( MSOLEDialogObjectCreator::impl_staticGetImplementationName() ) )
         {
-            xFactory= ::cppu::createOneInstanceFactory( reinterpret_cast< lang::XMultiServiceFactory*>( pServiceManager ),
+            xFactory= ::cppu::createOneInstanceFactory( static_cast< lang::XMultiServiceFactory*>( pServiceManager ),
                                                 MSOLEDialogObjectCreator::impl_staticGetImplementationName(),
                                                 MSOLEDialogObjectCreator::impl_staticCreateSelfInstance,
                                                 MSOLEDialogObjectCreator::impl_staticGetSupportedServiceNames() );
