@@ -18,9 +18,9 @@
  */
 
 #include "unotypewrapper.hxx"
-#include "rtl/ustring.hxx"
+#include <rtl/ustring.hxx>
 #include <osl/diagnose.h>
-
+#include <o3tl/char16_t2wchar_t.hxx>
 
 bool createUnoTypeWrapper(BSTR sTypeName, VARIANT * pVar)
 {
@@ -32,17 +32,9 @@ bool createUnoTypeWrapper(BSTR sTypeName, VARIANT * pVar)
     {
         pObj->AddRef();
         pVar->vt= VT_DISPATCH;
-#ifdef __MINGW32__
-        pVar->pdispVal= CComQIPtr<IDispatch, &__uuidof(IDispatch)>(pObj->GetUnknown());
-#else
         pVar->pdispVal= CComQIPtr<IDispatch>(pObj->GetUnknown());
-#endif
         //now set the value, e.i. the name of the type
-#ifdef __MINGW32__
-        CComQIPtr<IUnoTypeWrapper, &__uuidof(IUnoTypeWrapper)> spType(pVar->pdispVal);
-#else
         CComQIPtr<IUnoTypeWrapper> spType(pVar->pdispVal);
-#endif
         OSL_ASSERT(spType);
         if (SUCCEEDED(spType->put_Name(sTypeName)))
         {
@@ -55,7 +47,7 @@ bool createUnoTypeWrapper(BSTR sTypeName, VARIANT * pVar)
 
 bool createUnoTypeWrapper(const OUString& sTypeName, VARIANT * pVar)
 {
-    CComBSTR bstr(reinterpret_cast<LPCOLESTR>(sTypeName.getStr()));
+    CComBSTR bstr(o3tl::toW(sTypeName.getStr()));
     return createUnoTypeWrapper(bstr, pVar);
 }
 
@@ -114,7 +106,7 @@ STDMETHODIMP UnoTypeWrapper::Invoke( DISPID dispIdMember,
                          EXCEPINFO* /*pExcepInfo*/,
                          UINT* /*puArgErr*/)
 {
-    if (pDispParams == NULL)
+    if (pDispParams == nullptr)
         return DISP_E_EXCEPTION;
 
     if( pDispParams->cNamedArgs)
@@ -127,7 +119,7 @@ STDMETHODIMP UnoTypeWrapper::Invoke( DISPID dispIdMember,
     case DISPID_VALUE: // DISPID_VALUE
         if (wFlags & DISPATCH_PROPERTYGET)
         {
-            if (pVarResult == NULL)
+            if (pVarResult == nullptr)
             {
                 ret = E_POINTER;
                 break;
@@ -148,24 +140,21 @@ STDMETHODIMP UnoTypeWrapper::Invoke( DISPID dispIdMember,
 STDMETHODIMP UnoTypeWrapper::put_Name(BSTR  val)
 {
      Lock();
-     HRESULT hr = S_OK;
     m_sName = val;
      Unlock();
-     return hr;
+     return S_OK;
 }
 
 // (UnoTypeWrapper-----------------------
 STDMETHODIMP UnoTypeWrapper::get_Name(BSTR  *pVal)
 {
      Lock();
-    HRESULT hr = S_OK;
      if( !pVal)
          return E_POINTER;
     *pVal = m_sName.Copy();
      Unlock();
-     return hr;
+     return S_OK;
 }
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
