@@ -20,9 +20,10 @@
 
 #include "eventhandler.hxx"
 #include "pcrservices.hxx"
-#include "propctrlr.hrc"
+#include <helpids.h>
+#include <propctrlr.h>
 #include "formbrowsertools.hxx"
-#include "formresid.hrc"
+#include <strings.hrc>
 #include "formstrings.hxx"
 #include "handlerhelper.hxx"
 #include "modulepcr.hxx"
@@ -47,14 +48,14 @@
 #include <com/sun/star/lang/NullPointerException.hpp>
 #include <com/sun/star/script/XEventAttacherManager.hpp>
 #include <com/sun/star/script/XScriptEventsSupplier.hpp>
-#include <com/sun/star/util/XModifiable.hpp>
 #include <com/sun/star/uri/UriReferenceFactory.hpp>
 #include <com/sun/star/uri/XVndSunStarScriptUrlReference.hpp>
 
 #include <comphelper/namedvaluecollection.hxx>
 #include <comphelper/evtmethodhelper.hxx>
+#include <comphelper/sequence.hxx>
 #include <comphelper/types.hxx>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <rtl/ref.hxx>
 #include <rtl/ustrbuf.hxx>
@@ -68,7 +69,8 @@
 
 #include <map>
 #include <algorithm>
-#include <o3tl/compat_functional.hxx>
+#include <iterator>
+#include <o3tl/functional.hxx>
 
 extern "C" void SAL_CALL createRegistryInfo_EventHandler()
 {
@@ -80,7 +82,6 @@ namespace pcr
 
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::uno::XComponentContext;
-    using ::com::sun::star::beans::XPropertySet;
     using ::com::sun::star::uno::Any;
     using ::com::sun::star::uno::TypeClass_STRING;
     using ::com::sun::star::uno::Type;
@@ -122,7 +123,6 @@ namespace pcr
     using ::com::sun::star::inspection::InteractiveSelectionResult_Cancelled;
     using ::com::sun::star::inspection::InteractiveSelectionResult_Success;
     using ::com::sun::star::inspection::XObjectInspectorUI;
-    using ::com::sun::star::util::XModifiable;
     using ::com::sun::star::beans::PropertyChangeEvent;
     using ::com::sun::star::frame::XFrame;
     using ::com::sun::star::frame::XModel;
@@ -133,22 +133,22 @@ namespace pcr
     using com::sun::star::uri::XVndSunStarScriptUrlReference;
     using ::com::sun::star::lang::XEventListener;
 
-    namespace PropertyControlType = ::com::sun::star::inspection::PropertyControlType;
-    namespace PropertyAttribute = ::com::sun::star::beans::PropertyAttribute;
-    namespace FormComponentType = ::com::sun::star::form::FormComponentType;
+    namespace PropertyControlType = css::inspection::PropertyControlType;
+    namespace PropertyAttribute = css::beans::PropertyAttribute;
+    namespace FormComponentType = css::form::FormComponentType;
 
     EventDescription::EventDescription( EventId _nId, const sal_Char* _pListenerNamespaceAscii, const sal_Char* _pListenerClassAsciiName,
-            const sal_Char* _pListenerMethodAsciiName, sal_uInt16 _nDisplayNameResId, const OString& _sHelpId, const OString& _sUniqueBrowseId )
-        :sDisplayName(PcrRes( _nDisplayNameResId ).toString())
+            const sal_Char* _pListenerMethodAsciiName, const char* pDisplayNameResId, const OString& _sHelpId, const OString& _sUniqueBrowseId )
+        :sDisplayName(PcrRes( pDisplayNameResId ))
         ,sListenerMethodName( OUString::createFromAscii( _pListenerMethodAsciiName ) )
         ,sHelpId( _sHelpId )
         ,sUniqueBrowseId( _sUniqueBrowseId )
         ,nId( _nId )
     {
         OUStringBuffer aQualifiedListenerClass;
-        aQualifiedListenerClass.appendAscii( "com.sun.star." );
+        aQualifiedListenerClass.append( "com.sun.star." );
         aQualifiedListenerClass.appendAscii( _pListenerNamespaceAscii );
-        aQualifiedListenerClass.appendAscii( "." );
+        aQualifiedListenerClass.append( "." );
         aQualifiedListenerClass.appendAscii( _pListenerClassAsciiName );
         sListenerClassName = aQualifiedListenerClass.makeStringAndClear();
     }
@@ -156,9 +156,9 @@ namespace pcr
     namespace
     {
         #define DESCRIBE_EVENT( asciinamespace, asciilistener, asciimethod, id_postfix ) \
-            s_aKnownEvents.insert( EventMap::value_type( \
+            s_aKnownEvents.emplace(  \
                 asciimethod, \
-                EventDescription( ++nEventId, asciinamespace, asciilistener, asciimethod, RID_STR_EVT_##id_postfix, HID_EVT_##id_postfix, UID_BRWEVT_##id_postfix ) ) )
+                EventDescription( ++nEventId, asciinamespace, asciilistener, asciimethod, RID_STR_EVT_##id_postfix, HID_EVT_##id_postfix, UID_BRWEVT_##id_postfix ) )
 
         bool lcl_getEventDescriptionForMethod( const OUString& _rMethodName, EventDescription& _out_rDescription )
         {
@@ -216,14 +216,10 @@ namespace pcr
 
         OUString lcl_getEventPropertyName( const OUString& _rListenerClassName, const OUString& _rMethodName )
         {
-            OUStringBuffer aPropertyName;
-            aPropertyName.append( _rListenerClassName );
-            aPropertyName.append( ';' );
-            aPropertyName.append( _rMethodName.getStr() );
-            return aPropertyName.makeStringAndClear();
+            return _rListenerClassName + OUStringLiteral1(';') + _rMethodName;
         }
 
-        ScriptEventDescriptor lcl_getAssignedScriptEvent( const EventDescription& _rEvent, const Sequence< ScriptEventDescriptor >& _rAllAssignedMacros )
+        ScriptEventDescriptor lcl_getAssignedScriptEvent( const EventDescription& _rEvent, const std::vector< ScriptEventDescriptor >& _rAllAssignedMacros )
         {
             ScriptEventDescriptor aScriptEvent;
             // for the case there is actually no event assigned, initialize at least ListenerType and MethodName,
@@ -231,24 +227,22 @@ namespace pcr
             aScriptEvent.ListenerType = _rEvent.sListenerClassName;
             aScriptEvent.EventMethod = _rEvent.sListenerMethodName;
 
-            const ScriptEventDescriptor* pAssignedEvent = _rAllAssignedMacros.getConstArray();
-            sal_Int32 assignedEventCount( _rAllAssignedMacros.getLength() );
-            for ( sal_Int32 assignedEvent = 0; assignedEvent < assignedEventCount; ++assignedEvent, ++pAssignedEvent )
+            for ( const ScriptEventDescriptor& rSED :  _rAllAssignedMacros )
             {
-                if  (   ( pAssignedEvent->ListenerType != _rEvent.sListenerClassName )
-                    ||  ( pAssignedEvent->EventMethod != _rEvent.sListenerMethodName )
+                if  (   rSED.ListenerType != _rEvent.sListenerClassName
+                    ||  rSED.EventMethod != _rEvent.sListenerMethodName
                     )
                     continue;
 
-                if  (   ( pAssignedEvent->ScriptCode.isEmpty() )
-                    ||  ( pAssignedEvent->ScriptType.isEmpty() )
+                if  (  rSED.ScriptCode.isEmpty()
+                    || rSED.ScriptType.isEmpty()
                     )
                 {
                     OSL_FAIL( "lcl_getAssignedScriptEvent: me thinks this should not happen!" );
                     continue;
                 }
 
-                aScriptEvent = *pAssignedEvent;
+                aScriptEvent = rSED;
 
                 if ( aScriptEvent.ScriptType != "StarBasic" )
                     continue;
@@ -264,9 +258,9 @@ namespace pcr
                 OUString sMacroPath = aScriptEvent.ScriptCode.copy( nPrefixLen + 1 );
 
                 OUStringBuffer aNewStyleSpec;
-                aNewStyleSpec.appendAscii( "vnd.sun.star.script:" );
+                aNewStyleSpec.append( "vnd.sun.star.script:" );
                 aNewStyleSpec.append     ( sMacroPath );
-                aNewStyleSpec.appendAscii( "?language=Basic&location=" );
+                aNewStyleSpec.append( "?language=Basic&location=" );
                 aNewStyleSpec.append     ( sLocation );
 
                 aScriptEvent.ScriptCode = aNewStyleSpec.makeStringAndClear();
@@ -290,7 +284,7 @@ namespace pcr
             return _rFormComponentEventDescriptor.ListenerType;
         }
 
-        typedef ::std::set< Type, TypeLessByName > TypeBag;
+        typedef std::set< Type, TypeLessByName > TypeBag;
 
         void lcl_addListenerTypesFor_throw( const Reference< XInterface >& _rxComponent,
             const Reference< XIntrospection >& _rxIntrospection, TypeBag& _out_rTypes )
@@ -304,29 +298,19 @@ namespace pcr
 
             Sequence< Type > aListeners( xIntrospectionAccess->getSupportedListeners() );
 
-            ::std::copy( aListeners.getConstArray(), aListeners.getConstArray() + aListeners.getLength(),
-                ::std::insert_iterator< TypeBag >( _out_rTypes, _out_rTypes.begin() ) );
-        }
-
-        bool operator ==( const ScriptEventDescriptor& _lhs, const ScriptEventDescriptor& _rhs )
-        {
-            return  (   ( _lhs.ListenerType         == _rhs.ListenerType        )
-                    &&  ( _lhs.EventMethod          == _rhs.EventMethod         )
-                    &&  ( _lhs.AddListenerParam     == _rhs.AddListenerParam    )
-                    &&  ( _lhs.ScriptType           == _rhs.ScriptType          )
-                    &&  ( _lhs.ScriptCode           == _rhs.ScriptCode          )
-                    );
+            std::copy( aListeners.begin(), aListeners.end(),
+                         std::insert_iterator< TypeBag >( _out_rTypes, _out_rTypes.begin() ) );
         }
     }
 
-    typedef ::cppu::WeakImplHelper1 <   ::com::sun::star::container::XNameReplace
+    typedef ::cppu::WeakImplHelper <   css::container::XNameReplace
                                     >   EventHolder_Base;
     /* An UNO component holding assigned event descriptions, for use with a SvxMacroAssignDlg */
     class EventHolder : public EventHolder_Base
     {
     private:
-        typedef std::unordered_map< OUString, ScriptEventDescriptor, OUStringHash >  EventMap;
-        typedef ::std::map< EventId, EventMap::iterator >                                       EventMapIndexAccess;
+        typedef std::unordered_map< OUString, ScriptEventDescriptor >  EventMap;
+        typedef std::map< EventId, EventMap::iterator >                                       EventMapIndexAccess;
 
         EventMap            m_aEventNameAccess;
         EventMapIndexAccess m_aEventIndexAccess;
@@ -342,15 +326,15 @@ namespace pcr
         ScriptEventDescriptor getNormalizedDescriptorByName( const OUString& _rEventName ) const;
 
         // XNameReplace
-        virtual void SAL_CALL replaceByName( const OUString& _rName, const Any& aElement ) throw (IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual Any SAL_CALL getByName( const OUString& _rName ) throw (NoSuchElementException, WrappedTargetException, RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual Sequence< OUString > SAL_CALL getElementNames(  ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual sal_Bool SAL_CALL hasByName( const OUString& _rName ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual Type SAL_CALL getElementType(  ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual sal_Bool SAL_CALL hasElements(  ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL replaceByName( const OUString& _rName, const Any& aElement ) override;
+        virtual Any SAL_CALL getByName( const OUString& _rName ) override;
+        virtual Sequence< OUString > SAL_CALL getElementNames(  ) override;
+        virtual sal_Bool SAL_CALL hasByName( const OUString& _rName ) override;
+        virtual Type SAL_CALL getElementType(  ) override;
+        virtual sal_Bool SAL_CALL hasElements(  ) override;
 
     protected:
-        virtual ~EventHolder( );
+        virtual ~EventHolder( ) override;
 
     private:
         ScriptEventDescriptor impl_getDescriptor_throw( const OUString& _rEventName ) const;
@@ -369,8 +353,8 @@ namespace pcr
 
     void EventHolder::addEvent( EventId _nId, const OUString& _rEventName, const ScriptEventDescriptor& _rScriptEvent )
     {
-        ::std::pair< EventMap::iterator, bool > insertionResult =
-            m_aEventNameAccess.insert( EventMap::value_type( _rEventName, _rScriptEvent ) );
+        std::pair< EventMap::iterator, bool > insertionResult =
+            m_aEventNameAccess.emplace( _rEventName, _rScriptEvent );
         OSL_ENSURE( insertionResult.second, "EventHolder::addEvent: there already was a MacroURL for this event!" );
         m_aEventIndexAccess[ _nId ] = insertionResult.first;
     }
@@ -388,7 +372,7 @@ namespace pcr
         return pos->second;
     }
 
-    void SAL_CALL EventHolder::replaceByName( const OUString& _rName, const Any& _rElement ) throw (IllegalArgumentException, NoSuchElementException, WrappedTargetException, RuntimeException, std::exception)
+    void SAL_CALL EventHolder::replaceByName( const OUString& _rName, const Any& _rElement )
     {
         EventMap::iterator pos = m_aEventNameAccess.find( _rName );
         if ( pos == m_aEventNameAccess.end() )
@@ -403,7 +387,7 @@ namespace pcr
         pos->second.ScriptCode = aExtractor.getOrDefault( "Script", OUString() );
     }
 
-    Any SAL_CALL EventHolder::getByName( const OUString& _rName ) throw (NoSuchElementException, WrappedTargetException, RuntimeException, std::exception)
+    Any SAL_CALL EventHolder::getByName( const OUString& _rName )
     {
         ScriptEventDescriptor aDescriptor( impl_getDescriptor_throw( _rName ) );
 
@@ -416,7 +400,7 @@ namespace pcr
         return makeAny( aScriptDescriptor );
     }
 
-    Sequence< OUString > SAL_CALL EventHolder::getElementNames(  ) throw (RuntimeException, std::exception)
+    Sequence< OUString > SAL_CALL EventHolder::getElementNames(  )
     {
         Sequence< OUString > aReturn( m_aEventIndexAccess.size() );
         OUString* pReturn = aReturn.getArray();
@@ -438,18 +422,18 @@ namespace pcr
         return aReturn;
     }
 
-    sal_Bool SAL_CALL EventHolder::hasByName( const OUString& _rName ) throw (RuntimeException, std::exception)
+    sal_Bool SAL_CALL EventHolder::hasByName( const OUString& _rName )
     {
         EventMap::const_iterator pos = m_aEventNameAccess.find( _rName );
         return pos != m_aEventNameAccess.end();
     }
 
-    Type SAL_CALL EventHolder::getElementType(  ) throw (RuntimeException, std::exception)
+    Type SAL_CALL EventHolder::getElementType(  )
     {
         return cppu::UnoType<Sequence< PropertyValue >>::get();
     }
 
-    sal_Bool SAL_CALL EventHolder::hasElements(  ) throw (RuntimeException, std::exception)
+    sal_Bool SAL_CALL EventHolder::hasElements(  )
     {
         return !m_aEventNameAccess.empty();
     }
@@ -469,30 +453,29 @@ namespace pcr
     {
     }
 
-    OUString SAL_CALL EventHandler::getImplementationName(  ) throw (RuntimeException, std::exception)
+    OUString SAL_CALL EventHandler::getImplementationName(  )
     {
         return getImplementationName_static();
     }
 
-    sal_Bool SAL_CALL EventHandler::supportsService( const OUString& ServiceName ) throw (RuntimeException, std::exception)
+    sal_Bool SAL_CALL EventHandler::supportsService( const OUString& ServiceName )
     {
         return cppu::supportsService(this, ServiceName);
     }
 
-    Sequence< OUString > SAL_CALL EventHandler::getSupportedServiceNames(  ) throw (RuntimeException, std::exception)
+    Sequence< OUString > SAL_CALL EventHandler::getSupportedServiceNames(  )
     {
         return getSupportedServiceNames_static();
     }
 
-    OUString SAL_CALL EventHandler::getImplementationName_static(  ) throw (RuntimeException)
+    OUString SAL_CALL EventHandler::getImplementationName_static(  )
     {
         return OUString(  "com.sun.star.comp.extensions.EventHandler"  );
     }
 
-    Sequence< OUString > SAL_CALL EventHandler::getSupportedServiceNames_static(  ) throw (RuntimeException)
+    Sequence< OUString > SAL_CALL EventHandler::getSupportedServiceNames_static(  )
     {
-        Sequence< OUString > aSupported( 1 );
-        aSupported[0] = "com.sun.star.form.inspection.EventHandler";
+        Sequence<OUString> aSupported { "com.sun.star.form.inspection.EventHandler" };
         return aSupported;
     }
 
@@ -501,14 +484,14 @@ namespace pcr
         return *( new EventHandler( _rxContext ) );
     }
 
-    void SAL_CALL EventHandler::inspect( const Reference< XInterface >& _rxIntrospectee ) throw (RuntimeException, NullPointerException, std::exception)
+    void SAL_CALL EventHandler::inspect( const Reference< XInterface >& _rxIntrospectee )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
         if ( !_rxIntrospectee.is() )
             throw NullPointerException();
 
-        m_xComponent = Reference< XPropertySet >( _rxIntrospectee, UNO_QUERY_THROW );
+        m_xComponent.set( _rxIntrospectee, UNO_QUERY_THROW );
 
         m_bEventsMapInitialized = false;
         EventMap aEmpty;
@@ -540,26 +523,23 @@ namespace pcr
         }
     }
 
-    Any SAL_CALL EventHandler::getPropertyValue( const OUString& _rPropertyName ) throw (UnknownPropertyException, RuntimeException, std::exception)
+    Any SAL_CALL EventHandler::getPropertyValue( const OUString& _rPropertyName )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
         const EventDescription& rEvent = impl_getEventForName_throw( _rPropertyName );
 
-        Sequence< ScriptEventDescriptor > aEvents;
+        std::vector< ScriptEventDescriptor > aEvents;
         impl_getComponentScriptEvents_nothrow( aEvents );
 
-        sal_Int32 nEventCount = aEvents.getLength();
-        const ScriptEventDescriptor* pEvents = aEvents.getConstArray();
-
         ScriptEventDescriptor aPropertyValue;
-        for ( sal_Int32 event = 0; event < nEventCount; ++event, ++pEvents )
+        for ( const ScriptEventDescriptor& rSCD : aEvents )
         {
-            if  (   rEvent.sListenerClassName == pEvents->ListenerType
-                &&  rEvent.sListenerMethodName == pEvents->EventMethod
+            if  (   rEvent.sListenerClassName == rSCD.ListenerType
+                &&  rEvent.sListenerMethodName == rSCD.EventMethod
                 )
             {
-                aPropertyValue = *pEvents;
+                aPropertyValue = rSCD;
                 break;
             }
         }
@@ -567,7 +547,7 @@ namespace pcr
         return makeAny( aPropertyValue );
     }
 
-    void SAL_CALL EventHandler::setPropertyValue( const OUString& _rPropertyName, const Any& _rValue ) throw (UnknownPropertyException, RuntimeException, std::exception)
+    void SAL_CALL EventHandler::setPropertyValue( const OUString& _rPropertyName, const Any& _rValue )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -597,14 +577,14 @@ namespace pcr
         m_aPropertyListeners.notify( aEvent, &XPropertyChangeListener::propertyChange );
     }
 
-    Any SAL_CALL EventHandler::convertToPropertyValue( const OUString& _rPropertyName, const Any& _rControlValue ) throw (UnknownPropertyException, RuntimeException, std::exception)
+    Any SAL_CALL EventHandler::convertToPropertyValue( const OUString& _rPropertyName, const Any& _rControlValue )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
         OUString sNewScriptCode;
         OSL_VERIFY( _rControlValue >>= sNewScriptCode );
 
-        Sequence< ScriptEventDescriptor > aAllAssignedEvents;
+        std::vector< ScriptEventDescriptor > aAllAssignedEvents;
         impl_getComponentScriptEvents_nothrow( aAllAssignedEvents );
 
         const EventDescription& rEvent = impl_getEventForName_throw( _rPropertyName );
@@ -616,15 +596,15 @@ namespace pcr
         // The only exception is the user pressing "DEL" while the control has the focus, in this case, we reset the
         // control content to an empty string. So this is the only scenario where this method is allowed to be called.
 
-        // Striclty, we would be able to convert the display value to a property value,
+        // Strictly, we would be able to convert the display value to a property value,
         // using the "name (location, language)" format we used in convertToControlValue. However,
-        // there is no need for this code ...
+        // there is no need for this code...
 
         aAssignedScript.ScriptCode = sNewScriptCode;
         return makeAny( aAssignedScript );
     }
 
-    Any SAL_CALL EventHandler::convertToControlValue( const OUString& /*_rPropertyName*/, const Any& _rPropertyValue, const Type& _rControlValueType ) throw (UnknownPropertyException, RuntimeException, std::exception)
+    Any SAL_CALL EventHandler::convertToControlValue( const OUString& /*_rPropertyName*/, const Any& _rPropertyValue, const Type& _rControlValueType )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
 
@@ -633,7 +613,6 @@ namespace pcr
 
         OSL_ENSURE( _rControlValueType.getTypeClass() == TypeClass_STRING,
             "EventHandler::convertToControlValue: unexpected ControlValue type class!" );
-        (void)_rControlValueType;
 
         OUString sScript( aScriptEvent.ScriptCode );
         if ( !sScript.isEmpty() )
@@ -658,14 +637,14 @@ namespace pcr
 
                 if ( !(sLocation.isEmpty() && sLanguage.isEmpty()) )
                 {
-                    aComposeBuffer.appendAscii( " (" );
+                    aComposeBuffer.append( " (" );
 
                     // location
                     OSL_ENSURE( !sLocation.isEmpty(), "EventHandler::convertToControlValue: unexpected: no location!" );
                     if ( !sLocation.isEmpty() )
                     {
                         aComposeBuffer.append( sLocation );
-                        aComposeBuffer.appendAscii( ", " );
+                        aComposeBuffer.append( ", " );
                     }
 
                     // language
@@ -688,12 +667,12 @@ namespace pcr
         return makeAny( sScript );
     }
 
-    PropertyState SAL_CALL EventHandler::getPropertyState( const OUString& /*_rPropertyName*/ ) throw (UnknownPropertyException, RuntimeException, std::exception)
+    PropertyState SAL_CALL EventHandler::getPropertyState( const OUString& /*_rPropertyName*/ )
     {
         return PropertyState_DIRECT_VALUE;
     }
 
-    void SAL_CALL EventHandler::addPropertyChangeListener( const Reference< XPropertyChangeListener >& _rxListener ) throw (NullPointerException, RuntimeException, std::exception)
+    void SAL_CALL EventHandler::addPropertyChangeListener( const Reference< XPropertyChangeListener >& _rxListener )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         if ( !_rxListener.is() )
@@ -701,41 +680,39 @@ namespace pcr
         m_aPropertyListeners.addListener( _rxListener );
     }
 
-    void SAL_CALL EventHandler::removePropertyChangeListener( const Reference< XPropertyChangeListener >& _rxListener ) throw (RuntimeException, std::exception)
+    void SAL_CALL EventHandler::removePropertyChangeListener( const Reference< XPropertyChangeListener >& _rxListener )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         m_aPropertyListeners.removeListener( _rxListener );
     }
 
-    Sequence< Property > SAL_CALL EventHandler::getSupportedProperties() throw (RuntimeException, std::exception)
+    Sequence< Property > SAL_CALL EventHandler::getSupportedProperties()
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         if ( !m_bEventsMapInitialized )
         {
-            const_cast< EventHandler* >( this )->m_bEventsMapInitialized = true;
+            m_bEventsMapInitialized = true;
             try
             {
-                Sequence< Type > aListeners;
-                impl_getCopmonentListenerTypes_nothrow( aListeners );
-                sal_Int32 listenerCount = aListeners.getLength();
+                std::vector< Type > aListeners;
+                impl_getComponentListenerTypes_nothrow( aListeners );
 
                 Property aCurrentProperty;
                 OUString sListenerClassName;
 
                 // loop through all listeners and all methods, and see which we can present at the UI
-                const Type* pListeners = aListeners.getConstArray();
-                for ( sal_Int32 listener = 0; listener < listenerCount; ++listener, ++pListeners )
+                for ( const Type& rListener : aListeners )
                 {
                     aCurrentProperty = Property();
 
                     // the programmatic name of the listener, to be used as "property" name
-                    sListenerClassName = pListeners->getTypeName();
+                    sListenerClassName = rListener.getTypeName();
                     OSL_ENSURE( !sListenerClassName.isEmpty(), "EventHandler::getSupportedProperties: strange - no listener name ..." );
                     if ( sListenerClassName.isEmpty() )
                         continue;
 
                     // loop through all methods
-                    Sequence< OUString > aMethods( comphelper::getEventMethodsForType( *pListeners ) );
+                    Sequence< OUString > aMethods( comphelper::getEventMethodsForType( rListener ) );
 
                     const OUString* pMethods = aMethods.getConstArray();
                     sal_uInt32 methodCount = aMethods.getLength();
@@ -749,8 +726,8 @@ namespace pcr
                         if ( !impl_filterMethod_nothrow( aEvent ) )
                             continue;
 
-                        const_cast< EventHandler* >( this )->m_aEvents.insert( EventMap::value_type(
-                            lcl_getEventPropertyName( sListenerClassName, *pMethods ), aEvent ) );
+                        m_aEvents.emplace(
+                            lcl_getEventPropertyName( sListenerClassName, *pMethods ), aEvent );
                     }
                 }
 
@@ -762,7 +739,7 @@ namespace pcr
         }
 
         // sort them by ID - this is the relative ordering in the UI
-        ::std::map< EventId, Property > aOrderedProperties;
+        std::map< EventId, Property > aOrderedProperties;
         for (   EventMap::const_iterator loop = m_aEvents.begin();
                 loop != m_aEvents.end();
                 ++loop
@@ -774,19 +751,16 @@ namespace pcr
                 PropertyAttribute::BOUND );
         }
 
-        StlSyntaxSequence< Property > aReturn( aOrderedProperties.size() );
-        ::std::transform( aOrderedProperties.begin(), aOrderedProperties.end(), aReturn.begin(),
-            ::o3tl::select2nd< ::std::map< EventId, Property >::value_type >() );
-        return aReturn;
+        return comphelper::mapValuesToSequence( aOrderedProperties );
     }
 
-    Sequence< OUString > SAL_CALL EventHandler::getSupersededProperties( ) throw (RuntimeException, std::exception)
+    Sequence< OUString > SAL_CALL EventHandler::getSupersededProperties( )
     {
         // none
         return Sequence< OUString >( );
     }
 
-    Sequence< OUString > SAL_CALL EventHandler::getActuatingProperties( ) throw (RuntimeException, std::exception)
+    Sequence< OUString > SAL_CALL EventHandler::getActuatingProperties( )
     {
         // none
         return Sequence< OUString >( );
@@ -794,7 +768,6 @@ namespace pcr
 
     LineDescriptor SAL_CALL EventHandler::describePropertyLine( const OUString& _rPropertyName,
         const Reference< XPropertyControlFactory >& _rxControlFactory )
-        throw (UnknownPropertyException, NullPointerException, RuntimeException, std::exception)
     {
         if ( !_rxControlFactory.is() )
             throw NullPointerException();
@@ -803,24 +776,24 @@ namespace pcr
 
         LineDescriptor aDescriptor;
 
-        aDescriptor.Control = _rxControlFactory->createPropertyControl( PropertyControlType::TextField, sal_True );
+        aDescriptor.Control = _rxControlFactory->createPropertyControl( PropertyControlType::TextField, true );
         Reference< XEventListener > xControlExtender = new PropertyControlExtender( aDescriptor.Control );
 
         const EventDescription& rEvent = impl_getEventForName_throw( _rPropertyName );
         aDescriptor.DisplayName = rEvent.sDisplayName;
         aDescriptor.HelpURL = HelpIdUrl::getHelpURL( rEvent.sHelpId );
         aDescriptor.PrimaryButtonId = OStringToOUString(rEvent.sUniqueBrowseId, RTL_TEXTENCODING_UTF8);
-        aDescriptor.HasPrimaryButton = sal_True;
+        aDescriptor.HasPrimaryButton = true;
         aDescriptor.Category = "Events";
         return aDescriptor;
     }
 
-    sal_Bool SAL_CALL EventHandler::isComposable( const OUString& /*_rPropertyName*/ ) throw (UnknownPropertyException, RuntimeException, std::exception)
+    sal_Bool SAL_CALL EventHandler::isComposable( const OUString& /*_rPropertyName*/ )
     {
-        return sal_False;
+        return false;
     }
 
-    InteractiveSelectionResult SAL_CALL EventHandler::onInteractivePropertySelection( const OUString& _rPropertyName, sal_Bool /*_bPrimary*/, Any& /*_rData*/, const Reference< XObjectInspectorUI >& _rxInspectorUI ) throw (UnknownPropertyException, NullPointerException, RuntimeException, std::exception)
+    InteractiveSelectionResult SAL_CALL EventHandler::onInteractivePropertySelection( const OUString& _rPropertyName, sal_Bool /*_bPrimary*/, Any& /*_rData*/, const Reference< XObjectInspectorUI >& _rxInspectorUI )
     {
         if ( !_rxInspectorUI.is() )
             throw NullPointerException();
@@ -828,7 +801,7 @@ namespace pcr
         ::osl::MutexGuard aGuard( m_aMutex );
         const EventDescription& rForEvent = impl_getEventForName_throw( _rPropertyName );
 
-        Sequence< ScriptEventDescriptor > aAllAssignedEvents;
+        std::vector< ScriptEventDescriptor > aAllAssignedEvents;
         impl_getComponentScriptEvents_nothrow( aAllAssignedEvents );
 
         // SvxMacroAssignDlg-compatible structure holding all event/assignments
@@ -846,15 +819,15 @@ namespace pcr
 
         // the initial selection in the dialog
         Sequence< OUString > aNames( pEventHolder->getElementNames() );
-        const OUString* pChosenEvent = ::std::find( aNames.getConstArray(), aNames.getConstArray() + aNames.getLength(), rForEvent.sListenerMethodName );
-        sal_uInt16 nInitialSelection = (sal_uInt16)( pChosenEvent - aNames.getConstArray() );
+        const OUString* pChosenEvent = std::find( aNames.begin(), aNames.end(), rForEvent.sListenerMethodName );
+        sal_uInt16 nInitialSelection = (sal_uInt16)( pChosenEvent - aNames.begin() );
 
         // the dialog
         SvxAbstractDialogFactory* pFactory = SvxAbstractDialogFactory::Create();
         if ( !pFactory )
             return InteractiveSelectionResult_Cancelled;
 
-        ::std::unique_ptr< VclAbstractDialog > pDialog( pFactory->CreateSvxMacroAssignDlg(
+        ScopedVclPtr<VclAbstractDialog> pDialog( pFactory->CreateSvxMacroAssignDlg(
             PropertyHandlerHelper::getDialogParentWindow( m_xContext ),
             impl_getContextFrame_nothrow(),
             m_bIsDialogElement,
@@ -894,7 +867,7 @@ namespace pcr
         return InteractiveSelectionResult_Success;
     }
 
-    void SAL_CALL EventHandler::actuatingPropertyChanged( const OUString& /*_rActuatingPropertyName*/, const Any& /*_rNewValue*/, const Any& /*_rOldValue*/, const Reference< XObjectInspectorUI >& /*_rxInspectorUI*/, sal_Bool /*_bFirstTimeInit*/ ) throw (NullPointerException, RuntimeException, std::exception)
+    void SAL_CALL EventHandler::actuatingPropertyChanged( const OUString& /*_rActuatingPropertyName*/, const Any& /*_rNewValue*/, const Any& /*_rOldValue*/, const Reference< XObjectInspectorUI >& /*_rxInspectorUI*/, sal_Bool /*_bFirstTimeInit*/ )
     {
         OSL_FAIL( "EventHandler::actuatingPropertyChanged: no actuating properties -> no callback (well, this is how it *should* be!)" );
     }
@@ -908,9 +881,9 @@ namespace pcr
         m_xComponent.clear();
     }
 
-    sal_Bool SAL_CALL EventHandler::suspend( sal_Bool /*_bSuspend*/ ) throw (RuntimeException, std::exception)
+    sal_Bool SAL_CALL EventHandler::suspend( sal_Bool /*_bSuspend*/ )
     {
-        return sal_True;
+        return true;
     }
 
     Reference< XFrame > EventHandler::impl_getContextFrame_nothrow() const
@@ -947,23 +920,20 @@ namespace pcr
         throw NoSuchElementException();
     }
 
-    void EventHandler::impl_getFormComponentScriptEvents_nothrow( Sequence < ScriptEventDescriptor >& _out_rEvents ) const
+    void EventHandler::impl_getFormComponentScriptEvents_nothrow( std::vector < ScriptEventDescriptor >& _out_rEvents ) const
     {
-        _out_rEvents = Sequence < ScriptEventDescriptor >();
+        _out_rEvents.clear();
         try
         {
             Reference< XChild > xChild( m_xComponent, UNO_QUERY_THROW );
             Reference< XEventAttacherManager > xEventManager( xChild->getParent(), UNO_QUERY_THROW );
-            _out_rEvents = xEventManager->getScriptEvents( impl_getComponentIndexInParent_throw() );
+            comphelper::sequenceToContainer(_out_rEvents, xEventManager->getScriptEvents( impl_getComponentIndexInParent_throw() ));
 
             // the form component script API has unqualified listener names, but for normalization
             // purpose, we want fully qualified ones
-            ScriptEventDescriptor* pEvents = _out_rEvents.getArray();
-            ScriptEventDescriptor* pEventsEnd = _out_rEvents.getArray() + _out_rEvents.getLength();
-            while ( pEvents != pEventsEnd )
+            for ( ScriptEventDescriptor& rSED :  _out_rEvents)
             {
-                pEvents->ListenerType = lcl_getQualifiedKnownListenerName( *pEvents );
-                ++pEvents;
+                rSED.ListenerType = lcl_getQualifiedKnownListenerName( rSED );
             }
         }
         catch( const Exception& )
@@ -972,9 +942,9 @@ namespace pcr
         }
     }
 
-    void EventHandler::impl_getCopmonentListenerTypes_nothrow( Sequence< Type >& _out_rTypes ) const
+    void EventHandler::impl_getComponentListenerTypes_nothrow( std::vector< Type >& _out_rTypes ) const
     {
-        _out_rTypes.realloc( 0 );
+        _out_rTypes.clear();
         try
         {
             // we use a set to avoid duplicates
@@ -994,8 +964,7 @@ namespace pcr
             }
 
             // now that they're disambiguated, copy these types into our member
-            _out_rTypes.realloc( aListeners.size() );
-            ::std::copy( aListeners.begin(), aListeners.end(), _out_rTypes.getArray() );
+            std::copy(aListeners.begin(), aListeners.end(), std::back_inserter(_out_rTypes));
         }
         catch( const Exception& )
         {
@@ -1003,9 +972,9 @@ namespace pcr
         }
     }
 
-    void EventHandler::impl_getDialogElementScriptEvents_nothrow( Sequence < ScriptEventDescriptor >& _out_rEvents ) const
+    void EventHandler::impl_getDialogElementScriptEvents_nothrow( std::vector < ScriptEventDescriptor >& _out_rEvents ) const
     {
-        _out_rEvents = Sequence < ScriptEventDescriptor >();
+        _out_rEvents.clear();
         try
         {
             Reference< XScriptEventsSupplier > xEventsSupplier( m_xComponent, UNO_QUERY_THROW );
@@ -1013,13 +982,10 @@ namespace pcr
             Sequence< OUString > aEventNames( xEvents->getElementNames() );
 
             sal_Int32 nEventCount = aEventNames.getLength();
-            _out_rEvents.realloc( nEventCount );
+            _out_rEvents.resize( nEventCount );
 
-            const OUString* pNames = aEventNames.getConstArray();
-            ScriptEventDescriptor* pDescs = _out_rEvents.getArray();
-
-            for( sal_Int32 i = 0 ; i < nEventCount ; ++i, ++pNames, ++pDescs )
-                OSL_VERIFY( xEvents->getByName( *pNames ) >>= *pDescs );
+            for( sal_Int32 i = 0; i < nEventCount; ++i )
+                OSL_VERIFY( xEvents->getByName( aEventNames[i] ) >>= _out_rEvents[i] );
         }
         catch( const Exception& )
         {
@@ -1061,7 +1027,7 @@ namespace pcr
 
     namespace
     {
-        static bool lcl_endsWith( const OUString& _rText, const OUString& _rCheck )
+        bool lcl_endsWith( const OUString& _rText, const OUString& _rCheck )
         {
             sal_Int32 nTextLen = _rText.getLength();
             sal_Int32 nCheckLen = _rCheck.getLength();
@@ -1083,13 +1049,14 @@ namespace pcr
             sal_Int32 nObjectIndex = impl_getComponentIndexInParent_throw();
             Reference< XChild > xChild( m_xComponent, UNO_QUERY_THROW );
             Reference< XEventAttacherManager > xEventManager( xChild->getParent(), UNO_QUERY_THROW );
-            Sequence< ScriptEventDescriptor > aEvents( xEventManager->getScriptEvents( nObjectIndex ) );
+            std::vector< ScriptEventDescriptor > aEvents;
+            comphelper::sequenceToContainer( aEvents, xEventManager->getScriptEvents( nObjectIndex ) );
 
             // is there already a registered script for this event?
-            ScriptEventDescriptor* pEvent = aEvents.getArray();
-            sal_Int32 eventCount = aEvents.getLength(), event = 0;
-            for ( event = 0; event < eventCount; ++event, ++pEvent )
+            sal_Int32 eventCount = aEvents.size(), event = 0;
+            for ( event = 0; event < eventCount; ++event )
             {
+                ScriptEventDescriptor* pEvent = &aEvents[event];
                 if  (   ( pEvent->EventMethod == _rScriptEvent.EventMethod )
                     &&  ( lcl_endsWith( _rScriptEvent.ListenerType, pEvent->ListenerType ) )
                           // (strange enough, the events we get from getScriptEvents are not fully qualified)
@@ -1104,9 +1071,8 @@ namespace pcr
                     }
                     else
                     {
-                        // set to empty -> remove from sequence
-                        ::std::copy( pEvent + 1, aEvents.getArray() + eventCount, pEvent );
-                        aEvents.realloc( eventCount - 1 );
+                        // set to empty -> remove from vector
+                        aEvents.erase(aEvents.begin() + event );
                         --eventCount;
                     }
                     break;
@@ -1115,12 +1081,11 @@ namespace pcr
             if ( ( event >= eventCount ) && !bResetScript )
             {
                 // no, did not find it -> append
-                aEvents.realloc( eventCount + 1 );
-                aEvents[ eventCount ] = _rScriptEvent;
+                aEvents.push_back( _rScriptEvent );
             }
 
             xEventManager->revokeScriptEvents( nObjectIndex );
-            xEventManager->registerScriptEvents( nObjectIndex, aEvents );
+            xEventManager->registerScriptEvents( nObjectIndex, comphelper::containerToSequence(aEvents) );
 
             PropertyHandlerHelper::setContextDocumentModified( m_xContext );
         }
@@ -1142,7 +1107,7 @@ namespace pcr
 
             OUStringBuffer aCompleteName;
             aCompleteName.append( _rScriptEvent.ListenerType );
-            aCompleteName.appendAscii( "::" );
+            aCompleteName.append( "::" );
             aCompleteName.append( _rScriptEvent.EventMethod );
             OUString sCompleteName( aCompleteName.makeStringAndClear() );
 
@@ -1172,7 +1137,7 @@ namespace pcr
     bool EventHandler::impl_filterMethod_nothrow( const EventDescription& _rEvent ) const
     {
         // some (control-triggered) events do not make sense for certain grid control columns. However,
-        // our mechnism to retrieve control-triggered events does not know about this, so we do some
+        // our mechanism to retrieve control-triggered events does not know about this, so we do some
         // late filtering here.
         switch ( m_nGridColumnType )
         {
