@@ -19,10 +19,10 @@
 
 #include <sfx2/sfxsids.hrc>
 #include "fontdialog.hxx"
-#include "formresid.hrc"
+#include <strings.hrc>
 #include "modulepcr.hxx"
-#include "formlocalid.hrc"
 #include <vcl/svapp.hxx>
+#include <vcl/unohelp.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <comphelper/types.hxx>
 #include <comphelper/extract.hxx>
@@ -55,32 +55,34 @@
 #include <svx/svxdlg.hxx>
 #include <svx/dialogs.hrc>
 #include <svx/flagsdef.hxx>
-//............................................................................
+#include <vcl/settings.hxx>
+
+
 namespace pcr
 {
-//............................................................................
+
 
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::beans;
 
-    //========================================================================
+
     //= OFontPropertyExtractor
-    //========================================================================
+
     class OFontPropertyExtractor
     {
     protected:
-        ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet >
+        css::uno::Reference< css::beans::XPropertySet >
                     m_xPropValueAccess;
-        ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertyState >
+        css::uno::Reference< css::beans::XPropertyState >
                     m_xPropStateAccess;
 
     public:
-        OFontPropertyExtractor( const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet >&
+        explicit OFontPropertyExtractor( const css::uno::Reference< css::beans::XPropertySet >&
             _rxProps );
 
     public:
-        sal_Bool        getCheckFontProperty(const OUString& _rPropName, ::com::sun::star::uno::Any& _rValue);
-        OUString getStringFontProperty(const OUString& _rPropName, const OUString& _rDefault);
+        bool            getCheckFontProperty(const OUString& _rPropName, css::uno::Any& _rValue);
+        OUString        getStringFontProperty(const OUString& _rPropName, const OUString& _rDefault);
         sal_Int16       getInt16FontProperty(const OUString& _rPropName, const sal_Int16 _nDefault);
         sal_Int32       getInt32FontProperty(const OUString& _rPropName, const sal_Int32 _nDefault);
         float           getFloatFontProperty(const OUString& _rPropName, const float _nDefault);
@@ -89,10 +91,10 @@ namespace pcr
                             const OUString& _rPropName,
                             sal_uInt16 _nItemId,
                             SfxItemSet& _rSet,
-                            sal_Bool _bForceInvalidation = sal_False);
+                            bool _bForceInvalidation = false);
     };
 
-    //------------------------------------------------------------------------
+
     OFontPropertyExtractor::OFontPropertyExtractor(const Reference< XPropertySet >& _rxProps)
         :m_xPropValueAccess(_rxProps)
         ,m_xPropStateAccess(_rxProps, UNO_QUERY)
@@ -100,17 +102,17 @@ namespace pcr
         OSL_ENSURE(m_xPropValueAccess.is(), "OFontPropertyExtractor::OFontPropertyExtractor: invalid property set!");
     }
 
-    //------------------------------------------------------------------------
-    sal_Bool OFontPropertyExtractor::getCheckFontProperty(const OUString& _rPropName, Any& _rValue)
+
+    bool OFontPropertyExtractor::getCheckFontProperty(const OUString& _rPropName, Any& _rValue)
     {
         _rValue = m_xPropValueAccess->getPropertyValue(_rPropName);
         if (m_xPropStateAccess.is())
             return PropertyState_DEFAULT_VALUE == m_xPropStateAccess->getPropertyState(_rPropName);
 
-        return sal_False;
+        return false;
     }
 
-    //------------------------------------------------------------------------
+
     OUString OFontPropertyExtractor::getStringFontProperty(const OUString& _rPropName, const OUString& _rDefault)
     {
         Any aValue;
@@ -120,7 +122,7 @@ namespace pcr
         return ::comphelper::getString(aValue);
     }
 
-    //------------------------------------------------------------------------
+
     sal_Int16 OFontPropertyExtractor::getInt16FontProperty(const OUString& _rPropName, const sal_Int16 _nDefault)
     {
         Any aValue;
@@ -132,7 +134,7 @@ namespace pcr
         return (sal_Int16)nValue;
     }
 
-    //------------------------------------------------------------------------
+
     sal_Int32 OFontPropertyExtractor::getInt32FontProperty(const OUString& _rPropName, const sal_Int32 _nDefault)
     {
         Any aValue;
@@ -144,7 +146,7 @@ namespace pcr
         return nValue;
     }
 
-    //------------------------------------------------------------------------
+
     float OFontPropertyExtractor::getFloatFontProperty(const OUString& _rPropName, const float _nDefault)
     {
         Any aValue;
@@ -154,8 +156,8 @@ namespace pcr
         return ::comphelper::getFloat(aValue);
     }
 
-    //------------------------------------------------------------------------
-    void OFontPropertyExtractor::invalidateItem(const OUString& _rPropName, sal_uInt16 _nItemId, SfxItemSet& _rSet, sal_Bool _bForceInvalidation)
+
+    void OFontPropertyExtractor::invalidateItem(const OUString& _rPropName, sal_uInt16 _nItemId, SfxItemSet& _rSet, bool _bForceInvalidation)
     {
         if  (   _bForceInvalidation
             ||  (   m_xPropStateAccess.is()
@@ -165,26 +167,27 @@ namespace pcr
             _rSet.InvalidateItem(_nItemId);
     }
 
-    //========================================================================
+
     //= ControlCharacterDialog
-    //========================================================================
-    //------------------------------------------------------------------------
-    ControlCharacterDialog::ControlCharacterDialog(Window* _pParent, const SfxItemSet& _rCoreSet)
-        :SfxTabDialog(_pParent, PcrRes(RID_TABDLG_FONTDIALOG), &_rCoreSet)
+
+
+    ControlCharacterDialog::ControlCharacterDialog(vcl::Window* _pParent, const SfxItemSet& _rCoreSet)
+        : SfxTabDialog(_pParent, "ControlFontDialog",
+            "modules/spropctrlr/ui/controlfontdialog.ui", &_rCoreSet)
+        , m_nCharsId(0)
     {
-        FreeResource();
         SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-        DBG_ASSERT(pFact, "CreateFactory fail!");
-        AddTabPage(TABPAGE_CHARACTERS, pFact->GetTabPageCreatorFunc(RID_SVXPAGE_CHAR_NAME), 0 );
-        AddTabPage(TABPAGE_CHARACTERS_EXT, pFact->GetTabPageCreatorFunc(RID_SVXPAGE_CHAR_EFFECTS), 0 );
+        assert(pFact); //CreateFactory fail!
+        m_nCharsId = AddTabPage("font", pFact->GetTabPageCreatorFunc(RID_SVXPAGE_CHAR_NAME), nullptr );
+        AddTabPage("fonteffects", pFact->GetTabPageCreatorFunc(RID_SVXPAGE_CHAR_EFFECTS), nullptr );
     }
 
-    //------------------------------------------------------------------------
+
     ControlCharacterDialog::~ControlCharacterDialog()
     {
     }
 
-    //------------------------------------------------------------------------
+
     void ControlCharacterDialog::translatePropertiesToItems(const Reference< XPropertySet >& _rxModel, SfxItemSet* _pSet)
     {
         OSL_ENSURE(_pSet && _rxModel.is(), "ControlCharacterDialog::translatePropertiesToItems: invalid arguments!");
@@ -196,8 +199,8 @@ namespace pcr
             OFontPropertyExtractor aPropExtractor(_rxModel);
 
             // some items, which may be in default state, have to be filled with non-void information
-            Font aDefaultVCLFont = Application::GetDefaultDevice()->GetSettings().GetStyleSettings().GetAppFont();
-            ::com::sun::star::awt::FontDescriptor aDefaultFont = VCLUnoHelper::CreateFontDescriptor(aDefaultVCLFont);
+            vcl::Font aDefaultVCLFont = Application::GetDefaultDevice()->GetSettings().GetStyleSettings().GetAppFont();
+            css::awt::FontDescriptor aDefaultFont = VCLUnoHelper::CreateFontDescriptor(aDefaultVCLFont);
 
             // get the current properties
             OUString aFontName       = aPropExtractor.getStringFontProperty(PROPERTY_FONT_NAME, aDefaultFont.Name);
@@ -206,27 +209,27 @@ namespace pcr
             sal_Int16   nFontCharset        = aPropExtractor.getInt16FontProperty(PROPERTY_FONT_CHARSET, aDefaultFont.CharSet);
             float   nFontHeight             = aPropExtractor.getFloatFontProperty(PROPERTY_FONT_HEIGHT, (float)aDefaultFont.Height);
             float   nFontWeight             = aPropExtractor.getFloatFontProperty(PROPERTY_FONT_WEIGHT, aDefaultFont.Weight);
-            sal_Int16 nFontSlant            = aPropExtractor.getInt16FontProperty(PROPERTY_FONT_SLANT, (sal_Int16)aDefaultFont.Slant);
-            sal_Int16 nFontUnderline        = aPropExtractor.getInt16FontProperty(PROPERTY_FONT_UNDERLINE, aDefaultFont.Underline);
+            css::awt::FontSlant nFontSlant  = static_cast<css::awt::FontSlant>(aPropExtractor.getInt16FontProperty(PROPERTY_FONT_SLANT, (sal_Int16)aDefaultFont.Slant));
+            sal_Int16 nFontLineStyle        = aPropExtractor.getInt16FontProperty(PROPERTY_FONT_UNDERLINE, aDefaultFont.Underline);
             sal_Int16 nFontStrikeout        = aPropExtractor.getInt16FontProperty(PROPERTY_FONT_STRIKEOUT, aDefaultFont.Strikeout);
 
             sal_Int32 nTextLineColor        = aPropExtractor.getInt32FontProperty(PROPERTY_TEXTLINECOLOR, COL_AUTO);
             sal_Int16 nFontRelief           = aPropExtractor.getInt16FontProperty(PROPERTY_FONT_RELIEF, (sal_Int16)aDefaultVCLFont.GetRelief());
-            sal_Int16 nFontEmphasisMark     = aPropExtractor.getInt16FontProperty(PROPERTY_FONT_EMPHASIS_MARK, aDefaultVCLFont.GetEmphasisMark());
+            sal_Int16 nFontEmphasisMark     = aPropExtractor.getInt16FontProperty(PROPERTY_FONT_EMPHASIS_MARK, (sal_uInt16)aDefaultVCLFont.GetEmphasisMark());
 
             Any aValue;
-            sal_Bool bWordLineMode          = aPropExtractor.getCheckFontProperty(PROPERTY_WORDLINEMODE, aValue) ? aDefaultFont.WordLineMode : ::cppu::any2bool(aValue);
+            bool bWordLineMode          = aPropExtractor.getCheckFontProperty(PROPERTY_WORDLINEMODE, aValue) ? aDefaultFont.WordLineMode : ::cppu::any2bool(aValue);
             sal_Int32 nColor32              = aPropExtractor.getInt32FontProperty(PROPERTY_TEXTCOLOR, 0);
 
             // build SfxItems with the values
             SvxFontItem aFontItem((FontFamily)nFontFamily, aFontName, aFontStyleName, PITCH_DONTKNOW, nFontCharset, CFID_FONT);
 
-            nFontHeight = (float)OutputDevice::LogicToLogic(Size(0, (sal_Int32)nFontHeight), MAP_POINT, MAP_TWIP).Height();
+            nFontHeight = (float)OutputDevice::LogicToLogic(Size(0, (sal_Int32)nFontHeight), MapMode(MapUnit::MapPoint), MapMode(MapUnit::MapTwip)).Height();
             SvxFontHeightItem aSvxFontHeightItem((sal_uInt32)nFontHeight,100,CFID_HEIGHT);
 
-            FontWeight      eWeight=VCLUnoHelper::ConvertFontWeight(nFontWeight);
-            FontItalic      eItalic=(FontItalic)nFontSlant;
-            FontUnderline   eUnderline=(FontUnderline)nFontUnderline;
+            FontWeight      eWeight=vcl::unohelper::ConvertFontWeight(nFontWeight);
+            FontItalic      eItalic=vcl::unohelper::ConvertFontSlant(nFontSlant);
+            FontLineStyle    eUnderline=(FontLineStyle)nFontLineStyle;
             FontStrikeout   eStrikeout=(FontStrikeout)nFontStrikeout;
 
             SvxWeightItem       aWeightItem(eWeight,CFID_WEIGHT);
@@ -245,24 +248,24 @@ namespace pcr
             SvxCharReliefItem aFontReliefItem((FontRelief)nFontRelief, CFID_RELIEF);
             SvxEmphasisMarkItem aEmphasisMarkitem((FontEmphasisMark)nFontEmphasisMark, CFID_EMPHASIS);
 
-            _pSet->Put(aFontItem, CFID_FONT);
-            _pSet->Put(aSvxFontHeightItem,CFID_HEIGHT);
-            _pSet->Put(aWeightItem, CFID_WEIGHT);
-            _pSet->Put(aPostureItem, CFID_POSTURE);
-            _pSet->Put(aLanguageItem, CFID_LANGUAGE);
-            _pSet->Put(aUnderlineItem,CFID_UNDERLINE);
-            _pSet->Put(aCrossedOutItem,CFID_STRIKEOUT);
-            _pSet->Put(aWordLineModeItem, CFID_WORDLINEMODE);
-            _pSet->Put(aSvxColorItem, CFID_CHARCOLOR);
-            _pSet->Put(aFontReliefItem, CFID_RELIEF);
-            _pSet->Put(aEmphasisMarkitem, CFID_EMPHASIS);
+            _pSet->Put(aFontItem);
+            _pSet->Put(aSvxFontHeightItem);
+            _pSet->Put(aWeightItem);
+            _pSet->Put(aPostureItem);
+            _pSet->Put(aLanguageItem);
+            _pSet->Put(aUnderlineItem);
+            _pSet->Put(aCrossedOutItem);
+            _pSet->Put(aWordLineModeItem);
+            _pSet->Put(aSvxColorItem);
+            _pSet->Put(aFontReliefItem);
+            _pSet->Put(aEmphasisMarkitem);
 
             aPropExtractor.invalidateItem(PROPERTY_FONT_NAME, CFID_FONT, *_pSet);
             aPropExtractor.invalidateItem(PROPERTY_FONT_HEIGHT, CFID_HEIGHT, *_pSet);
-            aPropExtractor.invalidateItem(PROPERTY_FONT_WEIGHT, CFID_WEIGHT, *_pSet, ::com::sun::star::awt::FontWeight::DONTKNOW == nFontWeight);
-            aPropExtractor.invalidateItem(PROPERTY_FONT_SLANT, CFID_POSTURE, *_pSet, ::com::sun::star::awt::FontSlant_DONTKNOW == nFontSlant);
-            aPropExtractor.invalidateItem(PROPERTY_FONT_UNDERLINE, CFID_UNDERLINE, *_pSet, ::com::sun::star::awt::FontUnderline::DONTKNOW == nFontUnderline);
-            aPropExtractor.invalidateItem(PROPERTY_FONT_STRIKEOUT, CFID_STRIKEOUT, *_pSet, ::com::sun::star::awt::FontStrikeout::DONTKNOW == nFontStrikeout);
+            aPropExtractor.invalidateItem(PROPERTY_FONT_WEIGHT, CFID_WEIGHT, *_pSet, css::awt::FontWeight::DONTKNOW == nFontWeight);
+            aPropExtractor.invalidateItem(PROPERTY_FONT_SLANT, CFID_POSTURE, *_pSet, css::awt::FontSlant_DONTKNOW == nFontSlant);
+            aPropExtractor.invalidateItem(PROPERTY_FONT_UNDERLINE, CFID_UNDERLINE, *_pSet, css::awt::FontUnderline::DONTKNOW == nFontLineStyle);
+            aPropExtractor.invalidateItem(PROPERTY_FONT_STRIKEOUT, CFID_STRIKEOUT, *_pSet, css::awt::FontStrikeout::DONTKNOW == nFontStrikeout);
             aPropExtractor.invalidateItem(PROPERTY_WORDLINEMODE, CFID_WORDLINEMODE, *_pSet);
             aPropExtractor.invalidateItem(PROPERTY_TEXTCOLOR, CFID_CHARCOLOR, *_pSet);
             aPropExtractor.invalidateItem(PROPERTY_FONT_RELIEF, CFID_RELIEF, *_pSet);
@@ -285,83 +288,82 @@ namespace pcr
 
     }
 
-    //------------------------------------------------------------------------
+
     namespace
     {
-        void lcl_pushBackPropertyValue( Sequence< NamedValue >& _out_properties, const OUString& _name, const Any& _value )
+        void lcl_pushBackPropertyValue( std::vector< NamedValue >& _out_properties, const OUString& _name, const Any& _value )
         {
-            _out_properties.realloc( _out_properties.getLength() + 1 );
-            _out_properties[ _out_properties.getLength() - 1 ] = NamedValue( _name, _value );
+            _out_properties.push_back( NamedValue( _name, _value ) );
         }
     }
 
-    //------------------------------------------------------------------------
-    void ControlCharacterDialog::translateItemsToProperties( const SfxItemSet& _rSet, Sequence< NamedValue >& _out_properties )
+
+    void ControlCharacterDialog::translateItemsToProperties( const SfxItemSet& _rSet, std::vector< NamedValue >& _out_properties )
     {
-        _out_properties.realloc( 0 );
+        _out_properties.clear();
 
         try
         {
-            // --------------------------
+
             // font name
             SfxItemState eState = _rSet.GetItemState(CFID_FONT);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxFontItem& rFontItem =
                     static_cast<const SvxFontItem&>(_rSet.Get(CFID_FONT));
 
-                lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_NAME     , makeAny(OUString(rFontItem.GetFamilyName())));
-                lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_STYLENAME, makeAny(OUString(rFontItem.GetStyleName())));
+                lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_NAME     , makeAny(rFontItem.GetFamilyName()));
+                lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_STYLENAME, makeAny(rFontItem.GetStyleName()));
                 lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_FAMILY   , makeAny((sal_Int16)rFontItem.GetFamily()));
                 lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_CHARSET  , makeAny((sal_Int16)rFontItem.GetCharSet()));
             }
 
-            // --------------------------
+
             // font height
             eState = _rSet.GetItemState(CFID_HEIGHT);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxFontHeightItem& rSvxFontHeightItem =
                     static_cast<const SvxFontHeightItem&>(_rSet.Get(CFID_HEIGHT));
 
-                float nHeight = (float)OutputDevice::LogicToLogic(Size(0, rSvxFontHeightItem.GetHeight()), MAP_TWIP, MAP_POINT).Height();
+                float nHeight = (float)OutputDevice::LogicToLogic(Size(0, rSvxFontHeightItem.GetHeight()), MapMode(MapUnit::MapTwip), MapMode(MapUnit::MapPoint)).Height();
                 lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_HEIGHT,makeAny(nHeight));
 
             }
 
-            // --------------------------
+
             // font weight
             eState = _rSet.GetItemState(CFID_WEIGHT);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxWeightItem& rWeightItem =
                     static_cast<const SvxWeightItem&>(_rSet.Get(CFID_WEIGHT));
 
-                float nWeight = VCLUnoHelper::ConvertFontWeight( rWeightItem.GetWeight());
+                float nWeight = vcl::unohelper::ConvertFontWeight(rWeightItem.GetWeight());
                 lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_WEIGHT,makeAny(nWeight));
             }
 
-            // --------------------------
+
             // font slant
             eState = _rSet.GetItemState(CFID_POSTURE);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxPostureItem& rPostureItem =
                     static_cast<const SvxPostureItem&>(_rSet.Get(CFID_POSTURE));
 
-                ::com::sun::star::awt::FontSlant eSlant = (::com::sun::star::awt::FontSlant)rPostureItem.GetPosture();
+                css::awt::FontSlant eSlant = vcl::unohelper::ConvertFontSlant(rPostureItem.GetPosture());
                 lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_SLANT, makeAny((sal_Int16)eSlant));
             }
 
-            // --------------------------
+
             // font underline
             eState = _rSet.GetItemState(CFID_UNDERLINE);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxUnderlineItem& rUnderlineItem =
                     static_cast<const SvxUnderlineItem&>(_rSet.Get(CFID_UNDERLINE));
@@ -379,11 +381,11 @@ namespace pcr
                 lcl_pushBackPropertyValue( _out_properties, PROPERTY_TEXTLINECOLOR, aUnoColor );
             }
 
-            // --------------------------
+
             // font strikeout
             eState = _rSet.GetItemState(CFID_STRIKEOUT);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxCrossedOutItem& rCrossedOutItem =
                     static_cast<const SvxCrossedOutItem&>(_rSet.Get(CFID_STRIKEOUT));
@@ -393,24 +395,22 @@ namespace pcr
             }
 
 
-            // --------------------------
             // font wordline mode
             eState = _rSet.GetItemState(CFID_WORDLINEMODE);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxWordLineModeItem& rWordLineModeItem =
                     static_cast<const SvxWordLineModeItem&>(_rSet.Get(CFID_WORDLINEMODE));
 
-                lcl_pushBackPropertyValue( _out_properties, PROPERTY_WORDLINEMODE, ::cppu::bool2any(rWordLineModeItem.GetValue()));
+                lcl_pushBackPropertyValue( _out_properties, PROPERTY_WORDLINEMODE, css::uno::makeAny(rWordLineModeItem.GetValue()));
             }
 
 
-            // --------------------------
             // text color
             eState = _rSet.GetItemState(CFID_CHARCOLOR);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxColorItem& rColorItem =
                     static_cast<const SvxColorItem&>(_rSet.Get(CFID_CHARCOLOR));
@@ -424,11 +424,11 @@ namespace pcr
                 lcl_pushBackPropertyValue( _out_properties, PROPERTY_TEXTCOLOR, aUnoColor );
             }
 
-            // --------------------------
+
             // font relief
             eState = _rSet.GetItemState(CFID_RELIEF);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxCharReliefItem& rReliefItem =
                     static_cast<const SvxCharReliefItem&>(_rSet.Get(CFID_RELIEF));
@@ -436,11 +436,11 @@ namespace pcr
                 lcl_pushBackPropertyValue( _out_properties, PROPERTY_FONT_RELIEF, makeAny((sal_Int16)rReliefItem.GetValue()) );
             }
 
-            // --------------------------
+
             // font emphasis mark
             eState = _rSet.GetItemState(CFID_EMPHASIS);
 
-            if ( eState == SFX_ITEM_SET )
+            if ( eState == SfxItemState::SET )
             {
                 const SvxEmphasisMarkItem& rEmphMarkItem =
                     static_cast<const SvxEmphasisMarkItem&>(_rSet.Get(CFID_EMPHASIS));
@@ -454,21 +454,19 @@ namespace pcr
         }
     }
 
-    //------------------------------------------------------------------------
+
     void ControlCharacterDialog::translateItemsToProperties( const SfxItemSet& _rSet, const Reference< XPropertySet >& _rxModel)
     {
         OSL_ENSURE( _rxModel.is(), "ControlCharacterDialog::translateItemsToProperties: invalid arguments!" );
         if ( !_rxModel.is())
             return;
 
-        Sequence< NamedValue > aPropertyValues;
+        std::vector< NamedValue > aPropertyValues;
         translateItemsToProperties( _rSet, aPropertyValues );
         try
         {
-            const NamedValue* propertyValue = aPropertyValues.getConstArray();
-            const NamedValue* propertyValueEnd = propertyValue + aPropertyValues.getLength();
-            for ( ; propertyValue != propertyValueEnd; ++propertyValue )
-                _rxModel->setPropertyValue( propertyValue->Name, propertyValue->Value );
+            for ( const NamedValue& rNV : aPropertyValues )
+                _rxModel->setPropertyValue( rNV.Name, rNV.Value );
         }
         catch( const Exception& )
         {
@@ -476,22 +474,22 @@ namespace pcr
         }
     }
 
-    //------------------------------------------------------------------------
-    SfxItemSet* ControlCharacterDialog::createItemSet(SfxItemSet*& _rpSet, SfxItemPool*& _rpPool, SfxPoolItem**& _rppDefaults)
+
+    SfxItemSet* ControlCharacterDialog::createItemSet(SfxItemSet*& _rpSet, SfxItemPool*& _rpPool, std::vector<SfxPoolItem*>*& _rpDefaults)
     {
         // just to be sure ....
-        _rpSet = NULL;
-        _rpPool = NULL;
-        _rppDefaults = NULL;
+        _rpSet = nullptr;
+        _rpPool = nullptr;
+        _rpDefaults = nullptr;
 
         // create and initialize the defaults
-        _rppDefaults = new SfxPoolItem*[CFID_LAST_ITEM_ID - CFID_FIRST_ITEM_ID + 1];
+        _rpDefaults = new std::vector<SfxPoolItem*>(CFID_LAST_ITEM_ID - CFID_FIRST_ITEM_ID + 1);
 
-        Font aDefaultVCLFont = Application::GetDefaultDevice()->GetSettings().GetStyleSettings().GetAppFont();
+        vcl::Font aDefaultVCLFont = Application::GetDefaultDevice()->GetSettings().GetStyleSettings().GetAppFont();
 
-        SfxPoolItem** pCounter = _rppDefaults;  // want to modify this without affecting the out param _rppDefaults
-        *pCounter++ = new SvxFontItem(aDefaultVCLFont.GetFamily(), aDefaultVCLFont.GetName(), aDefaultVCLFont.GetStyleName(), aDefaultVCLFont.GetPitch(), aDefaultVCLFont.GetCharSet(), CFID_FONT);
-        *pCounter++ = new SvxFontHeightItem(aDefaultVCLFont.GetHeight(), 100, CFID_HEIGHT);
+        SfxPoolItem** pCounter = _rpDefaults->data();  // want to modify this without affecting the out param _rppDefaults
+        *pCounter++ = new SvxFontItem(aDefaultVCLFont.GetFamilyType(), aDefaultVCLFont.GetFamilyName(), aDefaultVCLFont.GetStyleName(), aDefaultVCLFont.GetPitch(), aDefaultVCLFont.GetCharSet(), CFID_FONT);
+        *pCounter++ = new SvxFontHeightItem(aDefaultVCLFont.GetFontHeight(), 100, CFID_HEIGHT);
         *pCounter++ = new SvxWeightItem(aDefaultVCLFont.GetWeight(), CFID_WEIGHT);
         *pCounter++ = new SvxPostureItem(aDefaultVCLFont.GetItalic(), CFID_POSTURE);
         *pCounter++ = new SvxLanguageItem(Application::GetSettings().GetUILanguageTag().getLanguageType(), CFID_LANGUAGE);
@@ -502,96 +500,93 @@ namespace pcr
         *pCounter++ = new SvxCharReliefItem(aDefaultVCLFont.GetRelief(), CFID_RELIEF);
         *pCounter++ = new SvxEmphasisMarkItem(aDefaultVCLFont.GetEmphasisMark(), CFID_EMPHASIS);
 
-        *pCounter++ = new SvxFontItem(aDefaultVCLFont.GetFamily(), aDefaultVCLFont.GetName(), aDefaultVCLFont.GetStyleName(), aDefaultVCLFont.GetPitch(), aDefaultVCLFont.GetCharSet(), CFID_CJK_FONT);
-        *pCounter++ = new SvxFontHeightItem(aDefaultVCLFont.GetHeight(), 100, CFID_CJK_HEIGHT);
+        *pCounter++ = new SvxFontItem(aDefaultVCLFont.GetFamilyType(), aDefaultVCLFont.GetFamilyName(), aDefaultVCLFont.GetStyleName(), aDefaultVCLFont.GetPitch(), aDefaultVCLFont.GetCharSet(), CFID_CJK_FONT);
+        *pCounter++ = new SvxFontHeightItem(aDefaultVCLFont.GetFontHeight(), 100, CFID_CJK_HEIGHT);
         *pCounter++ = new SvxWeightItem(aDefaultVCLFont.GetWeight(), CFID_CJK_WEIGHT);
         *pCounter++ = new SvxPostureItem(aDefaultVCLFont.GetItalic(), CFID_CJK_POSTURE);
         *pCounter++ = new SvxLanguageItem(Application::GetSettings().GetUILanguageTag().getLanguageType(), CFID_CJK_LANGUAGE);
 
-        *pCounter++ = new SvxCaseMapItem(SVX_CASEMAP_NOT_MAPPED, CFID_CASEMAP);
-        *pCounter++ = new SvxContourItem(sal_False, CFID_CONTOUR);
-        *pCounter++ = new SvxShadowedItem(sal_False, CFID_SHADOWED);
+        *pCounter++ = new SvxCaseMapItem(SvxCaseMap::NotMapped, CFID_CASEMAP);
+        *pCounter++ = new SvxContourItem(false, CFID_CONTOUR);
+        *pCounter++ = new SvxShadowedItem(false, CFID_SHADOWED);
 
         *pCounter++ = new SvxFontListItem (new FontList(Application::GetDefaultDevice()), CFID_FONTLIST);
 
         // create the pool
         static SfxItemInfo const aItemInfos[CFID_LAST_ITEM_ID - CFID_FIRST_ITEM_ID + 1] =
         {
-            { SID_ATTR_CHAR_FONT,               0 },
-            { SID_ATTR_CHAR_FONTHEIGHT,         0 },
-            { SID_ATTR_CHAR_WEIGHT,             0 },
-            { SID_ATTR_CHAR_POSTURE,            0 },
-            { SID_ATTR_CHAR_LANGUAGE,           0 },
-            { SID_ATTR_CHAR_UNDERLINE,          0 },
-            { SID_ATTR_CHAR_STRIKEOUT,          0 },
-            { SID_ATTR_CHAR_WORDLINEMODE,       0 },
-            { SID_ATTR_CHAR_COLOR,              0 },
-            { SID_ATTR_CHAR_RELIEF,             0 },
-            { SID_ATTR_CHAR_EMPHASISMARK,       0 },
-            { 0,                                0 },
-            { 0,                                0 },
-            { 0,                                0 },
-            { 0,                                0 },
-            { 0,                                0 },
-            { 0,                                0 },
-            { 0,                                0 },
-            { 0,                                0 },
-            { SID_ATTR_CHAR_FONTLIST,           0 }
+            { SID_ATTR_CHAR_FONT,               false },
+            { SID_ATTR_CHAR_FONTHEIGHT,         false },
+            { SID_ATTR_CHAR_WEIGHT,             false },
+            { SID_ATTR_CHAR_POSTURE,            false },
+            { SID_ATTR_CHAR_LANGUAGE,           false },
+            { SID_ATTR_CHAR_UNDERLINE,          false },
+            { SID_ATTR_CHAR_STRIKEOUT,          false },
+            { SID_ATTR_CHAR_WORDLINEMODE,       false },
+            { SID_ATTR_CHAR_COLOR,              false },
+            { SID_ATTR_CHAR_RELIEF,             false },
+            { SID_ATTR_CHAR_EMPHASISMARK,       false },
+            { 0,                                false },
+            { 0,                                false },
+            { 0,                                false },
+            { 0,                                false },
+            { 0,                                false },
+            { 0,                                false },
+            { 0,                                false },
+            { 0,                                false },
+            { SID_ATTR_CHAR_FONTLIST,           false }
         };
 
-        _rpPool = new SfxItemPool(OUString("PCRControlFontItemPool"), CFID_FIRST_ITEM_ID, CFID_LAST_ITEM_ID,
-            aItemInfos, _rppDefaults);
+        _rpPool = new SfxItemPool("PCRControlFontItemPool", CFID_FIRST_ITEM_ID, CFID_LAST_ITEM_ID,
+            aItemInfos, _rpDefaults);
         _rpPool->FreezeIdRanges();
 
         // and, finally, the set
-        _rpSet = new SfxItemSet(*_rpPool, sal_True);
+        _rpSet = new SfxItemSet(*_rpPool);
 
         return _rpSet;
     }
 
-    //-------------------------------------------------------------------------
-    void ControlCharacterDialog::destroyItemSet(SfxItemSet*& _rpSet, SfxItemPool*& _rpPool, SfxPoolItem**& _rppDefaults)
+
+    void ControlCharacterDialog::destroyItemSet(SfxItemSet*& _rpSet, SfxItemPool*& _rpPool, std::vector<SfxPoolItem*>*& _rpDefaults)
     {
         // from the pool, get and remember the font list (needs to be deleted)
         const SvxFontListItem& rFontListItem = static_cast<const SvxFontListItem&>(_rpPool->GetDefaultItem(CFID_FONTLIST));
         const FontList* pFontList = rFontListItem.GetFontList();
 
-        // _first_ delete the set (refering the pool)
+        // _first_ delete the set (referring the pool)
         if (_rpSet)
         {
             delete _rpSet;
-            _rpSet = NULL;
+            _rpSet = nullptr;
         }
 
         // delete the pool
-        if (_rpPool)
-        {
-            _rpPool->ReleaseDefaults(sal_True);
-                // the "true" means delete the items, too
-            SfxItemPool::Free(_rpPool);
-            _rpPool = NULL;
-        }
+        _rpPool->ReleaseDefaults(true);
+            // the "true" means delete the items, too
+        SfxItemPool::Free(_rpPool);
+        _rpPool = nullptr;
 
         // reset the defaults ptr
-        _rppDefaults = NULL;
+        _rpDefaults = nullptr;
             // no need to explicitly delete the defaults, this has been done by the ReleaseDefaults
 
         delete pFontList;
     }
 
-    //------------------------------------------------------------------------
+
     void ControlCharacterDialog::PageCreated( sal_uInt16 _nId, SfxTabPage& _rPage )
     {
         SfxAllItemSet aSet(*(GetInputSetImpl()->GetPool()));
-        if ( _nId == TABPAGE_CHARACTERS ) {
+        if ( _nId == m_nCharsId ) {
             aSet.Put (SvxFontListItem(static_cast<const SvxFontListItem&>(GetInputSetImpl()->Get(CFID_FONTLIST))));
             aSet.Put (SfxUInt16Item(SID_DISABLE_CTL,DISABLE_HIDE_LANGUAGE));
             _rPage.PageCreated(aSet);
         }
     }
 
-//............................................................................
+
 }   // namespace pcr
-//............................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
