@@ -22,12 +22,10 @@
 #include "pcrservices.hxx"
 #include "formstrings.hxx"
 #include "defaultforminspection.hxx"
-#include "propctrlr.hrc"
+#include <propctrlr.h>
 
 #include <com/sun/star/beans/PropertyAttribute.hpp>
-#include <com/sun/star/form/XGridColumnFactory.hpp>
-#include <com/sun/star/form/XForm.hpp>
-#include <com/sun/star/container/XChild.hpp>
+#include <com/sun/star/util/VetoException.hpp>
 #include <cppuhelper/typeprovider.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 
@@ -62,13 +60,8 @@ namespace pcr
     using ::com::sun::star::util::VetoException;
     using ::com::sun::star::beans::PropertyVetoException;
     using ::com::sun::star::uno::UNO_QUERY;
-    using ::com::sun::star::form::XGridColumnFactory;
-    using ::com::sun::star::form::XForm;
-    using ::com::sun::star::container::XChild;
-    using ::com::sun::star::frame::XFrame;
-    using ::com::sun::star::awt::XWindow;
 
-    namespace PropertyAttribute = ::com::sun::star::beans::PropertyAttribute;
+    namespace PropertyAttribute = css::beans::PropertyAttribute;
 
 
     //= FormController
@@ -100,12 +93,12 @@ namespace pcr
     IMPLEMENT_FORWARD_XINTERFACE2( FormController, OPropertyBrowserController, FormController_PropertyBase1 )
 
 
-    Sequence< Type > SAL_CALL FormController::getTypes(  ) throw(RuntimeException, std::exception)
+    Sequence< Type > SAL_CALL FormController::getTypes(  )
     {
         ::cppu::OTypeCollection aTypes(
-            ::getCppuType( static_cast< Reference< XPropertySet >* >(NULL) ),
-            ::getCppuType( static_cast< Reference< XMultiPropertySet >* >(NULL) ),
-            ::getCppuType( static_cast< Reference< XFastPropertySet >* >(NULL) ),
+            cppu::UnoType<XPropertySet>::get(),
+            cppu::UnoType<XMultiPropertySet>::get(),
+            cppu::UnoType<XFastPropertySet>::get(),
             OPropertyBrowserController::getTypes());
         return aTypes.getTypes();
     }
@@ -114,13 +107,13 @@ namespace pcr
     IMPLEMENT_GET_IMPLEMENTATION_ID( FormController )
 
 
-    OUString SAL_CALL FormController::getImplementationName(  ) throw(RuntimeException, std::exception)
+    OUString SAL_CALL FormController::getImplementationName(  )
     {
         return m_aServiceDescriptor.GetImplementationName();
     }
 
 
-    Sequence< OUString > SAL_CALL FormController::getSupportedServiceNames(  ) throw(RuntimeException, std::exception)
+    Sequence< OUString > SAL_CALL FormController::getSupportedServiceNames(  )
     {
         Sequence< OUString > aSupported( m_aServiceDescriptor.GetSupportedServiceNames() );
         aSupported.realloc( aSupported.getLength() + 1 );
@@ -129,16 +122,15 @@ namespace pcr
     }
 
 
-    OUString FormController::getImplementationName_static(  ) throw(RuntimeException)
+    OUString FormController::getImplementationName_static(  )
     {
         return OUString("org.openoffice.comp.extensions.FormController");
     }
 
 
-    Sequence< OUString > FormController::getSupportedServiceNames_static(  ) throw(RuntimeException)
+    Sequence< OUString > FormController::getSupportedServiceNames_static(  )
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.form.PropertyBrowserController";
+        Sequence< OUString > aSupported { "com.sun.star.form.PropertyBrowserController" };
         return aSupported;
     }
 
@@ -152,7 +144,7 @@ namespace pcr
     }
 
 
-    Reference< XPropertySetInfo > SAL_CALL FormController::getPropertySetInfo(  ) throw(RuntimeException, std::exception)
+    Reference< XPropertySetInfo > SAL_CALL FormController::getPropertySetInfo(  )
     {
         return ::cppu::OPropertySetHelper::createPropertySetInfo(getInfoHelper());
     }
@@ -183,7 +175,7 @@ namespace pcr
     }
 
 
-    sal_Bool SAL_CALL FormController::convertFastPropertyValue( Any & rConvertedValue, Any & rOldValue, sal_Int32 nHandle, const Any& rValue ) throw (IllegalArgumentException)
+    sal_Bool SAL_CALL FormController::convertFastPropertyValue( Any & rConvertedValue, Any & rOldValue, sal_Int32 nHandle, const Any& rValue )
     {
         switch ( nHandle )
         {
@@ -199,11 +191,11 @@ namespace pcr
 
         getFastPropertyValue( rOldValue, nHandle );
         rConvertedValue = rValue;
-        return sal_True;
+        return true;
     }
 
 
-    void SAL_CALL FormController::setFastPropertyValue_NoBroadcast(sal_Int32 _nHandle, const Any& _rValue) throw (Exception, std::exception)
+    void SAL_CALL FormController::setFastPropertyValue_NoBroadcast(sal_Int32 _nHandle, const Any& _rValue)
     {
         switch ( _nHandle )
         {
@@ -239,7 +231,7 @@ namespace pcr
     }
 
 
-    void SAL_CALL FormController::getFastPropertyValue( ::com::sun::star::uno::Any& rValue, sal_Int32 nHandle ) const
+    void SAL_CALL FormController::getFastPropertyValue( css::uno::Any& rValue, sal_Int32 nHandle ) const
     {
         switch ( nHandle )
         {
@@ -257,16 +249,15 @@ namespace pcr
     //= DialogController
 
 
-    OUString DialogController::getImplementationName_static(  ) throw(RuntimeException)
+    OUString DialogController::getImplementationName_static(  )
     {
         return OUString("org.openoffice.comp.extensions.DialogController");
     }
 
 
-    Sequence< OUString > DialogController::getSupportedServiceNames_static(  ) throw(RuntimeException)
+    Sequence< OUString > DialogController::getSupportedServiceNames_static(  )
     {
-        Sequence< OUString > aSupported(1);
-        aSupported[0] = "com.sun.star.awt.PropertyBrowserController";
+        Sequence< OUString > aSupported { "com.sun.star.awt.PropertyBrowserController" };
         return aSupported;
     }
 
