@@ -33,13 +33,14 @@
 #include <com/sun/star/inspection/XNumericControl.hpp>
 #include <com/sun/star/util/MeasureUnit.hpp>
 #include <com/sun/star/text/TextContentAnchorType.hpp>
+#include <com/sun/star/lang/NullPointerException.hpp>
 #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <com/sun/star/sheet/XSpreadsheet.hpp>
 #include <com/sun/star/table/XColumnRowRange.hpp>
-#include <com/sun/star/table/XCellRange.hpp>
 #include <com/sun/star/container/XChild.hpp>
 #include <com/sun/star/form/XGridColumnFactory.hpp>
 
+#include <cppuhelper/implbase.hxx>
 #include <cppuhelper/interfacecontainer.hxx>
 #include <comphelper/componentbase.hxx>
 #include <tools/diagnose_ex.h>
@@ -58,7 +59,6 @@ namespace pcr
     using ::com::sun::star::uno::Any;
     using ::com::sun::star::uno::makeAny;
     using ::com::sun::star::uno::Sequence;
-    using ::com::sun::star::uno::Type;
     using ::com::sun::star::uno::XComponentContext;
     using ::com::sun::star::beans::UnknownPropertyException;
     using ::com::sun::star::beans::Property;
@@ -85,15 +85,11 @@ namespace pcr
     using ::com::sun::star::table::XColumnRowRange;
     using ::com::sun::star::table::XTableColumns;
     using ::com::sun::star::table::XTableRows;
-    using ::com::sun::star::table::XCellRange;
     using ::com::sun::star::container::XIndexAccess;
     using ::com::sun::star::container::XChild;
     using ::com::sun::star::form::XGridColumnFactory;
 
-    namespace MeasureUnit = ::com::sun::star::util::MeasureUnit;
-
-    typedef ::com::sun::star::awt::Point    AwtPoint;
-    typedef ::com::sun::star::awt::Size     AwtSize;
+    namespace MeasureUnit = css::util::MeasureUnit;
 
     #define ANCHOR_TO_SHEET 0
     #define ANCHOR_TO_CELL  1
@@ -104,7 +100,7 @@ namespace pcr
     class BroadcastHelperBase
     {
     protected:
-        BroadcastHelperBase( ::osl::Mutex& _rMutex )
+        explicit BroadcastHelperBase( ::osl::Mutex& _rMutex )
             :maBHelper( _rMutex )
         {
         }
@@ -123,7 +119,7 @@ namespace pcr
         in the XShape implementation, which broadcasts way too generous and unspecified
     */
     typedef ::comphelper::ComponentBase ShapeGeometryChangeNotifier_CBase;
-    typedef ::cppu::WeakImplHelper1 <   ::com::sun::star::beans::XPropertyChangeListener
+    typedef ::cppu::WeakImplHelper <   css::beans::XPropertyChangeListener
                                     >   ShapeGeometryChangeNotifier_IBase;
 
     class ShapeGeometryChangeNotifier   :public BroadcastHelperBase
@@ -161,24 +157,24 @@ namespace pcr
         }
 
         // XInterface
-        virtual void SAL_CALL acquire(  ) throw () SAL_OVERRIDE
+        virtual void SAL_CALL acquire(  ) throw () override
         {
             m_rParent.acquire();
         }
 
-        virtual void SAL_CALL release(  ) throw () SAL_OVERRIDE
+        virtual void SAL_CALL release(  ) throw () override
         {
             m_rParent.release();
         }
 
         // XPropertyChangeListener
-        virtual void SAL_CALL propertyChange( const PropertyChangeEvent& _event ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL propertyChange( const PropertyChangeEvent& _event ) override;
 
         // XEventListener
-        virtual void SAL_CALL disposing( const EventObject& _event ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL disposing( const EventObject& _event ) override;
 
     protected:
-        virtual ~ShapeGeometryChangeNotifier()
+        virtual ~ShapeGeometryChangeNotifier() override
         {
             if ( !getBroadcastHelper().bDisposed )
             {
@@ -196,7 +192,7 @@ namespace pcr
 
     private:
         ::cppu::OWeakObject&                m_rParent;
-        ::cppu::OInterfaceContainerHelper   m_aPropertyChangeListeners;
+        ::comphelper::OInterfaceContainerHelper2   m_aPropertyChangeListeners;
         Reference< XShape >                 m_xShape;
     };
 
@@ -210,34 +206,36 @@ namespace pcr
     class FormGeometryHandler : public FormGeometryHandler_Base
     {
     public:
-        FormGeometryHandler(
+        explicit FormGeometryHandler(
             const Reference< XComponentContext >& _rxContext
         );
 
-        static OUString SAL_CALL getImplementationName_static(  ) throw (RuntimeException);
-        static Sequence< OUString > SAL_CALL getSupportedServiceNames_static(  ) throw (RuntimeException);
+        /// @throws RuntimeException
+        static OUString SAL_CALL getImplementationName_static(  );
+        /// @throws RuntimeException
+        static Sequence< OUString > SAL_CALL getSupportedServiceNames_static(  );
 
     protected:
-        virtual ~FormGeometryHandler();
+        virtual ~FormGeometryHandler() override;
 
     protected:
         // XPropertyHandler overriables
-        virtual Any                         SAL_CALL getPropertyValue( const OUString& _rPropertyName ) throw (UnknownPropertyException, RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void                        SAL_CALL setPropertyValue( const OUString& _rPropertyName, const Any& _rValue ) throw (UnknownPropertyException, RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual LineDescriptor              SAL_CALL describePropertyLine( const OUString& _rPropertyName, const ::com::sun::star::uno::Reference< ::com::sun::star::inspection::XPropertyControlFactory >& _rxControlFactory ) throw (::com::sun::star::beans::UnknownPropertyException, ::com::sun::star::lang::NullPointerException, ::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void                        SAL_CALL addPropertyChangeListener( const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertyChangeListener >& _rxListener ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void                        SAL_CALL removePropertyChangeListener( const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertyChangeListener >& _rxListener ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual Sequence< OUString > SAL_CALL getActuatingProperties( ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void                        SAL_CALL actuatingPropertyChanged( const OUString& _rActuatingPropertyName, const Any& _rNewValue, const Any& _rOldValue, const Reference< XObjectInspectorUI >& _rxInspectorUI, sal_Bool _bFirstTimeInit ) throw (NullPointerException, RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual Any                         SAL_CALL getPropertyValue( const OUString& _rPropertyName ) override;
+        virtual void                        SAL_CALL setPropertyValue( const OUString& _rPropertyName, const Any& _rValue ) override;
+        virtual LineDescriptor              SAL_CALL describePropertyLine( const OUString& _rPropertyName, const css::uno::Reference< css::inspection::XPropertyControlFactory >& _rxControlFactory ) override;
+        virtual void                        SAL_CALL addPropertyChangeListener( const css::uno::Reference< css::beans::XPropertyChangeListener >& _rxListener ) override;
+        virtual void                        SAL_CALL removePropertyChangeListener( const css::uno::Reference< css::beans::XPropertyChangeListener >& _rxListener ) override;
+        virtual Sequence< OUString >        SAL_CALL getActuatingProperties( ) override;
+        virtual void                        SAL_CALL actuatingPropertyChanged( const OUString& _rActuatingPropertyName, const Any& _rNewValue, const Any& _rOldValue, const Reference< XObjectInspectorUI >& _rxInspectorUI, sal_Bool _bFirstTimeInit ) override;
 
         // OComponentHandler overridables
-        virtual void SAL_CALL disposing() SAL_OVERRIDE;
+        virtual void SAL_CALL disposing() override;
 
         // PropertyHandler overridables
-        virtual Sequence< Property >        SAL_CALL doDescribeSupportedProperties() const SAL_OVERRIDE;
+        virtual Sequence< Property >        SAL_CALL doDescribeSupportedProperties() const override;
 
     protected:
-        virtual void onNewComponent() SAL_OVERRIDE;
+        virtual void onNewComponent() override;
 
     private:
         bool    impl_haveTextAnchorType_nothrow() const;
@@ -311,21 +309,20 @@ namespace pcr
     }
 
 
-    OUString SAL_CALL FormGeometryHandler::getImplementationName_static(  ) throw (RuntimeException)
+    OUString SAL_CALL FormGeometryHandler::getImplementationName_static(  )
     {
         return OUString( "com.sun.star.comp.extensions.FormGeometryHandler" );
     }
 
 
-    Sequence< OUString > SAL_CALL FormGeometryHandler::getSupportedServiceNames_static(  ) throw (RuntimeException)
+    Sequence< OUString > SAL_CALL FormGeometryHandler::getSupportedServiceNames_static(  )
     {
-        Sequence< OUString > aSupported( 1 );
-        aSupported[0] = "com.sun.star.form.inspection.FormGeometryHandler";
+        Sequence<OUString> aSupported { "com.sun.star.form.inspection.FormGeometryHandler" };
         return aSupported;
     }
 
 
-    Any SAL_CALL FormGeometryHandler::getPropertyValue( const OUString& _rPropertyName ) throw (UnknownPropertyException, RuntimeException, std::exception)
+    Any SAL_CALL FormGeometryHandler::getPropertyValue( const OUString& _rPropertyName )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         PropertyId nPropId( impl_getPropertyId_throwUnknownProperty( _rPropertyName ) );
@@ -374,7 +371,7 @@ namespace pcr
     }
 
 
-    void SAL_CALL FormGeometryHandler::setPropertyValue( const OUString& _rPropertyName, const Any& _rValue ) throw (UnknownPropertyException, RuntimeException, std::exception)
+    void SAL_CALL FormGeometryHandler::setPropertyValue( const OUString& _rPropertyName, const Any& _rValue )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         PropertyId nPropId( impl_getPropertyId_throwUnknownProperty( _rPropertyName ) );
@@ -392,7 +389,7 @@ namespace pcr
                 sal_Int32 nPosition(0);
                 OSL_VERIFY( _rValue >>= nPosition );
 
-                AwtPoint aPos( m_xAssociatedShape->getPosition() );
+                css::awt::Point aPos( m_xAssociatedShape->getPosition() );
                 if ( nPropId == PROPERTY_ID_POSITIONX )
                     aPos.X = nPosition;
                 else
@@ -407,7 +404,7 @@ namespace pcr
                 sal_Int32 nSize(0);
                 OSL_VERIFY( _rValue >>= nSize );
 
-                AwtSize aSize( m_xAssociatedShape->getSize() );
+                css::awt::Size aSize( m_xAssociatedShape->getSize() );
                 if ( nPropId == PROPERTY_ID_WIDTH )
                     aSize.Width = nSize;
                 else
@@ -442,7 +439,6 @@ namespace pcr
 
     LineDescriptor SAL_CALL FormGeometryHandler::describePropertyLine( const OUString& _rPropertyName,
             const Reference< XPropertyControlFactory >& _rxControlFactory )
-        throw (UnknownPropertyException, NullPointerException, RuntimeException, std::exception)
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         PropertyId nPropId( impl_getPropertyId_throwUnknownProperty( _rPropertyName ) );
@@ -456,12 +452,12 @@ namespace pcr
             case PROPERTY_ID_WIDTH:
             case PROPERTY_ID_HEIGHT:
                 bIsSize = true;
-                // NO break!
+                SAL_FALLTHROUGH;
             case PROPERTY_ID_POSITIONX:
             case PROPERTY_ID_POSITIONY:
             {
-                Optional< double > aZero( sal_True, 0 );
-                Optional< double > aValueNotPresent( sal_False, 0 );
+                Optional< double > aZero( true, 0 );
+                Optional< double > aValueNotPresent( false, 0 );
                 aLineDesc.Control = PropertyHandlerHelper::createNumericControl(
                     _rxControlFactory, 2, bIsSize ? aZero : aValueNotPresent, aValueNotPresent, false );
 
@@ -489,7 +485,7 @@ namespace pcr
     }
 
 
-    void SAL_CALL FormGeometryHandler::addPropertyChangeListener( const Reference< XPropertyChangeListener >& _listener ) throw (RuntimeException, std::exception)
+    void SAL_CALL FormGeometryHandler::addPropertyChangeListener( const Reference< XPropertyChangeListener >& _listener )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         OSL_PRECOND( m_xChangeNotifier.is(), "FormGeometryHandler::addPropertyChangeListener: no notified, implies no shape!?" );
@@ -498,7 +494,7 @@ namespace pcr
     }
 
 
-    void SAL_CALL FormGeometryHandler::removePropertyChangeListener( const Reference< XPropertyChangeListener >& _listener ) throw (RuntimeException, std::exception)
+    void SAL_CALL FormGeometryHandler::removePropertyChangeListener( const Reference< XPropertyChangeListener >& _listener )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
         OSL_PRECOND( m_xChangeNotifier.is(), "FormGeometryHandler::removePropertyChangeListener: no notified, implies no shape!?" );
@@ -507,15 +503,14 @@ namespace pcr
     }
 
 
-    Sequence< OUString > SAL_CALL FormGeometryHandler::getActuatingProperties( ) throw (RuntimeException, std::exception)
+    Sequence< OUString > SAL_CALL FormGeometryHandler::getActuatingProperties( )
     {
-        Sequence< OUString > aInterestedIn(1);
-        aInterestedIn[0] = PROPERTY_TEXT_ANCHOR_TYPE;
+        Sequence< OUString > aInterestedIn { PROPERTY_TEXT_ANCHOR_TYPE };
         return aInterestedIn;
     }
 
 
-    void SAL_CALL FormGeometryHandler::actuatingPropertyChanged( const OUString& _rActuatingPropertyName, const Any& _rNewValue, const Any& /*_rOldValue*/, const Reference< XObjectInspectorUI >& _rxInspectorUI, sal_Bool /*_bFirstTimeInit*/ ) throw (NullPointerException, RuntimeException, std::exception)
+    void SAL_CALL FormGeometryHandler::actuatingPropertyChanged( const OUString& _rActuatingPropertyName, const Any& _rNewValue, const Any& /*_rOldValue*/, const Reference< XObjectInspectorUI >& _rxInspectorUI, sal_Bool /*_bFirstTimeInit*/ )
     {
         if ( !_rxInspectorUI.is() )
             throw NullPointerException();
@@ -547,7 +542,7 @@ namespace pcr
         if ( !m_xAssociatedShape.is() )
             return Sequence< Property >();
 
-        ::std::vector< Property > aProperties;
+        std::vector< Property > aProperties;
 
         addInt32PropertyDescription( aProperties, PROPERTY_POSITIONX );
         addInt32PropertyDescription( aProperties, PROPERTY_POSITIONY );
@@ -615,8 +610,8 @@ namespace pcr
 
     namespace
     {
-        static sal_Int32 lcl_getLowerBoundRowOrColumn( const Reference< XIndexAccess >& _rxRowsOrColumns, const bool _bRows,
-            const AwtPoint& _rRelativePosition )
+        sal_Int32 lcl_getLowerBoundRowOrColumn( const Reference< XIndexAccess >& _rxRowsOrColumns, const bool _bRows,
+            const css::awt::Point& _rRelativePosition )
         {
             sal_Int32 nAccumulated = 0;
 
@@ -664,7 +659,7 @@ namespace pcr
                     "FormGeometryHandler::impl_setSheetAnchorType_nothrow: sheet not found!" );
                 if ( xSheet.is() )
                 {
-                    AwtPoint aPreservePosition( m_xAssociatedShape->getPosition() );
+                    css::awt::Point aPreservePosition( m_xAssociatedShape->getPosition() );
                     m_xShapeProperties->setPropertyValue( PROPERTY_ANCHOR, makeAny( xSheet ) );
                     m_xAssociatedShape->setPosition( aPreservePosition );
                 }
@@ -680,7 +675,7 @@ namespace pcr
                 OSL_ENSURE( xCurrentAnchor.is(), "FormGeometryHandler::impl_setSheetAnchorType_nothrow: only to be called when currently anchored to a sheet!" );
 
                 // get the current position
-                AwtPoint aRelativePosition( m_xAssociatedShape->getPosition() );
+                css::awt::Point aRelativePosition( m_xAssociatedShape->getPosition() );
 
                 Reference< XTableColumns > xCols( xColsRows->getColumns(), UNO_SET_THROW );
                 sal_Int32 nNewAnchorCol = lcl_getLowerBoundRowOrColumn( xCols.get(), false, aRelativePosition );
@@ -723,22 +718,22 @@ namespace pcr
     }
 
 
-    void SAL_CALL ShapeGeometryChangeNotifier::propertyChange( const PropertyChangeEvent& _event ) throw (RuntimeException, std::exception)
+    void SAL_CALL ShapeGeometryChangeNotifier::propertyChange( const PropertyChangeEvent& _event )
     {
         ::comphelper::ComponentMethodGuard aGuard( *this );
 
-        ::std::vector< EventTranslation > aEventTranslations;
+        std::vector< EventTranslation > aEventTranslations;
         aEventTranslations.reserve(2);
 
         if ( _event.PropertyName == "Position" )
         {
-            AwtPoint aPos = m_xShape->getPosition();
+            css::awt::Point aPos = m_xShape->getPosition();
             aEventTranslations.push_back( EventTranslation( PROPERTY_POSITIONX, makeAny( aPos.X ) ) );
             aEventTranslations.push_back( EventTranslation( PROPERTY_POSITIONY, makeAny( aPos.Y ) ) );
         }
         else if ( _event.PropertyName == "Size" )
         {
-            AwtSize aSize = m_xShape->getSize();
+            css::awt::Size aSize = m_xShape->getSize();
             aEventTranslations.push_back( EventTranslation( PROPERTY_WIDTH, makeAny( aSize.Width ) ) );
             aEventTranslations.push_back( EventTranslation( PROPERTY_HEIGHT, makeAny( aSize.Height ) ) );
         }
@@ -755,7 +750,7 @@ namespace pcr
         aTranslatedEvent.Source = m_rParent;
 
         aGuard.clear();
-        for ( ::std::vector< EventTranslation >::const_iterator t = aEventTranslations.begin();
+        for ( std::vector< EventTranslation >::const_iterator t = aEventTranslations.begin();
               t != aEventTranslations.end();
               ++t
             )
@@ -767,7 +762,7 @@ namespace pcr
     }
 
 
-    void SAL_CALL ShapeGeometryChangeNotifier::disposing( const EventObject& /*_event*/ ) throw (RuntimeException, std::exception)
+    void SAL_CALL ShapeGeometryChangeNotifier::disposing( const EventObject& /*_event*/ )
     {
         ::comphelper::ComponentMethodGuard aGuard( *this );
         impl_dispose_nothrow();
