@@ -19,13 +19,13 @@
 
 
 #include "filterfactory.hxx"
-#include "macros.hxx"
 #include "constant.hxx"
 #include "versions.hxx"
 
 #include <com/sun/star/lang/XInitialization.hpp>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/enumhelper.hxx>
+#include <comphelper/sequence.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <officecfg/Setup.hxx>
 #include <officecfg/TypeDetection/UISort.hxx>
@@ -60,33 +60,26 @@ FilterFactory::FilterFactory(const css::uno::Reference< css::uno::XComponentCont
 }
 
 
-
 FilterFactory::~FilterFactory()
 {
 }
 
 
-
 css::uno::Reference< css::uno::XInterface > SAL_CALL FilterFactory::createInstance(const OUString& sFilter)
-    throw(css::uno::Exception       ,
-          css::uno::RuntimeException, std::exception)
 {
     return createInstanceWithArguments(sFilter, css::uno::Sequence< css::uno::Any >());
 }
 
 
-
 css::uno::Reference< css::uno::XInterface > SAL_CALL FilterFactory::createInstanceWithArguments(const OUString&                     sFilter   ,
                                                                                                 const css::uno::Sequence< css::uno::Any >& lArguments)
-    throw(css::uno::Exception       ,
-          css::uno::RuntimeException, std::exception)
 {
     // SAFE ->
     ::osl::ResettableMutexGuard aLock(m_aLock);
 
     OUString sRealFilter = sFilter;
 
-    #ifdef _FILTER_CONFIG_MIGRATION_Q_
+    #ifdef FILTER_CONFIG_MIGRATION_Q_
 
         /* -> TODO - HACK
             check if the given filter name really exist ...
@@ -94,14 +87,13 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL FilterFactory::createInstan
             type name instead of a filter name. For a small migration time
             we must simulate this old feature :-( */
 
-        if (!m_rCache->hasItem(FilterCache::E_FILTER, sFilter) && m_rCache->hasItem(FilterCache::E_TYPE, sFilter))
+        auto & cache = TheFilterCache::get();
+
+        if (!cache.hasItem(FilterCache::E_FILTER, sFilter) && cache.hasItem(FilterCache::E_TYPE, sFilter))
         {
             OSL_FAIL("Who use this deprecated functionality?");
-            _FILTER_CONFIG_LOG_("FilterFactory::createInstanceWithArguments() ... simulate old type search functionality!\n");
 
-            css::uno::Sequence< css::beans::NamedValue > lQuery(1);
-            lQuery[0].Name    = PROPNAME_TYPE;
-            lQuery[0].Value <<= sFilter;
+            css::uno::Sequence< css::beans::NamedValue > lQuery { { PROPNAME_TYPE, css::uno::makeAny(sFilter) } };
 
             css::uno::Reference< css::container::XEnumeration > xSet = createSubSetEnumerationByProperties(lQuery);
             while(xSet->hasMoreElements())
@@ -112,17 +104,17 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL FilterFactory::createInstan
             }
 
             // prevent outside code against NoSuchElementException!
-            // But dont implement such defensive strategy for our new create handling :-)
-            if (!m_rCache->hasItem(FilterCache::E_FILTER, sRealFilter))
+            // But don't implement such defensive strategy for our new create handling :-)
+            if (!cache.hasItem(FilterCache::E_FILTER, sRealFilter))
                 return css::uno::Reference< css::uno::XInterface>();
         }
 
         /* <- HACK */
 
-    #endif // _FILTER_CONFIG_MIGRATION_Q_
+    #endif // FILTER_CONFIG_MIGRATION_Q_
 
     // search filter on cache
-    CacheItem aFilter = m_rCache->getItem(FilterCache::E_FILTER, sRealFilter);
+    CacheItem aFilter = cache.getItem(FilterCache::E_FILTER, sRealFilter);
     OUString sFilterService;
     aFilter[PROPNAME_FILTERSERVICE] >>= sFilterService;
 
@@ -142,13 +134,10 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL FilterFactory::createInstan
         css::uno::Sequence< css::beans::PropertyValue > lConfig;
         aFilter >> lConfig;
 
-        ::comphelper::SequenceAsVector< css::uno::Any > stlArguments(lArguments);
+        ::std::vector< css::uno::Any > stlArguments(comphelper::sequenceToContainer< ::std::vector< css::uno::Any > >(lArguments));
         stlArguments.insert(stlArguments.begin(), css::uno::makeAny(lConfig));
 
-        css::uno::Sequence< css::uno::Any > lInitData;
-        stlArguments >> lInitData;
-
-        xInit->initialize(lInitData);
+        xInit->initialize(comphelper::containerToSequence(stlArguments));
     }
 
     return xFilter;
@@ -156,15 +145,13 @@ css::uno::Reference< css::uno::XInterface > SAL_CALL FilterFactory::createInstan
 }
 
 
-
 css::uno::Sequence< OUString > SAL_CALL FilterFactory::getAvailableServiceNames()
-    throw(css::uno::RuntimeException, std::exception)
 {
     /* Attention: Instead of getElementNames() this method have to return only filter names,
-                  which can be created as UNO Services really. Thats why we search for filters,
-                  which dont have a valid value for the property "FilterService".
+                  which can be created as UNO Services really. That's why we search for filters,
+                  which don't have a valid value for the property "FilterService".
                   Of course we can't check for corrupted service names here. We can check
-                  for empty strings only ...
+                  for empty strings only...
     */
     CacheItem lIProps;
     CacheItem lEProps;
@@ -173,25 +160,23 @@ css::uno::Sequence< OUString > SAL_CALL FilterFactory::getAvailableServiceNames(
     OUStringList lUNOFilters;
     try
     {
-        lUNOFilters = m_rCache->getMatchingItemsByProps(FilterCache::E_FILTER, lIProps, lEProps);
+        lUNOFilters = TheFilterCache::get().getMatchingItemsByProps(FilterCache::E_FILTER, lIProps, lEProps);
     }
     catch(const css::uno::RuntimeException&)
         { throw; }
     catch(const css::uno::Exception&)
         { lUNOFilters.clear(); }
 
-    return lUNOFilters.getAsConstList();
+    return comphelper::containerToSequence(lUNOFilters);
 }
 
 
-
 css::uno::Reference< css::container::XEnumeration > SAL_CALL FilterFactory::createSubSetEnumerationByQuery(const OUString& sQuery)
-    throw (css::uno::RuntimeException, std::exception)
 {
     // reject old deprecated queries ...
-    if (sQuery.matchAsciiL("_filterquery_",13,0))
+    if (sQuery.startsWith("_filterquery_"))
         throw css::uno::RuntimeException(
-                    _FILTER_CONFIG_FROM_ASCII_("Use of deprecated and now unsupported query!"),
+                    "Use of deprecated and now unsupported query!",
                     static_cast< css::container::XContainerQuery* >(this));
 
     // convert "_query_xxx:..." to "getByDocService=xxx:..."
@@ -234,13 +219,12 @@ css::uno::Reference< css::container::XEnumeration > SAL_CALL FilterFactory::crea
     // pack list of item names as an enum list
     // Attention: Do not return empty reference for empty list!
     // The outside check "hasMoreElements()" should be enough, to detect this state :-)
-    css::uno::Sequence< OUString > lSet = lEnumSet.getAsConstList();
+    css::uno::Sequence< OUString > lSet = comphelper::containerToSequence(lEnumSet);
     ::comphelper::OEnumerationByName* pEnum = new ::comphelper::OEnumerationByName(this, lSet);
     return css::uno::Reference< css::container::XEnumeration >(static_cast< css::container::XEnumeration* >(pEnum), css::uno::UNO_QUERY);
 }
 
 
-
 OUStringList FilterFactory::impl_queryMatchByDocumentService(const QueryTokenizer& lTokens) const
 {
     // analyze query
@@ -295,11 +279,11 @@ OUStringList FilterFactory::impl_queryMatchByDocumentService(const QueryTokenize
 
     pIt = lTokens.find(QUERY_PARAM_IFLAGS);
     if (pIt != lTokens.end())
-        nIFlags = OUString(pIt->second).toInt32();
+        nIFlags = pIt->second.toInt32();
 
     pIt = lTokens.find(QUERY_PARAM_EFLAGS);
     if (pIt != lTokens.end())
-        nEFlags = OUString(pIt->second).toInt32();
+        nEFlags = pIt->second.toInt32();
 
     // SAFE -> ----------------------
     ::osl::ResettableMutexGuard aLock(m_aLock);
@@ -325,8 +309,8 @@ OUStringList FilterFactory::impl_queryMatchByDocumentService(const QueryTokenize
             OUString sCheckValue = aFilter.getUnpackedValueOrDefault(PROPNAME_DOCUMENTSERVICE, OUString());
             if (
                 (!sDocumentService.isEmpty()                   ) &&
-                (!sDocumentService.equals(QUERY_CONSTVALUE_ALL)) &&
-                (!sCheckValue.equals(sDocumentService)         )
+                (sDocumentService != QUERY_CONSTVALUE_ALL      ) &&
+                (sCheckValue != sDocumentService         )
             )
             {
                 continue; // ignore filter -> try next one!
@@ -374,7 +358,6 @@ OUStringList FilterFactory::impl_queryMatchByDocumentService(const QueryTokenize
 }
 
 
-
 class stlcomp_removeIfMatchFlags
 {
     private:
@@ -400,7 +383,7 @@ class stlcomp_removeIfMatchFlags
 
                 bool bMatch = false;
                 if (m_bIFlags)
-                    // IFlags are interpeted as ALL_FLAGS_MUST_MATCH !
+                    // IFlags are interpreted as ALL_FLAGS_MUST_MATCH !
                     bMatch = ((nFlags & m_nFlags) == m_nFlags);
                 else
                     // EFlags are interpreted as ATE_LEAST_ONE_FLAG_MUST_MATCH !
@@ -416,7 +399,6 @@ class stlcomp_removeIfMatchFlags
 };
 
 
-
 OUStringList FilterFactory::impl_getSortedFilterList(const QueryTokenizer& lTokens) const
 {
     // analyze the given query parameter
@@ -431,10 +413,10 @@ OUStringList FilterFactory::impl_getSortedFilterList(const QueryTokenizer& lToke
         sModule = pIt1->second;
     pIt1 = lTokens.find(QUERY_PARAM_IFLAGS);
     if (pIt1 != lTokens.end())
-        nIFlags = OUString(pIt1->second).toInt32();
+        nIFlags = pIt1->second.toInt32();
     pIt1 = lTokens.find(QUERY_PARAM_EFLAGS);
     if (pIt1 != lTokens.end())
-        nEFlags = OUString(pIt1->second).toInt32();
+        nEFlags = pIt1->second.toInt32();
 
     // simple search for filters of one specific module.
     OUStringList lFilterList;
@@ -467,7 +449,6 @@ OUStringList FilterFactory::impl_getSortedFilterList(const QueryTokenizer& lToke
 }
 
 
-
 OUStringList FilterFactory::impl_getListOfInstalledModules() const
 {
     // SAFE -> ----------------------
@@ -477,12 +458,11 @@ OUStringList FilterFactory::impl_getListOfInstalledModules() const
     // <- SAFE ----------------------
 
     css::uno::Reference< css::container::XNameAccess > xModuleConfig = officecfg::Setup::Office::Factories::get(xContext);
-    OUStringList lModules(xModuleConfig->getElementNames());
+    OUStringList lModules(comphelper::sequenceToContainer<OUStringList>(xModuleConfig->getElementNames()));
     return lModules;
 }
 
 
-
 OUStringList FilterFactory::impl_getSortedFilterListForModule(const OUString& sModule,
                                                                     sal_Int32        nIFlags,
                                                                     sal_Int32        nEFlags) const
@@ -500,7 +480,7 @@ OUStringList FilterFactory::impl_getSortedFilterListForModule(const OUString& sM
     aLock.clear();
     // <- SAFE ----------------------
 
-    // bring "other" filters in an alphabeticly order
+    // bring "other" filters in an alphabetical order
     // It's needed below.
     ::std::sort(lOtherFilters.begin(), lOtherFilters.end());
 
@@ -537,7 +517,6 @@ OUStringList FilterFactory::impl_getSortedFilterListForModule(const OUString& sM
 }
 
 
-
 OUStringList FilterFactory::impl_readSortedFilterListFromConfig(const OUString& sModule) const
 {
     // SAFE -> ----------------------
@@ -549,7 +528,7 @@ OUStringList FilterFactory::impl_readSortedFilterListFromConfig(const OUString&
     try
     {
         css::uno::Reference< css::container::XNameAccess > xUISortConfig = officecfg::TypeDetection::UISort::ModuleDependendFilterOrder::get(xContext);
-        // dont check the module name here. If it does not exists, an exception is thrown and catched below.
+        // don't check the module name here. If it does not exists, an exception is thrown and caught below.
         // We return an empty list as result then.
         css::uno::Reference< css::container::XNameAccess > xModule;
         xUISortConfig->getByName(sModule) >>= xModule;
@@ -558,7 +537,8 @@ OUStringList FilterFactory::impl_readSortedFilterListFromConfig(const OUString&
             // Note: conversion of the returned Any to OUStringList throws
             // an IllegalArgumentException if the type does not match ...
             // but it resets the OUStringList to a length of 0 if the Any is empty!
-            OUStringList lSortedFilters(xModule->getByName(PROPNAME_SORTEDFILTERLIST));
+            OUStringList lSortedFilters(
+                    comphelper::sequenceToContainer<OUStringList>(xModule->getByName(PROPNAME_SORTEDFILTERLIST).get<css::uno::Sequence<OUString> >()));
             return lSortedFilters;
         }
     }
@@ -571,23 +551,18 @@ OUStringList FilterFactory::impl_readSortedFilterListFromConfig(const OUString&
 }
 
 
-
 OUString FilterFactory::impl_getImplementationName()
 {
     return OUString( "com.sun.star.comp.filter.config.FilterFactory" );
 }
 
 
-
 css::uno::Sequence< OUString > FilterFactory::impl_getSupportedServiceNames()
 {
-    css::uno::Sequence< OUString > lServiceNames(1);
-    lServiceNames[0] = "com.sun.star.document.FilterFactory";
-    return lServiceNames;
+    return { "com.sun.star.document.FilterFactory" };
 }
 
 
-
 css::uno::Reference< css::uno::XInterface > SAL_CALL FilterFactory::impl_createInstance(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR)
 {
     FilterFactory* pNew = new FilterFactory( comphelper::getComponentContext(xSMGR) );
