@@ -19,6 +19,7 @@
 
 
 #include "ccidecom.hxx"
+#include <tools/stream.hxx>
 
 //=============================== Huffman tables ========================
 
@@ -563,25 +564,23 @@ const CCIHuffmanTableEntry CCIUncompTableSave[CCIUncompTableSize]={
 };
 
 
-
-
 CCIDecompressor::CCIDecompressor( sal_uLong nOpts, sal_uInt32 nImageWidth ) :
     bTableBad   ( false ),
     bStatus     ( false ),
-    pByteSwap   ( NULL ),
-    pIStream    ( NULL ),
+    pByteSwap   ( nullptr ),
+    pIStream    ( nullptr ),
     nEOLCount   ( 0 ),
     nWidth      ( nImageWidth ),
     nOptions    ( nOpts ),
     bFirstEOL   ( false ),
     nInputBitsBuf( 0 ),
     nInputBitsBufSize( 0 ),
-    pLastLine   ( NULL ),
+    pLastLine   ( nullptr ),
     nLastLineSize( 0 )
 {
     if ( nOpts & CCI_OPTION_INVERSEBITORDER )
     {
-        pByteSwap = new sal_uInt8[ 256 ];
+        pByteSwap.reset( new sal_uInt8[ 256 ] );
         for ( int i = 0; i < 256; i++ )
         {
             pByteSwap[ i ] = sal::static_int_cast< sal_uInt8 >(
@@ -590,26 +589,15 @@ CCIDecompressor::CCIDecompressor( sal_uLong nOpts, sal_uInt32 nImageWidth ) :
         }
     }
 
-    pWhiteLookUp =new CCILookUpTableEntry[1<<13];
-    pBlackLookUp =new CCILookUpTableEntry[1<<13];
-    p2DModeLookUp=new CCILookUpTableEntry[1<<10];
-    pUncompLookUp=new CCILookUpTableEntry[1<<11];
-
-    MakeLookUp(CCIWhiteTable,CCIWhiteTableSave,pWhiteLookUp,CCIWhiteTableSize,13);
-    MakeLookUp(CCIBlackTable,CCIBlackTableSave,pBlackLookUp,CCIBlackTableSize,13);
-    MakeLookUp(CCI2DModeTable,CCI2DModeTableSave,p2DModeLookUp,CCI2DModeTableSize,10);
-    MakeLookUp(CCIUncompTable,CCIUncompTableSave,pUncompLookUp,CCIUncompTableSize,11);
+    MakeLookUp(CCIWhiteTable,CCIWhiteTableSave,pWhiteLookUp.data(),CCIWhiteTableSize,13);
+    MakeLookUp(CCIBlackTable,CCIBlackTableSave,pBlackLookUp.data(),CCIBlackTableSize,13);
+    MakeLookUp(CCI2DModeTable,CCI2DModeTableSave,p2DModeLookUp.data(),CCI2DModeTableSize,10);
+    MakeLookUp(CCIUncompTable,CCIUncompTableSave,pUncompLookUp.data(),CCIUncompTableSize,11);
 }
 
 
 CCIDecompressor::~CCIDecompressor()
 {
-    delete[] pByteSwap;
-    delete[] pLastLine;
-    delete[] pWhiteLookUp;
-    delete[] pBlackLookUp;
-    delete[] p2DModeLookUp;
-    delete[] pUncompLookUp;
 }
 
 
@@ -625,16 +613,17 @@ void CCIDecompressor::StartDecompression( SvStream & rIStream )
         return;
 }
 
-
-bool CCIDecompressor::DecompressScanline( sal_uInt8 * pTarget, sal_uLong nTargetBits, bool bLastLine )
+DecompressStatus CCIDecompressor::DecompressScanline( sal_uInt8 * pTarget, sal_uLong nTargetBits, bool bLastLine )
 {
-    bool b2D;
+    //Read[1|2]DScanlineData take a sal_uInt16, so its either limit here or expand there
+    if (nTargetBits > SAL_MAX_UINT16)
+        return DecompressStatus(false, true);
 
     if ( nEOLCount >= 5 )   // RTC (Return To Controller)
-        return true;
+        return DecompressStatus(true, true);
 
     if ( !bStatus )
-        return false;
+        return DecompressStatus(false, true);
 
     // If EOL-Codes exist, the EOL-Code also appeared in front of the first line.
     // (and I thought it means 'End of Line'...)
@@ -646,7 +635,7 @@ bool CCIDecompressor::DecompressScanline( sal_uInt8 * pTarget, sal_uLong nTarget
             sal_uInt32 nCurPos = pIStream->Tell();
             sal_uInt16 nOldInputBitsBufSize = nInputBitsBufSize;
             sal_uInt32 nOldInputBitsBuf = nInputBitsBuf;
-            if ( !ReadEOL( 32 ) )
+            if ( !ReadEOL() )
             {
                 nInputBitsBufSize = nOldInputBitsBufSize;
                 nInputBitsBuf = nOldInputBitsBuf;
@@ -657,32 +646,31 @@ bool CCIDecompressor::DecompressScanline( sal_uInt8 * pTarget, sal_uLong nTarget
         }
         else
         {
-            if ( !ReadEOL( nTargetBits ) )
+            if ( !ReadEOL() )
             {
-                return bStatus;
+                return DecompressStatus(bStatus, true);
             }
         }
     }
 
     if ( nEOLCount >= 5 )   // RTC (Return To Controller)
-        return true;
+        return DecompressStatus(true, true);
 
     // should the situation arise, generate a white previous line for 2D:
     if ( nOptions & CCI_OPTION_2D )
     {
-        if ( pLastLine == NULL || nLastLineSize != ( ( nTargetBits + 7 ) >> 3 ) )
+        if ( pLastLine == nullptr || nLastLineSize != ( ( nTargetBits + 7 ) >> 3 ) )
         {
-            if ( pLastLine == NULL )
-                delete[] pLastLine;
             nLastLineSize = ( nTargetBits + 7 ) >> 3;
-            pLastLine = new sal_uInt8[ nLastLineSize ];
-            memset(pLastLine, 0, nLastLineSize);
+            pLastLine.reset( new sal_uInt8[ nLastLineSize ] );
+            memset(pLastLine.get(), 0, nLastLineSize);
         }
     }
     // conditionally align start of line to next byte:
     if ( nOptions & CCI_OPTION_BYTEALIGNROW )
         nInputBitsBufSize &= 0xfff8;
 
+    bool b2D;
     // is it a 2D row?
     if ( nOptions & CCI_OPTION_2D )
     {
@@ -694,16 +682,17 @@ bool CCIDecompressor::DecompressScanline( sal_uInt8 * pTarget, sal_uLong nTarget
     else
         b2D = false;
 
+    bool bUnchanged;
     // read scanline:
     if ( b2D )
-        Read2DScanlineData( pTarget, (sal_uInt16)nTargetBits );
+        bUnchanged = Read2DScanlineData(pTarget, nTargetBits);
     else
-        Read1DScanlineData( pTarget, (sal_uInt16)nTargetBits );
+        bUnchanged = Read1DScanlineData(pTarget, nTargetBits);
 
     // if we're in 2D mode we have to remember the line:
     if ( nOptions & CCI_OPTION_2D && bStatus )
     {
-        memcpy(pLastLine, pTarget, nLastLineSize);
+        memcpy(pLastLine.get(), pTarget, nLastLineSize);
     }
 
     // #i122984#
@@ -715,7 +704,7 @@ bool CCIDecompressor::DecompressScanline( sal_uInt8 * pTarget, sal_uLong nTarget
     if ( pIStream->GetError() )
         bStatus = false;
 
-    return bStatus;
+    return DecompressStatus(bStatus, bUnchanged);
 }
 
 
@@ -760,7 +749,7 @@ void CCIDecompressor::MakeLookUp(const CCIHuffmanTableEntry * pHufTab,
 }
 
 
-bool CCIDecompressor::ReadEOL( sal_uInt32 /*nMaxFillBits*/ )
+bool CCIDecompressor::ReadEOL()
 {
     sal_uInt16  nCode;
     sal_uInt8   nByte;
@@ -770,7 +759,7 @@ bool CCIDecompressor::ReadEOL( sal_uInt32 /*nMaxFillBits*/ )
     // or there exist some nasty export filter who always do align.
     // In addition files were found in which more than the necessary maximum of 7 filling
     // bits were found. Therefore we now generally accept up to 32 nonsense bits in front of the EOL-Code:
-    // And I found a file in which up to ??? nonsense bits are written. Furthemore the byte order is switched in it. (SJ)
+    // And I found a file in which up to ??? nonsense bits are written. Furthermore the byte order is switched in it. (SJ)
 
     sal_uInt32 nMaxPos = pIStream->Tell();
     nMaxPos += nWidth >> 3;
@@ -780,7 +769,7 @@ bool CCIDecompressor::ReadEOL( sal_uInt32 /*nMaxFillBits*/ )
         while ( nInputBitsBufSize < 12 )
         {
             pIStream->ReadUChar( nByte );
-            if ( pIStream->IsEof() )
+            if (!pIStream->good())
                 return false;
             if ( pIStream->Tell() > nMaxPos )
                 return false;
@@ -808,7 +797,7 @@ bool CCIDecompressor::Read2DTag()
 {
     sal_uInt8 nByte;
 
-    // read abit and return sal_True if it's 0, otherwise return sal_False
+    // read a bit and return sal_True if it's 0, otherwise return sal_False
     if (nInputBitsBufSize==0) {
         pIStream->ReadUChar( nByte );
         if ( nOptions & CCI_OPTION_INVERSEBITORDER )
@@ -817,8 +806,7 @@ bool CCIDecompressor::Read2DTag()
         nInputBitsBufSize=8;
     }
     nInputBitsBufSize--;
-    if ( ((nInputBitsBuf>>nInputBitsBufSize)&0x0001) ) return false;
-    else return true;
+    return ((nInputBitsBuf>>nInputBitsBufSize)&0x0001) == 0;
 }
 
 
@@ -835,7 +823,7 @@ sal_uInt8 CCIDecompressor::ReadBlackOrWhite()
         nInputBitsBufSize=8;
     }
     nInputBitsBufSize--;
-    if ( ((nInputBitsBuf>>nInputBitsBufSize)&0x0001) ) return 0xff;
+    if ( (nInputBitsBuf>>nInputBitsBufSize) & 0x0001 ) return 0xff;
     else return 0x00;
 }
 
@@ -890,7 +878,7 @@ sal_uInt16 CCIDecompressor::CountBits(const sal_uInt8 * pData, sal_uInt16 nDataS
                                   sal_uInt16 nBitPos, sal_uInt8 nBlackOrWhite)
 {
     // here the number of bits belonging together is being counted
-    // which all have the color nBlackOrWhite (0xff oder 0x00)
+    // which all have the color nBlackOrWhite (0xff or 0x00)
     // from the position nBitPos on
     sal_uInt16 nPos = nBitPos;
     for (;;)
@@ -921,8 +909,9 @@ sal_uInt16 CCIDecompressor::CountBits(const sal_uInt8 * pData, sal_uInt16 nDataS
     return nPos-nBitPos;
 }
 
-void CCIDecompressor::Read1DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTargetBits)
+bool CCIDecompressor::Read1DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nBitsToRead)
 {
+    sal_uInt16 nTargetBits = nBitsToRead;
     sal_uInt16 nCode,nCodeBits,nDataBits,nTgtFreeByteBits;
     sal_uInt8 nByte;
     sal_uInt8 nBlackOrWhite; // is 0xff for black or 0x00 for white
@@ -937,7 +926,7 @@ void CCIDecompressor::Read1DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTarget
     // loop through codes from the input stream:
     do {
 
-        // fetch next 13 bits into nCodem but dont remove them from
+        // fetch next 13 bits into nCodem but don't remove them from
         // the input buffer:
         while (nInputBitsBufSize<13) {
             pIStream->ReadUChar( nByte );
@@ -960,22 +949,22 @@ void CCIDecompressor::Read1DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTarget
         // is that an invalid code?
         if ( nDataBits == 9999 )
         {
-            return;
+            return nTargetBits == nBitsToRead;
         }
         if ( nCodeBits == 0 )
         {
-            return;             // could be filling bits now
+            return nTargetBits == nBitsToRead;  // could be filling bits now
         }
         nEOLCount = 0;
         // too much data?
         if (nDataBits>nTargetBits) {
             // Yes, could be a subsequent error cause by an invalid code
-            // Thefore continue anyhow:
+            // Therefore continue anyhow:
             nDataBits=nTargetBits;
         }
 
         // is that a 'Terminating-Code'?
-        if (nDataBits<64) bTerminatingCode=true; else bTerminatingCode=false;
+        bTerminatingCode = nDataBits<64;
 
         // remove the read bits from the input buffer:
         nInputBitsBufSize = nInputBitsBufSize - nCodeBits;
@@ -996,10 +985,14 @@ void CCIDecompressor::Read1DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTarget
                 nDataBits = nDataBits - nTgtFreeByteBits;
                 pTarget++;
                 nTgtFreeByteBits=8;
-                while (nDataBits>=8) {
-                    *(pTarget++)=nBlackOrWhite;
-                    nDataBits-=8;
+                if (nDataBits >= 8)
+                {
+                    const sal_uInt16 nDataBytes = nDataBits / 8;
+                    memset(pTarget, nBlackOrWhite, nDataBytes);
+                    pTarget += nDataBytes;
+                    nDataBits -= nDataBytes * 8;
                 }
+
                 if (nDataBits>0) {
                     *pTarget=nBlackOrWhite;
                     nTgtFreeByteBits = nTgtFreeByteBits - nDataBits;
@@ -1011,11 +1004,11 @@ void CCIDecompressor::Read1DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTarget
         if (bTerminatingCode) nBlackOrWhite = ~nBlackOrWhite;
 
     } while (nTargetBits>0 || !bTerminatingCode);
+
+    return nTargetBits == nBitsToRead;
 }
 
-
-
-void CCIDecompressor::Read2DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTargetBits)
+bool CCIDecompressor::Read2DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTargetBits)
 {
     sal_uInt16 n2DMode,nBitPos,nUncomp,nRun,nRun2,nt;
     sal_uInt8 nBlackOrWhite;
@@ -1025,13 +1018,13 @@ void CCIDecompressor::Read2DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTarget
 
     while (nBitPos<nTargetBits && bStatus) {
 
-        n2DMode=ReadCodeAndDecode(p2DModeLookUp,10);
+        n2DMode=ReadCodeAndDecode(p2DModeLookUp.data(),10);
         if (!bStatus)
-            return;
+            return nBitPos == 0;
 
         if (n2DMode==CCI2DMODE_UNCOMP) {
             for (;;) {
-                nUncomp=ReadCodeAndDecode(pUncompLookUp,11);
+                nUncomp=ReadCodeAndDecode(pUncompLookUp.data(),11);
                 if (!bStatus)
                     break;
                 if ( nUncomp <= CCIUNCOMP_4White_1Black ) {
@@ -1056,12 +1049,12 @@ void CCIDecompressor::Read2DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTarget
         }
 
         else if (n2DMode==CCI2DMODE_PASS) {
-            if (nBitPos==0 && nBlackOrWhite==0x00 && CountBits(pLastLine,nTargetBits,0,0xff)!=0) nRun=0;
+            if (nBitPos==0 && nBlackOrWhite==0x00 && CountBits(pLastLine.get(), nTargetBits, 0, 0xff)!=0) nRun=0;
             else {
-                nRun=CountBits(pLastLine,nTargetBits,nBitPos,~nBlackOrWhite);
-                nRun = nRun + CountBits(pLastLine,nTargetBits,nBitPos+nRun,nBlackOrWhite);
+                nRun = CountBits(pLastLine.get(), nTargetBits, nBitPos, ~nBlackOrWhite);
+                nRun = nRun + CountBits(pLastLine.get(), nTargetBits, nBitPos + nRun, nBlackOrWhite);
             }
-            nRun = nRun + CountBits(pLastLine,nTargetBits,nBitPos+nRun,~nBlackOrWhite);
+            nRun = nRun + CountBits(pLastLine.get(), nTargetBits, nBitPos + nRun, ~nBlackOrWhite);
             FillBits(pTarget,nTargetBits,nBitPos,nRun,nBlackOrWhite);
             nBitPos = nBitPos + nRun;
         }
@@ -1070,24 +1063,24 @@ void CCIDecompressor::Read2DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTarget
             if (nBlackOrWhite==0x00) {
                 nRun=0;
                 do {
-                    nt=ReadCodeAndDecode(pWhiteLookUp,13);
+                    nt=ReadCodeAndDecode(pWhiteLookUp.data(),13);
                     nRun = nRun + nt;
                 } while (nt>=64);
                 nRun2=0;
                 do {
-                    nt=ReadCodeAndDecode(pBlackLookUp,13);
+                    nt=ReadCodeAndDecode(pBlackLookUp.data(),13);
                     nRun2 = nRun2 + nt;
                 } while (nt>=64);
             }
             else {
                 nRun=0;
                 do {
-                    nt=ReadCodeAndDecode(pBlackLookUp,13);
+                    nt=ReadCodeAndDecode(pBlackLookUp.data(),13);
                     nRun = nRun + nt;
                 } while (nt>=64);
                 nRun2=0;
                 do {
-                    nt=ReadCodeAndDecode(pWhiteLookUp,13);
+                    nt=ReadCodeAndDecode(pWhiteLookUp.data(),13);
                     nRun2 = nRun2 + nt;
                 } while (nt>=64);
             }
@@ -1098,10 +1091,10 @@ void CCIDecompressor::Read2DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTarget
         }
 
         else { // it's one of the modes CCI2DMODE_VERT_...
-            if (nBitPos==0 && nBlackOrWhite==0x00 && CountBits(pLastLine,nTargetBits,0,0xff)!=0) nRun=0;
+            if (nBitPos==0 && nBlackOrWhite==0x00 && CountBits(pLastLine.get(), nTargetBits, 0, 0xff)!=0) nRun=0;
             else {
-                nRun=CountBits(pLastLine,nTargetBits,nBitPos,~nBlackOrWhite);
-                nRun = nRun + CountBits(pLastLine,nTargetBits,nBitPos+nRun,nBlackOrWhite);
+                nRun = CountBits(pLastLine.get(), nTargetBits, nBitPos, ~nBlackOrWhite);
+                nRun = nRun + CountBits(pLastLine.get(), nTargetBits, nBitPos + nRun, nBlackOrWhite);
             }
             nRun+=n2DMode-CCI2DMODE_VERT_0;
             FillBits(pTarget,nTargetBits,nBitPos,nRun,nBlackOrWhite);
@@ -1109,7 +1102,8 @@ void CCIDecompressor::Read2DScanlineData(sal_uInt8 * pTarget, sal_uInt16 nTarget
             nBlackOrWhite=~nBlackOrWhite;
         }
     }
+
+    return nBitPos == 0;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
