@@ -19,7 +19,10 @@
 
 #include <algorithm>
 #include <filter/msfilter/dffpropset.hxx>
+#include <filter/msfilter/dffrecordheader.hxx>
+#include <svx/msdffdef.hxx>
 #include <rtl/ustrbuf.hxx>
+#include <tools/stream.hxx>
 
 static const DffPropSetEntry mso_PropSetDefaults[] = {
 
@@ -1104,7 +1107,6 @@ void DffPropSet::ReadPropSet( SvStream& rIn, bool bSetUninitializedOnly )
 
     sal_uInt32 nPropCount = aHd.nRecInstance;
 
-    // FilePos der ComplexData merken
     sal_uInt32 nComplexDataFilePos = rIn.Tell() + ( nPropCount * 6 );
 
     for( sal_uInt32 nPropNum = 0; nPropNum < nPropCount; nPropNum++ )
@@ -1157,7 +1159,7 @@ void DffPropSet::ReadPropSet( SvStream& rIn, bool bSetUninitializedOnly )
                 // normally nContent is the complete size of the complex property,
                 // but this is not always true for IMsoArrays ( what the hell is a IMsoArray ? )
 
-                // I love special threatments :-(
+                // I love special treatments :-(
                 if ( ( nRecType == DFF_Prop_pVertices ) || ( nRecType == DFF_Prop_pSegmentInfo )
                     || ( nRecType == DFF_Prop_fillShadeColors ) || ( nRecType == DFF_Prop_lineDashStyle )
                         || ( nRecType == DFF_Prop_pWrapPolygonVertices ) || ( nRecType == DFF_Prop_connectorPoints )
@@ -1166,11 +1168,11 @@ void DffPropSet::ReadPropSet( SvStream& rIn, bool bSetUninitializedOnly )
                 {
                     // now check if the current content size is possible, or 6 bytes too small
                     sal_uInt32  nOldPos = rIn.Tell();
-                    sal_Int16   nNumElem, nNumElemReserved, nSize;
 
-                    rIn.Seek( nComplexDataFilePos );
-                    rIn. ReadInt16( nNumElem ).ReadInt16( nNumElemReserved ).ReadInt16( nSize );
-                    if ( nNumElemReserved >= nNumElem )
+                    sal_Int16 nNumElem(0), nNumElemReserved(0), nSize(0);
+                    if (checkSeek(rIn, nComplexDataFilePos))
+                        rIn.ReadInt16(nNumElem).ReadInt16(nNumElemReserved).ReadInt16(nSize);
+                    if (nNumElemReserved >= nNumElem)
                     {
                         // the size of these array elements is nowhere defined,
                         // what if the size is negative ?
@@ -1283,20 +1285,20 @@ sal_uInt32 DffPropSet::GetPropertyValue( sal_uInt32 nId, sal_uInt32 nDefault ) c
     return ( mpPropSetEntries[ nId ].aFlags.bSet ) ? mpPropSetEntries[ nId ].nContent : nDefault;
 };
 
-bool DffPropSet::GetPropertyBool( sal_uInt32 nId, bool bDefault ) const
+bool DffPropSet::GetPropertyBool( sal_uInt32 nId ) const
 {
     sal_uInt32 nBaseId = nId | 31;              // base ID to get the sal_uInt32 property value
     sal_uInt32 nMask = 1 << (nBaseId - nId);    // bit mask of the boolean property
 
-    sal_uInt32 nPropValue = GetPropertyValue( nBaseId, bDefault ? nMask : 0 );
+    sal_uInt32 nPropValue = GetPropertyValue( nBaseId, 0 );
     return (nPropValue & nMask) != 0;
 }
 
 OUString DffPropSet::GetPropertyString( sal_uInt32 nId, SvStream& rStrm ) const
 {
-    sal_Size nOldPos = rStrm.Tell();
+    sal_uInt64 const nOldPos = rStrm.Tell();
     OUStringBuffer aBuffer;
-    sal_uInt32 nBufferSize = GetPropertyValue( nId );
+    sal_uInt32 nBufferSize = GetPropertyValue( nId, 0 );
     if( (nBufferSize > 0) && SeekToContent( nId, rStrm ) )
     {
         sal_Int32 nStrLen = static_cast< sal_Int32 >( nBufferSize / 2 );
@@ -1328,8 +1330,7 @@ bool DffPropSet::SeekToContent( sal_uInt32 nRecType, SvStream& rStrm ) const
             sal_uInt16 nIndex = mpPropSetEntries[ nRecType ].nComplexIndexOrFlagsHAttr;
             if ( nIndex < maOffsets.size() )
             {
-                rStrm.Seek( maOffsets[ nIndex ] );
-                return true;
+                return checkSeek(rStrm, maOffsets[nIndex]);
             }
         }
     }
