@@ -9,11 +9,14 @@
 #include <filter/msfilter/mstoolbar.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <stdarg.h>
+#include <com/sun/star/container/XIndexContainer.hpp>
+#include <com/sun/star/ui/XUIConfigurationManager.hpp>
+#include <com/sun/star/ui/XUIConfigurationManagerSupplier.hpp>
 #include <com/sun/star/ui/XUIConfigurationPersistence.hpp>
 #include <com/sun/star/ui/XImageManager.hpp>
+#include <com/sun/star/ui/ImageType.hpp>
 #include <com/sun/star/ui/ItemType.hpp>
 #include <com/sun/star/ui/ItemStyle.hpp>
-#include <com/sun/star/frame/XLayoutManager.hpp>
 #include <fstream>
 #include <vcl/dibtools.hxx>
 #include <vcl/graph.hxx>
@@ -37,12 +40,12 @@ void CustomToolBarImportHelper::ScaleImage( uno::Reference< graphic::XGraphic >&
     Size aSize = aGraphic.GetSizePixel();
     if ( aSize.Height() && ( aSize.Height() == aSize.Width() ) )
     {
-        Image aImage( xGraphic );
+        Graphic aImage(xGraphic);
         if ( aSize.Height() != nNewSize )
         {
             BitmapEx aBitmap = aImage.GetBitmapEx();
             BitmapEx aBitmapex = BitmapEx::AutoScaleBitmap(aBitmap, nNewSize );
-            aImage = Image( aBitmapex);
+            aImage = Graphic(aBitmapex);
             xGraphic = aImage.GetXGraphic();
         }
     }
@@ -52,18 +55,16 @@ void CustomToolBarImportHelper::applyIcons()
 {
     for ( std::vector< iconcontrolitem >::iterator it = iconcommands.begin(); it != iconcommands.end(); ++it )
     {
-        uno::Sequence< OUString > commands(1);
-        commands[ 0 ] = it->sCommand;
+        uno::Sequence<OUString> commands { it->sCommand };
         uno::Sequence< uno::Reference< graphic::XGraphic > > images(1);
         images[ 0 ] = it->image;
 
-        OSL_TRACE("About to applyIcons for command %s, have image ? %s", OUStringToOString( commands[ 0 ], RTL_TEXTENCODING_UTF8 ).getStr(), images[ 0 ].is() ? "yes" : "no" );
         uno::Reference< ui::XImageManager > xImageManager( getCfgManager()->getImageManager(), uno::UNO_QUERY_THROW );
         sal_uInt16 nColor = ui::ImageType::COLOR_NORMAL;
 
-        Window* topwin = Application::GetActiveTopWindow();
-    if ( topwin != NULL && topwin->GetDisplayBackground().GetColor().IsDark() )
-            nColor = css::ui::ImageType::COLOR_HIGHCONTRAST;
+        vcl::Window* topwin = Application::GetActiveTopWindow();
+        if ( topwin != nullptr && topwin->GetDisplayBackground().GetColor().IsDark() )
+                nColor = css::ui::ImageType::COLOR_HIGHCONTRAST;
 
         ScaleImage( images[ 0 ], 16 );
         xImageManager->replaceImages( ui::ImageType::SIZE_DEFAULT | nColor,  commands, images );
@@ -92,20 +93,13 @@ CustomToolBarImportHelper::getCfgManager()
     return m_xCfgSupp->getUIConfigurationManager();
 }
 
-uno::Reference< ui::XUIConfigurationManager >
-CustomToolBarImportHelper::getAppCfgManager()
-{
-    return m_xAppCfgMgr;
-}
 
 uno::Any
 CustomToolBarImportHelper::createCommandFromMacro( const OUString& sCmd )
 {
-//"vnd.sun.star.script:Standard.Module1.Main?language=Basic&location=document"
-    static OUString scheme( "vnd.sun.star.script:" );
-    static OUString part2( "?language=Basic&location=document" );
+    //"vnd.sun.star.script:Standard.Module1.Main?language=Basic&location=document"
     // create script url
-    OUString scriptURL = scheme + sCmd + part2;
+    OUString scriptURL = "vnd.sun.star.script:" + sCmd + "?language=Basic&location=document";
     return uno::makeAny( scriptURL );
 }
 
@@ -126,7 +120,7 @@ OUString CustomToolBarImportHelper::MSOTCIDToOOCommand( sal_Int16 msoTCID )
 }
 
 bool
-CustomToolBarImportHelper::createMenu( const OUString& rName, const uno::Reference< container::XIndexAccess >& xMenuDesc, bool bPersist )
+CustomToolBarImportHelper::createMenu( const OUString& rName, const uno::Reference< container::XIndexAccess >& xMenuDesc )
 {
     bool bRes = true;
     try
@@ -142,21 +136,18 @@ CustomToolBarImportHelper::createMenu( const OUString& rName, const uno::Referen
         {
             uno::Sequence< beans::PropertyValue > aPopupMenu( 4 );
             aPopupMenu[0].Name = "CommandURL";
-            aPopupMenu[0].Value = uno::makeAny( OUString("vnd.openoffice.org:") + rName );
+            aPopupMenu[0].Value <<= "vnd.openoffice.org:" + rName;
             aPopupMenu[1].Name = "Label";
             aPopupMenu[1].Value <<= rName;
             aPopupMenu[2].Name = "ItemDescriptorContainer";
-            aPopupMenu[2].Value = uno::makeAny( xMenuDesc );
+            aPopupMenu[2].Value <<= xMenuDesc;
             aPopupMenu[3].Name = "Type";
             aPopupMenu[3].Value <<= sal_Int32( 0 );
 
             xPopup->insertByIndex( xPopup->getCount(), uno::makeAny( aPopupMenu ) );
-            if ( bPersist )
-            {
-                xCfgManager->insertSettings( sMenuBar, uno::Reference< container::XIndexAccess >( xPopup, uno::UNO_QUERY ) );
-                uno::Reference< ui::XUIConfigurationPersistence > xPersistence( xCfgManager, uno::UNO_QUERY_THROW );
-                xPersistence->store();
-            }
+            xCfgManager->insertSettings( sMenuBar, uno::Reference< container::XIndexAccess >( xPopup, uno::UNO_QUERY ) );
+            uno::Reference< ui::XUIConfigurationPersistence > xPersistence( xCfgManager, uno::UNO_QUERY_THROW );
+            xPersistence->store();
         }
     }
     catch( const uno::Exception& )
@@ -166,8 +157,8 @@ CustomToolBarImportHelper::createMenu( const OUString& rName, const uno::Referen
     return bRes;
 }
 
-void
-TBBase::indent_printf( FILE* fp, const char* format, ... )
+#ifdef DEBUG_FILTER_MSTOOLBAR
+void TBBase::indent_printf( FILE* fp, const char* format, ... )
 {
    va_list ap;
    va_start ( ap, format );
@@ -179,36 +170,39 @@ TBBase::indent_printf( FILE* fp, const char* format, ... )
    vfprintf( fp, format, ap );
    va_end( ap );
 }
+#endif
 
-TBCHeader::TBCHeader() : bSignature( 0x3 )
-,bVersion( 0x01 )
-,bFlagsTCR( 0 )
-,tct(0x1) // default to Button
-,tcid(0)
-,tbct(0)
+TBCHeader::TBCHeader()
+    : bSignature(0x3)
+    , bVersion(0x01)
+    , bFlagsTCR(0)
+    , tct(0x1) // default to Button
+    , tcid(0)
+    , tbct(0)
+    , bPriority(0)
 {
 }
 
-
 TBCHeader::~TBCHeader()
 {
 }
 
 bool TBCHeader::Read( SvStream &rS )
 {
-    OSL_TRACE("TBCHeader::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
-    rS >> bSignature >> bVersion >> bFlagsTCR >> tct >> tcid >> tbct >> bPriority;
+    rS.ReadSChar( bSignature ).ReadSChar( bVersion ).ReadUChar( bFlagsTCR ).ReadUChar( tct ).ReadUInt16( tcid ).ReadUInt32( tbct ).ReadUChar( bPriority );
     //  bit 4 ( from lsb )
     if ( bFlagsTCR & 0x10 )
     {
         width.reset( new sal_uInt16 );
         height.reset( new sal_uInt16 );
-        rS >> *width >> *height;
+        rS.ReadUInt16( *width ).ReadUInt16( *height );
     }
     return true;
 }
 
+#ifdef DEBUG_FILTER_MSTOOLBAR
 void TBCHeader::Print( FILE* fp )
 {
     Indent a;
@@ -225,6 +219,7 @@ void TBCHeader::Print( FILE* fp )
     if ( height.get() )
         indent_printf(fp,"  height 0x%d(0x%x)\n", *height, *height);
 }
+#endif
 
 TBCData::TBCData( const TBCHeader& Header ) : rHeader( Header )
 {
@@ -232,7 +227,7 @@ TBCData::TBCData( const TBCHeader& Header ) : rHeader( Header )
 
 bool TBCData::Read(SvStream &rS)
 {
-    OSL_TRACE("TBCData::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
     if ( !controlGeneralInfo.Read(rS) /*|| !controlSpecificInfo.Read(rS)*/ )
         return false;
@@ -277,7 +272,7 @@ bool TBCData::ImportToolBarControl( CustomToolBarImportHelper& helper, std::vect
     controlGeneralInfo.ImportToolBarControlData( helper, props );
     beans::PropertyValue aProp;
     aProp.Name = "Visible";
-    aProp.Value = uno::makeAny( rHeader.isVisible() ); // where is the visible attribute stored
+    aProp.Value <<= rHeader.isVisible(); // where is the visible attribute stored
     props.push_back( aProp );
     if ( rHeader.getTct() == 0x01
     || rHeader.getTct() == 0x10 )
@@ -314,8 +309,7 @@ bool TBCData::ImportToolBarControl( CustomToolBarImportHelper& helper, std::vect
                 OUString sBuiltInCmd = helper.MSOTCIDToOOCommand(  *pSpecificInfo->getBtnFace() );
                 if ( !sBuiltInCmd.isEmpty() )
                 {
-                    uno::Sequence< OUString> sCmds(1);
-                    sCmds[ 0 ] = sBuiltInCmd;
+                    uno::Sequence<OUString> sCmds { sBuiltInCmd };
                     uno::Reference< ui::XImageManager > xImageManager( helper.getAppCfgManager()->getImageManager(), uno::UNO_QUERY_THROW );
                     // 0 = default image size
                     uno::Sequence< uno::Reference< graphic::XGraphic > > sImages = xImageManager->getImages( 0, sCmds );
@@ -332,7 +326,7 @@ bool TBCData::ImportToolBarControl( CustomToolBarImportHelper& helper, std::vect
 
         TBCMenuSpecific* pMenu = getMenuSpecific();
         if ( pMenu )
-            aProp.Value = uno::makeAny( sMenuBar += pMenu->Name() ); // name of popup
+            aProp.Value <<= sMenuBar += pMenu->Name(); // name of popup
         nStyle |= ui::ItemStyle::DROP_DOWN;
         props.push_back( aProp );
     }
@@ -358,6 +352,7 @@ bool TBCData::ImportToolBarControl( CustomToolBarImportHelper& helper, std::vect
     return true; // just ignore
 }
 
+#ifdef DEBUG_FILTER_MSTOOLBAR
 void TBCData::Print( FILE* fp )
 {
     Indent a;
@@ -371,39 +366,44 @@ void TBCData::Print( FILE* fp )
         controlSpecificInfo->Print( fp );
     }
 }
+#endif
 
 bool
 WString::Read( SvStream &rS )
 {
-    OSL_TRACE("WString::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
     sal_uInt8 nChars = 0;
-    rS >> nChars;
+    rS.ReadUChar( nChars );
     sString = read_uInt16s_ToOUString(rS, nChars);
     return true;
 }
 
-TBCExtraInfo::TBCExtraInfo() : idHelpContext( 0 )
+TBCExtraInfo::TBCExtraInfo()
+    : idHelpContext(0)
+    , tbcu(0)
+    , tbmg(0)
 {
 }
 
 bool
 TBCExtraInfo::Read( SvStream &rS )
 {
-    OSL_TRACE("TBCExtraInfo::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
     if( !wstrHelpFile.Read( rS )  )
         return false;
 
-    rS >> idHelpContext;
+    rS.ReadInt32( idHelpContext );
 
     if ( !wstrTag.Read( rS ) || !wstrOnAction.Read( rS ) || !wstrParam.Read( rS ) )
         return false;
 
-    rS >> tbcu >> tbmg;
+    rS.ReadSChar( tbcu ).ReadSChar( tbmg );
     return true;
 }
 
+#ifdef DEBUG_FILTER_MSTOOLBAR
 void
 TBCExtraInfo::Print( FILE* fp )
 {
@@ -420,8 +420,8 @@ TBCExtraInfo::Print( FILE* fp )
         OUStringToOString( wstrParam.getString(), RTL_TEXTENCODING_UTF8 ).getStr() );
     indent_printf( fp, "  tbcu 0x%x\n", tbcu );
     indent_printf( fp, "  tbmg 0x%x\n", tbmg );
-
 }
+#endif
 
 OUString
 TBCExtraInfo::getOnAction()
@@ -435,9 +435,9 @@ TBCGeneralInfo::TBCGeneralInfo() : bFlags( 0 )
 
 bool TBCGeneralInfo::Read( SvStream &rS )
 {
-    OSL_TRACE("TBCGeneralInfo::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
-    rS >> bFlags;
+    rS.ReadUChar( bFlags );
 
     if ( ( bFlags & 0x1 ) && !customText.Read( rS ) )
         return false;
@@ -448,6 +448,7 @@ bool TBCGeneralInfo::Read( SvStream &rS )
     return true;
 }
 
+#ifdef DEBUG_FILTER_MSFILTER
 void
 TBCGeneralInfo::Print( FILE* fp )
 {
@@ -463,11 +464,12 @@ TBCGeneralInfo::Print( FILE* fp )
     if ( bFlags & 0x4 )
         extraInfo.Print( fp );
 }
+#endif
 
-bool
+void
 TBCGeneralInfo::ImportToolBarControlData( CustomToolBarImportHelper& helper, std::vector< beans::PropertyValue >& sControlData )
 {
-    if ( ( bFlags & 0x5 ) )
+    if ( bFlags & 0x5 )
     {
         beans::PropertyValue aProp;
         // probably access to the header would be a better test than seeing if there is an action, e.g.
@@ -477,22 +479,22 @@ TBCGeneralInfo::ImportToolBarControlData( CustomToolBarImportHelper& helper, std
             aProp.Name = "CommandURL";
             ooo::vba::MacroResolvedInfo aMacroInf = ooo::vba::resolveVBAMacro( &helper.GetDocShell(), extraInfo.getOnAction(), true );
             if ( aMacroInf.mbFound )
-                aProp.Value = helper.createCommandFromMacro( aMacroInf.msResolvedMacro );
+                aProp.Value = CustomToolBarImportHelper::createCommandFromMacro( aMacroInf.msResolvedMacro );
             else
-                aProp.Value <<= OUString( "UnResolvedMacro[" ).concat( extraInfo.getOnAction() ).concat( OUString( "]" ) );
+                aProp.Value <<= OUString( "UnResolvedMacro[" ).concat( extraInfo.getOnAction() ).concat( "]" );
             sControlData.push_back( aProp );
         }
 
         aProp.Name = "Label";
-        aProp.Value = uno::makeAny( customText.getString().replace('&','~') );
+        aProp.Value <<= customText.getString().replace('&','~');
         sControlData.push_back( aProp );
 
         aProp.Name = "Type";
-        aProp.Value = uno::makeAny( ui::ItemType::DEFAULT );
+        aProp.Value <<= ui::ItemType::DEFAULT;
         sControlData.push_back( aProp );
 
         aProp.Name = "Tooltip";
-        aProp.Value = uno::makeAny( tooltip.getString() );
+        aProp.Value <<= tooltip.getString();
         sControlData.push_back( aProp );
 /*
 aToolbarItem(0).Name = "CommandURL" wstrOnAction
@@ -505,7 +507,6 @@ aToolbarItem(3).Name = "Visible"
 aToolbarItem(3).Value = true
 */
     }
-    return true;
 }
 
 TBCMenuSpecific::TBCMenuSpecific() : tbid( 0 )
@@ -515,9 +516,9 @@ TBCMenuSpecific::TBCMenuSpecific() : tbid( 0 )
 bool
 TBCMenuSpecific::Read( SvStream &rS)
 {
-    OSL_TRACE("TBCMenuSpecific::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
-    rS >> tbid;
+    rS.ReadInt32( tbid );
     if ( tbid == 1 )
     {
         name.reset( new WString() );
@@ -526,6 +527,7 @@ TBCMenuSpecific::Read( SvStream &rS)
     return true;
 }
 
+#ifdef DEBUG_FILTER_MSFILTER
 void
 TBCMenuSpecific::Print( FILE* fp )
 {
@@ -534,8 +536,8 @@ TBCMenuSpecific::Print( FILE* fp )
     indent_printf( fp, "  tbid 0x%x\n", static_cast< unsigned int >( tbid ) );
     if ( tbid == 1 )
         indent_printf( fp, "  name %s\n", OUStringToOString( name->getString(), RTL_TEXTENCODING_UTF8 ).getStr() );
-
 }
+#endif
 
 OUString TBCMenuSpecific::Name()
 {
@@ -550,9 +552,9 @@ TBCBSpecific::TBCBSpecific() : bFlags( 0 )
 
 bool TBCBSpecific::Read( SvStream &rS)
 {
-    OSL_TRACE("TBCBSpecific::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
-    rS >> bFlags;
+    rS.ReadUChar( bFlags );
 
     // bFlags determines what we read next
 
@@ -568,7 +570,7 @@ bool TBCBSpecific::Read( SvStream &rS)
     if ( bFlags & 0x10 )
     {
         iBtnFace.reset( new sal_uInt16 );
-        rS >> *iBtnFace.get();
+        rS.ReadUInt16( *iBtnFace.get() );
     }
     // if bFlags.fAccelerator equals 1 ( 0x04 )
     if ( bFlags & 0x04 )
@@ -580,6 +582,7 @@ bool TBCBSpecific::Read( SvStream &rS)
 }
 
 
+#ifdef DEBUG_FILTER_MSFILTER
 void TBCBSpecific::Print( FILE* fp )
 {
     Indent a;
@@ -608,6 +611,7 @@ void TBCBSpecific::Print( FILE* fp )
     bResult = ( wstrAcc.get() != NULL );
     indent_printf( fp, "  option string present? %s ->%s<-\n", bResult ? "true" : "false", bResult ? OUStringToOString( wstrAcc->getString(), RTL_TEXTENCODING_UTF8 ).getStr() : "N/A" );
 }
+#endif
 
 TBCBitMap*
 TBCBSpecific::getIcon()
@@ -635,6 +639,7 @@ bool TBCComboDropdownSpecific::Read( SvStream &rS)
     return true;
 }
 
+#ifdef DEBUG_FILTER_MSFILTER
 void TBCComboDropdownSpecific::Print( FILE* fp)
 {
     Indent a;
@@ -644,11 +649,14 @@ void TBCComboDropdownSpecific::Print( FILE* fp)
     else
         indent_printf(fp," no data " );
 }
+#endif
 
-TBCCDData::TBCCDData() : cwstrItems( 0 )
-,iSel( 0 )
-,cLines( 0 )
-,dxWidth( 0 )
+TBCCDData::TBCCDData()
+    : cwstrItems(0)
+    , cwstrMRU(0)
+    , iSel(0)
+    , cLines(0)
+    , dxWidth(0)
 {
 }
 
@@ -659,9 +667,12 @@ TBCCDData::~TBCCDData()
 bool TBCCDData::Read( SvStream &rS)
 {
     nOffSet = rS.Tell();
-    rS >> cwstrItems;
-    if ( cwstrItems )
+    rS.ReadInt16( cwstrItems );
+    if (cwstrItems > 0)
     {
+        //each WString is at least one byte
+        if (rS.remainingSize() < static_cast<size_t>(cwstrItems))
+            return false;
         for( sal_Int32 index=0; index < cwstrItems; ++index )
         {
             WString aString;
@@ -670,11 +681,12 @@ bool TBCCDData::Read( SvStream &rS)
             wstrList.push_back( aString );
         }
     }
-    rS >> cwstrMRU >> iSel >> cLines >> dxWidth;
+    rS.ReadInt16( cwstrMRU ).ReadInt16( iSel ).ReadInt16( cLines ).ReadInt16( dxWidth );
 
     return wstrEdit.Read( rS );
 }
 
+#ifdef DEBUG_FILTER_MSFILTER
 void TBCCDData::Print( FILE* fp)
 {
     Indent a;
@@ -691,6 +703,7 @@ void TBCCDData::Print( FILE* fp)
     indent_printf(fp,"  dxWidth width in pixels 0x%d", dxWidth);
     indent_printf(fp,"  wstrEdit %s", OUStringToOString( wstrEdit.getString(), RTL_TEXTENCODING_UTF8 ).getStr() );
 }
+#endif
 
 TBCBitMap::TBCBitMap() : cbDIB( 0 )
 {
@@ -700,28 +713,23 @@ TBCBitMap::~TBCBitMap()
 {
 }
 
-// #FIXME Const-ness
-Bitmap&
-TBCBitMap::getBitMap()
-{
-    return mBitMap;
-}
-
 bool TBCBitMap::Read( SvStream& rS)
 {
-    OSL_TRACE("TBCBitMap::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
-    rS >> cbDIB;
+    rS.ReadInt32( cbDIB );
     // cbDIB = sizeOf(biHeader) + sizeOf(colors) + sizeOf(bitmapData) + 10
-    return ReadDIB(mBitMap, rS, false);
+    return ReadDIB(mBitMap, rS, false, true);
 }
 
+#ifdef DEBUG_FILTER_MSTOOLBAR
 void TBCBitMap::Print( FILE* fp )
 {
     Indent a;
     indent_printf(fp, "[ 0x%x ] TBCBitMap -- dump\n", nOffSet );
     indent_printf(fp, "  TBCBitMap size of bitmap data 0x%x\n", static_cast< unsigned int > ( cbDIB ) );
 }
+#endif
 
 TB::TB() : bSignature(0x2),
 bVersion(0x1),
@@ -735,9 +743,9 @@ bFlags( 0 )
 
 bool TB::Read(SvStream &rS)
 {
-    OSL_TRACE("TB::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
-    rS >> bSignature >> bVersion >> cCL >> ltbid >> ltbtr >> cRowsDefault >> bFlags;
+    rS.ReadUChar( bSignature ).ReadUChar( bVersion ).ReadInt16( cCL ).ReadInt32( ltbid ).ReadUInt32( ltbtr ).ReadUInt16( cRowsDefault ).ReadUInt16( bFlags );
     name.Read( rS );
     return true;
 
@@ -748,6 +756,7 @@ bool TB::IsEnabled()
     return ( bFlags & 0x01 ) != 0x01;
 }
 
+#ifdef DEBUG_FILTER_MSTOOLBAR
 void TB::Print( FILE* fp )
 {
     Indent a;
@@ -761,6 +770,7 @@ void TB::Print( FILE* fp )
     indent_printf(fp,"  bFlags 0x%x\n", bFlags );
     indent_printf(fp, "  name %s\n", OUStringToOString( name.getString(), RTL_TEXTENCODING_UTF8 ).getStr() );
 }
+#endif
 
 TBVisualData::TBVisualData() : tbds(0), tbv(0), tbdsDock(0), iRow(0)
 {
@@ -768,14 +778,15 @@ TBVisualData::TBVisualData() : tbds(0), tbv(0), tbdsDock(0), iRow(0)
 
 bool TBVisualData::Read( SvStream& rS )
 {
-    OSL_TRACE("TBVisualData::Read() stream pos 0x%x", rS.Tell() );
+    SAL_INFO("filter.ms", "stream pos " << rS.Tell());
     nOffSet = rS.Tell();
-    rS >> tbds >> tbv >> tbdsDock >> iRow;
+    rS.ReadSChar( tbds ).ReadSChar( tbv ).ReadSChar( tbdsDock ).ReadSChar( iRow );
     rcDock.Read( rS );
     rcFloat.Read( rS );
     return true;
 }
 
+#ifdef DEBUG_FILTER_MSTOOLBAR
 void SRECT::Print( FILE* fp )
 {
     Indent a;
@@ -784,7 +795,9 @@ void SRECT::Print( FILE* fp )
     indent_printf( fp, "  right 0x%x\n", right);
     indent_printf( fp, "  bottom 0x%x\n", bottom);
 }
+#endif
 
+#ifdef DEBUG_FILTER_MSTOOLBAR
 void TBVisualData::Print( FILE* fp )
 {
     Indent a;
@@ -796,5 +809,6 @@ void TBVisualData::Print( FILE* fp )
     rcDock.Print( fp );
     rcFloat.Print( fp );
 }
+#endif
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
