@@ -19,11 +19,9 @@
 
 #include <iostream>
 #include <stdlib.h>
-#include <ctype.h>
 #include <rtl/ustring.hxx>
 #include <tools/urlobj.hxx>
 #include "XmlFilterAdaptor.hxx"
-#include <osl/diagnose.h>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/uno/RuntimeException.hpp>
 #include <com/sun/star/io/XActiveDataSource.hpp>
@@ -32,10 +30,8 @@
 #include <com/sun/star/xml/sax/XDocumentHandler.hpp>
 #include <com/sun/star/xml/sax/InputSource.hpp>
 #include <com/sun/star/xml/sax/Parser.hpp>
-#include <com/sun/star/frame/XConfigManager.hpp>
 #include <com/sun/star/xml/XImportFilter.hpp>
 #include <com/sun/star/xml/XExportFilter.hpp>
-#include <com/sun/star/frame/XController.hpp>
 #include <com/sun/star/task/XStatusIndicator.hpp>
 #include <com/sun/star/task/XStatusIndicatorFactory.hpp>
 #include <com/sun/star/style/XStyleFamiliesSupplier.hpp>
@@ -61,28 +57,22 @@ using namespace com::sun::star::document;
 using namespace com::sun::star::style;
 using namespace com::sun::star::xml;
 using namespace com::sun::star::xml::sax;
-using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::task;
 
 bool SAL_CALL XmlFilterAdaptor::importImpl( const Sequence< css::beans::PropertyValue >& aDescriptor )
-    throw (RuntimeException, std::exception)
 {
-    OUString udConvertClass=msUserData[0];
-    OUString udImport =msUserData[2];
+    OUString udConvertClass    = msUserData[0];
+    const OUString sXMLImportService = msUserData[2];
     sal_Int32 nSteps= 0;
-    sal_Int32 nProgressRange = 4;
 
     utl::MediaDescriptor aMediaMap(aDescriptor);
     Reference< XStatusIndicator > xStatusIndicator(aMediaMap.getUnpackedValueOrDefault(
         utl::MediaDescriptor::PROP_STATUSINDICATOR(), Reference< XStatusIndicator >()));
 
     if (xStatusIndicator.is()){
-        xStatusIndicator->start( "Loading :",nProgressRange);
+        xStatusIndicator->start( "Loading :", 4);
     }
 
-    OUString sXMLImportService (  udImport  );
-    Reference < XParser > xSaxParser = Parser::create( mxContext );
-
     Sequence< Any > aAnys(1);
     OUString aBaseURI;
     if (aMediaMap.find(OUString( "URL" ))->second >>= aBaseURI)
@@ -90,19 +80,19 @@ bool SAL_CALL XmlFilterAdaptor::importImpl( const Sequence< css::beans::Property
         INetURLObject aURLObj(aBaseURI);
         // base URI in this case is the URI of the actual saving location
         // aURLObj.removeSegment();
-        aBaseURI = aURLObj.GetMainURL(INetURLObject::NO_DECODE);
+        aBaseURI = aURLObj.GetMainURL(INetURLObject::DecodeMechanism::NONE);
     }
 
     // create an XProperty set to configure the exporter for pretty printing
     PropertyMapEntry aImportInfoMap[] =
-     {
+    {
         { OUString("BaseURI"), 0, ::cppu::UnoType<OUString>::get(), PropertyAttribute::MAYBEVOID, 0},
-         { OUString(), 0, css::uno::Type(), 0, 0 }
-     };
+        { OUString(), 0, css::uno::Type(), 0, 0 }
+    };
 
-     Reference< XPropertySet > xInfoSet(
-        GenericPropertySet_CreateInstance( new PropertySetInfo( aImportInfoMap ) ) );
-     xInfoSet->setPropertyValue( "BaseURI", makeAny( aBaseURI ));
+    Reference< XPropertySet > xInfoSet(
+            GenericPropertySet_CreateInstance( new PropertySetInfo( aImportInfoMap ) ) );
+    xInfoSet->setPropertyValue( "BaseURI", makeAny( aBaseURI ));
     aAnys[0] <<= xInfoSet;
 
 
@@ -138,18 +128,16 @@ bool SAL_CALL XmlFilterAdaptor::importImpl( const Sequence< css::beans::Property
         Reference< XStyleFamiliesSupplier > xstylefamiliessupplier(mxDoc, UNO_QUERY);
         Reference< XStyleLoader > xstyleLoader (xstylefamiliessupplier->getStyleFamilies(), UNO_QUERY);
         if(xstyleLoader.is()){
-            Sequence<css::beans::PropertyValue> pValue=xstyleLoader->getStyleLoaderOptions();
+            Sequence<css::beans::PropertyValue> aValue = xstyleLoader->getStyleLoaderOptions();
 
             //Load the Styles from the Template URL Supplied in the TypeDetection file
             if(!comphelper::isFileUrl(msTemplateName))
             {
                 SvtPathOptions aOptions;
-                OUString PathString = aOptions.SubstituteVariable("$(progurl)");
-                PathString = PathString.concat("/");
-                msTemplateName=PathString.concat(msTemplateName);
+                msTemplateName = aOptions.SubstituteVariable("$(progurl)") + "/" + msTemplateName;
             }
 
-            xstyleLoader->loadStylesFromURL(msTemplateName,pValue);
+            xstyleLoader->loadStylesFromURL(msTemplateName,aValue);
         }
     }
 
@@ -173,7 +161,7 @@ bool SAL_CALL XmlFilterAdaptor::importImpl( const Sequence< css::beans::Property
         if (xStatusIndicator.is())
                xStatusIndicator->end();
 
-        SAL_WARN("filter.xmlfa", "XmlFilterAdaptor: exception: " << e.Message);
+        SAL_WARN("filter.xmlfa", "XmlFilterAdaptor: " << e);
         return false;
     }
     if (xStatusIndicator.is()) {
@@ -184,7 +172,6 @@ bool SAL_CALL XmlFilterAdaptor::importImpl( const Sequence< css::beans::Property
 }
 
 bool SAL_CALL XmlFilterAdaptor::exportImpl( const Sequence< css::beans::PropertyValue >& aDescriptor )
-    throw (RuntimeException)
 {
 
     OUString udConvertClass = msUserData[0];
@@ -192,13 +179,12 @@ bool SAL_CALL XmlFilterAdaptor::exportImpl( const Sequence< css::beans::Property
 
     // Status Bar
     sal_Int32 nSteps= 1;
-    sal_Int32 nProgressRange(3);
     utl::MediaDescriptor aMediaMap(aDescriptor);
     Reference< XStatusIndicator > xStatusIndicator(aMediaMap.getUnpackedValueOrDefault(
         utl::MediaDescriptor::PROP_STATUSINDICATOR(), Reference< XStatusIndicator >()));
 
     if (xStatusIndicator.is())
-       xStatusIndicator->start( "Saving :",nProgressRange);
+       xStatusIndicator->start( "Saving :", 3);
 
     // Set up converter bridge.
     Reference< css::xml::XExportFilter > xConverter(mxContext->getServiceManager()->createInstanceWithContext( udConvertClass, mxContext ), UNO_QUERY);
@@ -243,7 +229,7 @@ bool SAL_CALL XmlFilterAdaptor::exportImpl( const Sequence< css::beans::Property
             INetURLObject aURLObj(aBaseURI);
             // base URI in this case is the URI of the actual saving location
             // aURLObj.removeSegment();
-            aBaseURI = aURLObj.GetMainURL(INetURLObject::NO_DECODE);
+            aBaseURI = aURLObj.GetMainURL(INetURLObject::DecodeMechanism::NONE);
         }
 
         // create an XProperty set to configure the exporter for pretty printing
@@ -286,7 +272,7 @@ bool SAL_CALL XmlFilterAdaptor::exportImpl( const Sequence< css::beans::Property
     }
     catch (const Exception& e)
     {
-        SAL_WARN("filter.xmlfa", "XmlFilterAdaptor: exception: " << e.Message);
+        SAL_WARN("filter.xmlfa", "XmlFilterAdaptor: " << e);
         if (xStatusIndicator.is())
             xStatusIndicator->end();
         return false;
@@ -299,17 +285,14 @@ bool SAL_CALL XmlFilterAdaptor::exportImpl( const Sequence< css::beans::Property
 }
 
 sal_Bool SAL_CALL XmlFilterAdaptor::filter( const Sequence< css::beans::PropertyValue >& aDescriptor )
-  throw (RuntimeException, std::exception)
 {
     return meType == FILTER_EXPORT ? exportImpl ( aDescriptor ) : importImpl ( aDescriptor );
 }
 void SAL_CALL XmlFilterAdaptor::cancel(  )
-    throw (RuntimeException, std::exception)
 {
 }
 // XExporter
 void SAL_CALL XmlFilterAdaptor::setSourceDocument( const Reference< css::lang::XComponent >& xDoc )
-    throw (css::lang::IllegalArgumentException, RuntimeException, std::exception)
 {
     meType = FILTER_EXPORT;
     mxDoc = xDoc;
@@ -317,14 +300,12 @@ void SAL_CALL XmlFilterAdaptor::setSourceDocument( const Reference< css::lang::X
 
 // XImporter
 void SAL_CALL XmlFilterAdaptor::setTargetDocument( const Reference< css::lang::XComponent >& xDoc )
-    throw (css::lang::IllegalArgumentException, RuntimeException, std::exception)
 {
     meType = FILTER_IMPORT;
     mxDoc = xDoc;
 }
 // XInitialization
 void SAL_CALL XmlFilterAdaptor::initialize( const Sequence< Any >& aArguments )
-    throw (Exception, RuntimeException, std::exception)
 {
     Sequence < PropertyValue > aAnySeq;
     sal_Int32 nLength = aArguments.getLength();
@@ -340,13 +321,11 @@ void SAL_CALL XmlFilterAdaptor::initialize( const Sequence< Any >& aArguments )
     }
 }
 OUString XmlFilterAdaptor_getImplementationName ()
-    throw (RuntimeException)
 {
     return OUString( "com.sun.star.comp.Writer.XmlFilterAdaptor" );
 }
 
 Sequence< OUString > SAL_CALL XmlFilterAdaptor_getSupportedServiceNames(  )
-    throw (RuntimeException)
 {
     Sequence < OUString > aRet(2);
     OUString* pArray = aRet.getArray();
@@ -356,26 +335,22 @@ Sequence< OUString > SAL_CALL XmlFilterAdaptor_getSupportedServiceNames(  )
 }
 
 Reference< XInterface > SAL_CALL XmlFilterAdaptor_createInstance( const Reference< XMultiServiceFactory > & rSMgr)
-    throw( Exception )
 {
     return static_cast<cppu::OWeakObject*>(new XmlFilterAdaptor( comphelper::getComponentContext(rSMgr) ));
 }
 
 // XServiceInfo
 OUString SAL_CALL XmlFilterAdaptor::getImplementationName(  )
-    throw (RuntimeException, std::exception)
 {
     return XmlFilterAdaptor_getImplementationName();
 }
 
 sal_Bool SAL_CALL XmlFilterAdaptor::supportsService( const OUString& rServiceName )
-    throw (RuntimeException, std::exception)
 {
     return cppu::supportsService( this, rServiceName );
 }
 
 Sequence< OUString > SAL_CALL XmlFilterAdaptor::getSupportedServiceNames(  )
-    throw (RuntimeException, std::exception)
 {
     return XmlFilterAdaptor_getSupportedServiceNames();
 }
