@@ -29,6 +29,7 @@
 #include <com/sun/star/awt/XVclWindowPeer.hpp>
 
 #include <vcl/svapp.hxx>
+#include <vcl/keycodes.hxx>
 #include <tools/wintypes.hxx>
 
 #include <connectivity/dbtools.hxx>
@@ -36,7 +37,6 @@
 #include <connectivity/dbconversion.hxx>
 
 #include <tools/diagnose_ex.h>
-#include <tools/debug.hxx>
 
 #include <comphelper/container.hxx>
 #include <comphelper/numbers.hxx>
@@ -44,7 +44,6 @@
 
 using namespace dbtools;
 
-//.........................................................................
 namespace frm
 {
 using namespace ::com::sun::star::uno;
@@ -60,13 +59,7 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::form::binding;
 
-//------------------------------------------------------------------
-InterfaceRef SAL_CALL OEditControl_CreateInstance(const Reference< XMultiServiceFactory > & _rxFactory)
-{
-    return *(new OEditControl( comphelper::getComponentContext(_rxFactory) ));
-}
 
-//------------------------------------------------------------------------------
 Sequence<Type> OEditControl::_getTypes()
 {
     static Sequence<Type> aTypes;
@@ -78,8 +71,8 @@ Sequence<Type> OEditControl::_getTypes()
     return aTypes;
 }
 
-//------------------------------------------------------------------------------
-Any SAL_CALL OEditControl::queryAggregation(const Type& _rType) throw (RuntimeException)
+
+Any SAL_CALL OEditControl::queryAggregation(const Type& _rType)
 {
     Any aReturn = OBoundControl::queryAggregation(_rType);
     if (!aReturn.hasValue())
@@ -88,16 +81,14 @@ Any SAL_CALL OEditControl::queryAggregation(const Type& _rType) throw (RuntimeEx
     return aReturn;
 }
 
-DBG_NAME(OEditControl);
-//------------------------------------------------------------------------------
+
 OEditControl::OEditControl(const Reference<XComponentContext>& _rxFactory)
                :OBoundControl( _rxFactory, FRM_SUN_CONTROL_RICHTEXTCONTROL )
                ,m_aChangeListeners(m_aMutex)
-               ,m_nKeyEvent( 0 )
+               ,m_nKeyEvent( nullptr )
 {
-    DBG_CTOR(OEditControl,NULL);
 
-    increment(m_refCount);
+    osl_atomic_increment(&m_refCount);
     {
         Reference<XWindow>  xComp;
         if (query_aggregation(m_xAggregate, xComp))
@@ -106,10 +97,10 @@ OEditControl::OEditControl(const Reference<XComponentContext>& _rxFactory)
             xComp->addKeyListener(this);
         }
     }
-    decrement(m_refCount);
+    osl_atomic_decrement(&m_refCount);
 }
 
-//------------------------------------------------------------------------------
+
 OEditControl::~OEditControl()
 {
     if( m_nKeyEvent )
@@ -121,24 +112,23 @@ OEditControl::~OEditControl()
         dispose();
     }
 
-    DBG_DTOR(OEditControl,NULL);
 }
 
 // XChangeBroadcaster
-//------------------------------------------------------------------------------
-void OEditControl::addChangeListener(const Reference<XChangeListener>& l) throw ( ::com::sun::star::uno::RuntimeException)
+
+void OEditControl::addChangeListener(const Reference<XChangeListener>& l)
 {
     m_aChangeListeners.addInterface( l );
 }
 
-//------------------------------------------------------------------------------
-void OEditControl::removeChangeListener(const Reference<XChangeListener>& l) throw ( ::com::sun::star::uno::RuntimeException)
+
+void OEditControl::removeChangeListener(const Reference<XChangeListener>& l)
 {
     m_aChangeListeners.removeInterface( l );
 }
 
 // OComponentHelper
-//------------------------------------------------------------------------------
+
 void OEditControl::disposing()
 {
     OBoundControl::disposing();
@@ -148,35 +138,37 @@ void OEditControl::disposing()
 }
 
 // XServiceInfo
-//------------------------------------------------------------------------------
-StringSequence  OEditControl::getSupportedServiceNames() throw()
+
+css::uno::Sequence<OUString>  OEditControl::getSupportedServiceNames()
 {
-    StringSequence aSupported = OBoundControl::getSupportedServiceNames();
-    aSupported.realloc(aSupported.getLength() + 1);
+    css::uno::Sequence<OUString> aSupported = OBoundControl::getSupportedServiceNames();
+    aSupported.realloc(aSupported.getLength() + 3);
 
     OUString*pArray = aSupported.getArray();
-    pArray[aSupported.getLength()-1] = FRM_SUN_CONTROL_TEXTFIELD;
+    pArray[aSupported.getLength()-3] = FRM_SUN_CONTROL_TEXTFIELD;
+    pArray[aSupported.getLength()-2] = STARDIV_ONE_FORM_CONTROL_EDIT;
+    pArray[aSupported.getLength()-1] = STARDIV_ONE_FORM_CONTROL_TEXTFIELD;
     return aSupported;
 }
 
 // XEventListener
-//------------------------------------------------------------------------------
-void OEditControl::disposing(const EventObject& Source) throw( RuntimeException )
+
+void OEditControl::disposing(const EventObject& Source)
 {
     OBoundControl::disposing(Source);
 }
 
 // XFocusListener
-//------------------------------------------------------------------------------
-void OEditControl::focusGained( const FocusEvent& /*e*/ ) throw ( ::com::sun::star::uno::RuntimeException)
+
+void OEditControl::focusGained( const FocusEvent& /*e*/ )
 {
     Reference<XPropertySet>  xSet(getModel(), UNO_QUERY);
     if (xSet.is())
         xSet->getPropertyValue( PROPERTY_TEXT ) >>= m_aHtmlChangeValue;
 }
 
-//------------------------------------------------------------------------------
-void OEditControl::focusLost( const FocusEvent& /*e*/ ) throw ( ::com::sun::star::uno::RuntimeException)
+
+void OEditControl::focusLost( const FocusEvent& /*e*/ )
 {
     Reference<XPropertySet>  xSet(getModel(), UNO_QUERY);
     if (xSet.is())
@@ -192,8 +184,8 @@ void OEditControl::focusLost( const FocusEvent& /*e*/ ) throw ( ::com::sun::star
 }
 
 // XKeyListener
-//------------------------------------------------------------------------------
-void OEditControl::keyPressed(const ::com::sun::star::awt::KeyEvent& e) throw ( ::com::sun::star::uno::RuntimeException)
+
+void OEditControl::keyPressed(const css::awt::KeyEvent& e)
 {
     if( e.KeyCode != KEY_RETURN || e.Modifiers != 0 )
         return;
@@ -203,13 +195,13 @@ void OEditControl::keyPressed(const ::com::sun::star::awt::KeyEvent& e) throw (
     if( !xSet.is() )
         return;
 
-    // Not for  multiline edits
+    // Not for multiline edits
     Any aTmp( xSet->getPropertyValue(PROPERTY_MULTILINE));
-    if ((aTmp.getValueType().equals(::getBooleanCppuType())) && getBOOL(aTmp))
+    if ((aTmp.getValueType().equals(cppu::UnoType<bool>::get())) && getBOOL(aTmp))
         return;
 
     Reference<XFormComponent>  xFComp(xSet, UNO_QUERY);
-    InterfaceRef  xParent = xFComp->getParent();
+    css::uno::Reference<css::uno::XInterface>  xParent = xFComp->getParent();
     if( !xParent.is() )
         return;
 
@@ -218,7 +210,7 @@ void OEditControl::keyPressed(const ::com::sun::star::awt::KeyEvent& e) throw (
         return;
 
     aTmp = xFormSet->getPropertyValue( PROPERTY_TARGET_URL );
-    if (!aTmp.getValueType().equals(::getCppuType((const OUString*)NULL)) ||
+    if (!aTmp.getValueType().equals(cppu::UnoType<OUString>::get()) ||
         getString(aTmp).isEmpty() )
         return;
 
@@ -246,67 +238,44 @@ void OEditControl::keyPressed(const ::com::sun::star::awt::KeyEvent& e) throw (
     // Because we're still in the header, trigger submit asynchronously
     if( m_nKeyEvent )
         Application::RemoveUserEvent( m_nKeyEvent );
-    m_nKeyEvent = Application::PostUserEvent( LINK(this, OEditControl,OnKeyPressed) );
+    m_nKeyEvent = Application::PostUserEvent( LINK(this, OEditControl, OnKeyPressed) );
 }
 
-//------------------------------------------------------------------------------
-void OEditControl::keyReleased(const ::com::sun::star::awt::KeyEvent& /*e*/) throw ( ::com::sun::star::uno::RuntimeException)
+
+void OEditControl::keyReleased(const css::awt::KeyEvent& /*e*/)
 {
 }
 
-//------------------------------------------------------------------------------
-IMPL_LINK(OEditControl, OnKeyPressed, void*, /*EMPTYARG*/)
+
+IMPL_LINK_NOARG(OEditControl, OnKeyPressed, void*, void)
 {
-    m_nKeyEvent = 0;
+    m_nKeyEvent = nullptr;
 
     Reference<XFormComponent>  xFComp(getModel(), UNO_QUERY);
-    InterfaceRef  xParent = xFComp->getParent();
+    css::uno::Reference<css::uno::XInterface>  xParent = xFComp->getParent();
     Reference<XSubmit>  xSubmit(xParent, UNO_QUERY);
     if (xSubmit.is())
-        xSubmit->submit( Reference<XControl>(), ::com::sun::star::awt::MouseEvent() );
-    return 0L;
-}
-
-//------------------------------------------------------------------
-void SAL_CALL OEditControl::createPeer( const Reference< XToolkit>& _rxToolkit, const Reference< XWindowPeer>& _rxParent ) throw ( RuntimeException )
-{
-    OBoundControl::createPeer(_rxToolkit, _rxParent);
-}
-
-/*************************************************************************/
-//------------------------------------------------------------------
-InterfaceRef SAL_CALL OEditModel_CreateInstance(const Reference<XMultiServiceFactory>& _rxFactory)
-{
-    return *(new OEditModel( comphelper::getComponentContext(_rxFactory) ));
-}
-
-//------------------------------------------------------------------------------
-Sequence<Type> OEditModel::_getTypes()
-{
-    return OEditBaseModel::_getTypes();
+        xSubmit->submit( Reference<XControl>(), css::awt::MouseEvent() );
 }
 
 
-DBG_NAME(OEditModel);
-//------------------------------------------------------------------
+
 OEditModel::OEditModel(const Reference<XComponentContext>& _rxFactory)
-    :OEditBaseModel( _rxFactory, FRM_SUN_COMPONENT_RICHTEXTCONTROL, FRM_SUN_CONTROL_TEXTFIELD, sal_True, sal_True )
-    ,m_bMaxTextLenModified(sal_False)
-    ,m_bWritingFormattedFake(sal_False)
+    :OEditBaseModel( _rxFactory, FRM_SUN_COMPONENT_RICHTEXTCONTROL, FRM_SUN_CONTROL_TEXTFIELD, true, true )
+    ,m_bMaxTextLenModified(false)
+    ,m_bWritingFormattedFake(false)
 {
-    DBG_CTOR(OEditModel,NULL);
 
     m_nClassId = FormComponentType::TEXTFIELD;
     initValueProperty( PROPERTY_TEXT, PROPERTY_ID_TEXT );
 }
 
-//------------------------------------------------------------------
+
 OEditModel::OEditModel( const OEditModel* _pOriginal, const Reference<XComponentContext>& _rxFactory )
     :OEditBaseModel( _pOriginal, _rxFactory )
-    ,m_bMaxTextLenModified(sal_False)
-    ,m_bWritingFormattedFake(sal_False)
+    ,m_bMaxTextLenModified(false)
+    ,m_bWritingFormattedFake(false)
 {
-    DBG_CTOR( OEditModel, NULL );
 
     // Note that most of the properties are not clone from the original object:
     // Things as the format key, it's type, and such, depend on the field being part of a loaded form
@@ -315,7 +284,7 @@ OEditModel::OEditModel( const OEditModel* _pOriginal, const Reference<XComponent
     // they will be set to new values, anyway ....
 }
 
-//------------------------------------------------------------------
+
 OEditModel::~OEditModel()
 {
     if (!OComponentHelper::rBHelper.bDisposed)
@@ -324,13 +293,12 @@ OEditModel::~OEditModel()
         dispose();
     }
 
-    DBG_DTOR(OEditModel,NULL);
 }
 
-//------------------------------------------------------------------------------
+
 IMPLEMENT_DEFAULT_CLONING( OEditModel )
 
-//------------------------------------------------------------------------------
+
 void OEditModel::disposing()
 {
     OEditBaseModel::disposing();
@@ -338,20 +306,20 @@ void OEditModel::disposing()
 }
 
 // XPersistObject
-//------------------------------------------------------------------------------
-OUString SAL_CALL OEditModel::getServiceName() throw ( ::com::sun::star::uno::RuntimeException)
+
+OUString SAL_CALL OEditModel::getServiceName()
 {
     return OUString(FRM_COMPONENT_EDIT);  // old (non-sun) name for compatibility !
 }
 
 // XServiceInfo
-//------------------------------------------------------------------------------
-StringSequence SAL_CALL OEditModel::getSupportedServiceNames() throw()
+
+css::uno::Sequence<OUString> SAL_CALL OEditModel::getSupportedServiceNames()
 {
-    StringSequence aSupported = OBoundControlModel::getSupportedServiceNames();
+    css::uno::Sequence<OUString> aSupported = OBoundControlModel::getSupportedServiceNames();
 
     sal_Int32 nOldLen = aSupported.getLength();
-    aSupported.realloc( nOldLen + 8 );
+    aSupported.realloc( nOldLen + 9 );
     OUString* pStoreTo = aSupported.getArray() + nOldLen;
 
     *pStoreTo++ = BINDABLE_CONTROL_MODEL;
@@ -365,6 +333,8 @@ StringSequence SAL_CALL OEditModel::getSupportedServiceNames() throw()
     *pStoreTo++ = FRM_SUN_COMPONENT_DATABASE_TEXTFIELD;
     *pStoreTo++ = BINDABLE_DATABASE_TEXT_FIELD;
 
+    *pStoreTo++ = FRM_COMPONENT_TEXTFIELD;
+
     return aSupported;
 }
 
@@ -384,7 +354,7 @@ void SAL_CALL OEditModel::getFastPropertyValue(Any& rValue, sal_Int32 nHandle )
     }
 }
 
-//------------------------------------------------------------------------------
+
 void OEditModel::describeFixedProperties( Sequence< Property >& _rProps ) const
 {
     BEGIN_DESCRIBE_PROPERTIES( 5, OEditBaseModel )
@@ -396,7 +366,7 @@ void OEditModel::describeFixedProperties( Sequence< Property >& _rProps ) const
     END_DESCRIBE_PROPERTIES();
 }
 
-//------------------------------------------------------------------------------
+
 void OEditModel::describeAggregateProperties( Sequence< Property >& _rAggregateProps ) const
 {
     OEditBaseModel::describeAggregateProperties( _rAggregateProps );
@@ -411,10 +381,10 @@ void OEditModel::describeAggregateProperties( Sequence< Property >& _rAggregateP
 
 }
 
-//------------------------------------------------------------------------------
+
 bool OEditModel::implActsAsRichText( ) const
 {
-    sal_Bool bActAsRichText = sal_False;
+    bool bActAsRichText = false;
     if ( m_xAggregateSet.is() )
     {
         OSL_VERIFY( m_xAggregateSet->getPropertyValue( PROPERTY_RICH_TEXT ) >>= bActAsRichText );
@@ -422,8 +392,8 @@ bool OEditModel::implActsAsRichText( ) const
     return bActAsRichText;
 }
 
-//------------------------------------------------------------------------------
-void SAL_CALL OEditModel::reset(  ) throw(RuntimeException)
+
+void SAL_CALL OEditModel::reset(  )
 {
     // no reset if we currently act as rich text control
     if ( implActsAsRichText() )
@@ -432,7 +402,7 @@ void SAL_CALL OEditModel::reset(  ) throw(RuntimeException)
     OEditBaseModel::reset();
 }
 
-//------------------------------------------------------------------------------
+
 namespace
 {
     void lcl_transferProperties( const Reference< XPropertySet >& _rxSource, const Reference< XPropertySet >& _rxDest )
@@ -454,45 +424,29 @@ namespace
             }
 
             Sequence< Property > aSourceProps( xSourceInfo->getProperties() );
-            const Property* pSourceProps = aSourceProps.getConstArray();
-            const Property* pSourcePropsEnd = aSourceProps.getConstArray() + aSourceProps.getLength();
-            while ( pSourceProps != pSourcePropsEnd )
+            for ( auto const & sourceprop : aSourceProps )
             {
-                if ( !xDestInfo->hasPropertyByName( pSourceProps->Name ) )
+                if ( !xDestInfo->hasPropertyByName( sourceprop.Name ) )
                 {
-                    ++pSourceProps;
                     continue;
                 }
 
-                Property aDestProp( xDestInfo->getPropertyByName( pSourceProps->Name ) );
+                Property aDestProp( xDestInfo->getPropertyByName( sourceprop.Name ) );
                 if ( 0 != ( aDestProp.Attributes & PropertyAttribute::READONLY ) )
                 {
-                    ++pSourceProps;
                     continue;
                 }
 
                 try
                 {
-                    _rxDest->setPropertyValue( pSourceProps->Name, _rxSource->getPropertyValue( pSourceProps->Name ) );
+                    _rxDest->setPropertyValue( sourceprop.Name, _rxSource->getPropertyValue( sourceprop.Name ) );
                 }
                 catch(const IllegalArgumentException& e)
                 {
-#if OSL_DEBUG_LEVEL > 0
-                    OString sMessage( "could not transfer the property named '" );
-                    sMessage += OString( pSourceProps->Name.getStr(), pSourceProps->Name.getLength(), RTL_TEXTENCODING_ASCII_US );
-                    sMessage += OString( "'." );
-                    if ( !e.Message.isEmpty() )
-                    {
-                        sMessage += OString( "\n\nMessage:\n" );
-                        sMessage += OString( e.Message.getStr(), e.Message.getLength(), RTL_TEXTENCODING_ASCII_US );
-                    }
-                    OSL_FAIL( sMessage.getStr() );
-#else
-                    (void)e;
-#endif
+                    SAL_WARN( "forms.component", "could not transfer the property named '"
+                                << sourceprop.Name
+                                << "'. " << e );
                 }
-
-                ++pSourceProps;
             }
         }
         catch( const Exception& )
@@ -502,14 +456,14 @@ namespace
     }
 }
 
-//------------------------------------------------------------------------------
+
 void OEditModel::writeAggregate( const Reference< XObjectOutputStream >& _rxOutStream ) const
 {
     // we need to fake the writing of our aggregate. Since #i24387#, we have another aggregate,
     // but for compatibility, we need to use an "old" aggregate for writing and reading
 
     Reference< XPropertySet > xFakedAggregate(
-        getContext()->getServiceManager()->createInstanceWithContext( (OUString)VCL_CONTROLMODEL_EDIT, getContext() ),
+        getContext()->getServiceManager()->createInstanceWithContext( VCL_CONTROLMODEL_EDIT, getContext() ),
         UNO_QUERY
     );
     OSL_ENSURE( xFakedAggregate.is(), "OEditModel::writeAggregate: could not create an old EditControlModel!" );
@@ -524,14 +478,14 @@ void OEditModel::writeAggregate( const Reference< XObjectOutputStream >& _rxOutS
         xFakedPersist->write( _rxOutStream );
 }
 
-//------------------------------------------------------------------------------
+
 void OEditModel::readAggregate( const Reference< XObjectInputStream >& _rxInStream )
 {
     // we need to fake the reading of our aggregate. Since #i24387#, we have another aggregate,
     // but for compatibility, we need to use an "old" aggregate for writing and reading
 
     Reference< XPropertySet > xFakedAggregate(
-        getContext()->getServiceManager()->createInstanceWithContext( (OUString)VCL_CONTROLMODEL_EDIT, getContext() ),
+        getContext()->getServiceManager()->createInstanceWithContext( VCL_CONTROLMODEL_EDIT, getContext() ),
         UNO_QUERY
     );
     Reference< XPersistObject > xFakedPersist( xFakedAggregate, UNO_QUERY );
@@ -543,8 +497,8 @@ void OEditModel::readAggregate( const Reference< XObjectInputStream >& _rxInStre
     }
 }
 
-//------------------------------------------------------------------------------
-void OEditModel::write(const Reference<XObjectOutputStream>& _rxOutStream) throw ( ::com::sun::star::io::IOException, ::com::sun::star::uno::RuntimeException)
+
+void OEditModel::write(const Reference<XObjectOutputStream>& _rxOutStream)
 {
     Any aCurrentText;
     sal_Int16 nOldTextLen = 0;
@@ -573,8 +527,8 @@ void OEditModel::write(const Reference<XObjectOutputStream>& _rxOutStream) throw
     }
 }
 
-//------------------------------------------------------------------------------
-void OEditModel::read(const Reference<XObjectInputStream>& _rxInStream) throw ( ::com::sun::star::io::IOException, ::com::sun::star::uno::RuntimeException)
+
+void OEditModel::read(const Reference<XObjectInputStream>& _rxInStream)
 {
     OEditBaseModel::read(_rxInStream);
 
@@ -588,14 +542,14 @@ void OEditModel::read(const Reference<XObjectInputStream>& _rxInStream) throw (
             &&  (getString(aDefaultControl) == STARDIV_ONE_FORM_CONTROL_TEXTFIELD )
             )
         {
-            m_xAggregateSet->setPropertyValue( PROPERTY_DEFAULTCONTROL, makeAny( (OUString)STARDIV_ONE_FORM_CONTROL_EDIT ) );
+            m_xAggregateSet->setPropertyValue( PROPERTY_DEFAULTCONTROL, makeAny( OUString(STARDIV_ONE_FORM_CONTROL_EDIT) ) );
             // Older as well as current versions should understand this : the former knew only the STARDIV_ONE_FORM_CONTROL_EDIT,
             // the latter are registered for both STARDIV_ONE_FORM_CONTROL_EDIT and STARDIV_ONE_FORM_CONTROL_TEXTFIELD.
         }
     }
 }
 
-//------------------------------------------------------------------------------
+
 sal_uInt16 OEditModel::getPersistenceFlags() const
 {
     sal_uInt16 nFlags = OEditBaseModel::getPersistenceFlags();
@@ -606,7 +560,7 @@ sal_uInt16 OEditModel::getPersistenceFlags() const
     return nFlags;
 }
 
-//------------------------------------------------------------------------------
+
 void OEditModel::onConnectedDbColumn( const Reference< XInterface >& _rxForm )
 {
     Reference< XPropertySet > xField = getField();
@@ -628,16 +582,16 @@ void OEditModel::onConnectedDbColumn( const Reference< XInterface >& _rxForm )
                     aVal <<= (sal_Int16)nFieldLen;
                     m_xAggregateSet->setPropertyValue(PROPERTY_MAXTEXTLEN, aVal);
 
-                    m_bMaxTextLenModified = sal_True;
+                    m_bMaxTextLenModified = true;
                 }
             }
             else
-                m_bMaxTextLenModified = sal_False; // to get sure that the text len won't be set in unloaded
+                m_bMaxTextLenModified = false; // to get sure that the text len won't be set in unloaded
         }
     }
 }
 
-//------------------------------------------------------------------------------
+
 void OEditModel::onDisconnectedDbColumn()
 {
     OEditBaseModel::onDisconnectedDbColumn();
@@ -649,28 +603,22 @@ void OEditModel::onDisconnectedDbColumn()
         Any aVal;
         aVal <<= (sal_Int16)0;  // Only if it was 0, I switched it in onConnectedDbColumn
         m_xAggregateSet->setPropertyValue(PROPERTY_MAXTEXTLEN, aVal);
-        m_bMaxTextLenModified = sal_False;
+        m_bMaxTextLenModified = false;
     }
 }
 
-//------------------------------------------------------------------------------
-sal_Bool OEditModel::approveDbColumnType( sal_Int32 _nColumnType )
+
+bool OEditModel::approveDbColumnType( sal_Int32 _nColumnType )
 {
     // if we act as rich text currently, we do not allow binding to a database column
     if ( implActsAsRichText() )
-        return sal_False;
+        return false;
 
     return OEditBaseModel::approveDbColumnType( _nColumnType );
 }
 
-//------------------------------------------------------------------------------
-void OEditModel::resetNoBroadcast()
-{
-    OEditBaseModel::resetNoBroadcast();
-}
 
-//------------------------------------------------------------------------------
-sal_Bool OEditModel::commitControlValueToDbColumn( bool /*_bPostReset*/ )
+bool OEditModel::commitControlValueToDbColumn( bool /*_bPostReset*/ )
 {
     Any aNewValue( m_xAggregateFastSet->getFastPropertyValue( getValuePropertyAggHandle() ) );
 
@@ -693,21 +641,21 @@ sal_Bool OEditModel::commitControlValueToDbColumn( bool /*_bPostReset*/ )
             if ( m_pValueFormatter.get() )
             {
                 if ( !m_pValueFormatter->setFormattedValue( sNewValue ) )
-                    return sal_False;
+                    return false;
             }
             else
                 m_xColumnUpdate->updateString( sNewValue );
         }
         catch ( const Exception& )
         {
-            return sal_False;
+            return false;
         }
     }
 
-    return sal_True;
+    return true;
 }
 
-//------------------------------------------------------------------------------
+
 Any OEditModel::translateDbColumnToControlValue()
 {
     OSL_PRECOND( m_pValueFormatter.get(), "OEditModel::translateDbColumnToControlValue: no value formatter!" );
@@ -738,14 +686,26 @@ Any OEditModel::translateDbColumnToControlValue()
     return aRet.hasValue() ? aRet : makeAny( OUString() );
 }
 
-//------------------------------------------------------------------------------
+
 Any OEditModel::getDefaultForReset() const
 {
     return makeAny( m_aDefaultText );
 }
 
-//.........................................................................
 }
-//.........................................................................
+
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
+com_sun_star_form_OEditModel_get_implementation(css::uno::XComponentContext* component,
+        css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new frm::OEditModel(component));
+}
+
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
+com_sun_star_form_OEditControl_get_implementation(css::uno::XComponentContext* component,
+        css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new frm::OEditControl(component));
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
