@@ -19,35 +19,28 @@
 
 
 #include "navbarcontrol.hxx"
-#include "frm_strings.hxx"
-#include "frm_module.hxx"
-#include "FormComponent.hxx"
-#include "componenttools.hxx"
-#include "navtoolbar.hxx"
-#include "commandimageprovider.hxx"
-#include "commanddescriptionprovider.hxx"
+#include <frm_strings.hxx>
+#include <FormComponent.hxx>
+#include <componenttools.hxx>
+#include <navtoolbar.hxx>
+#include <commandimageprovider.hxx>
 
 #include <com/sun/star/awt/XView.hpp>
 #include <com/sun/star/awt/PosSize.hpp>
 #include <com/sun/star/form/runtime/FormFeature.hpp>
 #include <com/sun/star/awt/XControlModel.hpp>
 #include <com/sun/star/graphic/XGraphic.hpp>
+#include <com/sun/star/frame/ModuleManager.hpp>
 
 #include <comphelper/processfactory.hxx>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
 #include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
 
-//--------------------------------------------------------------------------
-extern "C" void SAL_CALL createRegistryInfo_ONavigationBarControl()
-{
-    static ::frm::OMultiInstanceAutoRegistration< ::frm::ONavigationBarControl > aAutoRegistration;
-}
 
-//.........................................................................
 namespace frm
 {
-//.........................................................................
 
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::beans;
@@ -64,28 +57,21 @@ namespace frm
         xTypedPeer->method( param1 );  \
     }
 
-    //==================================================================
-    // ONavigationBarControl
-    //==================================================================
-    DBG_NAME( ONavigationBarControl )
-    //------------------------------------------------------------------
     ONavigationBarControl::ONavigationBarControl( const Reference< XComponentContext >& _rxORB)
         :UnoControl(), m_xContext(_rxORB)
     {
-        DBG_CTOR( ONavigationBarControl, NULL );
     }
 
-    //------------------------------------------------------------------
+
     ONavigationBarControl::~ONavigationBarControl()
     {
-        DBG_DTOR( ONavigationBarControl, NULL );
     }
 
-    //------------------------------------------------------------------
+
     IMPLEMENT_FORWARD_XTYPEPROVIDER2( ONavigationBarControl, UnoControl, ONavigationBarControl_Base )
 
-    //------------------------------------------------------------------
-    Any SAL_CALL ONavigationBarControl::queryAggregation( const Type& _rType ) throw ( RuntimeException )
+
+    Any SAL_CALL ONavigationBarControl::queryAggregation( const Type& _rType )
     {
         Any aReturn = UnoControl::queryAggregation( _rType );
 
@@ -95,11 +81,11 @@ namespace frm
         return aReturn;
     }
 
-    //------------------------------------------------------------------
+
     namespace
     {
-        //..............................................................
-        static WinBits lcl_getWinBits_nothrow( const Reference< XControlModel >& _rxModel )
+
+        WinBits lcl_getWinBits_nothrow( const Reference< XControlModel >& _rxModel )
         {
             WinBits nBits = 0;
             try
@@ -112,7 +98,7 @@ namespace frm
                     if ( nBorder )
                         nBits |= WB_BORDER;
 
-                    sal_Bool bTabStop = sal_False;
+                    bool bTabStop = false;
                     if ( xProps->getPropertyValue( PROPERTY_TABSTOP ) >>= bTabStop )
                         nBits |= ( bTabStop ? WB_TABSTOP : WB_NOTABSTOP );
                 }
@@ -125,34 +111,31 @@ namespace frm
         }
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL ONavigationBarControl::createPeer( const Reference< XToolkit >& /*_rToolkit*/, const Reference< XWindowPeer >& _rParentPeer ) throw( RuntimeException )
+
+    void SAL_CALL ONavigationBarControl::createPeer( const Reference< XToolkit >& /*_rToolkit*/, const Reference< XWindowPeer >& _rParentPeer )
     {
         SolarMutexGuard aGuard;
 
         if (!getPeer().is())
         {
-            mbCreatingPeer = sal_True;
+            mbCreatingPeer = true;
 
             // determine the VLC window for the parent
-            Window* pParentWin = NULL;
+            vcl::Window* pParentWin = nullptr;
             if ( _rParentPeer.is() )
             {
                 VCLXWindow* pParentXWin = VCLXWindow::GetImplementation( _rParentPeer );
                 if ( pParentXWin )
-                    pParentWin = pParentXWin->GetWindow();
+                    pParentWin = pParentXWin->GetWindow().get();
                 DBG_ASSERT( pParentWin, "ONavigationBarControl::createPeer: could not obtain the VCL-level parent window!" );
             }
 
             // create the peer
-            ONavigationBarPeer* pPeer = ONavigationBarPeer::Create( m_xContext, pParentWin, getModel() );
-            DBG_ASSERT( pPeer, "ONavigationBarControl::createPeer: invalid peer returned!" );
-            if ( pPeer )
-                // by definition, the returned component is aquired once
-                pPeer->release();
+            rtl::Reference<ONavigationBarPeer> pPeer = ONavigationBarPeer::Create( m_xContext, pParentWin, getModel() );
+            assert(pPeer && "ONavigationBarControl::createPeer: invalid peer returned!");
 
             // announce the peer to the base class
-            setPeer( pPeer );
+            setPeer( pPeer.get() );
 
             // initialize ourself (and thus the peer) with the model properties
             updateFromModel();
@@ -173,90 +156,69 @@ namespace frm
 
             peerCreated();
 
-            mbCreatingPeer = sal_False;
-
-            OControl::initFormControlPeer( getPeer() );
+            mbCreatingPeer = false;
         }
     }
 
-    //------------------------------------------------------------------
-    OUString SAL_CALL ONavigationBarControl::getImplementationName()  throw( RuntimeException )
-    {
-        return getImplementationName_Static();
-    }
 
-    //------------------------------------------------------------------
-    Sequence< OUString > SAL_CALL ONavigationBarControl::getSupportedServiceNames()  throw( RuntimeException )
-    {
-        return getSupportedServiceNames_Static();
-    }
-
-    //------------------------------------------------------------------
-    OUString SAL_CALL ONavigationBarControl::getImplementationName_Static()
+    OUString SAL_CALL ONavigationBarControl::getImplementationName()
     {
         return OUString( "com.sun.star.comp.form.ONavigationBarControl" );
     }
 
-    //------------------------------------------------------------------
-    Sequence< OUString > SAL_CALL ONavigationBarControl::getSupportedServiceNames_Static()
+
+    Sequence< OUString > SAL_CALL ONavigationBarControl::getSupportedServiceNames()
     {
-        Sequence< OUString > aServices( 2 );
-        aServices[ 0 ] = "com.sun.star.awt.UnoControl";
-        aServices[ 1 ] = "com.sun.star.form.control.NavigationToolBar";
-        return aServices;
+        return { "com.sun.star.awt.UnoControl",
+        "com.sun.star.form.control.NavigationToolBar" };
     }
 
-    //------------------------------------------------------------------
-    Reference< XInterface > SAL_CALL ONavigationBarControl::Create( const Reference< XMultiServiceFactory >& _rxFactory )
-    {
-        return *( new ONavigationBarControl( comphelper::getComponentContext(_rxFactory) ) );
-    }
 
-    //------------------------------------------------------------------
-    void SAL_CALL ONavigationBarControl::registerDispatchProviderInterceptor( const Reference< XDispatchProviderInterceptor >& _rxInterceptor ) throw (RuntimeException)
+    void SAL_CALL ONavigationBarControl::registerDispatchProviderInterceptor( const Reference< XDispatchProviderInterceptor >& _rxInterceptor )
     {
         FORWARD_TO_PEER_1( XDispatchProviderInterception, registerDispatchProviderInterceptor, _rxInterceptor );
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL ONavigationBarControl::releaseDispatchProviderInterceptor( const Reference< XDispatchProviderInterceptor >& _rxInterceptor ) throw (RuntimeException)
+
+    void SAL_CALL ONavigationBarControl::releaseDispatchProviderInterceptor( const Reference< XDispatchProviderInterceptor >& _rxInterceptor )
     {
         FORWARD_TO_PEER_1( XDispatchProviderInterception, releaseDispatchProviderInterceptor, _rxInterceptor );
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL ONavigationBarControl::setDesignMode( sal_Bool _bOn ) throw( RuntimeException )
+
+    void SAL_CALL ONavigationBarControl::setDesignMode( sal_Bool _bOn )
     {
         UnoControl::setDesignMode( _bOn );
         FORWARD_TO_PEER_1( XVclWindowPeer, setDesignMode, _bOn );
     }
 
-    //==================================================================
+
     // ONavigationBarPeer
-    //==================================================================
-    DBG_NAME( ONavigationBarPeer )
-    //------------------------------------------------------------------
-    ONavigationBarPeer* ONavigationBarPeer::Create( const Reference< XComponentContext >& _rxORB,
-        Window* _pParentWindow, const Reference< XControlModel >& _rxModel )
+
+
+    rtl::Reference<ONavigationBarPeer> ONavigationBarPeer::Create( const Reference< XComponentContext >& _rxORB,
+        vcl::Window* _pParentWindow, const Reference< XControlModel >& _rxModel )
     {
         DBG_TESTSOLARMUTEX();
 
         // the peer itself
-        ONavigationBarPeer* pPeer = new ONavigationBarPeer( _rxORB );
-        pPeer->acquire();   // by definition, the returned object is aquired once
+        rtl::Reference<ONavigationBarPeer> pPeer(new ONavigationBarPeer( _rxORB ));
 
         // the VCL control for the peer
         Reference< XModel > xContextDocument( getXModel( _rxModel ) );
-        NavigationToolBar* pNavBar = new NavigationToolBar(
+        Reference< XModuleManager2 > xModuleManager( ModuleManager::create(_rxORB) );
+        OUString sModuleID = xModuleManager->identify( xContextDocument );
+
+        VclPtrInstance<NavigationToolBar> pNavBar(
             _pParentWindow,
             lcl_getWinBits_nothrow( _rxModel ),
             createDocumentCommandImageProvider( _rxORB, xContextDocument ),
-            createDocumentCommandDescriptionProvider( _rxORB, xContextDocument )
+            sModuleID
         );
 
         // some knittings
-        pNavBar->setDispatcher( pPeer );
-        pNavBar->SetComponentInterface( pPeer );
+        pNavBar->setDispatcher( pPeer.get() );
+        pNavBar->SetComponentInterface( pPeer.get() );
 
         // we want a faster repeating rate for the slots in this
         // toolbox
@@ -264,44 +226,42 @@ namespace frm
         MouseSettings aMouseSettings = aSettings.GetMouseSettings();
         aMouseSettings.SetButtonRepeat( 10 );
         aSettings.SetMouseSettings( aMouseSettings );
-        pNavBar->SetSettings( aSettings, sal_True );
+        pNavBar->SetSettings( aSettings, true );
 
         // outta here
         return pPeer;
     }
 
-    //------------------------------------------------------------------
+
     ONavigationBarPeer::ONavigationBarPeer( const Reference< XComponentContext >& _rxORB )
         :OFormNavigationHelper( _rxORB )
     {
-        DBG_CTOR( ONavigationBarPeer, NULL );
     }
 
-    //------------------------------------------------------------------
+
     ONavigationBarPeer::~ONavigationBarPeer()
     {
-        DBG_DTOR( ONavigationBarPeer, NULL );
     }
 
-    //------------------------------------------------------------------
+
     IMPLEMENT_FORWARD_XINTERFACE2( ONavigationBarPeer, VCLXWindow, OFormNavigationHelper )
 
-    //------------------------------------------------------------------
+
     IMPLEMENT_FORWARD_XTYPEPROVIDER2( ONavigationBarPeer, VCLXWindow, OFormNavigationHelper )
 
-    //------------------------------------------------------------------
-    void SAL_CALL ONavigationBarPeer::dispose(  ) throw( RuntimeException )
+
+    void SAL_CALL ONavigationBarPeer::dispose(  )
     {
         VCLXWindow::dispose();
         OFormNavigationHelper::dispose();
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL ONavigationBarPeer::setProperty( const OUString& _rPropertyName, const Any& _rValue ) throw( RuntimeException )
+
+    void SAL_CALL ONavigationBarPeer::setProperty( const OUString& _rPropertyName, const Any& _rValue )
     {
         SolarMutexGuard aGuard;
 
-        NavigationToolBar* pNavBar = static_cast< NavigationToolBar* >( GetWindow() );
+        VclPtr< NavigationToolBar > pNavBar = GetAs< NavigationToolBar >();
         if ( !pNavBar )
         {
             VCLXWindow::setProperty( _rPropertyName, _rValue );
@@ -310,13 +270,13 @@ namespace frm
 
         bool bVoid = !_rValue.hasValue();
 
-        sal_Bool  bBoolValue = sal_False;
+        bool  bBoolValue = false;
         sal_Int32 nColor = COL_TRANSPARENT;
 
         // TODO: more generic mechanisms for this (the grid control implementation,
         // when used herein, will do the same stuff for lot of these)
 
-        if ( _rPropertyName.equals( PROPERTY_BACKGROUNDCOLOR ) )
+        if ( _rPropertyName == PROPERTY_BACKGROUNDCOLOR )
         {
             Wallpaper aTest = pNavBar->GetBackground();
             if ( bVoid )
@@ -332,7 +292,7 @@ namespace frm
                 pNavBar->SetControlBackground( aColor );
             }
         }
-        else if ( _rPropertyName.equals( PROPERTY_TEXTLINECOLOR ) )
+        else if ( _rPropertyName == PROPERTY_TEXTLINECOLOR )
         {
             if ( bVoid )
             {
@@ -344,28 +304,28 @@ namespace frm
                 pNavBar->SetTextLineColor( nColor );
             }
         }
-        else if ( _rPropertyName.equals( PROPERTY_ICONSIZE ) )
+        else if ( _rPropertyName == PROPERTY_ICONSIZE )
         {
             sal_Int16 nInt16Value = 0;
             OSL_VERIFY( _rValue >>= nInt16Value );
             pNavBar->SetImageSize( nInt16Value ? NavigationToolBar::eLarge : NavigationToolBar::eSmall );
         }
-        else if ( _rPropertyName.equals( PROPERTY_SHOW_POSITION ) )
+        else if ( _rPropertyName == PROPERTY_SHOW_POSITION )
         {
             OSL_VERIFY( _rValue >>= bBoolValue );
             pNavBar->ShowFunctionGroup( NavigationToolBar::ePosition, bBoolValue );
         }
-        else if ( _rPropertyName.equals( PROPERTY_SHOW_NAVIGATION ) )
+        else if ( _rPropertyName == PROPERTY_SHOW_NAVIGATION )
         {
             OSL_VERIFY( _rValue >>= bBoolValue );
             pNavBar->ShowFunctionGroup( NavigationToolBar::eNavigation, bBoolValue );
         }
-        else if ( _rPropertyName.equals( PROPERTY_SHOW_RECORDACTIONS ) )
+        else if ( _rPropertyName == PROPERTY_SHOW_RECORDACTIONS )
         {
             OSL_VERIFY( _rValue >>= bBoolValue );
             pNavBar->ShowFunctionGroup( NavigationToolBar::eRecordActions, bBoolValue );
         }
-        else if ( _rPropertyName.equals( PROPERTY_SHOW_FILTERSORT ) )
+        else if ( _rPropertyName == PROPERTY_SHOW_FILTERSORT )
         {
             OSL_VERIFY( _rValue >>= bBoolValue );
             pNavBar->ShowFunctionGroup( NavigationToolBar::eFilterSort, bBoolValue );
@@ -376,43 +336,43 @@ namespace frm
         }
     }
 
-    //------------------------------------------------------------------
-    Any SAL_CALL ONavigationBarPeer::getProperty( const OUString& _rPropertyName ) throw( RuntimeException )
+
+    Any SAL_CALL ONavigationBarPeer::getProperty( const OUString& _rPropertyName )
     {
         SolarMutexGuard aGuard;
 
         Any aReturn;
-        NavigationToolBar* pNavBar = static_cast< NavigationToolBar* >( GetWindow() );
+        VclPtr< NavigationToolBar > pNavBar = GetAs< NavigationToolBar >();
 
-        if ( _rPropertyName.equals( PROPERTY_BACKGROUNDCOLOR ) )
+        if ( _rPropertyName == PROPERTY_BACKGROUNDCOLOR )
         {
             aReturn <<= (sal_Int32)pNavBar->GetControlBackground().GetColor();
         }
-        else if ( _rPropertyName.equals( PROPERTY_TEXTLINECOLOR ) )
+        else if ( _rPropertyName == PROPERTY_TEXTLINECOLOR )
         {
             aReturn <<= (sal_Int32)pNavBar->GetTextLineColor().GetColor();
         }
-        else if ( _rPropertyName.equals( PROPERTY_ICONSIZE ) )
+        else if ( _rPropertyName == PROPERTY_ICONSIZE )
         {
             sal_Int16 nIconType = ( NavigationToolBar::eLarge == pNavBar->GetImageSize() )
                                 ? 1 : 0;
             aReturn <<= nIconType;
         }
-        else if ( _rPropertyName.equals( PROPERTY_SHOW_POSITION ) )
+        else if ( _rPropertyName == PROPERTY_SHOW_POSITION )
         {
-            aReturn <<= (sal_Bool)( pNavBar->IsFunctionGroupVisible( NavigationToolBar::ePosition ) );
+            aReturn <<= pNavBar->IsFunctionGroupVisible( NavigationToolBar::ePosition );
         }
-        else if ( _rPropertyName.equals( PROPERTY_SHOW_NAVIGATION ) )
+        else if ( _rPropertyName == PROPERTY_SHOW_NAVIGATION )
         {
-            aReturn <<= (sal_Bool)( pNavBar->IsFunctionGroupVisible( NavigationToolBar::eNavigation ) );
+            aReturn <<= pNavBar->IsFunctionGroupVisible( NavigationToolBar::eNavigation );
         }
-        else if ( _rPropertyName.equals( PROPERTY_SHOW_RECORDACTIONS ) )
+        else if ( _rPropertyName == PROPERTY_SHOW_RECORDACTIONS )
         {
-            aReturn <<= (sal_Bool)( pNavBar->IsFunctionGroupVisible( NavigationToolBar::eRecordActions ) );
+            aReturn <<= pNavBar->IsFunctionGroupVisible( NavigationToolBar::eRecordActions );
         }
-        else if ( _rPropertyName.equals( PROPERTY_SHOW_FILTERSORT ) )
+        else if ( _rPropertyName == PROPERTY_SHOW_FILTERSORT )
         {
-            aReturn <<= (sal_Bool)( pNavBar->IsFunctionGroupVisible( NavigationToolBar::eFilterSort ) );
+            aReturn <<= pNavBar->IsFunctionGroupVisible( NavigationToolBar::eFilterSort );
         }
         else
             aReturn = VCLXWindow::getProperty( _rPropertyName );
@@ -420,7 +380,7 @@ namespace frm
         return aReturn;
     }
 
-    //------------------------------------------------------------------
+
     void ONavigationBarPeer::interceptorsChanged( )
     {
         if ( isDesignMode() )
@@ -430,11 +390,11 @@ namespace frm
         OFormNavigationHelper::interceptorsChanged();
     }
 
-    //------------------------------------------------------------------
-    void ONavigationBarPeer::featureStateChanged( sal_Int16 _nFeatureId, sal_Bool _bEnabled )
+
+    void ONavigationBarPeer::featureStateChanged( sal_Int16 _nFeatureId, bool _bEnabled )
     {
         // enable this button on the toolbox
-        NavigationToolBar* pNavBar = static_cast< NavigationToolBar* >( GetWindow() );
+        VclPtr< NavigationToolBar > pNavBar = GetAs< NavigationToolBar >();
         if ( pNavBar )
         {
             pNavBar->enableFeature( _nFeatureId, _bEnabled );
@@ -458,19 +418,22 @@ namespace frm
         OFormNavigationHelper::featureStateChanged( _nFeatureId, _bEnabled );
     }
 
-    //------------------------------------------------------------------
+
     void ONavigationBarPeer::allFeatureStatesChanged( )
     {
-        // force the control to update it's states
-        NavigationToolBar* pNavBar = static_cast< NavigationToolBar* >( GetWindow() );
-        if ( pNavBar )
-            pNavBar->setDispatcher( this );
+        {
+            // force the control to update it's states
+            SolarMutexGuard g;
+            VclPtr< NavigationToolBar > pNavBar = GetAs< NavigationToolBar >();
+            if ( pNavBar )
+                pNavBar->setDispatcher( this );
+        }
 
         // base class
         OFormNavigationHelper::allFeatureStatesChanged( );
     }
 
-    //------------------------------------------------------------------
+
     bool ONavigationBarPeer::isEnabled( sal_Int16 _nFeatureId ) const
     {
         if ( const_cast< ONavigationBarPeer* >( this )->isDesignMode() )
@@ -479,8 +442,8 @@ namespace frm
         return OFormNavigationHelper::isEnabled( _nFeatureId );
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL ONavigationBarPeer::setDesignMode( sal_Bool _bOn ) throw( RuntimeException )
+
+    void SAL_CALL ONavigationBarPeer::setDesignMode( sal_Bool _bOn )
     {
         VCLXWindow::setDesignMode( _bOn  );
 
@@ -491,14 +454,14 @@ namespace frm
             // this will connect if not already connected and just update else
     }
 
-    //------------------------------------------------------------------
-    void SAL_CALL ONavigationBarPeer::disposing( const EventObject& _rSource ) throw (RuntimeException)
+
+    void SAL_CALL ONavigationBarPeer::disposing( const EventObject& _rSource )
     {
         VCLXWindow::disposing( _rSource );
         OFormNavigationHelper::disposing( _rSource );
     }
 
-    //------------------------------------------------------------------
+
     void ONavigationBarPeer::getSupportedFeatures( ::std::vector< sal_Int16 >& _rFeatureIds )
     {
         _rFeatureIds.push_back( FormFeature::MoveAbsolute );
@@ -522,8 +485,14 @@ namespace frm
         _rFeatureIds.push_back( FormFeature::RemoveFilterAndSort );
     }
 
-//.........................................................................
 }   // namespace frm
-//.........................................................................
+
+
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
+com_sun_star_comp_form_ONavigationBarControl_get_implementation (css::uno::XComponentContext* context,
+                                                                 css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new frm::ONavigationBarControl(context));
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
