@@ -37,6 +37,8 @@
 #include <algorithm>
 #include <functional>
 
+#include <com/sun/star/form/binding/IncompatibleTypesException.hpp>
+#include <com/sun/star/form/binding/InvalidBindingStateException.hpp>
 #include <com/sun/star/uno/Any.hxx>
 #include <com/sun/star/xml/dom/XNodeList.hpp>
 #include <com/sun/star/xml/dom/XNode.hpp>
@@ -48,7 +50,6 @@
 #include <com/sun/star/xml/dom/events/XDocumentEvent.hpp>
 #include <com/sun/star/lang/XUnoTunnel.hpp>
 #include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
-#include <com/sun/star/container/XSet.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
 
 #include <comphelper/propertysetinfo.hxx>
@@ -64,20 +65,13 @@ using xforms::MIP;
 using xforms::Model;
 using xforms::getResource;
 using xforms::EvaluationContext;
-using com::sun::star::beans::PropertyVetoException;
-using com::sun::star::beans::UnknownPropertyException;
 using com::sun::star::beans::XPropertySet;
-using com::sun::star::container::XSet;
 using com::sun::star::container::XNameAccess;
 using com::sun::star::form::binding::IncompatibleTypesException;
 using com::sun::star::form::binding::InvalidBindingStateException;
 using com::sun::star::form::binding::XValueBinding;
 using com::sun::star::lang::EventObject;
-using com::sun::star::lang::IllegalArgumentException;
 using com::sun::star::lang::IndexOutOfBoundsException;
-using com::sun::star::lang::NoSupportException;
-using com::sun::star::lang::NullPointerException;
-using com::sun::star::lang::WrappedTargetException;
 using com::sun::star::lang::XUnoTunnel;
 using com::sun::star::uno::Any;
 using com::sun::star::uno::Reference;
@@ -99,9 +93,7 @@ using com::sun::star::xml::dom::events::XEventTarget;
 using com::sun::star::xsd::XDataType;
 
 
-
-
-#define EXCEPT(msg) OUString(msg),static_cast<XValueBinding*>(this)
+#define EXCEPT(msg) msg,static_cast<XValueBinding*>(this)
 
 #define HANDLE_BindingID 0
 #define HANDLE_BindingExpression 1
@@ -295,7 +287,6 @@ OUString Binding::explainInvalid()
 }
 
 
-
 EvaluationContext Binding::getEvaluationContext() const
 {
     OSL_ENSURE( getModelImpl() != nullptr, "need model impl" );
@@ -329,9 +320,6 @@ Binding* SAL_CALL Binding::getBinding( const Reference<XPropertySet>& xPropertyS
 }
 
 
-
-
-
 void Binding::setBindingID( const OUString& sBindingID )
 {
     msBindingID = sBindingID;
@@ -462,19 +450,11 @@ bool Binding::getExternalData() const
 
 
 void Binding::checkLive()
-    throw( RuntimeException )
 {
     if( ! isLive() )
         throw RuntimeException( EXCEPT("Binding not initialized") );
 }
 
-void Binding::checkModel()
-    throw( RuntimeException )
-{
-    if( ! mxModel.is() )
-        throw RuntimeException( EXCEPT("Binding has no Model") );
-}
-
 bool Binding::isLive() const
 {
     const Model* pModel = getModelImpl();
@@ -496,8 +476,8 @@ Model* Binding::getModelImpl( const css::uno::Reference<css::xforms::XModel>& xM
     return pModel;
 }
 
-static void lcl_addListenerToNode( Reference<XNode> xNode,
-                            Reference<XEventListener> xListener )
+static void lcl_addListenerToNode( const Reference<XNode>& xNode,
+                                   const Reference<XEventListener>& xListener )
 {
     Reference<XEventTarget> xTarget( xNode, UNO_QUERY );
     if( xTarget.is() )
@@ -517,8 +497,8 @@ static void lcl_addListenerToNode( Reference<XNode> xNode,
     }
 }
 
-static void lcl_removeListenerFromNode( Reference<XNode> xNode,
-                                 Reference<XEventListener> xListener )
+static void lcl_removeListenerFromNode( const Reference<XNode>& xNode,
+                                        const Reference<XEventListener>& xListener )
 {
     Reference<XEventTarget> xTarget( xNode, UNO_QUERY );
     if( xTarget.is() )
@@ -552,16 +532,15 @@ static void lcl_removeListenerFromNode( Reference<XNode> xNode,
         OSL_ENSURE( aIter->is(), "no node?" );
 
         // create proper evaluation context for this MIP
-        aVector.push_back( EvaluationContext( *aIter, getModel(),
-                                              getBindingNamespaces(),
-                                              nCount, aNodes.size() ) );
+        aVector.emplace_back( *aIter, getModel(), getBindingNamespaces() );
     }
     return aVector;
 }
 
 void Binding::bind( bool bForceRebind )
 {
-    checkModel();
+    if( ! mxModel.is() )
+        throw RuntimeException( EXCEPT("Binding has no Model") );
 
     // bind() will evaluate this binding as follows:
     // 1) evaluate the binding expression
@@ -610,9 +589,8 @@ void Binding::bind( bool bForceRebind )
                  ++aIter )
                 maEventNodes.push_back( *aIter );
         else
-            maEventNodes.push_back(
-                Reference<XNode>( aContext.mxContextNode->getOwnerDocument(),
-                                  UNO_QUERY_THROW ) );
+            maEventNodes.emplace_back( aContext.mxContextNode->getOwnerDocument(),
+                                  UNO_QUERY_THROW );
         for( PathExpression::NodeVector_t::iterator aIter2 = maEventNodes.begin();
              aIter2 != maEventNodes.end();
              ++aIter2 )
@@ -727,9 +705,8 @@ void Binding::valueModified()
 
 void Binding::distributeMIP( const css::uno::Reference<css::xml::dom::XNode> & rxNode ) {
 
-    OUString sEventName("xforms-generic");
     css::xforms::XFormsEventConcrete *pEvent = new css::xforms::XFormsEventConcrete;
-    pEvent->initXFormsEvent(sEventName, sal_True, sal_False);
+    pEvent->initXFormsEvent("xforms-generic", true, false);
     Reference<XEvent> xEvent(pEvent);
 
     // naive depth-first traversal
@@ -854,7 +831,7 @@ void Binding::clear()
 
 
 static void lcl_removeOtherNamespaces( const css::uno::Reference<css::container::XNameContainer>& xFrom,
-                                css::uno::Reference<css::container::XNameContainer>& xTo )
+                                css::uno::Reference<css::container::XNameContainer> const & xTo )
 {
     OSL_ENSURE( xFrom.is(), "no source" );
     OSL_ENSURE( xTo.is(), "no target" );
@@ -881,7 +858,7 @@ static void lcl_removeOtherNamespaces( const css::uno::Reference<css::container:
  *                    false: use only elements from target
  */
 static void lcl_copyNamespaces( const css::uno::Reference<css::container::XNameContainer>& xFrom,
-                         css::uno::Reference<css::container::XNameContainer>& xTo,
+                         css::uno::Reference<css::container::XNameContainer> const & xTo,
                          bool bOverwrite )
 {
     OSL_ENSURE( xFrom.is(), "no source" );
@@ -1009,27 +986,20 @@ void Binding::_checkBindingID()
 }
 
 
-
-
-
 // XValueBinding
 
 
 css::uno::Sequence<css::uno::Type> Binding::getSupportedValueTypes()
-    throw( RuntimeException, std::exception )
 {
     return Convert::get().getTypes();
 }
 
 sal_Bool Binding::supportsType( const css::uno::Type& rType )
-    throw( RuntimeException, std::exception )
 {
     return Convert::get().hasType( rType );
 }
 
 css::uno::Any Binding::getValue( const css::uno::Type& rType )
-    throw( IncompatibleTypesException,
-           RuntimeException, std::exception )
 {
     // first, check for model
     checkLive();
@@ -1050,10 +1020,6 @@ css::uno::Any Binding::getValue( const css::uno::Type& rType )
 }
 
 void Binding::setValue( const css::uno::Any& aValue )
-    throw( IncompatibleTypesException,
-           InvalidBindingStateException,
-           NoSupportException,
-           RuntimeException, std::exception )
 {
     // first, check for model
     checkLive();
@@ -1062,30 +1028,26 @@ void Binding::setValue( const css::uno::Any& aValue )
     if( ! supportsType( aValue.getValueType() ) )
         throw IncompatibleTypesException( EXCEPT( "type unsupported" ) );
 
-    if( maBindingExpression.hasValue() )
-    {
-        css::uno::Reference<css::xml::dom::XNode> xNode = maBindingExpression.getNode();
-        if( xNode.is() )
-        {
-            OUString sValue = Convert::get().toXSD( aValue );
-            bool bSuccess = getModelImpl()->setSimpleContent( xNode, sValue );
-            if( ! bSuccess )
-                throw InvalidBindingStateException( EXCEPT( "can't set value" ) );
-        }
-        else
-            throw InvalidBindingStateException( EXCEPT( "no suitable node found" ) );
-    }
-    else
+    if( !maBindingExpression.hasValue() )
         throw InvalidBindingStateException( EXCEPT( "no suitable node found" ) );
-}
 
+    css::uno::Reference<css::xml::dom::XNode> xNode = maBindingExpression.getNode();
+    if( !xNode.is() )
+        throw InvalidBindingStateException( EXCEPT( "no suitable node found" ) );
+
+    OUString sValue = Convert::get().toXSD( aValue );
+    bool bSuccess = getModelImpl()->setSimpleContent( xNode, sValue );
+    if( ! bSuccess )
+        throw InvalidBindingStateException( EXCEPT( "can't set value" ) );
+
+
+}
 
 
 // XListEntry Source
 
 
 sal_Int32 Binding::getListEntryCount()
-    throw( RuntimeException, std::exception )
 {
     // first, check for model
     checkLive();
@@ -1120,8 +1082,6 @@ static OUString lcl_getString( const Reference<XNode>& xNode )
 }
 
 OUString Binding::getListEntry( sal_Int32 nPosition )
-    throw( IndexOutOfBoundsException,
-           RuntimeException, std::exception )
 {
     // first, check for model
     checkLive();
@@ -1134,7 +1094,6 @@ OUString Binding::getListEntry( sal_Int32 nPosition )
 }
 
 Sequence<OUString> Binding::getAllListEntries()
-    throw( RuntimeException, std::exception )
 {
     // first, check for model
     checkLive();
@@ -1152,8 +1111,6 @@ Sequence<OUString> Binding::getAllListEntries()
 }
 
 void Binding::addListEntryListener( const css::uno::Reference<css::form::binding::XListEntryListener>& xListener )
-    throw( NullPointerException,
-           RuntimeException, std::exception )
 {
     OSL_ENSURE( xListener.is(), "need listener!" );
     if( ::std::find( maListEntryListeners.begin(),
@@ -1164,8 +1121,6 @@ void Binding::addListEntryListener( const css::uno::Reference<css::form::binding
 }
 
 void Binding::removeListEntryListener( const css::uno::Reference<css::form::binding::XListEntryListener>& xListener )
-    throw( NullPointerException,
-           RuntimeException, std::exception )
 {
     XListEntryListeners_t::iterator aIter =
         ::std::find( maListEntryListeners.begin(), maListEntryListeners.end(),
@@ -1175,12 +1130,10 @@ void Binding::removeListEntryListener( const css::uno::Reference<css::form::bind
 }
 
 
-
 // XValidator
 
 
 sal_Bool Binding::isValid( const css::uno::Any& )
-    throw( RuntimeException, std::exception )
 {
     // first, check for model
     checkLive();
@@ -1191,7 +1144,6 @@ sal_Bool Binding::isValid( const css::uno::Any& )
 
 OUString Binding::explainInvalid(
     const css::uno::Any& /*Value*/ )
-    throw( RuntimeException, std::exception )
 {
     // first, check for model
     checkLive();
@@ -1202,8 +1154,6 @@ OUString Binding::explainInvalid(
 
 void Binding::addValidityConstraintListener(
     const css::uno::Reference<css::form::validation::XValidityConstraintListener>& xListener )
-    throw( NullPointerException,
-           RuntimeException, std::exception )
 {
     OSL_ENSURE( xListener.is(), "need listener!" );
     if( ::std::find(maValidityListeners.begin(), maValidityListeners.end(), xListener)
@@ -1213,8 +1163,6 @@ void Binding::addValidityConstraintListener(
 
 void Binding::removeValidityConstraintListener(
     const css::uno::Reference<css::form::validation::XValidityConstraintListener>& xListener )
-    throw( NullPointerException,
-           RuntimeException, std::exception )
 {
     XValidityConstraintListeners_t::iterator aIter =
         ::std::find( maValidityListeners.begin(), maValidityListeners.end(),
@@ -1224,13 +1172,10 @@ void Binding::removeValidityConstraintListener(
 }
 
 
-
-
 // xml::dom::event::XEventListener
 
 
 void Binding::handleEvent( const css::uno::Reference<css::xml::dom::events::XEvent>& xEvent )
-    throw( RuntimeException, std::exception )
 {
     OUString sType(xEvent->getType());
     //OUString sEventMIPChanged("xforms-generic");
@@ -1238,7 +1183,7 @@ void Binding::handleEvent( const css::uno::Reference<css::xml::dom::events::XEve
     if(sType == "xforms-generic") {
 
         // the modification of the 'mnDeferModifyNotifications'-member
-        // is necessary to prevent infinite notication looping.
+        // is necessary to prevent infinite notification looping.
         // This can happened in case the binding which caused
         // the notification chain is listening to those events
         // as well...
@@ -1258,12 +1203,10 @@ void Binding::handleEvent( const css::uno::Reference<css::xml::dom::events::XEve
 }
 
 
-
 // lang::XUnoTunnel
 
 
 sal_Int64 Binding::getSomething( const css::uno::Sequence<sal_Int8>& xId )
-    throw( RuntimeException, std::exception )
 {
     return reinterpret_cast<sal_Int64>( ( xId == getUnoTunnelID() ) ? this : nullptr );
 }
@@ -1273,7 +1216,6 @@ sal_Int64 Binding::getSomething( const css::uno::Sequence<sal_Int8>& xId )
 
 
 css::uno::Reference<css::util::XCloneable> SAL_CALL Binding::createClone()
-    throw( RuntimeException, std::exception )
 {
     Reference< XPropertySet > xClone;
 
@@ -1302,7 +1244,7 @@ css::uno::Reference<css::util::XCloneable> SAL_CALL Binding::createClone()
 
 #define REGISTER_BOOL_PROPERTY_RO( property )   \
     registerProperty( PROPERTY_RO( property, sal_Bool ), \
-    new BooleanPropertyAccessor< Binding, bool >( this, nullptr, &Binding::get##property ) );
+    new BooleanPropertyAccessor< Binding >( this, nullptr, &Binding::get##property ) );
 
 void Binding::initializePropertySet()
 {
@@ -1329,7 +1271,6 @@ void Binding::initializePropertySet()
 
 void Binding::addModifyListener(
     const css::uno::Reference<css::util::XModifyListener>& xListener )
-    throw( RuntimeException, std::exception )
 {
     OSL_ENSURE( xListener.is(), "need listener!" );
     if( ::std::find( maModifyListeners.begin(), maModifyListeners.end(), xListener )
@@ -1344,7 +1285,6 @@ void Binding::addModifyListener(
 
 void Binding::removeModifyListener(
     const css::uno::Reference<css::util::XModifyListener>& xListener )
-    throw( RuntimeException, std::exception )
 {
     ModifyListeners_t::iterator aIter =
         ::std::find( maModifyListeners.begin(), maModifyListeners.end(), xListener );
@@ -1353,16 +1293,12 @@ void Binding::removeModifyListener(
 }
 
 
-
-
 OUString Binding::getName()
-    throw( RuntimeException, std::exception )
 {
     return getBindingID();
 }
 
 void SAL_CALL Binding::setName( const OUString& rName )
-    throw( RuntimeException, std::exception )
 {
     // use the XPropertySet methods, so the change in the name is notified to the
     // property listeners
