@@ -23,10 +23,6 @@
 
 #include "VistaFilePicker.hxx"
 
-// Without IFileDialogCustomize we can't do much
-#ifdef __IFileDialogCustomize_INTERFACE_DEFINED__
-
-#include "WinFileOpenImpl.hxx"
 #include "../misc/WinImplHelper.hxx"
 #include "shared.hxx"
 
@@ -40,13 +36,8 @@
 #include <cppuhelper/interfacecontainer.h>
 #include <cppuhelper/supportsservice.hxx>
 #include <comphelper/processfactory.hxx>
-#include <osl/diagnose.h>
 #include <osl/mutex.hxx>
 #include <osl/file.hxx>
-#include <tchar.h>
-#ifdef RGB
-#undef RGB
-#endif
 #include <officecfg/Office/Common.hxx>
 
 #ifdef _MSC_VER
@@ -57,26 +48,12 @@
 #pragma warning (pop)
 #endif
 
-
-// namespace directives
-
-
 namespace fpicker{
 namespace win32{
 namespace vista{
 
-#define FILE_PICKER_DLL_NAME  TEXT("fps.dll")
-
-
-// helper functions
-
-
 namespace
 {
-    // controlling event notifications
-    const bool STARTUP_SUSPENDED = true;
-    const bool STARTUP_ALIVE     = false;
-
     css::uno::Sequence< OUString > SAL_CALL VistaFilePicker_getSupportedServiceNames()
     {
         css::uno::Sequence< OUString > aRet(2);
@@ -86,7 +63,6 @@ namespace
     }
 }
 
-
 VistaFilePicker::VistaFilePicker(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR)
     : TVistaFilePickerBase  (m_aMutex                 )
     , m_xSMGR               (xSMGR                    )
@@ -97,14 +73,11 @@ VistaFilePicker::VistaFilePicker(const css::uno::Reference< css::lang::XMultiSer
 {
 }
 
-
 VistaFilePicker::~VistaFilePicker()
 {
 }
 
-
 void SAL_CALL VistaFilePicker::addFilePickerListener(const css::uno::Reference< css::ui::dialogs::XFilePickerListener >& xListener)
-    throw(css::uno::RuntimeException)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_ADD_PICKER_LISTENER);
@@ -113,9 +86,7 @@ void SAL_CALL VistaFilePicker::addFilePickerListener(const css::uno::Reference<
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
 void SAL_CALL VistaFilePicker::removeFilePickerListener(const css::uno::Reference< css::ui::dialogs::XFilePickerListener >& xListener )
-    throw(css::uno::RuntimeException)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_REMOVE_PICKER_LISTENER);
@@ -124,16 +95,14 @@ void SAL_CALL VistaFilePicker::removeFilePickerListener(const css::uno::Referenc
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
 void SAL_CALL VistaFilePicker::disposing(const css::lang::EventObject& /*aEvent*/)
-    throw(css::uno::RuntimeException)
 {
 }
 
-
 void SAL_CALL VistaFilePicker::setMultiSelectionMode(sal_Bool bMode)
-    throw(css::uno::RuntimeException)
 {
+    ensureInit();
+
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_SET_MULTISELECTION_MODE);
     rRequest->setArgument(PROP_MULTISELECTION_MODE, bMode);
@@ -141,10 +110,10 @@ void SAL_CALL VistaFilePicker::setMultiSelectionMode(sal_Bool bMode)
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
 void SAL_CALL VistaFilePicker::setTitle(const OUString& sTitle)
-    throw(css::uno::RuntimeException)
 {
+    ensureInit();
+
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_SET_TITLE);
     rRequest->setArgument(PROP_TITLE, sTitle);
@@ -152,11 +121,8 @@ void SAL_CALL VistaFilePicker::setTitle(const OUString& sTitle)
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
 void SAL_CALL VistaFilePicker::appendFilter(const OUString& sTitle ,
                                             const OUString& sFilter)
-    throw(css::lang::IllegalArgumentException,
-          css::uno::RuntimeException         )
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_APPEND_FILTER);
@@ -166,10 +132,7 @@ void SAL_CALL VistaFilePicker::appendFilter(const OUString& sTitle ,
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
 void SAL_CALL VistaFilePicker::setCurrentFilter(const OUString& sTitle)
-    throw(css::lang::IllegalArgumentException,
-          css::uno::RuntimeException         )
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_SET_CURRENT_FILTER);
@@ -178,9 +141,7 @@ void SAL_CALL VistaFilePicker::setCurrentFilter(const OUString& sTitle)
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
 OUString SAL_CALL VistaFilePicker::getCurrentFilter()
-    throw(css::uno::RuntimeException)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_GET_CURRENT_FILTER);
@@ -191,11 +152,8 @@ OUString SAL_CALL VistaFilePicker::getCurrentFilter()
     return sTitle;
 }
 
-
 void SAL_CALL VistaFilePicker::appendFilterGroup(const OUString&                              /*sGroupTitle*/,
                                                  const css::uno::Sequence< css::beans::StringPair >& rFilters   )
-    throw (css::lang::IllegalArgumentException,
-           css::uno::RuntimeException         )
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_APPEND_FILTERGROUP);
@@ -204,10 +162,10 @@ void SAL_CALL VistaFilePicker::appendFilterGroup(const OUString&
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
 void SAL_CALL VistaFilePicker::setDefaultName(const OUString& sName )
-    throw(css::uno::RuntimeException)
 {
+    ensureInit();
+
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_SET_DEFAULT_NAME);
     rRequest->setArgument(PROP_FILENAME, sName);
@@ -215,11 +173,10 @@ void SAL_CALL VistaFilePicker::setDefaultName(const OUString& sName )
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
 void SAL_CALL VistaFilePicker::setDisplayDirectory(const OUString& sDirectory)
-    throw (css::lang::IllegalArgumentException,
-           css::uno::RuntimeException         )
 {
+    ensureInit();
+
     bool bChanged = officecfg::Office::Common::Path::Info::WorkPathChanged::get(
         comphelper::getComponentContext(m_xSMGR));
     if (bChanged )
@@ -240,10 +197,10 @@ void SAL_CALL VistaFilePicker::setDisplayDirectory(const OUString& sDirectory)
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
 OUString SAL_CALL VistaFilePicker::getDisplayDirectory()
-    throw(css::uno::RuntimeException)
 {
+    ensureInit();
+
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_GET_DIRECTORY);
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::BLOCKED);
@@ -252,10 +209,8 @@ OUString SAL_CALL VistaFilePicker::getDisplayDirectory()
     return sDirectory;
 }
 
-
 // @deprecated can't be supported any longer ... see IDL description for further details
 css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getFiles()
-    throw(css::uno::RuntimeException)
 {
     css::uno::Sequence< OUString > lFiles = getSelectedFiles();
     // multiselection doesn't really work
@@ -266,9 +221,7 @@ css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getFiles()
     return lFiles;
 }
 
-
 css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getSelectedFiles()
-    throw(css::uno::RuntimeException, std::exception)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_GET_SELECTED_FILES);
@@ -280,9 +233,7 @@ css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getSelectedFiles()
     return lFiles;
 }
 
-
-::sal_Int16 SAL_CALL VistaFilePicker::execute()
-    throw(css::uno::RuntimeException)
+void VistaFilePicker::ensureInit()
 {
     bool bInitialized(false);
     {
@@ -292,11 +243,15 @@ css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getSelectedFiles()
 
     if ( !bInitialized )
     {
-        sal_Int16 nTemplateDescription = css::ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE;
         css::uno::Sequence < css::uno::Any > aInitArguments(1);
-        aInitArguments[0] <<= nTemplateDescription;
+        aInitArguments[0] <<= css::ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE;
         initialize(aInitArguments);
     }
+}
+
+::sal_Int16 SAL_CALL VistaFilePicker::execute()
+{
+    ensureInit();
 
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_SHOW_DIALOG_MODAL);
@@ -304,7 +259,7 @@ css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getSelectedFiles()
     // if we want to show a modal window, the calling thread needs to process messages
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::PROCESS_MESSAGES);
 
-    const sal_Bool bOK          = rRequest->getArgumentOrDefault(PROP_DIALOG_SHOW_RESULT, (sal_Bool)sal_False                  );
+    const bool bOK          = rRequest->getArgumentOrDefault(PROP_DIALOG_SHOW_RESULT, false );
                      m_lLastFiles = rRequest->getArgumentOrDefault(PROP_SELECTED_FILES    , css::uno::Sequence< OUString >());
 
     ::sal_Int16 nResult = css::ui::dialogs::ExecutableDialogResults::CANCEL;
@@ -313,14 +268,11 @@ css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getSelectedFiles()
     return nResult;
 }
 
-
-// XFilePicker functions
-
+// XFilePicker
 
 void SAL_CALL VistaFilePicker::setValue(      ::sal_Int16    nControlId    ,
                                               ::sal_Int16    nControlAction,
                                         const css::uno::Any& aValue        )
-    throw(css::uno::RuntimeException)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_SET_CONTROL_VALUE);
@@ -331,13 +283,8 @@ void SAL_CALL VistaFilePicker::setValue(      ::sal_Int16    nControlId    ,
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
-
-
-
 css::uno::Any SAL_CALL VistaFilePicker::getValue(::sal_Int16 nControlId    ,
                                                  ::sal_Int16 nControlAction)
-    throw(css::uno::RuntimeException)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_GET_CONTROL_VALUE);
@@ -345,17 +292,11 @@ css::uno::Any SAL_CALL VistaFilePicker::getValue(::sal_Int16 nControlId    ,
     rRequest->setArgument(PROP_CONTROL_ACTION, nControlAction);
 
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::BLOCKED);
-    const css::uno::Any aValue = rRequest->getArgumentOrDefault(PROP_CONTROL_VALUE, css::uno::Any());
-    return aValue;
+    return rRequest->getValue(PROP_CONTROL_VALUE);
 }
 
-
-
-
-
 void SAL_CALL VistaFilePicker::enableControl(::sal_Int16 nControlId,
                                              sal_Bool  bEnable   )
-    throw(css::uno::RuntimeException)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_ENABLE_CONTROL);
@@ -365,13 +306,8 @@ void SAL_CALL VistaFilePicker::enableControl(::sal_Int16 nControlId,
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
-
-
-
 void SAL_CALL VistaFilePicker::setLabel(      ::sal_Int16      nControlId,
                                          const OUString& sLabel    )
-    throw (css::uno::RuntimeException)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_SET_CONTROL_LABEL);
@@ -381,12 +317,7 @@ void SAL_CALL VistaFilePicker::setLabel(      ::sal_Int16      nControlId,
     m_aAsyncExecute.triggerRequestThreadAware(rRequest, AsyncRequests::NON_BLOCKED);
 }
 
-
-
-
-
 OUString SAL_CALL VistaFilePicker::getLabel(::sal_Int16 nControlId)
-    throw (css::uno::RuntimeException)
 {
     RequestRef rRequest(new Request());
     rRequest->setRequest (VistaFilePickerImpl::E_GET_CONTROL_LABEL);
@@ -397,131 +328,91 @@ OUString SAL_CALL VistaFilePicker::getLabel(::sal_Int16 nControlId)
     return sLabel;
 }
 
-
-
-
-
 css::uno::Sequence< ::sal_Int16 > SAL_CALL VistaFilePicker::getSupportedImageFormats()
-    throw (css::uno::RuntimeException)
 {
     return css::uno::Sequence< sal_Int16 >();
 }
 
-
-
-
-
 sal_Int32 SAL_CALL VistaFilePicker::getTargetColorDepth()
-    throw (css::uno::RuntimeException)
 {
     return 0;
 }
 
-
-
-
-
 sal_Int32 SAL_CALL VistaFilePicker::getAvailableWidth()
-    throw (css::uno::RuntimeException)
 {
     return 0;
 }
 
-
-
-
-
 sal_Int32 SAL_CALL VistaFilePicker::getAvailableHeight()
-    throw (css::uno::RuntimeException)
 {
     return 0;
 }
 
-
-
-
-
 void SAL_CALL VistaFilePicker::setImage(      sal_Int16      /*nImageFormat*/,
                                          const css::uno::Any& /*aImage      */)
-    throw (css::lang::IllegalArgumentException,
-           css::uno::RuntimeException         )
 {
 }
 
-
-
-
-
 sal_Bool SAL_CALL VistaFilePicker::setShowState(sal_Bool /*bShowState*/)
-    throw (css::uno::RuntimeException)
 {
-    return sal_False;
+    return false;
 }
 
-
-
-
-
 sal_Bool SAL_CALL VistaFilePicker::getShowState()
-    throw (css::uno::RuntimeException)
 {
-    return sal_False;
+    return false;
 }
 
-
-
-
-
 void SAL_CALL VistaFilePicker::initialize(const css::uno::Sequence< css::uno::Any >& lArguments)
-    throw(css::uno::Exception       ,
-          css::uno::RuntimeException)
 {
     if (lArguments.getLength() < 1)
         throw css::lang::IllegalArgumentException(
-                OUString( "XInitialization::initialize() called without arguments." ),
+                "XInitialization::initialize() called without arguments.",
                 static_cast< css::ui::dialogs::XFilePicker2* >( this ),
                 1);
 
     sal_Int32         nTemplate = -1;
     lArguments[0] >>= nTemplate;
 
-    sal_Bool  bFileOpenDialog = sal_True;
+    bool bFileOpenDialog = true;
     ::sal_Int32 nFeatures       = 0;
 
     switch(nTemplate)
     {
         case css::ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE :
         {
-            bFileOpenDialog = sal_True;
+            bFileOpenDialog = true;
         }
         break;
 
         case css::ui::dialogs::TemplateDescription::FILESAVE_SIMPLE :
         {
-            bFileOpenDialog = sal_False;
+            bFileOpenDialog = false;
         }
         break;
 
         case css::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD :
         {
-            bFileOpenDialog  = sal_False;
+            bFileOpenDialog  = false;
             nFeatures        |= FEATURE_AUTOEXTENSION;
             nFeatures        |= FEATURE_PASSWORD;
+            nFeatures        |= FEATURE_GPGPASSWORD;
         }
         break;
 
         case css::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD_FILTEROPTIONS :
         {
-            bFileOpenDialog = sal_False;
+            bFileOpenDialog = false;
             nFeatures        |= FEATURE_AUTOEXTENSION;
             nFeatures        |= FEATURE_PASSWORD;
             nFeatures        |= FEATURE_FILTEROPTIONS;
+            nFeatures        |= FEATURE_GPGPASSWORD;
         }
         break;
 
         case css::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_SELECTION :
         {
-            bFileOpenDialog  = sal_False;
+            bFileOpenDialog  = false;
             nFeatures        |= FEATURE_AUTOEXTENSION;
             nFeatures        |= FEATURE_SELECTION;
         }
@@ -529,7 +420,7 @@ void SAL_CALL VistaFilePicker::initialize(const css::uno::Sequence< css::uno::An
 
         case css::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION_TEMPLATE :
         {
-            bFileOpenDialog  = sal_False;
+            bFileOpenDialog  = false;
             nFeatures        |= FEATURE_AUTOEXTENSION;
             nFeatures        |= FEATURE_TEMPLATE;
         }
@@ -537,7 +428,7 @@ void SAL_CALL VistaFilePicker::initialize(const css::uno::Sequence< css::uno::An
 
         case css::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PREVIEW_IMAGE_TEMPLATE :
         {
-            bFileOpenDialog  = sal_True;
+            bFileOpenDialog  = true;
             nFeatures        |= FEATURE_LINK;
             nFeatures        |= FEATURE_PREVIEW;
             nFeatures        |= FEATURE_IMAGETEMPLATE;
@@ -546,14 +437,22 @@ void SAL_CALL VistaFilePicker::initialize(const css::uno::Sequence< css::uno::An
 
         case css::ui::dialogs::TemplateDescription::FILEOPEN_PLAY :
         {
-            bFileOpenDialog  = sal_True;
+            bFileOpenDialog  = true;
+            nFeatures        |= FEATURE_PLAY;
+        }
+        break;
+
+        case css::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PLAY :
+        {
+            bFileOpenDialog  = true;
+            nFeatures        |= FEATURE_LINK;
             nFeatures        |= FEATURE_PLAY;
         }
         break;
 
         case css::ui::dialogs::TemplateDescription::FILEOPEN_READONLY_VERSION :
         {
-            bFileOpenDialog  = sal_True;
+            bFileOpenDialog  = true;
             nFeatures        |= FEATURE_READONLY;
             nFeatures        |= FEATURE_VERSION;
         }
@@ -561,7 +460,7 @@ void SAL_CALL VistaFilePicker::initialize(const css::uno::Sequence< css::uno::An
 
         case css::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PREVIEW :
         {
-            bFileOpenDialog  = sal_True;
+            bFileOpenDialog  = true;
             nFeatures        |= FEATURE_LINK;
             nFeatures        |= FEATURE_PREVIEW;
         }
@@ -569,10 +468,17 @@ void SAL_CALL VistaFilePicker::initialize(const css::uno::Sequence< css::uno::An
 
         case css::ui::dialogs::TemplateDescription::FILESAVE_AUTOEXTENSION :
         {
-            bFileOpenDialog  = sal_False;
+            bFileOpenDialog  = false;
             nFeatures        |= FEATURE_AUTOEXTENSION;
         }
         break;
+
+        case css::ui::dialogs::TemplateDescription::FILEOPEN_PREVIEW :
+        {
+            bFileOpenDialog  = true;
+            nFeatures        |= FEATURE_PREVIEW;
+        }
+        break;
     }
     css::uno::Reference<css::awt::XWindow> xParentWindow;
     if(lArguments.getLength() > 1)
@@ -598,38 +504,23 @@ void SAL_CALL VistaFilePicker::initialize(const css::uno::Sequence< css::uno::An
     }
 }
 
-
-
-
-
 void SAL_CALL VistaFilePicker::cancel()
-    throw(css::uno::RuntimeException)
 {
 }
 
-
 // XServiceInfo
 
-
 OUString SAL_CALL VistaFilePicker::getImplementationName()
-    throw(css::uno::RuntimeException)
 {
     return OUString("com.sun.star.comp.fpicker.VistaFileDialog");
 }
 
-//  XServiceInfo
 sal_Bool SAL_CALL VistaFilePicker::supportsService(const OUString& sServiceName)
-    throw(css::uno::RuntimeException )
 {
     return cppu::supportsService(this, sServiceName);
 }
 
-
-//  XServiceInfo
-
-
 css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getSupportedServiceNames()
-    throw(css::uno::RuntimeException)
 {
     return VistaFilePicker_getSupportedServiceNames();
 }
@@ -638,6 +529,4 @@ css::uno::Sequence< OUString > SAL_CALL VistaFilePicker::getSupportedServiceName
 } // namespace win32
 } // namespace fpicker
 
-#endif // __IFileDialogCustomize_INTERFACE_DEFINED__
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
