@@ -19,19 +19,20 @@
 
 #include "VistaFilePickerImpl.hxx"
 
-// Without IFileDialogCustomize we can't do much
-#ifdef __IFileDialogCustomize_INTERFACE_DEFINED__
-
 #include <com/sun/star/ui/dialogs/ExtendedFilePickerElementIds.hpp>
 #include <com/sun/star/ui/dialogs/ControlActions.hpp>
 #include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
 #include <com/sun/star/beans/StringPair.hpp>
+#include <com/sun/star/awt/XWindow.hpp>
+#include <com/sun/star/awt/XSystemDependentWindowPeer.hpp>
+#include <com/sun/star/lang/SystemDependent.hpp>
 #include <comphelper/sequence.hxx>
+#include <fpicker/strings.hrc>
+#include <fpsofficeResMgr.hxx>
 #include <osl/file.hxx>
 #include <osl/mutex.hxx>
-#ifdef __MINGW32__
-#include <limits.h>
-#endif
+#include <rtl/process.h>
+#include <o3tl/char16_t2wchar_t.hxx>
 #include "../misc/WinImplHelper.hxx"
 
 #include <shlguid.h>
@@ -60,14 +61,9 @@ bool createFolderItem(OUString const & url, ComPtr<IShellItem> & folder) {
     {
         return false;
     }
-#if defined __MINGW32__
     HRESULT res = SHCreateItemFromParsingName(
-        reinterpret_cast<LPCTSTR>(path.getStr()), NULL, IID_IShellItem,
-        reinterpret_cast<void **>(&folder));
-#else
-    HRESULT res = SHCreateItemFromParsingName(
-        path.getStr(), NULL, IID_PPV_ARGS(&folder));
-#endif
+        o3tl::toW(path.getStr()), nullptr,
+        IID_PPV_ARGS(&folder));
     return SUCCEEDED(res);
 }
 
@@ -81,7 +77,6 @@ namespace vista{
 // types, const etcpp.
 
 
-
 static const ::sal_Int16 INVALID_CONTROL_ID     = -1;
 static const ::sal_Int16 INVALID_CONTROL_ACTION = -1;
 
@@ -98,7 +93,7 @@ static const GUID CLIENTID_FILEOPEN_LINK            = {0x39AC4BAE, 0x7D2D, 0x46B
 
 OUString lcl_getURLFromShellItem (IShellItem* pItem)
 {
-    LPOLESTR pStr = NULL;
+    LPOLESTR pStr = nullptr;
     OUString sURL;
 
     SIGDN   eConversion = SIGDN_FILESYSPATH;
@@ -112,11 +107,11 @@ OUString lcl_getURLFromShellItem (IShellItem* pItem)
         if ( FAILED(hr) )
             return OUString();
 
-        sURL = OUString(reinterpret_cast<sal_Unicode*>(pStr));
+        sURL = o3tl::toU(pStr);
     }
     else
     {
-        ::osl::FileBase::getFileURLFromSystemPath( reinterpret_cast<sal_Unicode*>(pStr), sURL );
+        ::osl::FileBase::getFileURLFromSystemPath( o3tl::toU(pStr), sURL );
     }
 
     CoTaskMemFree (pStr);
@@ -134,8 +129,8 @@ OUString lcl_getURLFromShellItem (IShellItem* pItem)
     {
         COMDLG_FILTERSPEC aSpec;
 
-        aSpec.pszName = reinterpret_cast<LPCTSTR>(aFilter.first.getStr()) ;
-        aSpec.pszSpec = reinterpret_cast<LPCTSTR>(aFilter.second.getStr());
+        aSpec.pszName = o3tl::toW(aFilter.first.getStr()) ;
+        aSpec.pszSpec = o3tl::toW(aFilter.second.getStr());
 
         lList.push_back(aSpec);
     }
@@ -149,10 +144,9 @@ VistaFilePickerImpl::VistaFilePickerImpl()
     , m_iDialogSave  ()
     , m_hLastResult  ()
     , m_lFilters     ()
-    , m_lLastFiles   ()
     , m_iEventHandler(new VistaFilePickerEventHandler(this))
-    , m_bInExecute   (sal_False)
-    , m_bWasExecuted (sal_False)
+    , m_bInExecute   (false)
+    , m_bWasExecuted (false)
     , m_sDirectory   ()
     , m_sFilename    ()
 {
@@ -172,16 +166,16 @@ void VistaFilePickerImpl::before()
 
     // TRICKY .-)
     // osl::Thread class initializes COm already in MTA mode because it's needed
-    // by VCL and UNO so. There is no way to change that from outside ...
-    // but we need a STA environment ...
-    // So we make it by try-and-error ...
-    // If first CoInitialize will fail .. we unitialize COM initialize it new .-)
+    // by VCL and UNO so. There is no way to change that from outside...
+    // but we need a STA environment...
+    // So we make it by try-and-error...
+    // If first CoInitialize will fail... we uninitialize COM initialize it new .-)
 
-    m_hLastResult = CoInitializeEx(NULL, COINIT_APARTMENTTHREADED);
+    m_hLastResult = CoInitializeEx(nullptr, COINIT_APARTMENTTHREADED);
     if ( FAILED(m_hLastResult) )
     {
         CoUninitialize();
-        m_hLastResult = CoInitializeEx(NULL, COINIT_APARTMENTTHREADED);
+        m_hLastResult = CoInitializeEx(nullptr, COINIT_APARTMENTTHREADED);
     }
 }
 
@@ -303,7 +297,7 @@ void VistaFilePickerImpl::impl_sta_addFilePickerListener(const RequestRef& rRequ
     aLock.clear();
     // <- SYNCHRONIZED
 
-    VistaFilePickerEventHandler* pHandlerImpl = (VistaFilePickerEventHandler*)iHandler.get();
+    VistaFilePickerEventHandler* pHandlerImpl = static_cast<VistaFilePickerEventHandler*>(iHandler.get());
     if (pHandlerImpl)
         pHandlerImpl->addFilePickerListener(xListener);
 }
@@ -322,7 +316,7 @@ void VistaFilePickerImpl::impl_sta_removeFilePickerListener(const RequestRef& rR
     aLock.clear();
     // <- SYNCHRONIZED
 
-    VistaFilePickerEventHandler* pHandlerImpl = (VistaFilePickerEventHandler*)iHandler.get();
+    VistaFilePickerEventHandler* pHandlerImpl = static_cast<VistaFilePickerEventHandler*>(iHandler.get());
     if (pHandlerImpl)
         pHandlerImpl->removeFilePickerListener(xListener);
 }
@@ -349,7 +343,7 @@ void VistaFilePickerImpl::impl_sta_appendFilterGroup(const RequestRef& rRequest)
     ::osl::ResettableMutexGuard aLock(m_aMutex);
 
     if ( m_lFilters.numFilter() > 0 && aFilterGroup.getLength() > 0 )
-        m_lFilters.addFilter( STRING_SEPARATOR, "", sal_True );
+        m_lFilters.addFilter( STRING_SEPARATOR, "", true );
 
     ::sal_Int32 c = aFilterGroup.getLength();
     ::sal_Int32 i = 0;
@@ -414,11 +408,7 @@ void VistaFilePickerImpl::impl_sta_CreateOpenDialog(const RequestRef& rRequest)
         return;
 
     TFileDialog iDialog;
-#ifdef __MINGW32__
-    m_iDialogOpen->QueryInterface(IID_IFileDialog, (void **)(&iDialog));
-#else
     m_iDialogOpen.query(&iDialog);
-#endif
 
     TFileDialogEvents iHandler = m_iEventHandler;
 
@@ -440,7 +430,7 @@ void VistaFilePickerImpl::impl_sta_CreateOpenDialog(const RequestRef& rRequest)
     ::sal_Int32 nTemplate = rRequest->getArgumentOrDefault(PROP_TEMPLATE_DESCR, (::sal_Int32)0);
     impl_sta_enableFeatures(nFeatures, nTemplate);
 
-    VistaFilePickerEventHandler* pHandlerImpl = (VistaFilePickerEventHandler*)iHandler.get();
+    VistaFilePickerEventHandler* pHandlerImpl = static_cast<VistaFilePickerEventHandler*>(iHandler.get());
     if (pHandlerImpl)
         pHandlerImpl->startListening(iDialog);
 }
@@ -457,11 +447,7 @@ void VistaFilePickerImpl::impl_sta_CreateSaveDialog(const RequestRef& rRequest)
 
     TFileDialogEvents  iHandler = m_iEventHandler;
     TFileDialog        iDialog;
-#ifdef __MINGW32__
-    m_iDialogSave->QueryInterface(IID_IFileDialog, (void **)(&iDialog));
-#else
     m_iDialogSave.query(&iDialog);
-#endif
 
     aLock.clear();
     // <- SYNCHRONIZED
@@ -479,9 +465,24 @@ void VistaFilePickerImpl::impl_sta_CreateSaveDialog(const RequestRef& rRequest)
 
     ::sal_Int32 nFeatures = rRequest->getArgumentOrDefault(PROP_FEATURES, (::sal_Int32)0);
     ::sal_Int32 nTemplate = rRequest->getArgumentOrDefault(PROP_TEMPLATE_DESCR, (::sal_Int32)0);
+    css::uno::Reference<css::awt::XWindow> xWindow = rRequest->getArgumentOrDefault(PROP_PARENT_WINDOW, css::uno::Reference<css::awt::XWindow>());
+    if(xWindow.is())
+    {
+        css::uno::Reference<css::awt::XSystemDependentWindowPeer> xSysDepWin(xWindow,css::uno::UNO_QUERY);
+        if(xSysDepWin.is()) {
+            css::uno::Sequence<sal_Int8> aProcessIdent(16);
+            rtl_getGlobalProcessId(reinterpret_cast<sal_uInt8*>(aProcessIdent.getArray()));
+            css::uno::Any aAny = xSysDepWin->getWindowHandle(aProcessIdent,css::lang::SystemDependent::SYSTEM_WIN32);
+            sal_Int64 tmp = 0;
+            aAny >>= tmp;
+            if(tmp != 0)
+                m_hParentWindow = reinterpret_cast<HWND>(tmp);
+        }
+    }
+
     impl_sta_enableFeatures(nFeatures, nTemplate);
 
-    VistaFilePickerEventHandler* pHandlerImpl = (VistaFilePickerEventHandler*)iHandler.get();
+    VistaFilePickerEventHandler* pHandlerImpl = static_cast<VistaFilePickerEventHandler*>(iHandler.get());
     if (pHandlerImpl)
         pHandlerImpl->startListening(iDialog);
 }
@@ -493,11 +494,11 @@ static const ::sal_Int32 GROUP_IMAGETEMPLATE   =   3;
 static const ::sal_Int32 GROUP_CHECKBOXES      =   4;
 
 
-static void setLabelToControl(CResourceProvider& rResourceProvider, TFileDialogCustomize iCustom, sal_uInt16 nControlId)
+static void setLabelToControl(TFileDialogCustomize iCustom, sal_uInt16 nControlId)
 {
-    OUString aLabel = rResourceProvider.getResString(nControlId);
+    OUString aLabel = CResourceProvider::getResString(nControlId);
     aLabel = SOfficeToWindowsLabel(aLabel);
-    iCustom->SetControlLabel(nControlId, reinterpret_cast<LPCWSTR>(aLabel.getStr()) );
+    iCustom->SetControlLabel(nControlId, o3tl::toW(aLabel.getStr()) );
 }
 
 
@@ -507,6 +508,7 @@ void VistaFilePickerImpl::impl_sta_enableFeatures(::sal_Int32 nFeatures, ::sal_I
     switch (nTemplate)
     {
         case css::ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE :
+        case css::ui::dialogs::TemplateDescription::FILEOPEN_PREVIEW :
         case css::ui::dialogs::TemplateDescription::FILESAVE_SIMPLE :
             aGUID = CLIENTID_FILEDIALOG_SIMPLE;
             break;
@@ -534,6 +536,7 @@ void VistaFilePickerImpl::impl_sta_enableFeatures(::sal_Int32 nFeatures, ::sal_I
             break;
 
         case css::ui::dialogs::TemplateDescription::FILEOPEN_PLAY :
+        case css::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PLAY :
             aGUID = CLIENTID_FILEOPEN_PLAY;
             break;
 
@@ -548,7 +551,7 @@ void VistaFilePickerImpl::impl_sta_enableFeatures(::sal_Int32 nFeatures, ::sal_I
 
     if ((nFeatures & FEATURE_VERSION) == FEATURE_VERSION)
     {
-        iCustom->StartVisualGroup (GROUP_VERSION, L"Version");
+        iCustom->StartVisualGroup (GROUP_VERSION, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_VERSION).replaceFirst("~","").getStr()));
         iCustom->AddComboBox      (css::ui::dialogs::ExtendedFilePickerElementIds::LISTBOX_VERSION);
         iCustom->EndVisualGroup   ();
         iCustom->MakeProminent    (GROUP_VERSION);
@@ -556,7 +559,7 @@ void VistaFilePickerImpl::impl_sta_enableFeatures(::sal_Int32 nFeatures, ::sal_I
 
     if ((nFeatures & FEATURE_TEMPLATE) == FEATURE_TEMPLATE)
     {
-        iCustom->StartVisualGroup (GROUP_TEMPLATE, L"Template");
+        iCustom->StartVisualGroup (GROUP_TEMPLATE, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_TEMPLATES).replaceFirst("~","").getStr()));
         iCustom->AddComboBox      (css::ui::dialogs::ExtendedFilePickerElementIds::LISTBOX_TEMPLATE);
         iCustom->EndVisualGroup   ();
         iCustom->MakeProminent    (GROUP_TEMPLATE);
@@ -564,7 +567,7 @@ void VistaFilePickerImpl::impl_sta_enableFeatures(::sal_Int32 nFeatures, ::sal_I
 
     if ((nFeatures & FEATURE_IMAGETEMPLATE) == FEATURE_IMAGETEMPLATE)
     {
-        iCustom->StartVisualGroup (GROUP_IMAGETEMPLATE, L"Style");
+        iCustom->StartVisualGroup (GROUP_IMAGETEMPLATE, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_IMAGE_TEMPLATE).replaceFirst("~","").getStr()));
         iCustom->AddComboBox      (css::ui::dialogs::ExtendedFilePickerElementIds::LISTBOX_IMAGE_TEMPLATE);
         iCustom->EndVisualGroup   ();
         iCustom->MakeProminent    (GROUP_IMAGETEMPLATE);
@@ -576,43 +579,50 @@ void VistaFilePickerImpl::impl_sta_enableFeatures(::sal_Int32 nFeatures, ::sal_I
     if ((nFeatures & FEATURE_AUTOEXTENSION) == FEATURE_AUTOEXTENSION)
     {
         nControlId = css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_AUTOEXTENSION;
-        iCustom->AddCheckButton (nControlId, L"Auto Extension", true);
-        setLabelToControl(m_ResProvider, iCustom, nControlId);
+        iCustom->AddCheckButton (nControlId, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_AUTO_EXTENSION).replaceFirst("~","").getStr()), true);
+        setLabelToControl(iCustom, nControlId);
     }
 
     if ((nFeatures & FEATURE_PASSWORD) == FEATURE_PASSWORD)
     {
         nControlId = css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_PASSWORD;
-        iCustom->AddCheckButton (nControlId, L"Password", false);
-        setLabelToControl(m_ResProvider, iCustom, nControlId);
+        iCustom->AddCheckButton (nControlId, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_PASSWORD).replaceFirst("~","").getStr()), false);
+        setLabelToControl(iCustom, nControlId);
+    }
+
+    if ((nFeatures & FEATURE_GPGPASSWORD) == FEATURE_GPGPASSWORD)
+    {
+        nControlId = css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_GPGENCRYPTION;
+        iCustom->AddCheckButton (nControlId, L"GpgPassword", false);
+        setLabelToControl(iCustom, nControlId);
     }
 
     if ((nFeatures & FEATURE_READONLY) == FEATURE_READONLY)
     {
         nControlId = css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_READONLY;
-        iCustom->AddCheckButton (nControlId, L"Readonly", false);
-        setLabelToControl(m_ResProvider, iCustom, nControlId);
+        iCustom->AddCheckButton (nControlId, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_READONLY).replaceFirst("~","").getStr()), false);
+        setLabelToControl(iCustom, nControlId);
     }
 
     if ((nFeatures & FEATURE_FILTEROPTIONS) == FEATURE_FILTEROPTIONS)
     {
         nControlId = css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_FILTEROPTIONS;
-        iCustom->AddCheckButton (nControlId, L"Filter Options", false);
-        setLabelToControl(m_ResProvider, iCustom, nControlId);
+        iCustom->AddCheckButton (nControlId, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_FILTER_OPTIONS).replaceFirst("~","").getStr()), false);
+        setLabelToControl(iCustom, nControlId);
     }
 
     if ((nFeatures & FEATURE_LINK) == FEATURE_LINK)
     {
         nControlId = css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_LINK;
-        iCustom->AddCheckButton (nControlId, L"Link", false);
-        setLabelToControl(m_ResProvider, iCustom, nControlId);
+        iCustom->AddCheckButton (nControlId, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_INSERT_AS_LINK).replaceFirst("~","").getStr()), false);
+        setLabelToControl(iCustom, nControlId);
     }
 
     if ((nFeatures & FEATURE_SELECTION) == FEATURE_SELECTION)
     {
         nControlId = css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_SELECTION;
-        iCustom->AddCheckButton (nControlId, L"Selection", false);
-        setLabelToControl(m_ResProvider, iCustom, nControlId);
+        iCustom->AddCheckButton (nControlId, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_SELECTION).replaceFirst("~","").getStr()), false);
+        setLabelToControl(iCustom, nControlId);
     }
 
     /* can be ignored ... new COM dialog supports preview native now  !
@@ -623,14 +633,14 @@ void VistaFilePickerImpl::impl_sta_enableFeatures(::sal_Int32 nFeatures, ::sal_I
     iCustom->EndVisualGroup();
 
     if ((nFeatures & FEATURE_PLAY) == FEATURE_PLAY)
-        iCustom->AddPushButton (css::ui::dialogs::ExtendedFilePickerElementIds::PUSHBUTTON_PLAY, L"Play");
+        iCustom->AddPushButton (css::ui::dialogs::ExtendedFilePickerElementIds::PUSHBUTTON_PLAY, o3tl::toW(FpsResId(STR_SVT_FILEPICKER_PLAY).replaceFirst("~","").getStr()));
 
 }
 
 
 void VistaFilePickerImpl::impl_sta_SetMultiSelectionMode(const RequestRef& rRequest)
 {
-    const sal_Bool bMultiSelection = rRequest->getArgumentOrDefault(PROP_MULTISELECTION_MODE, (sal_Bool)sal_True);
+    const bool bMultiSelection = rRequest->getArgumentOrDefault(PROP_MULTISELECTION_MODE, true);
 
     // SYNCHRONIZED->
     ::osl::ResettableMutexGuard aLock(m_aMutex);
@@ -660,7 +670,7 @@ void VistaFilePickerImpl::impl_sta_SetTitle(const RequestRef& rRequest)
     aLock.clear();
     // <- SYNCHRONIZED
 
-    iDialog->SetTitle(reinterpret_cast<LPCTSTR>(sTitle.getStr()));
+    iDialog->SetTitle(o3tl::toW(sTitle.getStr()));
 }
 
 
@@ -674,7 +684,7 @@ void VistaFilePickerImpl::impl_sta_SetFileName(const RequestRef& rRequest)
     aLock.clear();
     // <- SYNCHRONIZED
 
-    iDialog->SetFileName(reinterpret_cast<LPCTSTR>(sFileName.getStr()));
+    iDialog->SetFileName(o3tl::toW(sFileName.getStr()));
 }
 
 
@@ -747,7 +757,7 @@ void VistaFilePickerImpl::impl_sta_SetDefaultName(const RequestRef& rRequest)
             sFilename = sFilename.copy(0, nSepPos);
     }
 
-    iDialog->SetFileName ( reinterpret_cast<LPCTSTR>(sFilename.getStr()));
+    iDialog->SetFileName (o3tl::toW(sFilename.getStr()));
     m_sFilename = sFilename;
 }
 
@@ -780,7 +790,7 @@ void VistaFilePickerImpl::impl_sta_setFiltersOnDialog()
 
     if ( bValue )
     {
-        LPCWSTR lpFilterExt = lFilters[0].pszSpec;
+        PCWSTR lpFilterExt = lFilters[0].pszSpec;
 
         lpFilterExt = wcsrchr( lpFilterExt, '.' );
         if ( lpFilterExt )
@@ -798,7 +808,7 @@ void VistaFilePickerImpl::impl_sta_getSelectedFiles(const RequestRef& rRequest)
 
     TFileOpenDialog iOpen      = m_iDialogOpen;
     TFileSaveDialog iSave      = m_iDialogSave;
-    sal_Bool      bInExecute = m_bInExecute;
+    bool bInExecute = m_bInExecute;
 
     aLock.clear();
     // <- SYNCHRONIZED
@@ -821,8 +831,7 @@ void VistaFilePickerImpl::impl_sta_getSelectedFiles(const RequestRef& rRequest)
                 hResult = iOpen->GetResult(&iItem);
         }
     }
-    else
-    if (iSave.is())
+    else if (iSave.is())
     {
         if (bInExecute)
             hResult = iSave->GetCurrentSelection(&iItem);
@@ -879,9 +888,9 @@ void VistaFilePickerImpl::impl_sta_ShowDialogModal(const RequestRef& rRequest)
     // it's important to know if we are showing the dialog.
     // Some dialog interface methods can't be called then or some
     // tasks must be done differently .-) (e.g. see impl_sta_getSelectedFiles())
-    m_bInExecute = sal_True;
+    m_bInExecute = true;
 
-    m_bWasExecuted = sal_True;
+    m_bWasExecuted = true;
 
     aLock.clear();
     // <- SYNCHRONIZED
@@ -917,11 +926,11 @@ void VistaFilePickerImpl::impl_sta_ShowDialogModal(const RequestRef& rRequest)
                         ::std::vector< COMDLG_FILTERSPEC > lFilters = lcl_buildFilterList(m_lFilters);
                         if ( nRealIndex < lFilters.size() )
                         {
-                            LPCWSTR lpFilterExt = lFilters[nRealIndex].pszSpec;
+                            PCWSTR lpFilterExt = lFilters[nRealIndex].pszSpec;
 
                             lpFilterExt = wcsrchr( lpFilterExt, '.' );
                             if ( lpFilterExt )
-                                aFileURL += reinterpret_cast<const sal_Unicode*>(lpFilterExt);
+                                aFileURL += o3tl::toU(lpFilterExt);
                         }
                     }
                 }
@@ -930,8 +939,8 @@ void VistaFilePickerImpl::impl_sta_ShowDialogModal(const RequestRef& rRequest)
                 OUString aSystemPath;
                 osl_getSystemPathFromFileURL( aFileURL.pData, &aSystemPath.pData );
 
-                WIN32_FIND_DATA aFindFileData;
-                HANDLE  hFind = FindFirstFile( reinterpret_cast<LPCWSTR>(aSystemPath.getStr()), &aFindFileData );
+                WIN32_FIND_DATAW aFindFileData;
+                HANDLE  hFind = FindFirstFileW( o3tl::toW(aSystemPath.getStr()), &aFindFileData );
                 if (hFind != INVALID_HANDLE_VALUE)
                     iDialog->SetFolder(pFolder);
                 else
@@ -960,7 +969,7 @@ void VistaFilePickerImpl::impl_sta_ShowDialogModal(const RequestRef& rRequest)
 
     // SYNCHRONIZED->
     aLock.reset();
-    m_bInExecute = sal_False;
+    m_bInExecute = false;
     aLock.clear();
     // <- SYNCHRONIZED
 
@@ -968,7 +977,7 @@ void VistaFilePickerImpl::impl_sta_ShowDialogModal(const RequestRef& rRequest)
         return;
 
     impl_sta_getSelectedFiles(rRequest);
-    rRequest->setArgument(PROP_DIALOG_SHOW_RESULT, sal_True);
+    rRequest->setArgument(PROP_DIALOG_SHOW_RESULT, true);
 }
 
 
@@ -980,17 +989,9 @@ TFileDialog VistaFilePickerImpl::impl_getBaseDialogInterface()
     ::osl::ResettableMutexGuard aLock(m_aMutex);
 
     if (m_iDialogOpen.is())
-#ifdef __MINGW32__
-        m_iDialogOpen->QueryInterface(IID_IFileDialog, (void**)(&iDialog));
-#else
         m_iDialogOpen.query(&iDialog);
-#endif
     if (m_iDialogSave.is())
-#ifdef __MINGW32__
-        m_iDialogSave->QueryInterface(IID_IFileDialog, (void**)(&iDialog));
-#else
         m_iDialogSave.query(&iDialog);
-#endif
 
     return iDialog;
 }
@@ -1004,18 +1005,9 @@ TFileDialogCustomize VistaFilePickerImpl::impl_getCustomizeInterface()
     ::osl::ResettableMutexGuard aLock(m_aMutex);
 
     if (m_iDialogOpen.is())
-#ifdef __MINGW32__
-        m_iDialogOpen->QueryInterface(IID_IFileDialogCustomize, (void**)(&iCustom));
-#else
         m_iDialogOpen.query(&iCustom);
-#endif
-    else
-    if (m_iDialogSave.is())
-#ifdef __MINGW32__
-        m_iDialogSave->QueryInterface(IID_IFileDialogCustomize, (void**)(&iCustom));
-#else
+    else if (m_iDialogSave.is())
         m_iDialogSave.query(&iCustom);
-#endif
 
     return iCustom;
 }
@@ -1038,7 +1030,7 @@ void VistaFilePickerImpl::impl_sta_SetControlValue(const RequestRef& rRequest)
 {
     ::sal_Int16   nId     = rRequest->getArgumentOrDefault(PROP_CONTROL_ID    , INVALID_CONTROL_ID    );
     ::sal_Int16   nAction = rRequest->getArgumentOrDefault(PROP_CONTROL_ACTION, INVALID_CONTROL_ACTION);
-    css::uno::Any aValue  = rRequest->getArgumentOrDefault(PROP_CONTROL_VALUE , css::uno::Any()       );
+    css::uno::Any aValue  = rRequest->getValue(PROP_CONTROL_VALUE);
 
     // don't check for right values here ...
     // most parameters are optional !
@@ -1057,7 +1049,7 @@ void VistaFilePickerImpl::impl_sta_SetControlValue(const RequestRef& rRequest)
         //case css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_PREVIEW : // can be ignored ... preview is supported native now !
         case css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_SELECTION :
             {
-                sal_Bool bValue   = sal_False;
+                bool bValue   = false;
                            aValue >>= bValue;
                 iCustom->SetCheckButtonState(nId, bValue);
             }
@@ -1085,7 +1077,7 @@ void VistaFilePickerImpl::impl_sta_SetControlValue(const RequestRef& rRequest)
                             for (::sal_Int32 i=0; i<lItems.getLength(); ++i)
                             {
                                 const OUString& sItem = lItems[i];
-                                hResult = iCustom->AddControlItem(nId, i, reinterpret_cast<LPCTSTR>(sItem.getStr()));
+                                hResult = iCustom->AddControlItem(nId, i, o3tl::toW(sItem.getStr()));
                             }
                         }
                         break;
@@ -1122,9 +1114,10 @@ void VistaFilePickerImpl::impl_sta_GetControlValue(const RequestRef& rRequest)
 
     css::uno::Any aValue;
     if( m_bWasExecuted )
-    switch (nId)
-    {
+        switch (nId)
+        {
         case css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_PASSWORD :
+        case css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_GPGENCRYPTION :
         case css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_READONLY :
         case css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_FILTEROPTIONS :
         case css::ui::dialogs::ExtendedFilePickerElementIds::CHECKBOX_LINK :
@@ -1134,10 +1127,10 @@ void VistaFilePickerImpl::impl_sta_GetControlValue(const RequestRef& rRequest)
                 BOOL    bValue  = FALSE;
                 HRESULT hResult = iCustom->GetCheckButtonState(nId, &bValue);
                 if ( SUCCEEDED(hResult) )
-                    aValue = css::uno::makeAny((sal_Bool)bValue);
+                    aValue <<= bool(bValue);
             }
             break;
-    }
+        }
 
     if (aValue.hasValue())
         rRequest->setArgument(PROP_CONTROL_VALUE, aValue);
@@ -1155,7 +1148,7 @@ void VistaFilePickerImpl::impl_sta_SetControlLabel(const RequestRef& rRequest)
     TFileDialogCustomize iCustom = impl_getCustomizeInterface();
     if ( ! iCustom.is())
         return;
-    iCustom->SetControlLabel ( nId, reinterpret_cast<LPCTSTR>(sLabel.getStr()));
+    iCustom->SetControlLabel (nId, o3tl::toW(sLabel.getStr()));
 }
 
 
@@ -1167,7 +1160,7 @@ void VistaFilePickerImpl::impl_sta_GetControlLabel(const RequestRef& /*rRequest*
 void VistaFilePickerImpl::impl_sta_EnableControl(const RequestRef& rRequest)
 {
     ::sal_Int16 nId      = rRequest->getArgumentOrDefault(PROP_CONTROL_ID    , INVALID_CONTROL_ID  );
-    sal_Bool  bEnabled = rRequest->getArgumentOrDefault(PROP_CONTROL_ENABLE, (sal_Bool)sal_True);
+    bool bEnabled = rRequest->getArgumentOrDefault(PROP_CONTROL_ENABLE, true);
 
     // don't check for right values here ...
     // most parameters are optional !
@@ -1201,7 +1194,7 @@ void VistaFilePickerImpl::impl_SetDefaultExtension( const OUString& currentFilte
             posOfSemiColon = FilterExt.getLength() - 1;
 
         FilterExt = OUString(pFirstExtStart, posOfSemiColon - posOfPoint);
-        iDialog->SetDefaultExtension ( reinterpret_cast<LPCTSTR>(FilterExt.getStr()) );
+        iDialog->SetDefaultExtension ( o3tl::toW(FilterExt.getStr()) );
    }
 }
 
@@ -1220,10 +1213,10 @@ void VistaFilePickerImpl::onAutoExtensionChanged (bool bChecked)
     aLock.clear();
     // <- SYNCHRONIZED
 
-    LPCWSTR pExt = 0;
+    PCWSTR pExt = nullptr;
     if ( bChecked )
     {
-        pExt = reinterpret_cast<LPCTSTR>(sExt.getStr());
+        pExt = o3tl::toW(sExt.getStr());
         pExt = wcsrchr( pExt, '.' );
         if ( pExt )
             pExt++;
@@ -1240,6 +1233,4 @@ bool VistaFilePickerImpl::onFileTypeChanged( UINT /*nTypeIndex*/ )
 } // namespace win32
 } // namespace fpicker
 
-#endif // __IFileDialogCustomize_INTERFACE_DEFINED__
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
