@@ -30,14 +30,14 @@ import java.sql.*;
 /**
  * Implements a log mechanism to create a protocol of all steps of e.g. an api test
  * It provides the possibility to write the logged meesages to a file and/or
- * to stdout/stderr (if neccessary at the same time!).
+ * to stdout/stderr (if necessary at the same time!).
  *
  *  TODO
- *      - implement filter, which e.g. supress showing of INFO data
+ *      - implement filter, which e.g. suppress showing of INFO data
  */
 public class Protocol extends JComponent
 {
-    // ____________________
+
     /**
      * Note: Following values can be combined - they are interpreted as flags.
      *
@@ -55,8 +55,8 @@ public class Protocol extends JComponent
      * @const   TYPE_INFO               this protocol line represent some debug data for analyzing
      */
     public  static final int    MODE_STDOUT             = 1;
-    public  static final int    MODE_STDERR             = 2;
-    public  static final int    MODE_ASCII              = 4;
+    private  static final int    MODE_STDERR             = 2;
+    private  static final int    MODE_ASCII              = 4;
     public  static final int    MODE_HTML               = 8;
 
     public  static final int    TYPE_OK                 =    1;
@@ -66,24 +66,24 @@ public class Protocol extends JComponent
     public  static final int    TYPE_SCOPE_OPEN         =   16;
     public  static final int    TYPE_SCOPE_CLOSE        =   32;
     public  static final int    TYPE_TESTMARK           =   64;
-    public  static final int    TYPE_ERROR_INFO         =  128;
+    private  static final int    TYPE_ERROR_INFO         =  128;
     public  static final int    TYPE_WARNING_INFO       =  256;
-    public  static final int    TYPE_STATISTIC          =  512;
-    public  static final int    TYPE_LINK               = 1024;
+    private  static final int    TYPE_STATISTIC          =  512;
+    private  static final int    TYPE_LINK               = 1024;
 
     public  static final int    FILTER_NONE             = 0;
-    public  static final int    FILTER_OK               = TYPE_OK;
-    public  static final int    FILTER_ERROR            = TYPE_ERROR;
-    public  static final int    FILTER_WARNING          = TYPE_WARNING;
-    public  static final int    FILTER_INFO             = TYPE_INFO;
-    public  static final int    FILTER_SCOPES           = TYPE_SCOPE_OPEN | TYPE_SCOPE_CLOSE;
-    public  static final int    FILTER_TESTMARK         = TYPE_TESTMARK;
-    public  static final int    FILTER_ERROR_INFO       = TYPE_ERROR_INFO;
-    public  static final int    FILTER_WARNING_INFO     = TYPE_WARNING_INFO;
-    public  static final int    FILTER_STATISTIC        = TYPE_STATISTIC;
-    public  static final int    FILTER_LINK             = TYPE_LINK;
 
-    // ____________________
+
+
+
+
+
+
+
+
+
+
+
     /**
      */
     private static final int    MARK_DIFF               = 5;
@@ -128,7 +128,7 @@ public class Protocol extends JComponent
     private static final String BGCOLOR_LINK            = BGCOLOR_INFO;
     private static final String FGCOLOR_LINK            = FGCOLOR_INFO;
 
-    // ____________________
+
     /**
      * @member  m_nMode         the mode, in which this protocol object runs
      * @member  m_nFilter       can be used to filter log messages by type
@@ -139,38 +139,37 @@ public class Protocol extends JComponent
      * @member  m_nWarnings     count warnings in protocol
      * @member  m_nTestMarks    count test marker in protocol
      */
-    private int                 m_nMode     ;
-    private int                 m_nFilter   ;
-    private String              m_sFileName ;
+    private final int                 m_nMode     ;
+    private final int                 m_nFilter   ;
+    private final String              m_sFileName ;
     private long                m_nLine     ;
     private long                m_nScope    ;
     private long                m_nErrors   ;
     private long                m_nWarnings ;
     private long                m_nTestMarks;
     private Timestamp           m_aStartTime;
-    private Timestamp           m_aEndTime  ;
 
-    // ____________________
+
     /**
      * special helper class to represent one line of a protocol.
      * Such line can be specified as a special one (ERROR, WARNING ...).
      * That makes it possible to analyze the whole protocol using tools.
      */
-    class ProtocolLine
+    private class ProtocolLine
     {
         /// the line number of this protocol line (size of the vector of all protocol lines cn be used to count such lines!)
-        private long m_nLine;
+        private final long m_nLine;
         /// deepness of the current scope
-        private long m_nScope;
+        private final long m_nScope;
         /// mark line as an error, warning, data entry ... (see const definitions before)
-        private int m_nType;
+        private final int m_nType;
         /// of course, we have to know the logged message too :-)
-        private String m_sMessage;
+        private final String m_sMessage;
         /// and it can be useful to know the current time, when this line was created
-        private Timestamp m_aStamp;
+        private final Timestamp m_aStamp;
 
         /** ctor for fast initializing of such line */
-        public ProtocolLine( long   nLine    ,
+        private ProtocolLine( long   nLine    ,
                              long   nScope   ,
                              int    nType    ,
                              String sMessage )
@@ -183,6 +182,7 @@ public class Protocol extends JComponent
         }
 
         /** format this line as an ascii string for writing log files */
+        @Override
         public synchronized String toString()
         {
             StringBuffer sLine = new StringBuffer(1000);
@@ -271,16 +271,16 @@ public class Protocol extends JComponent
          * format this line as a string for writing log files
          * using the html format
          */
-        public synchronized String toHTML()
+        private synchronized String toHTML()
         {
             StringBuffer sLine = new StringBuffer(1000);
             sLine.append("<tr>");
 
             // insert line number
             if (m_nLine % MARK_DIFF == 0)
-                impl_generateColoredHTMLCell(sLine, new Long(m_nLine).toString(), BGCOLOR_LINECOL, FGCOLOR_LINECOL_MARKED, true);
+                impl_generateColoredHTMLCell(sLine, Long.toString(m_nLine), BGCOLOR_LINECOL, FGCOLOR_LINECOL_MARKED, true);
             else
-                impl_generateColoredHTMLCell(sLine, new Long(m_nLine).toString(), BGCOLOR_LINECOL, FGCOLOR_LINECOL_NORMAL, false);
+                impl_generateColoredHTMLCell(sLine, Long.toString(m_nLine), BGCOLOR_LINECOL, FGCOLOR_LINECOL_NORMAL, false);
 
             // add time stamp
             impl_generateColoredHTMLCell(sLine, m_aStamp.toString()+" ", BGCOLOR_TIMESTAMP, FGCOLOR_TIMESTAMP, false);
@@ -350,7 +350,7 @@ public class Protocol extends JComponent
                 bTypeCellFilled = true;
             }
 
-            // if no tyope information was added to the current coloum, we must
+            // if no type information was added to the current column, we must
             // write any content into this cell. Otherwise some browser
             // shows a strange layout!
             if (! bTypeCellFilled)
@@ -405,7 +405,7 @@ public class Protocol extends JComponent
         }
 
         /**
-         * create a colored table cell formated as HTML.
+         * create a colored table cell formatted as HTML.
          *
          * @param   sCell
          *          an outside string buffer, which can be
@@ -443,16 +443,16 @@ public class Protocol extends JComponent
         }
     }
 
-    // ____________________
+
     /**
      * ctor
-     * It creates a new instance of this class and innitialize it in the right mode.
+     * It creates a new instance of this class and initializes it in the right mode.
      *
      * @param nMode
      *          specify how the log should be generated.
      *
      * @param nFilter
-     *          can be used to filter log messages by it's type.
+     *          can be used to filter log messages by its type.
      *
      * @param sFileName
      *          the name of the log file (if nMode requires a log file)
@@ -471,32 +471,15 @@ public class Protocol extends JComponent
         m_aStartTime = new Timestamp(System.currentTimeMillis());
     }
 
-    // ____________________
-    /**
-     * For some modes it's neccessary, that we write some additional
-     * information to the log. E.g. for html we must generate close targets.
-     */
-    public synchronized void finish()
-    {
-        // Preferr HTML ... because we can't write ASCII and HTML contents to the same log file!
-        String sContent;
-        if ((m_nMode & MODE_HTML) == MODE_HTML)
-            sContent = impl_generateHTMLFooter();
-        else
-        if ((m_nMode & MODE_ASCII) == MODE_ASCII)
-            sContent = impl_generateAsciiFooter();
-        else
-            return;
 
-        impl_writeToLogFile(m_sFileName, true, sContent);
-    }
 
-    // ____________________
+
+
     /**
      * log an unspecified message.
      *
-     * Sometimes it's not neccessary to set a special type for an message.
-     * The pure message seams to be enough. The type of such "pure messages"
+     * Sometimes it's not necessary to set a special type for an message.
+     * The pure message seems to be enough. The type of such "pure messages"
      * will be set to INFO.
      *
      * @param   sMessage
@@ -509,7 +492,7 @@ public class Protocol extends JComponent
         log(TYPE_INFO, sMessage);
     }
 
-    // ____________________
+
     /**
      * log an exception.
      *
@@ -531,48 +514,14 @@ public class Protocol extends JComponent
         log(TYPE_SCOPE_CLOSE | TYPE_ERROR_INFO, "");
     }
 
-    // ____________________
-    /**
-     * log different property arrays.
-     *
-     * @param   lProps
-     *              the array of properties
-     */
-    public synchronized void log( /*IN*/ com.sun.star.beans.NamedValue[] lProps )
-    {
-        StringBuffer sValues = new StringBuffer(1000);
-        impl_logPropertyArray(sValues, lProps);
 
-        log(TYPE_SCOPE_OPEN  | TYPE_INFO, "property array ["+lProps.length+"]:");
-        log(TYPE_SCOPE_CLOSE | TYPE_INFO, sValues.toString()                   );
-    }
 
-    public synchronized void log( /*IN*/ com.sun.star.beans.PropertyValue[] lProps )
-    {
-        StringBuffer sValues = new StringBuffer(1000);
-        impl_logPropertyArray(sValues, lProps);
 
-        log(TYPE_SCOPE_OPEN  | TYPE_INFO, "property array ["+lProps.length+"]:");
-        log(TYPE_SCOPE_CLOSE | TYPE_INFO, sValues.toString()                   );
-    }
 
-    public synchronized void log( /*IN*/ com.sun.star.beans.NamedValue aProp )
-    {
-        StringBuffer sValue = new StringBuffer(1000);
-        impl_logProperty(sValue, aProp);
 
-        log(TYPE_SCOPE_OPEN  | TYPE_INFO, "property:"      );
-        log(TYPE_SCOPE_CLOSE | TYPE_INFO, sValue.toString());
-    }
 
-    public synchronized void log( /*IN*/ com.sun.star.beans.PropertyValue aProp )
-    {
-        StringBuffer sValue = new StringBuffer(1000);
-        impl_logProperty(sValue, aProp);
 
-        log(TYPE_SCOPE_OPEN  | TYPE_INFO, "property:"      );
-        log(TYPE_SCOPE_CLOSE | TYPE_INFO, sValue.toString());
-    }
+
 
     public synchronized void log( /*IN*/ Object aAny )
     {
@@ -583,7 +532,7 @@ public class Protocol extends JComponent
         log(TYPE_SCOPE_CLOSE | TYPE_INFO, sValue.toString());
     }
 
-    // ____________________
+
     /**
      * log a message.
      *
@@ -606,7 +555,7 @@ public class Protocol extends JComponent
 
         ++m_nLine;
 
-        // it's necessary to open scopes before creatig the protocol line
+        // it's necessary to open scopes before creating the protocol line
         // to guarantee right tab handling for new scope value!
         if ((nType & TYPE_SCOPE_OPEN) == TYPE_SCOPE_OPEN)
             ++m_nScope;
@@ -616,7 +565,7 @@ public class Protocol extends JComponent
         String       sAsciiLog = aLine.toString();
         String       sHTMLLog  = aLine.toHTML();
 
-        // it's necessary to close scope after creatig the protocol line
+        // it's necessary to close scope after creating the protocol line
         // to guarantee right tab handling for old scope value!
         if (
             ( m_nScope                  >  0               ) &&
@@ -642,8 +591,8 @@ public class Protocol extends JComponent
             System.err.print(sAsciiLog);
         // no else - it's a bit field of possible reactions!
         // But these both conditions must be handled together.
-        // Because we cant generate different types of log contents to the same log file.
-        // We preferr HTML if both types are set.
+        // Because we can't generate different types of log contents to the same log file.
+        // We prefer HTML if both types are set.
         if (
             ((m_nMode & MODE_HTML ) == MODE_HTML ) ||
             ((m_nMode & MODE_ASCII) == MODE_ASCII)
@@ -670,24 +619,10 @@ public class Protocol extends JComponent
         }
     }
 
-    // ____________________
-    public synchronized void defineHyperlink( /*IN*/ String sTarget     ,
-                                              /*IN*/ String sDescription)
-    {
-        if ((m_nMode & MODE_HTML) != MODE_HTML)
-            return;
 
-        StringBuffer sLog = new StringBuffer(1000);
-        sLog.append("<a href=\"");
-        sLog.append(sTarget     );
-        sLog.append("\">"       );
-        sLog.append(sDescription);
-        sLog.append("</a>"      );
 
-        log(TYPE_LINK, sLog.toString());
-    }
 
-    // ____________________
+
     /**
      * log the current statistic values
      * We write it into our protocol buffer and
@@ -695,8 +630,8 @@ public class Protocol extends JComponent
      */
     public synchronized void logStatistics()
     {
-                  m_aEndTime = new Timestamp(System.currentTimeMillis());
-        Timestamp aDiff      = new Timestamp(m_aEndTime.getTime()-m_aStartTime.getTime());
+        Timestamp aEndTime   = new Timestamp(System.currentTimeMillis());
+        Timestamp aDiff      = new Timestamp(aEndTime.getTime()-m_aStartTime.getTime());
 
         int nLogType = TYPE_STATISTIC;
         if (m_nErrors > 0)
@@ -715,7 +650,7 @@ public class Protocol extends JComponent
         resetStatistics();
     }
 
-    public synchronized void resetStatistics()
+    private synchronized void resetStatistics()
     {
         m_nTestMarks = 0;
         m_nWarnings  = 0;
@@ -723,12 +658,12 @@ public class Protocol extends JComponent
         m_aStartTime = new Timestamp(System.currentTimeMillis());
     }
 
-    // ____________________
+
     /**
      * returns a generic html header for generating html log files
      *
-     * It's used from the method finish() to generate a valid html formated file.
-     * For that its neccessary to open some special html targets like e.g. <html>.
+     * It's used from the method finish() to generate a valid html formatted file.
+     * For that its necessary to open some special html targets like e.g. <html>.
      *
      * @return  A string, which includes the whole header.
      *
@@ -745,17 +680,6 @@ public class Protocol extends JComponent
         return "********************************************************************************\n";
     }
 
-    private String impl_generateHTMLFooter()
-    {
-        return "\n</table>\n</body>\n</html>\n";
-    }
-
-    private String impl_generateAsciiFooter()
-    {
-        return "\n\n";
-    }
-
-    // ____________________
     /**
      * helper to log different representations of a property(array)
      *
@@ -799,7 +723,7 @@ public class Protocol extends JComponent
         impl_logAny(sOut, aProp.Value);
     }
 
-    // ____________________
+
     /**
      * it trys to convert the given any into a suitable string notation .-)
     */
@@ -893,7 +817,7 @@ public class Protocol extends JComponent
             else
             if (com.sun.star.uno.AnyConverter.isArray(aAny))
             {
-                if (aAny instanceof java.lang.String[])
+                if (aAny instanceof String[])
                 {
                     sOut.append("[sequence< string >] {");
                     sOut.append("}");
@@ -940,7 +864,7 @@ public class Protocol extends JComponent
         }
     }
 
-    // ____________________
+
     /**
      * Writes the given content to the specified log file.
      */
