@@ -18,7 +18,6 @@
  */
 
 #include <classes/imagewrapper.hxx>
-#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/bitmap.hxx>
 #include <vcl/bitmapex.hxx>
@@ -32,10 +31,10 @@ using namespace com::sun::star::uno;
 namespace framework
 {
 
-static Sequence< sal_Int8 > impl_getStaticIdentifier()
+static Sequence< sal_Int8 > const & impl_getStaticIdentifier()
 {
     static const sal_uInt8 pGUID[16] = { 0x46, 0xAD, 0x69, 0xFB, 0xA7, 0xBE, 0x44, 0x83, 0xB2, 0xA7, 0xB3, 0xEC, 0x59, 0x4A, 0xB7, 0x00 };
-    static ::com::sun::star::uno::Sequence< sal_Int8 > seqID(reinterpret_cast<const sal_Int8*>(pGUID), 16);
+    static css::uno::Sequence< sal_Int8 > seqID(reinterpret_cast<const sal_Int8*>(pGUID), 16);
     return seqID;
 }
 
@@ -53,17 +52,17 @@ Sequence< sal_Int8 > ImageWrapper::GetUnoTunnelId()
 }
 
 // XBitmap
-com::sun::star::awt::Size SAL_CALL ImageWrapper::getSize() throw ( RuntimeException, std::exception )
+css::awt::Size SAL_CALL ImageWrapper::getSize()
 {
     SolarMutexGuard aGuard;
 
     BitmapEx    aBitmapEx( m_aImage.GetBitmapEx() );
     Size        aBitmapSize( aBitmapEx.GetSizePixel() );
 
-    return com::sun::star::awt::Size( aBitmapSize.Width(), aBitmapSize.Height() );
+    return css::awt::Size( aBitmapSize.Width(), aBitmapSize.Height() );
 }
 
-Sequence< sal_Int8 > SAL_CALL ImageWrapper::getDIB() throw ( RuntimeException, std::exception )
+Sequence< sal_Int8 > SAL_CALL ImageWrapper::getDIB()
 {
     SolarMutexGuard aGuard;
 
@@ -72,7 +71,7 @@ Sequence< sal_Int8 > SAL_CALL ImageWrapper::getDIB() throw ( RuntimeException, s
     return Sequence< sal_Int8 >( static_cast<sal_Int8 const *>(aMem.GetData()), aMem.Tell() );
 }
 
-Sequence< sal_Int8 > SAL_CALL ImageWrapper::getMaskDIB() throw ( RuntimeException, std::exception )
+Sequence< sal_Int8 > SAL_CALL ImageWrapper::getMaskDIB()
 {
     SolarMutexGuard aGuard;
     BitmapEx    aBmpEx( m_aImage.GetBitmapEx() );
@@ -94,7 +93,7 @@ Sequence< sal_Int8 > SAL_CALL ImageWrapper::getMaskDIB() throw ( RuntimeExceptio
 }
 
 // XUnoTunnel
-sal_Int64 SAL_CALL ImageWrapper::getSomething( const Sequence< sal_Int8 >& aIdentifier ) throw ( RuntimeException, std::exception )
+sal_Int64 SAL_CALL ImageWrapper::getSomething( const Sequence< sal_Int8 >& aIdentifier )
 {
     if ( aIdentifier == impl_getStaticIdentifier() )
         return reinterpret_cast< sal_Int64 >( this );
