@@ -17,12 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <framework/undomanagerhelper.hxx>
 
-#include "framework/undomanagerhelper.hxx"
-
+#include <com/sun/star/document/EmptyUndoStackException.hpp>
+#include <com/sun/star/document/UndoContextNotClosedException.hpp>
+#include <com/sun/star/document/UndoFailedException.hpp>
 #include <com/sun/star/lang/XComponent.hpp>
+#include <com/sun/star/util/InvalidStateException.hpp>
+#include <com/sun/star/util/NotLockedException.hpp>
 
-#include <cppuhelper/interfacecontainer.hxx>
+#include <comphelper/interfacecontainer2.hxx>
 #include <cppuhelper/exc_hlp.hxx>
 #include <comphelper/flagguard.hxx>
 #include <comphelper/asyncnotification.hxx>
@@ -30,26 +34,20 @@
 #include <tools/diagnose_ex.h>
 #include <osl/conditn.hxx>
 
+#include <functional>
 #include <stack>
 #include <queue>
-#include <boost/function.hpp>
 
-//......................................................................................................................
 namespace framework
 {
-//......................................................................................................................
 
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::uno::XInterface;
     using ::com::sun::star::uno::UNO_QUERY;
-    using ::com::sun::star::uno::UNO_QUERY_THROW;
-    using ::com::sun::star::uno::UNO_SET_THROW;
     using ::com::sun::star::uno::Exception;
     using ::com::sun::star::uno::RuntimeException;
     using ::com::sun::star::uno::Any;
-    using ::com::sun::star::uno::makeAny;
     using ::com::sun::star::uno::Sequence;
-    using ::com::sun::star::uno::Type;
     using ::com::sun::star::document::XUndoManagerListener;
     using ::com::sun::star::document::UndoManagerEvent;
     using ::com::sun::star::document::EmptyUndoStackException;
@@ -65,27 +63,25 @@ namespace framework
     using ::com::sun::star::util::XModifyListener;
     using ::svl::IUndoManager;
 
-    //==================================================================================================================
     //= UndoActionWrapper
-    //==================================================================================================================
+
     class UndoActionWrapper : public SfxUndoAction
     {
     public:
-                            UndoActionWrapper(
+        explicit            UndoActionWrapper(
                                 Reference< XUndoAction > const& i_undoAction
                             );
-        virtual             ~UndoActionWrapper();
+        virtual             ~UndoActionWrapper() override;
 
-        virtual OUString    GetComment() const;
-        virtual void        Undo();
-        virtual void        Redo();
-        virtual bool        CanRepeat(SfxRepeatTarget&) const;
+        virtual OUString    GetComment() const override;
+        virtual void        Undo() override;
+        virtual void        Redo() override;
+        virtual bool        CanRepeat(SfxRepeatTarget&) const override;
 
     private:
         const Reference< XUndoAction >  m_xUndoAction;
     };
 
-    //------------------------------------------------------------------------------------------------------------------
     UndoActionWrapper::UndoActionWrapper( Reference< XUndoAction > const& i_undoAction )
         :SfxUndoAction()
         ,m_xUndoAction( i_undoAction )
@@ -93,7 +89,6 @@ namespace framework
         ENSURE_OR_THROW( m_xUndoAction.is(), "illegal undo action" );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     UndoActionWrapper::~UndoActionWrapper()
     {
         try
@@ -108,7 +103,6 @@ namespace framework
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     OUString UndoActionWrapper::GetComment() const
     {
         OUString sComment;
@@ -123,31 +117,27 @@ namespace framework
         return sComment;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoActionWrapper::Undo()
     {
         m_xUndoAction->undo();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoActionWrapper::Redo()
     {
         m_xUndoAction->redo();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     bool UndoActionWrapper::CanRepeat(SfxRepeatTarget&) const
     {
-        return sal_False;
+        return false;
     }
 
-    //==================================================================================================================
     //= UndoManagerRequest
-    //==================================================================================================================
+
     class UndoManagerRequest : public ::comphelper::AnyEvent
     {
     public:
-        UndoManagerRequest( ::boost::function0< void > const& i_request )
+        explicit UndoManagerRequest( ::std::function<void ()> const& i_request )
             :m_request( i_request )
             ,m_caughtException()
             ,m_finishCondition()
@@ -178,39 +168,35 @@ namespace framework
         void cancel( const Reference< XInterface >& i_context )
         {
             m_caughtException <<= RuntimeException(
-                OUString( "Concurrency error: an ealier operation on the stack failed." ),
+                "Concurrency error: an earlier operation on the stack failed.",
                 i_context
             );
             m_finishCondition.set();
         }
 
     protected:
-        ~UndoManagerRequest()
+        virtual ~UndoManagerRequest() override
         {
         }
 
     private:
-        ::boost::function0< void >  m_request;
+        ::std::function<void ()>    m_request;
         Any                         m_caughtException;
         ::osl::Condition            m_finishCondition;
     };
 
-    //------------------------------------------------------------------------------------------------------------------
-
-    //==================================================================================================================
     //= UndoManagerHelper_Impl
-    //==================================================================================================================
+
     class UndoManagerHelper_Impl : public SfxUndoListener
     {
     private:
         ::osl::Mutex                        m_aMutex;
         ::osl::Mutex                        m_aQueueMutex;
-        bool                                m_disposed;
         bool                                m_bAPIActionRunning;
         bool                                m_bProcessingEvents;
         sal_Int32                           m_nLockCount;
-        ::cppu::OInterfaceContainerHelper   m_aUndoListeners;
-        ::cppu::OInterfaceContainerHelper   m_aModifyListeners;
+        ::comphelper::OInterfaceContainerHelper2   m_aUndoListeners;
+        ::comphelper::OInterfaceContainerHelper2   m_aModifyListeners;
         IUndoManagerImplementation&         m_rUndoManagerImplementation;
         ::std::stack< bool >                m_aContextVisibilities;
 #if OSL_DEBUG_LEVEL > 0
@@ -223,10 +209,9 @@ namespace framework
         ::osl::Mutex&   getMutex() { return m_aMutex; }
 
     public:
-        UndoManagerHelper_Impl( IUndoManagerImplementation& i_undoManagerImpl )
+        explicit UndoManagerHelper_Impl( IUndoManagerImplementation& i_undoManagerImpl )
             :m_aMutex()
             ,m_aQueueMutex()
-            ,m_disposed( false )
             ,m_bAPIActionRunning( false )
             ,m_bProcessingEvents( false )
             ,m_nLockCount( 0 )
@@ -241,30 +226,27 @@ namespace framework
         {
         }
 
-        //..............................................................................................................
         IUndoManager& getUndoManager() const
         {
             return m_rUndoManagerImplementation.getImplUndoManager();
         }
 
-        //..............................................................................................................
         Reference< XUndoManager > getXUndoManager() const
         {
             return m_rUndoManagerImplementation.getThis();
         }
 
         // SfxUndoListener
-        virtual void actionUndone( const OUString& i_actionComment );
-        virtual void actionRedone( const OUString& i_actionComment );
-        virtual void undoActionAdded( const OUString& i_actionComment );
-        virtual void cleared();
-        virtual void clearedRedo();
-        virtual void resetAll();
-        virtual void listActionEntered( const OUString& i_comment );
-        virtual void listActionLeft( const OUString& i_comment );
-        virtual void listActionLeftAndMerged();
-        virtual void listActionCancelled();
-        virtual void undoManagerDying();
+        virtual void actionUndone( const OUString& i_actionComment ) override;
+        virtual void actionRedone( const OUString& i_actionComment ) override;
+        virtual void undoActionAdded( const OUString& i_actionComment ) override;
+        virtual void cleared() override;
+        virtual void clearedRedo() override;
+        virtual void resetAll() override;
+        virtual void listActionEntered( const OUString& i_comment ) override;
+        virtual void listActionLeft( const OUString& i_comment ) override;
+        virtual void listActionCancelled() override;
+        virtual void undoManagerDying() override;
 
         // public operations
         void disposing();
@@ -308,16 +290,11 @@ namespace framework
         void notify(    OUString const& i_title,
                         void ( SAL_CALL XUndoManagerListener::*i_notificationMethod )( const UndoManagerEvent& )
                     );
-        void notify( void ( SAL_CALL XUndoManagerListener::*i_notificationMethod )( const UndoManagerEvent& ) )
-        {
-            notify( OUString(), i_notificationMethod );
-        }
-
         void notify( void ( SAL_CALL XUndoManagerListener::*i_notificationMethod )( const EventObject& ) );
 
     private:
         /// adds a function to be called to the request processor's queue
-        void impl_processRequest( ::boost::function0< void > const& i_request, IMutexGuard& i_instanceLock );
+        void impl_processRequest(::std::function<void ()> const& i_request, IMutexGuard& i_instanceLock);
 
         /// impl-versions of the XUndoManager API.
         void impl_enterUndoContext( const OUString& i_title, const bool i_hidden );
@@ -329,7 +306,6 @@ namespace framework
         void impl_reset();
     };
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::disposing()
     {
         EventObject aEvent;
@@ -340,11 +316,8 @@ namespace framework
         ::osl::MutexGuard aGuard( m_aMutex );
 
         getUndoManager().RemoveUndoListener( *this );
-
-        m_disposed = true;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     UndoManagerEvent UndoManagerHelper_Impl::buildEvent( OUString const& i_title ) const
     {
         UndoManagerEvent aEvent;
@@ -354,21 +327,19 @@ namespace framework
         return aEvent;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::impl_notifyModified()
     {
         const EventObject aEvent( getXUndoManager() );
         m_aModifyListeners.notifyEach( &XModifyListener::modified, aEvent );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::notify( OUString const& i_title,
         void ( SAL_CALL XUndoManagerListener::*i_notificationMethod )( const UndoManagerEvent& ) )
     {
         const UndoManagerEvent aEvent( buildEvent( i_title ) );
 
         // TODO: this notification method here is used by UndoManagerHelper_Impl, to multiplex the notifications we
-        // receive from the IUndoManager. Those notitications are sent with a locked SolarMutex, which means
+        // receive from the IUndoManager. Those notifications are sent with a locked SolarMutex, which means
         // we're doing the multiplexing here with a locked SM, too. Which is Bad (TM).
         // Fixing this properly would require outsourcing all the notifications into an own thread - which might lead
         // to problems of its own, since clients might expect synchronous notifications.
@@ -377,7 +348,6 @@ namespace framework
         impl_notifyModified();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::notify( void ( SAL_CALL XUndoManagerListener::*i_notificationMethod )( const EventObject& ) )
     {
         const EventObject aEvent( getXUndoManager() );
@@ -388,89 +358,61 @@ namespace framework
         impl_notifyModified();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::enterUndoContext( const OUString& i_title, const bool i_hidden, IMutexGuard& i_instanceLock )
     {
         impl_processRequest(
-            ::boost::bind(
-                &UndoManagerHelper_Impl::impl_enterUndoContext,
-                this,
-                ::boost::cref( i_title ),
-                i_hidden
-            ),
+            [this, &i_title, i_hidden] () { return this->impl_enterUndoContext(i_title, i_hidden); },
             i_instanceLock
         );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::leaveUndoContext( IMutexGuard& i_instanceLock )
     {
         impl_processRequest(
-            ::boost::bind(
-                &UndoManagerHelper_Impl::impl_leaveUndoContext,
-                this
-            ),
+            [this] () { return this->impl_leaveUndoContext(); },
             i_instanceLock
         );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::addUndoAction( const Reference< XUndoAction >& i_action, IMutexGuard& i_instanceLock )
     {
         if ( !i_action.is() )
             throw IllegalArgumentException(
-                OUString( "illegal undo action object" ),
+                "illegal undo action object",
                 getXUndoManager(),
                 1
             );
 
         impl_processRequest(
-            ::boost::bind(
-                &UndoManagerHelper_Impl::impl_addUndoAction,
-                this,
-                ::boost::ref( i_action )
-            ),
+            [this, &i_action] () { return this->impl_addUndoAction(i_action); },
             i_instanceLock
         );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::clear( IMutexGuard& i_instanceLock )
     {
         impl_processRequest(
-            ::boost::bind(
-                &UndoManagerHelper_Impl::impl_clear,
-                this
-            ),
+            [this] () { return this->impl_clear(); },
             i_instanceLock
         );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::clearRedo( IMutexGuard& i_instanceLock )
     {
         impl_processRequest(
-            ::boost::bind(
-                &UndoManagerHelper_Impl::impl_clearRedo,
-                this
-            ),
+            [this] () { return this->impl_clearRedo(); },
             i_instanceLock
         );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::reset( IMutexGuard& i_instanceLock )
     {
         impl_processRequest(
-            ::boost::bind(
-                &UndoManagerHelper_Impl::impl_reset,
-                this
-            ),
+            [this] () { return this->impl_reset(); },
             i_instanceLock
         );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::lock()
     {
         // SYNCHRONIZED --->
@@ -484,7 +426,6 @@ namespace framework
         // <--- SYNCHRONIZED
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::unlock()
     {
         // SYNCHRONIZED --->
@@ -501,8 +442,7 @@ namespace framework
         // <--- SYNCHRONIZED
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    void UndoManagerHelper_Impl::impl_processRequest( ::boost::function0< void > const& i_request, IMutexGuard& i_instanceLock )
+    void UndoManagerHelper_Impl::impl_processRequest(::std::function<void ()> const& i_request, IMutexGuard& i_instanceLock)
     {
         // create the request, and add it to our queue
         ::rtl::Reference< UndoManagerRequest > pRequest( new UndoManagerRequest( i_request ) );
@@ -563,7 +503,6 @@ namespace framework
         while ( true );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::impl_enterUndoContext( const OUString& i_title, const bool i_hidden )
     {
         // SYNCHRONIZED --->
@@ -574,15 +513,15 @@ namespace framework
             // ignore this request if the manager is locked
             return;
 
-        if ( i_hidden && ( rUndoManager.GetUndoActionCount( IUndoManager::CurrentLevel ) == 0 ) )
+        if ( i_hidden && ( rUndoManager.GetUndoActionCount() == 0 ) )
             throw EmptyUndoStackException(
-                OUString( "can't enter a hidden context without a previous Undo action" ),
+                "can't enter a hidden context without a previous Undo action",
                 m_rUndoManagerImplementation.getThis()
             );
 
         {
             ::comphelper::FlagGuard aNotificationGuard( m_bAPIActionRunning );
-            rUndoManager.EnterListAction( i_title, OUString() );
+            rUndoManager.EnterListAction( i_title, OUString(), 0, ViewShellId(-1) );
         }
 
         m_aContextVisibilities.push( i_hidden );
@@ -595,7 +534,6 @@ namespace framework
         impl_notifyModified();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::impl_leaveUndoContext()
     {
         // SYNCHRONIZED --->
@@ -608,13 +546,13 @@ namespace framework
 
         if ( !rUndoManager.IsInListAction() )
             throw InvalidStateException(
-                OUString( "no active undo context" ),
+                "no active undo context",
                 getXUndoManager()
             );
 
         size_t nContextElements = 0;
 
-        const bool isHiddenContext = m_aContextVisibilities.top();;
+        const bool isHiddenContext = m_aContextVisibilities.top();
         m_aContextVisibilities.pop();
 
         const bool bHadRedoActions = ( rUndoManager.GetRedoActionCount( IUndoManager::TopLevel ) > 0 );
@@ -628,7 +566,7 @@ namespace framework
         const bool bHasRedoActions = ( rUndoManager.GetRedoActionCount( IUndoManager::TopLevel ) > 0 );
 
         // prepare notification
-        void ( SAL_CALL XUndoManagerListener::*notificationMethod )( const UndoManagerEvent& ) = NULL;
+        void ( SAL_CALL XUndoManagerListener::*notificationMethod )( const UndoManagerEvent& ) = nullptr;
 
         UndoManagerEvent aContextEvent( buildEvent( OUString() ) );
         const EventObject aClearedEvent( getXUndoManager() );
@@ -642,7 +580,7 @@ namespace framework
         }
         else
         {
-            aContextEvent.UndoActionTitle = rUndoManager.GetUndoActionComment( 0, IUndoManager::CurrentLevel );
+            aContextEvent.UndoActionTitle = rUndoManager.GetUndoActionComment();
             notificationMethod = &XUndoManagerListener::leftContext;
         }
 
@@ -655,7 +593,6 @@ namespace framework
         impl_notifyModified();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::impl_doUndoRedo( IMutexGuard& i_externalLock, const bool i_undo )
     {
         ::osl::Guard< ::framework::IMutex > aExternalGuard( i_externalLock.getGuardedMutex() );
@@ -703,7 +640,6 @@ namespace framework
         // So, we do not need to do this notification here ourself.
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::impl_addUndoAction( const Reference< XUndoAction >& i_action )
     {
         // SYNCHRONIZED --->
@@ -717,12 +653,12 @@ namespace framework
         const UndoManagerEvent aEventAdd( buildEvent( i_action->getTitle() ) );
         const EventObject aEventClear( getXUndoManager() );
 
-        const bool bHadRedoActions = ( rUndoManager.GetRedoActionCount( IUndoManager::CurrentLevel ) > 0 );
+        const bool bHadRedoActions = ( rUndoManager.GetRedoActionCount() > 0 );
         {
             ::comphelper::FlagGuard aNotificationGuard( m_bAPIActionRunning );
             rUndoManager.AddUndoAction( new UndoActionWrapper( i_action ) );
         }
-        const bool bHasRedoActions = ( rUndoManager.GetRedoActionCount( IUndoManager::CurrentLevel ) > 0 );
+        const bool bHasRedoActions = ( rUndoManager.GetRedoActionCount() > 0 );
 
         aGuard.clear();
         // <--- SYNCHRONIZED
@@ -733,7 +669,6 @@ namespace framework
         impl_notifyModified();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::impl_clear()
     {
         // SYNCHRONIZED --->
@@ -756,7 +691,6 @@ namespace framework
         impl_notifyModified();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::impl_clearRedo()
     {
         // SYNCHRONIZED --->
@@ -779,7 +713,6 @@ namespace framework
         impl_notifyModified();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::impl_reset()
     {
         // SYNCHRONIZED --->
@@ -799,7 +732,6 @@ namespace framework
         impl_notifyModified();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::actionUndone( const OUString& i_actionComment )
     {
         UndoManagerEvent aEvent;
@@ -810,7 +742,6 @@ namespace framework
         impl_notifyModified();
     }
 
-     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::actionRedone( const OUString& i_actionComment )
     {
         UndoManagerEvent aEvent;
@@ -821,7 +752,6 @@ namespace framework
         impl_notifyModified();
     }
 
-     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::undoActionAdded( const OUString& i_actionComment )
     {
         if ( m_bAPIActionRunning )
@@ -830,7 +760,6 @@ namespace framework
         notify( i_actionComment, &XUndoManagerListener::undoActionAdded );
     }
 
-     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::cleared()
     {
         if ( m_bAPIActionRunning )
@@ -839,7 +768,6 @@ namespace framework
         notify( &XUndoManagerListener::allActionsCleared );
     }
 
-     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::clearedRedo()
     {
         if ( m_bAPIActionRunning )
@@ -848,7 +776,6 @@ namespace framework
         notify( &XUndoManagerListener::redoActionsCleared );
     }
 
-     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::resetAll()
     {
         if ( m_bAPIActionRunning )
@@ -857,7 +784,6 @@ namespace framework
         notify( &XUndoManagerListener::resetAll );
     }
 
-     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::listActionEntered( const OUString& i_comment )
     {
 #if OSL_DEBUG_LEVEL > 0
@@ -870,7 +796,6 @@ namespace framework
         notify( i_comment, &XUndoManagerListener::enteredContext );
     }
 
-     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::listActionLeft( const OUString& i_comment )
     {
 #if OSL_DEBUG_LEVEL > 0
@@ -885,22 +810,6 @@ namespace framework
         notify( i_comment, &XUndoManagerListener::leftContext );
     }
 
-     //------------------------------------------------------------------------------------------------------------------
-    void UndoManagerHelper_Impl::listActionLeftAndMerged()
-    {
-#if OSL_DEBUG_LEVEL > 0
-        const bool bCurrentContextIsAPIContext = m_aContextAPIFlags.top();
-        m_aContextAPIFlags.pop();
-        OSL_ENSURE( bCurrentContextIsAPIContext == m_bAPIActionRunning, "UndoManagerHelper_Impl::listActionLeftAndMerged: API and non-API contexts interwoven!" );
-#endif
-
-        if ( m_bAPIActionRunning )
-            return;
-
-        notify( &XUndoManagerListener::leftHiddenContext );
-    }
-
-     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::listActionCancelled()
     {
 #if OSL_DEBUG_LEVEL > 0
@@ -912,127 +821,101 @@ namespace framework
         if ( m_bAPIActionRunning )
             return;
 
-        notify( &XUndoManagerListener::cancelledContext );
+        notify( OUString(), &XUndoManagerListener::cancelledContext );
     }
 
-     //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::undoManagerDying()
     {
         // TODO: do we need to care? Or is this the responsibility of our owner?
     }
 
-    //==================================================================================================================
     //= UndoManagerHelper
-    //==================================================================================================================
-    //------------------------------------------------------------------------------------------------------------------
+
     UndoManagerHelper::UndoManagerHelper( IUndoManagerImplementation& i_undoManagerImpl )
-        :m_pImpl( new UndoManagerHelper_Impl( i_undoManagerImpl ) )
+        :m_xImpl( new UndoManagerHelper_Impl( i_undoManagerImpl ) )
     {
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     UndoManagerHelper::~UndoManagerHelper()
     {
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::disposing()
     {
-        m_pImpl->disposing();
+        m_xImpl->disposing();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::enterUndoContext( const OUString& i_title, IMutexGuard& i_instanceLock )
     {
-        m_pImpl->enterUndoContext( i_title, false, i_instanceLock );
+        m_xImpl->enterUndoContext( i_title, false, i_instanceLock );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::enterHiddenUndoContext( IMutexGuard& i_instanceLock )
     {
-        m_pImpl->enterUndoContext( OUString(), true, i_instanceLock );
+        m_xImpl->enterUndoContext( OUString(), true, i_instanceLock );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::leaveUndoContext( IMutexGuard& i_instanceLock )
     {
-        m_pImpl->leaveUndoContext( i_instanceLock );
+        m_xImpl->leaveUndoContext( i_instanceLock );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::undo( IMutexGuard& i_instanceLock )
     {
         impl_processRequest(
-            ::boost::bind(
-                &UndoManagerHelper_Impl::impl_doUndoRedo,
-                this,
-                ::boost::ref( i_instanceLock ),
-                true
-            ),
+            [this, &i_instanceLock] () { return this->impl_doUndoRedo(i_instanceLock, true); },
             i_instanceLock
         );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper_Impl::redo( IMutexGuard& i_instanceLock )
     {
         impl_processRequest(
-            ::boost::bind(
-                &UndoManagerHelper_Impl::impl_doUndoRedo,
-                this,
-                ::boost::ref( i_instanceLock ),
-                false
-            ),
+            [this, &i_instanceLock] () { return this->impl_doUndoRedo(i_instanceLock, false); },
             i_instanceLock
         );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::addUndoAction( const Reference< XUndoAction >& i_action, IMutexGuard& i_instanceLock )
     {
-        m_pImpl->addUndoAction( i_action, i_instanceLock );
+        m_xImpl->addUndoAction( i_action, i_instanceLock );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::undo( IMutexGuard& i_instanceLock )
     {
-        m_pImpl->undo( i_instanceLock );
+        m_xImpl->undo( i_instanceLock );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::redo( IMutexGuard& i_instanceLock )
     {
-        m_pImpl->redo( i_instanceLock );
+        m_xImpl->redo( i_instanceLock );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    ::sal_Bool UndoManagerHelper::isUndoPossible() const
+    bool UndoManagerHelper::isUndoPossible() const
     {
         // SYNCHRONIZED --->
-        ::osl::MutexGuard aGuard( m_pImpl->getMutex() );
-        IUndoManager& rUndoManager = m_pImpl->getUndoManager();
+        ::osl::MutexGuard aGuard( m_xImpl->getMutex() );
+        IUndoManager& rUndoManager = m_xImpl->getUndoManager();
         if ( rUndoManager.IsInListAction() )
-            return sal_False;
+            return false;
         return rUndoManager.GetUndoActionCount( IUndoManager::TopLevel ) > 0;
         // <--- SYNCHRONIZED
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    ::sal_Bool UndoManagerHelper::isRedoPossible() const
+    bool UndoManagerHelper::isRedoPossible() const
     {
         // SYNCHRONIZED --->
-        ::osl::MutexGuard aGuard( m_pImpl->getMutex() );
-        const IUndoManager& rUndoManager = m_pImpl->getUndoManager();
+        ::osl::MutexGuard aGuard( m_xImpl->getMutex() );
+        const IUndoManager& rUndoManager = m_xImpl->getUndoManager();
         if ( rUndoManager.IsInListAction() )
-            return sal_False;
+            return false;
         return rUndoManager.GetRedoActionCount( IUndoManager::TopLevel ) > 0;
         // <--- SYNCHRONIZED
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     namespace
     {
-        //..............................................................................................................
+
         OUString lcl_getCurrentActionTitle( UndoManagerHelper_Impl& i_impl, const bool i_undo )
         {
             // SYNCHRONIZED --->
@@ -1054,7 +937,6 @@ namespace framework
             // <--- SYNCHRONIZED
         }
 
-        //..............................................................................................................
         Sequence< OUString > lcl_getAllActionTitles( UndoManagerHelper_Impl& i_impl, const bool i_undo )
         {
             // SYNCHRONIZED --->
@@ -1077,101 +959,85 @@ namespace framework
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     OUString UndoManagerHelper::getCurrentUndoActionTitle() const
     {
-        return lcl_getCurrentActionTitle( *m_pImpl, true );
+        return lcl_getCurrentActionTitle( *m_xImpl, true );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     OUString UndoManagerHelper::getCurrentRedoActionTitle() const
     {
-        return lcl_getCurrentActionTitle( *m_pImpl, false );
+        return lcl_getCurrentActionTitle( *m_xImpl, false );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     Sequence< OUString > UndoManagerHelper::getAllUndoActionTitles() const
     {
-        return lcl_getAllActionTitles( *m_pImpl, true );
+        return lcl_getAllActionTitles( *m_xImpl, true );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     Sequence< OUString > UndoManagerHelper::getAllRedoActionTitles() const
     {
-        return lcl_getAllActionTitles( *m_pImpl, false );
+        return lcl_getAllActionTitles( *m_xImpl, false );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::clear( IMutexGuard& i_instanceLock )
     {
-        m_pImpl->clear( i_instanceLock );
+        m_xImpl->clear( i_instanceLock );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::clearRedo( IMutexGuard& i_instanceLock )
     {
-        m_pImpl->clearRedo( i_instanceLock );
+        m_xImpl->clearRedo( i_instanceLock );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::reset( IMutexGuard& i_instanceLock )
     {
-        m_pImpl->reset( i_instanceLock );
+        m_xImpl->reset( i_instanceLock );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::lock()
     {
-        m_pImpl->lock();
+        m_xImpl->lock();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::unlock()
     {
-        m_pImpl->unlock();
+        m_xImpl->unlock();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    ::sal_Bool UndoManagerHelper::isLocked()
+    bool UndoManagerHelper::isLocked()
     {
         // SYNCHRONIZED --->
-        ::osl::MutexGuard aGuard( m_pImpl->getMutex() );
+        ::osl::MutexGuard aGuard( m_xImpl->getMutex() );
 
-        IUndoManager& rUndoManager = m_pImpl->getUndoManager();
+        IUndoManager& rUndoManager = m_xImpl->getUndoManager();
         return !rUndoManager.IsUndoEnabled();
         // <--- SYNCHRONIZED
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::addUndoManagerListener( const Reference< XUndoManagerListener >& i_listener )
     {
         if ( i_listener.is() )
-            m_pImpl->addUndoManagerListener( i_listener );
+            m_xImpl->addUndoManagerListener( i_listener );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::removeUndoManagerListener( const Reference< XUndoManagerListener >& i_listener )
     {
         if ( i_listener.is() )
-            m_pImpl->removeUndoManagerListener( i_listener );
+            m_xImpl->removeUndoManagerListener( i_listener );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::addModifyListener( const Reference< XModifyListener >& i_listener )
     {
         if ( i_listener.is() )
-            m_pImpl->addModifyListener( i_listener );
+            m_xImpl->addModifyListener( i_listener );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
     void UndoManagerHelper::removeModifyListener( const Reference< XModifyListener >& i_listener )
     {
         if ( i_listener.is() )
-            m_pImpl->removeModifyListener( i_listener );
+            m_xImpl->removeModifyListener( i_listener );
     }
 
-//......................................................................................................................
 } // namespace framework
-//......................................................................................................................
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
