@@ -49,10 +49,12 @@ namespace framework{
     @return     An iterator which points to the found item inside the hash or PatternHash::end()
                 if no pattern match this given <var>sURL</var>.
  */
-PatternHash::iterator PatternHash::findPatternKey( const OUString& sURL )
+namespace {
+
+PatternHash::const_iterator findPatternKey(PatternHash const * hash, const OUString& sURL)
 {
-    PatternHash::iterator pItem = this->begin();
-    while( pItem!=this->end() )
+    auto pItem = hash->begin();
+    while( pItem!=hash->end() )
     {
         WildCard aPattern(pItem->first);
         if (aPattern.Matches(sURL))
@@ -62,19 +64,21 @@ PatternHash::iterator PatternHash::findPatternKey( const OUString& sURL )
     return pItem;
 }
 
+}
+
 /**
     @short      initialize static member of class HandlerCache
     @descr      We use a singleton pattern to implement this handler cache.
                 That means it use two static member list to hold all necessary information
                 and a ref count mechanism to create/destroy it on demand.
  */
-HandlerHash* HandlerCache::m_pHandler  = NULL;
-PatternHash* HandlerCache::m_pPattern  = NULL;
+HandlerHash* HandlerCache::m_pHandler  = nullptr;
+PatternHash* HandlerCache::m_pPattern  = nullptr;
 sal_Int32    HandlerCache::m_nRefCount = 0;
-HandlerCFGAccess* HandlerCache::m_pConfig = NULL;
+HandlerCFGAccess* HandlerCache::m_pConfig = nullptr;
 
 /**
-    @short      ctor of the cache of all registered protoco handler
+    @short      ctor of the cache of all registered protocol handler
     @descr      It tries to open the right configuration package automatically
                 and fill the internal structures. After that the cache can be
                 used for read access on this data and perform some search
@@ -86,8 +90,8 @@ HandlerCache::HandlerCache()
 
     if (m_nRefCount==0)
     {
-        m_pHandler = new HandlerHash();
-        m_pPattern = new PatternHash();
+        m_pHandler = new HandlerHash;
+        m_pPattern = new PatternHash;
         m_pConfig  = new HandlerCFGAccess(PACKAGENAME_PROTOCOLHANDLER);
         m_pConfig->read(&m_pHandler,&m_pPattern);
         m_pConfig->setCache(this);
@@ -107,16 +111,14 @@ HandlerCache::~HandlerCache()
 
     if( m_nRefCount==1)
     {
-        m_pConfig->setCache(NULL);
-        m_pHandler->free();
-        m_pPattern->free();
+        m_pConfig->setCache(nullptr);
 
         delete m_pConfig;
         delete m_pHandler;
         delete m_pPattern;
-        m_pConfig = NULL;
-        m_pHandler= NULL;
-        m_pPattern= NULL;
+        m_pConfig = nullptr;
+        m_pHandler= nullptr;
+        m_pPattern= nullptr;
     }
 
     --m_nRefCount;
@@ -133,7 +135,7 @@ bool HandlerCache::search( const OUString& sURL, ProtocolHandler* pReturn ) cons
 
     SolarMutexGuard aGuard;
 
-    PatternHash::const_iterator pItem = m_pPattern->findPatternKey(sURL);
+    PatternHash::const_iterator pItem = findPatternKey(m_pPattern, sURL);
     if (pItem!=m_pPattern->end())
     {
         *pReturn = (*m_pHandler)[pItem->second];
@@ -164,8 +166,6 @@ void HandlerCache::takeOver(HandlerHash* pHandler, PatternHash* pPattern)
     m_pHandler = pHandler;
     m_pPattern = pPattern;
 
-    pOldHandler->free();
-    pOldPattern->free();
     delete pOldHandler;
     delete pOldPattern;
 }
@@ -180,10 +180,9 @@ void HandlerCache::takeOver(HandlerHash* pHandler, PatternHash* pPattern)
  */
 HandlerCFGAccess::HandlerCFGAccess( const OUString& sPackage )
     : ConfigItem(sPackage)
-    , m_pCache(0)
+    , m_pCache(nullptr)
 {
-    css::uno::Sequence< OUString > lListenPaths(1);
-    lListenPaths[0] = SETNAME_HANDLER;
+    css::uno::Sequence< OUString > lListenPaths { SETNAME_HANDLER };
     EnableNotification(lListenPaths);
 }
 
@@ -202,7 +201,7 @@ void HandlerCFGAccess::read( HandlerHash** ppHandler ,
                              PatternHash** ppPattern )
 {
     // list of all uno implementation names without encoding
-    css::uno::Sequence< OUString > lNames = GetNodeNames( SETNAME_HANDLER, ::utl::CONFIG_NAME_LOCAL_PATH );
+    css::uno::Sequence< OUString > lNames = GetNodeNames( SETNAME_HANDLER, ::utl::ConfigNameFormat::LocalPath );
     sal_Int32 nSourceCount = lNames.getLength();
     sal_Int32 nTargetCount = nSourceCount;
     // list of all full qualified path names of configuration entries
@@ -241,7 +240,7 @@ void HandlerCFGAccess::read( HandlerHash** ppHandler ,
         aHandler.m_lProtocols = Converter::convert_seqOUString2OUStringList(lTemp);
 
         // register his pattern into the performance search hash
-        for (OUStringList::iterator pItem =aHandler.m_lProtocols.begin();
+        for (std::vector<OUString>::iterator pItem =aHandler.m_lProtocols.begin();
                                     pItem!=aHandler.m_lProtocols.end();
                                     ++pItem                             )
         {
