@@ -22,13 +22,16 @@
 #include <services.h>
 
 #include <com/sun/star/frame/Desktop.hpp>
+#include <com/sun/star/frame/TerminationVetoException.hpp>
 #include <com/sun/star/task/XJob.hpp>
 #include <com/sun/star/task/XAsyncJob.hpp>
+#include <com/sun/star/util/CloseVetoException.hpp>
 #include <com/sun/star/util/XCloseBroadcaster.hpp>
 #include <com/sun/star/util/XCloseable.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
 
 #include <comphelper/processfactory.hxx>
+#include <comphelper/sequence.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <vcl/svapp.hxx>
 
@@ -89,7 +92,7 @@ Job::Job( /*IN*/ const css::uno::Reference< css::uno::XComponentContext >& xCont
 }
 
 /**
-    @short  superflous!
+    @short  superfluous!
     @descr  Releasing of memory and reference must be done inside die() call.
             Otherwhise it's a bug.
 */
@@ -179,11 +182,11 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
     {
         // create the job
         // We must check for the supported interface on demand!
-        // But we preferr the synchronous one ...
+        // But we prefer the synchronous one ...
         m_xJob = m_xContext->getServiceManager()->createInstanceWithContext(m_aJobCfg.getService(), m_xContext);
-        xSJob  = css::uno::Reference< css::task::XJob >(m_xJob, css::uno::UNO_QUERY);
+        xSJob.set(m_xJob, css::uno::UNO_QUERY);
         if (!xSJob.is())
-            xAJob = css::uno::Reference< css::task::XAsyncJob >(m_xJob, css::uno::UNO_QUERY);
+            xAJob.set(m_xJob, css::uno::UNO_QUERY);
 
         // execute it asynchron
         if (xAJob.is())
@@ -213,7 +216,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
     #if OSL_DEBUG_LEVEL > 0
     catch(const css::uno::Exception& ex)
     {
-        SAL_INFO("fwk", "Job::execute(): Got exception during job execution. Original Message was: \"" << ex.Message << "\"");
+        SAL_INFO("fwk", "Job::execute(): Got exception during job execution. Original Message was: \"" << ex << "\"");
     }
     #else
     catch(const css::uno::Exception&)
@@ -239,7 +242,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
         {
             try
             {
-                xClose->close(sal_True);
+                xClose->close(true);
             }
             catch(const css::util::CloseVetoException&) {}
         }
@@ -253,7 +256,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
         {
             try
             {
-                xClose->close(sal_True);
+                xClose->close(true);
             }
             catch(const css::util::CloseVetoException&) {}
         }
@@ -270,7 +273,7 @@ void Job::execute( /*IN*/ const css::uno::Sequence< css::beans::NamedValue >& lD
     @short  kill this job
     @descr  It doesn't matter if this request is called from inside or
             from outside. We release our internal structures and stop
-            avary activity. After doing so - this instance will not be
+            every activity. After doing so - this instance will not be
             useable any longer! Of course we try to handle further requests
             carefully. Maybe someone else holds a reference to us ...
 */
@@ -297,12 +300,12 @@ void Job::die()
         }
     }
 
-    m_xJob               = css::uno::Reference< css::uno::XInterface >();
-    m_xFrame             = css::uno::Reference< css::frame::XFrame >();
-    m_xModel             = css::uno::Reference< css::frame::XModel >();
-    m_xDesktop           = css::uno::Reference< css::frame::XDesktop2 >();
-    m_xResultListener    = css::uno::Reference< css::frame::XDispatchResultListener >();
-    m_xResultSourceFake  = css::uno::Reference< css::uno::XInterface >();
+    m_xJob.clear();
+    m_xFrame.clear();
+    m_xModel.clear();
+    m_xDesktop.clear();
+    m_xResultListener.clear();
+    m_xResultSourceFake.clear();
     m_bPendingCloseFrame = false;
     m_bPendingCloseModel = false;
 }
@@ -364,7 +367,7 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
     // Means: if this job has any configuration data. Note: only really
     // filled lists will be set to the return structure at the end of this method.
     css::uno::Sequence< css::beans::NamedValue > lConfigArgs;
-    css::uno::Sequence< css::beans::NamedValue > lJobConfigArgs;
+    std::vector< css::beans::NamedValue > lJobConfigArgs;
     if (eMode==JobData::E_ALIAS || eMode==JobData::E_EVENT)
     {
         lConfigArgs    = m_aJobCfg.getConfig();
@@ -382,12 +385,12 @@ css::uno::Sequence< css::beans::NamedValue > Job::impl_generateJobArgs( /*IN*/ c
         lAllArgs[nLength].Name = "Config";
         lAllArgs[nLength].Value <<= lConfigArgs;
     }
-    if (lJobConfigArgs.getLength()>0)
+    if (!lJobConfigArgs.empty())
     {
         sal_Int32 nLength = lAllArgs.getLength();
         lAllArgs.realloc(nLength+1);
         lAllArgs[nLength].Name = "JobConfig";
-        lAllArgs[nLength].Value <<= lJobConfigArgs;
+        lAllArgs[nLength].Value <<= comphelper::containerToSequence(lJobConfigArgs);
     }
     if (lEnvArgs.getLength()>0)
     {
@@ -471,7 +474,7 @@ void Job::impl_reactForJobResult( /*IN*/ const css::uno::Any& aResult )
 /**
     @short  starts listening for office shutdown and closing of our
             given target frame (if it's a valid reference)
-    @descr  We will reghister ourself as terminate listener
+    @descr  We will register ourself as terminate listener
             at the global desktop instance. That will hold us
             alive and additional we get the information, if the
             office wish to shutdown. If then an internal job
@@ -618,7 +621,7 @@ void Job::impl_stopListening()
                 its results
 */
 void SAL_CALL Job::jobFinished( /*IN*/ const css::uno::Reference< css::task::XAsyncJob >& xJob    ,
-                                /*IN*/ const css::uno::Any&                               aResult ) throw(css::uno::RuntimeException, std::exception)
+                                /*IN*/ const css::uno::Any&                               aResult )
 {
     SolarMutexGuard g;
 
@@ -633,7 +636,7 @@ void SAL_CALL Job::jobFinished( /*IN*/ const css::uno::Reference< css::task::XAs
         impl_reactForJobResult(aResult);
 
         // Let the job die!
-        m_xJob = css::uno::Reference< css::uno::XInterface >();
+        m_xJob.clear();
     }
 
     // And let the start method "execute()" finishing it's job.
@@ -656,8 +659,7 @@ void SAL_CALL Job::jobFinished( /*IN*/ const css::uno::Reference< css::task::XAs
     @throw  TerminateVetoException
                 if our internal wrapped job is still running.
  */
-void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& ) throw(css::frame::TerminationVetoException,
-                                                                                         css::uno::RuntimeException, std::exception          )
+void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& )
 {
     SolarMutexGuard g;
 
@@ -667,7 +669,7 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& ) thro
     {
         try
         {
-            xClose->close(sal_False);
+            xClose->close(false);
             m_eRunState = E_STOPPED_OR_FINISHED;
         }
         catch(const css::util::CloseVetoException&) {}
@@ -686,14 +688,14 @@ void SAL_CALL Job::queryTermination( /*IN*/ const css::lang::EventObject& ) thro
             We have to accept it and cancel all current processes inside.
             It can occur only, if job was not already started if queryTermination() was called here ..
             Then we had not throwed a veto exception. But now we must agree with this situation and break
-            all our internal processes. Its not a good idea to mark this instance as non startable any longer
-            inside queryTermination() if no job was unning too. Because that would disable this job and may
-            the office does not really shutdownm, because another listener has thrown the suitable exception.
+            all our internal processes. It's not a good idea to mark this instance as non startable any longer
+            inside queryTermination() if no job was running too. Because that would disable this job and may
+            the office does not really shutdown, because another listener has thrown the suitable exception.
 
     @param  aEvent
                 describes the broadcaster and must be the desktop instance
  */
-void SAL_CALL Job::notifyTermination( /*IN*/ const css::lang::EventObject& ) throw(css::uno::RuntimeException, std::exception)
+void SAL_CALL Job::notifyTermination( /*IN*/ const css::lang::EventObject& )
 {
     die();
     // Do nothing else here. Our internal resources was released ...
@@ -718,8 +720,7 @@ void SAL_CALL Job::notifyTermination( /*IN*/ const css::lang::EventObject& ) thr
                 if our internal wrapped job is still running.
  */
 void SAL_CALL Job::queryClosing( const css::lang::EventObject& aEvent         ,
-                                       sal_Bool                bGetsOwnership ) throw(css::util::CloseVetoException,
-                                                                                      css::uno::RuntimeException, std::exception   )
+                                       sal_Bool                bGetsOwnership )
 {
     SolarMutexGuard g;
 
@@ -787,7 +788,7 @@ void SAL_CALL Job::queryClosing( const css::lang::EventObject& aEvent         ,
     @param  aEvent
             describes the broadcaster and must be the frame or model instance we know
  */
-void SAL_CALL Job::notifyClosing( const css::lang::EventObject& ) throw(css::uno::RuntimeException, std::exception)
+void SAL_CALL Job::notifyClosing( const css::lang::EventObject& )
 {
     die();
     // Do nothing else here. Our internal resources was released ...
@@ -801,7 +802,7 @@ void SAL_CALL Job::notifyClosing( const css::lang::EventObject& ) throw(css::uno
     @param      aEvent
                 describe the broadcaster
 */
-void SAL_CALL Job::disposing( const css::lang::EventObject& aEvent ) throw(css::uno::RuntimeException, std::exception)
+void SAL_CALL Job::disposing( const css::lang::EventObject& aEvent )
 {
     /* SAFE { */
     SolarMutexClearableGuard aWriteLock;
@@ -813,12 +814,12 @@ void SAL_CALL Job::disposing( const css::lang::EventObject& aEvent ) throw(css::
     }
     else if (m_xFrame.is() && aEvent.Source == m_xFrame)
     {
-        m_xFrame = css::uno::Reference< css::frame::XFrame >();
+        m_xFrame.clear();
         m_bListenOnFrame = false;
     }
     else if (m_xModel.is() && aEvent.Source == m_xModel)
     {
-        m_xModel = css::uno::Reference< css::frame::XModel >();
+        m_xModel.clear();
         m_bListenOnModel = false;
     }
 
