@@ -264,7 +264,7 @@ void JobData::setJobConfig( const std::vector< css::beans::NamedValue >& lArgume
 }
 
 /**
-    @short      set a new excution result
+    @short      set a new execution result
     @descr      Every executed job can have returned a result.
                 We set it here, so our user can use it may be later.
                 But the outside code can use it too, to analyze it and
@@ -441,8 +441,6 @@ void JobData::disableJob()
     aConfig.close();
 }
 
-/**
- */
 bool isEnabled( const OUString& sAdminTime ,
                     const OUString& sUserTime  )
 {
@@ -451,8 +449,7 @@ bool isEnabled( const OUString& sAdminTime ,
         we have to encode all '?' signs. Otherwhise e.g. "??-" will be translated
         to "~" ...
      */
-    static const char PATTERN_ISO8601[] = "\?\?\?\?-\?\?-\?\?*";
-    WildCard aISOPattern(PATTERN_ISO8601);
+    WildCard aISOPattern("\?\?\?\?-\?\?-\?\?*");
 
     bool bValidAdmin = aISOPattern.Matches(sAdminTime);
     bool bValidUser  = aISOPattern.Matches(sUserTime );
@@ -466,8 +463,6 @@ bool isEnabled( const OUString& sAdminTime ,
            );
 }
 
-/**
- */
 void JobData::appendEnabledJobsForEvent( const css::uno::Reference< css::uno::XComponentContext >&              rxContext,
                                          const OUString&                                                 sEvent ,
                                                ::std::vector< JobData::TJob2DocEventBinding >& lJobs  )
@@ -483,8 +478,6 @@ void JobData::appendEnabledJobsForEvent( const css::uno::Reference< css::uno::XC
     }
 }
 
-/**
- */
 bool JobData::hasCorrectContext(const OUString& rModuleIdent) const
 {
     sal_Int32 nContextLen  = m_sContext.getLength();
@@ -499,7 +492,7 @@ bool JobData::hasCorrectContext(const OUString& rModuleIdent) const
         if ( nIndex >= 0 && ( nIndex+nModuleIdLen <= nContextLen ))
     {
         OUString sContextModule = m_sContext.copy( nIndex, nModuleIdLen );
-        return sContextModule.equals( rModuleIdent );
+        return sContextModule == rModuleIdent;
     }
     }
 
@@ -537,17 +530,16 @@ std::vector< OUString > JobData::getEnabledJobsForEvent( const css::uno::Referen
     // step over all job entries ... check her time stamps ... and put only job names to the
     // destination list, which represent an enabled job.
     css::uno::Sequence< OUString > lAllJobs = xJobList->getElementNames();
-    OUString* pAllJobs = lAllJobs.getArray();
     sal_Int32 c = lAllJobs.getLength();
 
     std::vector< OUString > lEnabledJobs(c);
     sal_Int32 d = 0;
 
-    for (sal_Int32 s=0; s<c; ++s)
+    for (OUString const & jobName : lAllJobs)
     {
         css::uno::Reference< css::beans::XPropertySet > xJob;
         if (
-            !(xJobList->getByName(pAllJobs[s]) >>= xJob) ||
+            !(xJobList->getByName(jobName) >>= xJob) ||
             !(xJob.is()     )
            )
         {
@@ -563,7 +555,7 @@ std::vector< OUString > JobData::getEnabledJobsForEvent( const css::uno::Referen
         if (!isEnabled(sAdminTime, sUserTime))
             continue;
 
-        lEnabledJobs[d] = pAllJobs[s];
+        lEnabledJobs[d] = jobName;
         ++d;
     }
     lEnabledJobs.resize(d);
