@@ -27,10 +27,12 @@
 #include <protocols.h>
 #include <services.h>
 #include <comphelper/interaction.hxx>
+#include <comphelper/lok.hxx>
+#include <comphelper/propertysequence.hxx>
 #include <framework/interaction.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/configuration.hxx>
-#include "officecfg/Office/Common.hxx"
+#include <officecfg/Office/Common.hxx>
 
 #include <com/sun/star/awt/XWindow.hpp>
 #include <com/sun/star/awt/XWindow2.hpp>
@@ -54,6 +56,7 @@
 #include <com/sun/star/frame/FrameSearchFlag.hpp>
 #include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/lang/XComponent.hpp>
+#include <com/sun/star/lang/XInitialization.hpp>
 #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <com/sun/star/io/XInputStream.hpp>
@@ -64,6 +67,7 @@
 #include <com/sun/star/task/XStatusIndicator.hpp>
 #include <com/sun/star/uno/RuntimeException.hpp>
 #include <com/sun/star/ucb/UniversalContentBroker.hpp>
+#include <com/sun/star/util/CloseVetoException.hpp>
 #include <com/sun/star/util/URLTransformer.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/util/XCloseable.hpp>
@@ -82,8 +86,7 @@
 #include <rtl/bootstrap.hxx>
 #include <vcl/svapp.hxx>
 #include <cppuhelper/implbase.hxx>
-
-#include <config_orcus.h>
+#include <comphelper/profilezone.hxx>
 
 const char PROP_TYPES[] = "Types";
 const char PROP_NAME[] = "Name";
@@ -102,33 +105,28 @@ class LoadEnvListener : public ::cppu::WeakImplHelper< css::frame::XLoadEventLis
 
     public:
 
-        LoadEnvListener(LoadEnv* pLoadEnv)
+        explicit LoadEnvListener(LoadEnv* pLoadEnv)
             : m_bWaitingResult(true)
             , m_pLoadEnv(pLoadEnv)
         {
         }
 
         // frame.XLoadEventListener
-        virtual void SAL_CALL loadFinished(const css::uno::Reference< css::frame::XFrameLoader >& xLoader)
-            throw(css::uno::RuntimeException, std::exception) override;
+        virtual void SAL_CALL loadFinished(const css::uno::Reference< css::frame::XFrameLoader >& xLoader) override;
 
-        virtual void SAL_CALL loadCancelled(const css::uno::Reference< css::frame::XFrameLoader >& xLoader)
-            throw(css::uno::RuntimeException, std::exception) override;
+        virtual void SAL_CALL loadCancelled(const css::uno::Reference< css::frame::XFrameLoader >& xLoader) override;
 
         // frame.XDispatchResultListener
-        virtual void SAL_CALL dispatchFinished(const css::frame::DispatchResultEvent& aEvent)
-            throw(css::uno::RuntimeException, std::exception) override;
+        virtual void SAL_CALL dispatchFinished(const css::frame::DispatchResultEvent& aEvent) override;
 
         // lang.XEventListener
-        virtual void SAL_CALL disposing(const css::lang::EventObject& aEvent)
-            throw(css::uno::RuntimeException, std::exception) override;
+        virtual void SAL_CALL disposing(const css::lang::EventObject& aEvent) override;
 };
 
 LoadEnv::LoadEnv(const css::uno::Reference< css::uno::XComponentContext >& xContext)
-    throw(LoadEnvException, css::uno::RuntimeException)
     : m_xContext(xContext)
     , m_nSearchFlags(0)
-    , m_eFeature(E_NO_FEATURE)
+    , m_eFeature(LoadEnvFeatures::NONE)
     , m_eContentType(E_UNSUPPORTED_CONTENT)
     , m_bCloseFrameOnError(false)
     , m_bReactivateControllerOnError(false)
@@ -146,11 +144,9 @@ css::uno::Reference< css::lang::XComponent > LoadEnv::loadComponentFromURL(const
                                                                            const OUString&                                        sTarget,
                                                                                  sal_Int32                                               nFlags ,
                                                                            const css::uno::Sequence< css::beans::PropertyValue >&        lArgs  )
-    throw(css::lang::IllegalArgumentException,
-          css::io::IOException               ,
-          css::uno::RuntimeException         )
 {
     css::uno::Reference< css::lang::XComponent > xComponent;
+    comphelper::ProfileZone aZone("loadComponentFromURL");
 
     try
     {
@@ -221,7 +217,7 @@ utl::MediaDescriptor addModelArgs(const uno::Sequence<beans::PropertyValue>& rDe
 
 void LoadEnv::initializeLoading(const OUString& sURL, const uno::Sequence<beans::PropertyValue>& lMediaDescriptor,
         const uno::Reference<frame::XFrame>& xBaseFrame, const OUString& sTarget,
-        sal_Int32 nSearchFlags, EFeature eFeature, EContentType eContentType)
+        sal_Int32 nSearchFlags, LoadEnvFeatures eFeature)
 {
     osl::MutexGuard g(m_mutex);
 
@@ -236,7 +232,7 @@ void LoadEnv::initializeLoading(const OUString& sURL, const uno::Sequence<beans:
     m_sTarget = sTarget;
     m_nSearchFlags = nSearchFlags;
     m_eFeature = eFeature;
-    m_eContentType = eContentType;
+    m_eContentType = E_UNSUPPORTED_CONTENT;
     m_bCloseFrameOnError = false;
     m_bReactivateControllerOnError = false;
     m_bLoaded = false;
@@ -245,12 +241,9 @@ void LoadEnv::initializeLoading(const OUString& sURL, const uno::Sequence<beans:
     // We use a default value for this in-parameter. Then we have to start a complex check method
     // internally. But if this check was already done outside it can be suppressed to perform
     // the load request. We take over the result then!
+    m_eContentType = LoadEnv::classifyContent(sURL, lMediaDescriptor);
     if (m_eContentType == E_UNSUPPORTED_CONTENT)
-    {
-        m_eContentType = LoadEnv::classifyContent(sURL, lMediaDescriptor);
-        if (m_eContentType == E_UNSUPPORTED_CONTENT)
-            throw LoadEnvException(LoadEnvException::ID_UNSUPPORTED_CONTENT, "from LoadEnv::initializeLoading");
-    }
+        throw LoadEnvException(LoadEnvException::ID_UNSUPPORTED_CONTENT, "from LoadEnv::initializeLoading");
 
     // make URL part of the MediaDescriptor
     // It doesn't matter if it is already an item of it.
@@ -280,7 +273,7 @@ void LoadEnv::initializeLoading(const OUString& sURL, const uno::Sequence<beans:
 
     // UI mode
     const bool bUIMode =
-        ((m_eFeature & E_WORK_WITH_UI) == E_WORK_WITH_UI) &&
+        (m_eFeature & LoadEnvFeatures::WorkWithUI) &&
         !m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_HIDDEN(), false) &&
         !m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_PREVIEW(), false);
 
@@ -370,7 +363,7 @@ void LoadEnv::startLoading()
     // Use another strategy here. Try it and let it run into the case "loading not possible".
     bool bStarted = false;
     if (
-        ((m_eFeature & E_ALLOW_CONTENTHANDLER) == E_ALLOW_CONTENTHANDLER) &&
+        (m_eFeature & LoadEnvFeatures::AllowContentHandler) &&
         (m_eContentType                        != E_CAN_BE_SET          )   /* Attention: special feature to set existing component on a frame must ignore type detection! */
        )
     {
@@ -394,7 +387,7 @@ void LoadEnv::startLoading()
 -----------------------------------------------*/
 bool LoadEnv::waitWhileLoading(sal_uInt32 nTimeout)
 {
-    // Because its not a good idea to block the main thread
+    // Because it's not a good idea to block the main thread
     // (and we can't be sure that we are currently not used inside the
     // main thread!), we can't use conditions here really. We must yield
     // in an intelligent manner :-)
@@ -444,7 +437,6 @@ css::uno::Reference< css::lang::XComponent > LoadEnv::getTargetComponent() const
 }
 
 void SAL_CALL LoadEnvListener::loadFinished(const css::uno::Reference< css::frame::XFrameLoader >&)
-    throw(css::uno::RuntimeException, std::exception)
 {
     osl::MutexGuard g(m_mutex);
     if (m_bWaitingResult)
@@ -453,7 +445,6 @@ void SAL_CALL LoadEnvListener::loadFinished(const css::uno::Reference< css::fram
 }
 
 void SAL_CALL LoadEnvListener::loadCancelled(const css::uno::Reference< css::frame::XFrameLoader >&)
-    throw(css::uno::RuntimeException, std::exception)
 {
     osl::MutexGuard g(m_mutex);
     if (m_bWaitingResult)
@@ -462,7 +453,6 @@ void SAL_CALL LoadEnvListener::loadCancelled(const css::uno::Reference< css::fra
 }
 
 void SAL_CALL LoadEnvListener::dispatchFinished(const css::frame::DispatchResultEvent& aEvent)
-    throw(css::uno::RuntimeException, std::exception)
 {
     osl::MutexGuard g(m_mutex);
 
@@ -487,7 +477,6 @@ void SAL_CALL LoadEnvListener::dispatchFinished(const css::frame::DispatchResult
 }
 
 void SAL_CALL LoadEnvListener::disposing(const css::lang::EventObject&)
-    throw(css::uno::RuntimeException, std::exception)
 {
     osl::MutexGuard g(m_mutex);
     if (m_bWaitingResult)
@@ -528,12 +517,12 @@ LoadEnv::EContentType LoadEnv::classifyContent(const OUString&
 
     if(
         (sURL.isEmpty()                                          ) ||
-        (ProtocolCheck::isProtocol(sURL,ProtocolCheck::E_UNO    )) ||
-        (ProtocolCheck::isProtocol(sURL,ProtocolCheck::E_SLOT   )) ||
-        (ProtocolCheck::isProtocol(sURL,ProtocolCheck::E_MACRO  )) ||
-        (ProtocolCheck::isProtocol(sURL,ProtocolCheck::E_SERVICE)) ||
-        (ProtocolCheck::isProtocol(sURL,ProtocolCheck::E_MAILTO )) ||
-        (ProtocolCheck::isProtocol(sURL,ProtocolCheck::E_NEWS   ))
+        (ProtocolCheck::isProtocol(sURL,EProtocol::Uno    )) ||
+        (ProtocolCheck::isProtocol(sURL,EProtocol::Slot   )) ||
+        (ProtocolCheck::isProtocol(sURL,EProtocol::Macro  )) ||
+        (ProtocolCheck::isProtocol(sURL,EProtocol::Service)) ||
+        (ProtocolCheck::isProtocol(sURL,EProtocol::MailTo )) ||
+        (ProtocolCheck::isProtocol(sURL,EProtocol::News   ))
       )
     {
         return E_UNSUPPORTED_CONTENT;
@@ -555,13 +544,13 @@ LoadEnv::EContentType LoadEnv::classifyContent(const OUString&
     */
 
     // creation of new documents
-    if (ProtocolCheck::isProtocol(sURL,ProtocolCheck::E_PRIVATE_FACTORY))
+    if (ProtocolCheck::isProtocol(sURL,EProtocol::PrivateFactory))
         return E_CAN_BE_LOADED;
 
     // using of an existing input stream
     utl::MediaDescriptor                 stlMediaDescriptor(lMediaDescriptor);
     utl::MediaDescriptor::const_iterator pIt;
-    if (ProtocolCheck::isProtocol(sURL,ProtocolCheck::E_PRIVATE_STREAM))
+    if (ProtocolCheck::isProtocol(sURL,EProtocol::PrivateStream))
     {
         pIt = stlMediaDescriptor.find(utl::MediaDescriptor::PROP_INPUTSTREAM());
         css::uno::Reference< css::io::XInputStream > xStream;
@@ -569,12 +558,12 @@ LoadEnv::EContentType LoadEnv::classifyContent(const OUString&
             pIt->second >>= xStream;
         if (xStream.is())
             return E_CAN_BE_LOADED;
-        SAL_INFO("fwk", "LoadEnv::classifyContent(): loading from stream with right URL but invalid stream detected");
+        SAL_INFO("fwk.loadenv", "LoadEnv::classifyContent(): loading from stream with right URL but invalid stream detected");
         return E_UNSUPPORTED_CONTENT;
     }
 
     // using of a full featured document
-    if (ProtocolCheck::isProtocol(sURL,ProtocolCheck::E_PRIVATE_OBJECT))
+    if (ProtocolCheck::isProtocol(sURL,EProtocol::PrivateObject))
     {
         pIt = stlMediaDescriptor.find(utl::MediaDescriptor::PROP_MODEL());
         css::uno::Reference< css::frame::XModel > xModel;
@@ -582,7 +571,7 @@ LoadEnv::EContentType LoadEnv::classifyContent(const OUString&
             pIt->second >>= xModel;
         if (xModel.is())
             return E_CAN_BE_SET;
-        SAL_INFO("fwk", "LoadEnv::classifyContent(): loading with object with right URL but invalid object detected");
+        SAL_INFO("fwk.loadenv", "LoadEnv::classifyContent(): loading with object with right URL but invalid object detected");
         return E_UNSUPPORTED_CONTENT;
     }
 
@@ -608,8 +597,8 @@ LoadEnv::EContentType LoadEnv::classifyContent(const OUString&
     //      Mos of our filters are handled by our global
     //      default loader. But there exist some specialized
     //      loader, which does not work on top of filters!
-    //      So its not enough to search on the filter configuration.
-    //      Further its not enough to search for types!
+    //      So it's not enough to search on the filter configuration.
+    //      Further it's not enough to search for types!
     //      Because there exist some types, which are referenced by
     //      other objects ... but not by filters nor frame loaders!
 
@@ -655,8 +644,6 @@ LoadEnv::EContentType LoadEnv::classifyContent(const OUString&
 
 namespace {
 
-#if ENABLE_ORCUS
-
 bool queryOrcusTypeAndFilter(const uno::Sequence<beans::PropertyValue>& rDescriptor, OUString& rType, OUString& rFilter)
 {
     OUString aURL;
@@ -714,22 +701,10 @@ bool queryOrcusTypeAndFilter(const uno::Sequence<beans::PropertyValue>& rDescrip
     return false;
 }
 
-#else
-
-bool queryOrcusTypeAndFilter(const uno::Sequence<beans::PropertyValue>&, OUString&, OUString&)
-{
-    return false;
-}
-
-#endif
-
 }
 
 void LoadEnv::impl_detectTypeAndFilter()
-    throw(LoadEnvException, css::uno::RuntimeException, std::exception)
 {
-    static const char TYPEPROP_PREFERREDFILTER[] = "PreferredFilter";
-    static const char FILTERPROP_FLAGS        [] = "Flags";
     static sal_Int32       FILTERFLAG_TEMPLATEPATH  = 16;
 
     // SAFE ->
@@ -761,7 +736,7 @@ void LoadEnv::impl_detectTypeAndFilter()
         xContext->getServiceManager()->createInstanceWithContext(
             "com.sun.star.document.TypeDetection", xContext),
         css::uno::UNO_QUERY_THROW);
-    sType = xDetect->queryTypeByDescriptor(lDescriptor, sal_True); /*TODO should deep detection be able for enable/disable it from outside? */
+    sType = xDetect->queryTypeByDescriptor(lDescriptor, true); /*TODO should deep detection be able for enable/disable it from outside? */
 
     // no valid content -> loading not possible
     if (sType.isEmpty())
@@ -781,6 +756,11 @@ void LoadEnv::impl_detectTypeAndFilter()
     aWriteLock.clear();
     // <- SAFE
 
+    // We do have potentially correct type, but the detection process was aborted.
+    if (m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_ABORTED(), false))
+        throw LoadEnvException(
+            LoadEnvException::ID_UNSUPPORTED_CONTENT, "type detection aborted");
+
     // But the type isn't enough. For loading sometimes we need more information.
     // E.g. for our "_default" feature, where we recycle any frame which contains
     // and "Untitled" document, we must know if the new document is based on a template!
@@ -796,7 +776,7 @@ void LoadEnv::impl_detectTypeAndFilter()
         try
         {
             ::comphelper::SequenceAsHashMap lTypeProps(xTypeCont->getByName(sType));
-            sFilter = lTypeProps.getUnpackedValueOrDefault(TYPEPROP_PREFERREDFILTER, OUString());
+            sFilter = lTypeProps.getUnpackedValueOrDefault("PreferredFilter", OUString());
             if (!sFilter.isEmpty())
             {
                 // SAFE ->
@@ -825,7 +805,7 @@ void LoadEnv::impl_detectTypeAndFilter()
         try
         {
             ::comphelper::SequenceAsHashMap lFilterProps(xFilterCont->getByName(sFilter));
-            sal_Int32 nFlags         = lFilterProps.getUnpackedValueOrDefault(FILTERPROP_FLAGS, (sal_Int32)0);
+            sal_Int32 nFlags         = lFilterProps.getUnpackedValueOrDefault("Flags", (sal_Int32)0);
                       bIsOwnTemplate = ((nFlags & FILTERFLAG_TEMPLATEPATH) == FILTERFLAG_TEMPLATEPATH);
         }
         catch(const css::container::NoSuchElementException&)
@@ -838,14 +818,13 @@ void LoadEnv::impl_detectTypeAndFilter()
         // Don't overwrite external decisions! See comments before ...
         utl::MediaDescriptor::const_iterator pAsTemplateItem = m_lMediaDescriptor.find(utl::MediaDescriptor::PROP_ASTEMPLATE());
         if (pAsTemplateItem == m_lMediaDescriptor.end())
-            m_lMediaDescriptor[utl::MediaDescriptor::PROP_ASTEMPLATE()] <<= sal_True;
+            m_lMediaDescriptor[utl::MediaDescriptor::PROP_ASTEMPLATE()] <<= true;
         aWriteLock.clear();
         // <- SAFE
     }
 }
 
 bool LoadEnv::impl_handleContent()
-    throw(LoadEnvException, css::uno::RuntimeException, std::exception)
 {
     // SAFE -> -----------------------------------
     osl::ClearableMutexGuard aReadLock(m_mutex);
@@ -922,7 +901,7 @@ bool LoadEnv::impl_furtherDocsAllowed()
                                 "org.openoffice.Office.Common/",
                                 "Misc",
                                 "MaxOpenDocuments",
-                                ::comphelper::ConfigurationHelper::E_READONLY);
+                                ::comphelper::EConfigurationModes::ReadOnly);
 
         // NIL means: count of allowed documents = infinite !
         //     => return sal_True
@@ -939,11 +918,11 @@ bool LoadEnv::impl_furtherDocsAllowed()
 
             FrameListAnalyzer aAnalyzer(xDesktop,
                                         css::uno::Reference< css::frame::XFrame >(),
-                                        FrameListAnalyzer::E_HELP |
-                                        FrameListAnalyzer::E_BACKINGCOMPONENT |
-                                        FrameListAnalyzer::E_HIDDEN);
+                                        FrameAnalyzerFlags::Help |
+                                        FrameAnalyzerFlags::BackingComponent |
+                                        FrameAnalyzerFlags::Hidden);
 
-            sal_Int32 nOpenDocuments = aAnalyzer.m_lOtherVisibleFrames.getLength();
+            sal_Int32 nOpenDocuments = aAnalyzer.m_lOtherVisibleFrames.size();
                       bAllowed       = (nOpenDocuments < nMaxOpenDocuments);
         }
     }
@@ -974,7 +953,7 @@ bool LoadEnv::impl_furtherDocsAllowed()
                                    css::uno::UNO_QUERY_THROW);
 
             css::task::ErrorCodeRequest aErrorCode;
-            aErrorCode.ErrCode = ERRCODE_SFX_NOMOREDOCUMENTSALLOWED;
+            aErrorCode.ErrCode = sal_uInt32(ERRCODE_SFX_NOMOREDOCUMENTSALLOWED);
             aInteraction <<= aErrorCode;
             xInteraction->handle( InteractionRequest::CreateRequest(aInteraction, lContinuations) );
         }
@@ -983,15 +962,46 @@ bool LoadEnv::impl_furtherDocsAllowed()
     return bAllowed;
 }
 
+bool LoadEnv::impl_filterHasInteractiveDialog() const
+{
+    //show the frame now so it can be the parent for any message dialogs shown during import
+
+    //unless (tdf#114648) an Interactive case such as the new database wizard
+    if (m_aURL.Arguments == "Interactive")
+       return true;
+
+    // unless (tdf#116277) its the labels/business cards slave frame
+    if (m_aURL.Arguments.indexOf("slot=") != -1)
+        return true;
+
+    OUString sFilter = m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_FILTERNAME(), OUString());
+    if (sFilter.isEmpty())
+        return false;
+
+    // unless (tdf#115683) the filter has a UIComponent
+    OUString sUIComponent;
+    css::uno::Reference<css::container::XNameAccess> xFilterCont(m_xContext->getServiceManager()->createInstanceWithContext(SERVICENAME_FILTERFACTORY, m_xContext),
+                                                                 css::uno::UNO_QUERY_THROW);
+    try
+    {
+        ::comphelper::SequenceAsHashMap lFilterProps(xFilterCont->getByName(sFilter));
+        sUIComponent = lFilterProps.getUnpackedValueOrDefault("UIComponent", OUString());
+    }
+    catch(const css::container::NoSuchElementException&)
+    {
+    }
+
+    return !sUIComponent.isEmpty();
+}
+
 bool LoadEnv::impl_loadContent()
-    throw(LoadEnvException, css::uno::RuntimeException, std::exception)
 {
     // SAFE -> -----------------------------------
     osl::ClearableMutexGuard aWriteLock(m_mutex);
 
     // search or create right target frame
     OUString sTarget = m_sTarget;
-    if (TargetHelper::matchSpecialTarget(sTarget, TargetHelper::E_DEFAULT))
+    if (TargetHelper::matchSpecialTarget(sTarget, TargetHelper::ESpecialTarget::Default))
     {
         m_xTargetFrame = impl_searchAlreadyLoaded();
         if (m_xTargetFrame.is())
@@ -1005,8 +1015,8 @@ bool LoadEnv::impl_loadContent()
     if (! m_xTargetFrame.is())
     {
         if (
-            (TargetHelper::matchSpecialTarget(sTarget, TargetHelper::E_BLANK  )) ||
-            (TargetHelper::matchSpecialTarget(sTarget, TargetHelper::E_DEFAULT))
+            (TargetHelper::matchSpecialTarget(sTarget, TargetHelper::ESpecialTarget::Blank  )) ||
+            (TargetHelper::matchSpecialTarget(sTarget, TargetHelper::ESpecialTarget::Default))
            )
         {
             if (! impl_furtherDocsAllowed())
@@ -1068,15 +1078,37 @@ bool LoadEnv::impl_loadContent()
     bool bPreview   = m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_PREVIEW(), false);
     css::uno::Reference< css::task::XStatusIndicator > xProgress  = m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_STATUSINDICATOR(), css::uno::Reference< css::task::XStatusIndicator >());
 
-    if (!bHidden && !bMinimized && !bPreview && !xProgress.is())
+    if (!bHidden && !bMinimized && !bPreview)
     {
-        // Note: its an optional interface!
-        css::uno::Reference< css::task::XStatusIndicatorFactory > xProgressFactory(xTargetFrame, css::uno::UNO_QUERY);
-        if (xProgressFactory.is())
+        if (!xProgress.is())
         {
-            xProgress = xProgressFactory->createStatusIndicator();
-            if (xProgress.is())
-                m_lMediaDescriptor[utl::MediaDescriptor::PROP_STATUSINDICATOR()] <<= xProgress;
+            // Note: it's an optional interface!
+            css::uno::Reference< css::task::XStatusIndicatorFactory > xProgressFactory(xTargetFrame, css::uno::UNO_QUERY);
+            if (xProgressFactory.is())
+            {
+                xProgress = xProgressFactory->createStatusIndicator();
+                if (xProgress.is())
+                    m_lMediaDescriptor[utl::MediaDescriptor::PROP_STATUSINDICATOR()] <<= xProgress;
+            }
+        }
+
+        // Now that we have a target window into which we can load, reinit the interaction handler to have this
+        // window as its parent for modal dialogs and ensure the window is visible
+        css::uno::Reference< css::task::XInteractionHandler > xInteraction = m_lMediaDescriptor.getUnpackedValueOrDefault(
+                                                                                utl::MediaDescriptor::PROP_INTERACTIONHANDLER(),
+                                                                                css::uno::Reference< css::task::XInteractionHandler >());
+        css::uno::Reference<css::lang::XInitialization> xHandler(xInteraction, css::uno::UNO_QUERY);
+        if (xHandler.is())
+        {
+            css::uno::Reference<css::awt::XWindow> xWindow = xTargetFrame->getContainerWindow();
+            uno::Sequence<uno::Any> aArguments(comphelper::InitAnyPropertySequence(
+            {
+                {"Parent", uno::Any(xWindow)}
+            }));
+            xHandler->initialize(aArguments);
+            //show the frame as early as possible to make it the parent of any message dialogs
+            if (!impl_filterHasInteractiveDialog())
+                impl_makeFrameWindowVisible(xWindow, false);
         }
     }
 
@@ -1213,14 +1245,13 @@ void LoadEnv::impl_jumpToMark(const css::uno::Reference< css::frame::XFrame >& x
 }
 
 css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchAlreadyLoaded()
-    throw(LoadEnvException, css::uno::RuntimeException)
 {
     osl::MutexGuard g(m_mutex);
 
     // such search is allowed for special requests only ...
-    // or better its not allowed for some requests in general :-)
+    // or better it's not allowed for some requests in general :-)
     if (
-        ( ! TargetHelper::matchSpecialTarget(m_sTarget, TargetHelper::E_DEFAULT)                                               ) ||
+        ( ! TargetHelper::matchSpecialTarget(m_sTarget, TargetHelper::ESpecialTarget::Default)                                               ) ||
         m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_ASTEMPLATE() , false) ||
 //      (m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_HIDDEN()     , false) == sal_True) ||
         m_lMediaDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_OPENNEWVIEW(), false)
@@ -1230,11 +1261,11 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchAlreadyLoaded()
     }
 
     // check URL
-    // May its not useful to start expensive document search, if it
+    // May it's not useful to start expensive document search, if it
     // can fail only .. because we load from a stream or model directly!
     if (
-        (ProtocolCheck::isProtocol(m_aURL.Complete, ProtocolCheck::E_PRIVATE_STREAM )) ||
-        (ProtocolCheck::isProtocol(m_aURL.Complete, ProtocolCheck::E_PRIVATE_OBJECT ))
+        (ProtocolCheck::isProtocol(m_aURL.Complete, EProtocol::PrivateStream )) ||
+        (ProtocolCheck::isProtocol(m_aURL.Complete, EProtocol::PrivateObject ))
         /*TODO should be private:factory here tested too? */
        )
     {
@@ -1311,10 +1342,7 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchAlreadyLoaded()
             // They will be used as "last chance" if there is no visible frame pointing to the same model.
             // Safe the result but continue with current loop might be looking for other visible frames.
             bool bIsHidden = lOldDocDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_HIDDEN(), false);
-            if (
-                (   bIsHidden       ) &&
-                ( ! xHiddenTask.is())
-               )
+            if ( bIsHidden && ! xHiddenTask.is() )
             {
                 xHiddenTask = xTask;
                 xTask.clear ();
@@ -1358,7 +1386,7 @@ bool LoadEnv::impl_isFrameAlreadyUsedForLoading(const css::uno::Reference< css::
 
     // ? no lock interface ?
     // Might its an external written frame implementation :-(
-    // Allowing using of it ... but it can fail if its not synchronized with our processes !
+    // Allowing using of it ... but it can fail if it's not synchronized with our processes !
     if (!xLock.is())
         return false;
 
@@ -1367,7 +1395,6 @@ bool LoadEnv::impl_isFrameAlreadyUsedForLoading(const css::uno::Reference< css::
 }
 
 css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchRecycleTarget()
-    throw(LoadEnvException, css::uno::RuntimeException, std::exception)
 {
     // SAFE -> ..................................
     osl::ClearableMutexGuard aReadLock(m_mutex);
@@ -1380,13 +1407,14 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchRecycleTarget()
         return css::uno::Reference< css::frame::XFrame >();
 
     css::uno::Reference< css::frame::XFramesSupplier > xSupplier( css::frame::Desktop::create( m_xContext ), css::uno::UNO_QUERY);
-    FrameListAnalyzer aTasksAnalyzer(xSupplier, css::uno::Reference< css::frame::XFrame >(), FrameListAnalyzer::E_BACKINGCOMPONENT);
+    FrameListAnalyzer aTasksAnalyzer(xSupplier, css::uno::Reference< css::frame::XFrame >(), FrameAnalyzerFlags::BackingComponent);
     if (aTasksAnalyzer.m_xBackingComponent.is())
     {
         if (!impl_isFrameAlreadyUsedForLoading(aTasksAnalyzer.m_xBackingComponent))
         {
             // bring it to front ...
             impl_makeFrameWindowVisible(aTasksAnalyzer.m_xBackingComponent->getContainerWindow(), true);
+            m_bReactivateControllerOnError = true;
             return aTasksAnalyzer.m_xBackingComponent;
         }
     }
@@ -1403,9 +1431,9 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchRecycleTarget()
     // On the other side some special URLs will open a new frame every time (expecting
     // they can use the backing-mode frame!)
     if (
-        (ProtocolCheck::isProtocol(m_aURL.Complete, ProtocolCheck::E_PRIVATE_FACTORY )) ||
-        (ProtocolCheck::isProtocol(m_aURL.Complete, ProtocolCheck::E_PRIVATE_STREAM  )) ||
-        (ProtocolCheck::isProtocol(m_aURL.Complete, ProtocolCheck::E_PRIVATE_OBJECT  ))
+        (ProtocolCheck::isProtocol(m_aURL.Complete, EProtocol::PrivateFactory )) ||
+        (ProtocolCheck::isProtocol(m_aURL.Complete, EProtocol::PrivateStream  )) ||
+        (ProtocolCheck::isProtocol(m_aURL.Complete, EProtocol::PrivateObject  ))
        )
     {
         return css::uno::Reference< css::frame::XFrame >();
@@ -1443,7 +1471,7 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchRecycleTarget()
     if (xModified->isModified())
         return css::uno::Reference< css::frame::XFrame >();
 
-    vcl::Window* pWindow = VCLUnoHelper::GetWindow(xTask->getContainerWindow());
+    VclPtr<vcl::Window> pWindow = VCLUnoHelper::GetWindow(xTask->getContainerWindow());
     if (pWindow && pWindow->IsInModalMode())
         return css::uno::Reference< css::frame::XFrame >();
 
@@ -1475,7 +1503,7 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchRecycleTarget()
     css::uno::Reference< css::frame::XController > xOldDoc = xTask->getController();
     if (xOldDoc.is())
     {
-        bReactivateOldControllerOnError = xOldDoc->suspend(sal_True);
+        bReactivateOldControllerOnError = xOldDoc->suspend(true);
         if (! bReactivateOldControllerOnError)
             return css::uno::Reference< css::frame::XFrame >();
     }
@@ -1498,7 +1526,6 @@ css::uno::Reference< css::frame::XFrame > LoadEnv::impl_searchRecycleTarget()
 }
 
 void LoadEnv::impl_reactForLoadingState()
-    throw(LoadEnvException, css::uno::RuntimeException)
 {
     /*TODO reset action locks */
 
@@ -1517,10 +1544,10 @@ void LoadEnv::impl_reactForLoadingState()
         if (bMinimized)
         {
             SolarMutexGuard aSolarGuard;
-            vcl::Window* pWindow = VCLUnoHelper::GetWindow(xWindow);
+            VclPtr<vcl::Window> pWindow = VCLUnoHelper::GetWindow(xWindow);
             // check for system window is necessary to guarantee correct pointer cast!
             if (pWindow && pWindow->IsSystemWindow())
-                static_cast<WorkWindow*>(pWindow)->Minimize();
+                static_cast<WorkWindow*>(pWindow.get())->Minimize();
         }
         else if (!bHidden)
         {
@@ -1553,7 +1580,7 @@ void LoadEnv::impl_reactForLoadingState()
         m_xTargetFrame.clear();
         if (xOldDoc.is())
         {
-            bool bReactivated = xOldDoc->suspend(sal_False);
+            bool bReactivated = xOldDoc->suspend(false);
             if (!bReactivated)
                 throw LoadEnvException(LoadEnvException::ID_COULD_NOT_REACTIVATE_CONTROLLER);
             m_bReactivateControllerOnError = false;
@@ -1568,7 +1595,7 @@ void LoadEnv::impl_reactForLoadingState()
         try
         {
             if (xCloseable.is())
-                xCloseable->close(sal_True);
+                xCloseable->close(true);
             else
             if (xDisposable.is())
                 xDisposable->dispose();
@@ -1625,7 +1652,7 @@ void LoadEnv::impl_makeFrameWindowVisible(const css::uno::Reference< css::awt::X
     // <- SAFE ----------------------------------
 
     SolarMutexGuard aSolarGuard;
-    vcl::Window* pWindow = VCLUnoHelper::GetWindow(xWindow);
+    VclPtr<vcl::Window> pWindow = VCLUnoHelper::GetWindow(xWindow);
     if ( pWindow )
     {
         bool const preview( m_lMediaDescriptor.getUnpackedValueOrDefault(
@@ -1640,12 +1667,12 @@ void LoadEnv::impl_makeFrameWindowVisible(const css::uno::Reference< css::awt::X
                   "org.openoffice.Office.Common/View",
                   "NewDocumentHandling",
                   "ForceFocusAndToFront",
-                  ::comphelper::ConfigurationHelper::E_READONLY);
+                  ::comphelper::EConfigurationModes::ReadOnly);
             a >>= bForceFrontAndFocus;
         }
 
         if( pWindow->IsVisible() && (bForceFrontAndFocus || bForceToFront) )
-            pWindow->ToTop();
+            pWindow->ToTop( ToTopFlags::RestoreWhenMin | ToTopFlags::ForegroundTask );
         else
             pWindow->Show(true, (bForceFrontAndFocus || bForceToFront) ? ShowFlags::ForegroundTask : ShowFlags::NONE );
     }
@@ -1653,8 +1680,6 @@ void LoadEnv::impl_makeFrameWindowVisible(const css::uno::Reference< css::awt::X
 
 void LoadEnv::impl_applyPersistentWindowState(const css::uno::Reference< css::awt::XWindow >& xWindow)
 {
-    static const char PACKAGE_SETUP_MODULES[] = "/org.openoffice.Setup/Office/Factories";
-
     // no window -> action not possible
     if (!xWindow.is())
         return;
@@ -1671,18 +1696,18 @@ void LoadEnv::impl_applyPersistentWindowState(const css::uno::Reference< css::aw
     // SOLAR SAFE ->
     SolarMutexClearableGuard aSolarGuard1;
 
-    vcl::Window*  pWindow       = VCLUnoHelper::GetWindow(xWindow);
+    VclPtr<vcl::Window>  pWindow = VCLUnoHelper::GetWindow(xWindow);
     if (!pWindow)
         return;
 
     bool bSystemWindow = pWindow->IsSystemWindow();
-    bool bWorkWindow   = (pWindow->GetType() == WINDOW_WORKWINDOW);
+    bool bWorkWindow   = (pWindow->GetType() == WindowType::WORKWINDOW);
 
     if (!bSystemWindow && !bWorkWindow)
         return;
 
     // don't overwrite this special state!
-    WorkWindow* pWorkWindow = static_cast<WorkWindow*>(pWindow);
+    WorkWindow* pWorkWindow = static_cast<WorkWindow*>(pWindow.get());
     if (pWorkWindow->IsMinimized())
         return;
 
@@ -1716,15 +1741,19 @@ void LoadEnv::impl_applyPersistentWindowState(const css::uno::Reference< css::aw
         // get access to the configuration of this office module
         css::uno::Reference< css::container::XNameAccess > xModuleCfg(::comphelper::ConfigurationHelper::openConfig(
                                                                         xContext,
-                                                                        PACKAGE_SETUP_MODULES,
-                                                                        ::comphelper::ConfigurationHelper::E_READONLY),
+                                                                        "/org.openoffice.Setup/Office/Factories",
+                                                                        ::comphelper::EConfigurationModes::ReadOnly),
                                                                       css::uno::UNO_QUERY_THROW);
 
         // read window state from the configuration
         // and apply it on the window.
         // Do nothing, if no configuration entry exists!
         OUString sWindowState;
-        ::comphelper::ConfigurationHelper::readRelativeKey(xModuleCfg, sModule, OFFICEFACTORY_PROPNAME_ASCII_WINDOWATTRIBUTES) >>= sWindowState;
+
+        // Don't look for persistent window attributes when used through LibreOfficeKit
+        if( !comphelper::LibreOfficeKit::isActive() )
+            comphelper::ConfigurationHelper::readRelativeKey(xModuleCfg, sModule, OFFICEFACTORY_PROPNAME_ASCII_WINDOWATTRIBUTES) >>= sWindowState;
+
         if (!sWindowState.isEmpty())
         {
             // SOLAR SAFE ->
@@ -1735,11 +1764,11 @@ void LoadEnv::impl_applyPersistentWindowState(const css::uno::Reference< css::aw
             // But if we get a valid pointer we can be sure, that it's the system window pointer
             // we already checked and used before. Because nobody recycle the same uno reference for
             // a new internal c++ implementation ... hopefully .-))
-            vcl::Window* pWindowCheck  = VCLUnoHelper::GetWindow(xWindow);
+            VclPtr<vcl::Window> pWindowCheck = VCLUnoHelper::GetWindow(xWindow);
             if (! pWindowCheck)
                 return;
 
-            SystemWindow* pSystemWindow = static_cast<SystemWindow*>(pWindowCheck);
+            SystemWindow* pSystemWindow = static_cast<SystemWindow*>(pWindowCheck.get());
             pSystemWindow->SetWindowState(OUStringToOString(sWindowState,RTL_TEXTENCODING_UTF8));
             // <- SOLAR SAFE
         }
