@@ -18,6 +18,7 @@
  */
 
 
+#include <memory>
 #include <HelpCompiler.hxx>
 #include <BasCodeTagger.hxx>
 #include <limits.h>
@@ -28,14 +29,12 @@
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
 #include <osl/thread.hxx>
+#include <chrono>
+#include<rtl/character.hxx>
 
 static void impl_sleep( sal_uInt32 nSec )
 {
-    TimeValue aTime;
-    aTime.Seconds = nSec;
-    aTime.Nanosec = 0;
-
-    osl::Thread::wait( aTime );
+    osl::Thread::wait( std::chrono::seconds(nSec) );
 }
 HelpCompiler::HelpCompiler(StreamTable &in_streamTable, const fs::path &in_inputFile,
     const fs::path &in_src, const fs::path &in_zipdir, const fs::path &in_resCompactStylesheet,
@@ -87,7 +86,7 @@ xmlDocPtr HelpCompiler::compactXhpForJar( xmlDocPtr doc )
 void HelpCompiler::saveXhpForJar( xmlDocPtr doc, const fs::path &filePath )
 {
     //save processed xhp document in ziptmp<module>_<lang>/text directory
-#ifdef WNT
+#ifdef _WIN32
     std::string pathSep = "\\";
 #else
     std::string pathSep = "/";
@@ -332,14 +331,12 @@ void myparser::traverse( xmlNodePtr parentNode )
             xmlFree (branchxml);
             xmlFree (idxml);
 
-            std::string hid;
-
             if (branch.compare(0, 3, "hid") == 0)
             {
                 size_t index = branch.find('/');
                 if (index != std::string::npos)
                 {
-                    hid = branch.substr(1 + index);
+                    auto hid = branch.substr(1 + index);
                     // one shall serve as a documentId
                     if (documentId.empty())
                         documentId = hid;
@@ -420,7 +417,7 @@ void myparser::traverse( xmlNodePtr parentNode )
             {
                 //TODO: make these asserts and flush out all our broken help ids
                 SAL_WARN_IF(hidstr.empty(), "helpcompiler", "hid='' for text:" << text);
-                SAL_WARN_IF(!hidstr.empty() && extendedHelpText.empty(), "helpcompiler", "hid='.' with no hid bookmark branches for text:" << text);
+                SAL_WARN_IF(!hidstr.empty() && extendedHelpText.empty(), "helpcompiler", "hid='.' with no hid bookmark branches in file: " << fileName + " for text: " << text);
                 HashSet::const_iterator aEnd = extendedHelpText.end();
                 for (HashSet::const_iterator iter = extendedHelpText.begin(); iter != aEnd; ++iter)
                 {
@@ -436,7 +433,6 @@ void myparser::traverse( xmlNodePtr parentNode )
 }
 
 bool HelpCompiler::compile()
-    throw (HelpProcessingException, BasicCodeTagger::TaggerException, std::exception)
 {
     // we now have the jaroutputstream, which will contain the document.
     // now determine the document as a dom tree in variable docResolved
@@ -454,7 +450,7 @@ bool HelpCompiler::compile()
         {
             std::stringstream aStrStream;
             aStrStream << "ERROR: file not existing: " << inputFile.native_file_string().c_str() << std::endl;
-            throw HelpProcessingException( HELPPROCESSING_GENERAL_ERROR, aStrStream.str() );
+            throw HelpProcessingException( HelpProcessingErrorClass::General, aStrStream.str() );
         }
     }
 
@@ -463,9 +459,9 @@ bool HelpCompiler::compile()
     std::string title;
     // returns a clone of the document with switch-cases resolved
     std::string appl = module.substr(1);
-    for (size_t i = 0; i < appl.length(); ++i)
+    for (char & i : appl)
     {
-        appl[i]=toupper(appl[i]);
+        i=rtl::toAsciiUpperCase(static_cast<unsigned char>(i));
     }
     xmlNodePtr docResolved = clone(xmlDocGetRootElement(docResolvedOrg), appl);
     myparser aparser(documentId, fileName, title);
@@ -494,8 +490,7 @@ bool HelpCompiler::compile()
     {
         if (fileName.compare(0, 6, "/text/") == 0)
         {
-            int len = strlen("/text/");
-            actMod = fileName.substr(len);
+            actMod = fileName.substr(strlen("/text/"));
             actMod = actMod.substr(0, actMod.find('/'));
         }
     }
