@@ -20,7 +20,6 @@
 #include <assert.h>
 #include <stdio.h>
 #include <string.h>
-#include <ctype.h>
 
 // DVO: always use standard headers:
 #include <istream>
@@ -32,23 +31,32 @@ using namespace std;
 #include <sal/types.h>
 #include <sal/macros.h>
 
+#include <rtl/character.hxx>
+
 /* @Man: change the hwp formula to LaTeX */
-#ifdef WIN32
+#ifdef _WIN32
 # define ENDL  "\r\n"
 #else /* !WIN32 */
 # define ENDL  "\n"
 #endif
 
-#define WS  " \t\r\n\v\f"
-
 #define EQ_CASE 0x01    // case sensitive cmd
 #define EQ_ENV  0x02    // equiv to latex environment
 #define EQ_ATOP 0x04    // must revert order
 
-#define IS_WS(ch)   (strchr(WS, ch))
-#define IS_BINARY(ch)   (strchr("+-<=>", ch))
+static bool IS_WS(std::istream::int_type ch) {
+    return ch != std::istream::traits_type::eof()
+        && rtl::isAsciiWhiteSpace(
+            static_cast<unsigned char>(
+                std::istream::traits_type::to_char_type(ch)));
+}
 
-#ifdef WIN32
+static bool IS_BINARY(std::istream::int_type ch) {
+    return ch != std::istream::traits_type::eof()
+        && strchr("+-<=>", std::istream::traits_type::to_char_type(ch));
+}
+
+#ifdef _WIN32
 #define STRICMP stricmp
 #else
 #define STRICMP strcasecmp
@@ -380,7 +388,7 @@ static const hwpeq eq_tbl[] = {
   { "zeta",       nullptr,       0,  EQ_CASE }
 };
 
-static const hwpeq *lookup_eqn(char *str)
+static const hwpeq *lookup_eqn(char const *str)
 {
   static const int eqCount = SAL_N_ELEMENTS(eq_tbl);
   int l = 0, r = eqCount;
@@ -416,15 +424,16 @@ void make_keyword( char *keyword, const char *token)
     memcpy(keyword, token, len);
     keyword[len] = 0;
 
-    if( (token[0] & 0x80) || islower(token[0]) || strlen(token) < 2 )
+    if( (token[0] & 0x80) || rtl::isAsciiLowerCase(static_cast<unsigned char>(token[0])) || strlen(token) < 2 )
         return;
 
-    int capital = isupper(keyword[1]);
+    bool capital = rtl::isAsciiUpperCase(
+        static_cast<unsigned char>(keyword[1]));
     for( ptr = keyword + 2; *ptr && result; ptr++ )
     {
         if( (*ptr & 0x80) ||
-            (!capital && isupper(*ptr)) ||
-            (capital && islower(*ptr)) )
+            (!capital && rtl::isAsciiUpperCase(static_cast<unsigned char>(*ptr))) ||
+            (capital && rtl::isAsciiLowerCase(static_cast<unsigned char>(*ptr))) )
         {
             result = false;
         }
@@ -435,12 +444,12 @@ void make_keyword( char *keyword, const char *token)
         ptr = keyword;
         while( *ptr )
         {
-            if( isupper(*ptr) )
-                *ptr = sal::static_int_cast<char>(tolower(*ptr));
+            if( rtl::isAsciiUpperCase(static_cast<unsigned char>(*ptr)) )
+                *ptr = sal::static_int_cast<char>(
+                    rtl::toAsciiLowerCase(static_cast<unsigned char>(*ptr)));
             ptr++;
         }
     }
-    return;
 }
 
 // token reading function
@@ -450,7 +459,7 @@ struct eq_stack {
   istream   *strm;
 
   eq_stack() { strm = nullptr; };
-  bool state(istream *s) {
+  bool state(istream const *s) {
     if( strm != s) { white = nullptr; token = nullptr; }
     return token.length() != 0;
   }
@@ -458,7 +467,7 @@ struct eq_stack {
 
 static eq_stack *stk = nullptr;
 
-void push_token(MzString &white, MzString &token, istream *strm)
+void push_token(MzString const &white, MzString const &token, istream *strm)
 {
   // one time stack
   assert(stk->token.length() == 0);
@@ -475,7 +484,7 @@ void push_token(MzString &white, MzString &token, istream *strm)
  * alphabet string, sigle character */
 static int next_token(MzString &white, MzString &token, istream *strm)
 {
-  int  ch = 0;
+  std::istream::int_type ch = 0;
 
   if( stk->state(strm) ) {
     white = stk->white;
@@ -487,7 +496,7 @@ static int next_token(MzString &white, MzString &token, istream *strm)
 
   token = nullptr;
   white = nullptr;
-  if( !strm->good() || (ch = strm->get()) == EOF )
+  if( !strm->good() || (ch = strm->get()) == std::istream::traits_type::eof() )
     return 0;
 
   // read preceding ws
@@ -496,7 +505,9 @@ static int next_token(MzString &white, MzString &token, istream *strm)
     while( IS_WS(ch = strm->get()) );
   }
 
-  if( ch == '\\' || ch & 0x80 || isalpha(ch) ) {
+  if( ch == '\\' || ch & 0x80
+      || (ch != std::istream::traits_type::eof() && rtl::isAsciiAlpha(ch)) )
+  {
     if( ch == '\\' ) {
       token << (char) ch;
       ch = strm->get();
@@ -504,8 +515,9 @@ static int next_token(MzString &white, MzString &token, istream *strm)
     do {
       token << (char) ch;
       ch = strm->get();
-    } while( ch != EOF && (ch & 0x80 || isalpha(ch)) ) ;
-    strm->putback(sal::static_int_cast<char>(ch));
+    } while( ch != std::istream::traits_type::eof()
+             && (ch & 0x80 || rtl::isAsciiAlpha(ch)) ) ;
+    strm->putback(static_cast<char>(ch));
     /* special treatment of sub, sub, over, atop
        The reason for this is that affect next_state().
      */
@@ -526,12 +538,14 @@ static int next_token(MzString &white, MzString &token, istream *strm)
   else if( IS_BINARY(ch) ) {
     do token << (char) ch;
     while( IS_BINARY(ch = strm->get()) );
-    strm->putback(sal::static_int_cast<char>(ch));
+    strm->putback(static_cast<char>(ch));
   }
-  else if( isdigit(ch) ) {
-    do token << (char) ch;
-    while( isdigit(ch = strm->get()) );
-    strm->putback(sal::static_int_cast<char>(ch));
+  else if( ch != std::istream::traits_type::eof() && rtl::isAsciiDigit(ch) ) {
+    do {
+        token << (char) ch;
+        ch = strm->get();
+    } while( ch != std::istream::traits_type::eof() && rtl::isAsciiDigit(ch) );
+    strm->putback(static_cast<char>(ch));
   }
   else
     token << (char) ch;
@@ -539,20 +553,20 @@ static int next_token(MzString &white, MzString &token, istream *strm)
   return token.length();
 }
 
-static int read_white_space(MzString& outs, istream *strm)
+static std::istream::int_type read_white_space(MzString& outs, istream *strm)
 {
-  int   result;
+  std::istream::int_type result;
 
   if( stk->state(strm) ) {
     outs << stk->white;
     stk->white = nullptr;
-    result = stk->token[0];
+    result = std::istream::traits_type::to_int_type(stk->token[0]);
   }
   else {
-    int ch;
+    std::istream::int_type ch;
     while( IS_WS(ch = strm->get()) )
       outs << (char )ch;
-    strm->putback(sal::static_int_cast<char>(ch));
+    strm->putback(static_cast<char>(ch));
     result = ch;
   }
   return result;
@@ -614,7 +628,7 @@ static int eq_word(MzString& outs, istream *strm, int status)
       if( nullptr != (eq = lookup_eqn(keyword)) ) {
         int nargs = eq->nargs;
         while( nargs-- ) {
-          const int ch = read_white_space(state, strm);
+          const std::istream::int_type ch = read_white_space(state, strm);
           if( ch != '{' ) state << '{';
           eq_word(state, strm, script_status);
           if( ch != '{' ) state << '}';
@@ -673,7 +687,8 @@ static char eq2ltxconv(MzString& sstr, istream *strm, const char *sentinel)
 {
   MzString  white, token;
   char      key[256];
-  int       ch, result;
+  std::istream::int_type ch;
+  int       result;
 
   while( 0 != (result = next_token(white, token, strm)) ) {
     if( sentinel && (result == 1) && strchr(sentinel, token[0]) )
@@ -687,8 +702,10 @@ static char eq2ltxconv(MzString& sstr, istream *strm, const char *sentinel)
         key[0] = '\\';
         strcpy(key + 1, eq->key);
       }
-      if( (eq->flag & EQ_CASE) && isupper(token[0]) )
-        key[1] = sal::static_int_cast<char>(toupper(key[1]));
+      if( (eq->flag & EQ_CASE)
+          && rtl::isAsciiUpperCase(static_cast<unsigned char>(token[0])) )
+        key[1] = sal::static_int_cast<char>(
+            rtl::toAsciiUpperCase(static_cast<unsigned char>(key[1])));
       token = key;
     }
 
@@ -716,7 +733,8 @@ static char eq2ltxconv(MzString& sstr, istream *strm, const char *sentinel)
           sstr.replace(pos, ' ');
       }
       sstr << token;
-      while( (ch = strm->get()) != EOF && IS_WS(ch) )
+      while( (ch = strm->get()) != std::istream::traits_type::eof()
+             && IS_WS(ch) )
         sstr << (char)ch;
       if( ch != '{' )
         sstr << "{}";
@@ -731,7 +749,7 @@ static char eq2ltxconv(MzString& sstr, istream *strm, const char *sentinel)
   return token[0];
 }
 
-void eq2latex(MzString& outs, char *s)
+void eq2latex(MzString& outs, char const *s)
 {
   assert(s);
   if( stk == nullptr )
