@@ -17,8 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include "precompile.h"
 
+#include <algorithm>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -32,11 +34,10 @@
 #include "hpara.h"
 #include "htags.h"
 #include "hcode.h"
-#include "hstream.h"
+#include "hstream.hxx"
 
-#include <osl/diagnose.h>
 
-HWPFile *HWPFile::cur_doc = 0;
+HWPFile *HWPFile::cur_doc = nullptr;
 static int ccount = 0;
 static int pcount = 0;
 static int datecodecount = 0;
@@ -48,10 +49,11 @@ HWPFile::HWPFile()
     , linenumber(0)
     , info_block_len(0)
     , error_code(HWP_NoError)
-    , oledata(0)
+    , oledata(nullptr)
+    , readdepth(0)
     , m_nCurrentPage(1)
     , m_nMaxSettedPage(0)
-    , hiodev(0)
+    , hiodev(nullptr)
     , currenthyper(0)
 {
     SetCurrentDoc(this);
@@ -61,24 +63,6 @@ HWPFile::~HWPFile()
 {
     delete oledata;
     delete hiodev;
-
-    std::list < ColumnInfo* >::iterator it_column = columnlist.begin();
-    for (; it_column != columnlist.end(); ++it_column)
-        delete *it_column;
-
-    std::list < HWPPara* >::iterator it = plist.begin();
-    for (; it != plist.end(); ++it)
-        delete *it;
-
-    std::list < Table* >::iterator tbl = tables.begin();
-    for (; tbl != tables.end(); ++tbl)
-        delete *tbl;
-
-    std::list < HyperText* >::iterator hyp = hyperlist.begin();
-    for (; hyp != hyperlist.end(); ++hyp)
-    {
-        delete *hyp;
-    }
 }
 
 int HWPFile::ReadHwpFile(HStream * stream)
@@ -124,7 +108,7 @@ int HWPFile::Open(HStream * stream)
 
     char idstr[HWPIDLen];
 
-    if (ReadBlock(idstr, HWPIDLen) <= 0
+    if (ReadBlock(idstr, HWPIDLen) < HWPIDLen
         || HWP_V30 != (version = detect_hwp_version(idstr)))
     {
         return SetState(HWP_UNSUPPORTED_VERSION);
@@ -138,15 +122,10 @@ int HWPFile::SetState(int errcode)
     return error_code;
 }
 
-bool HWPFile::Read1b(unsigned char &out)
-{
-    return hiodev ? hiodev->read1b(out) : false;
-}
-
 bool HWPFile::Read1b(char &out)
 {
     unsigned char tmp8;
-    if (!Read1b(tmp8))
+    if (!hiodev || !hiodev->read1b(tmp8))
         return false;
     out = tmp8;
     return true;
@@ -154,12 +133,12 @@ bool HWPFile::Read1b(char &out)
 
 bool HWPFile::Read2b(unsigned short &out)
 {
-    return hiodev ? hiodev->read2b(out) : false;
+    return hiodev && hiodev->read2b(out);
 }
 
 bool HWPFile::Read4b(unsigned int &out)
 {
-    return hiodev ? hiodev->read4b(out) : false;
+    return hiodev && hiodev->read4b(out);
 }
 
 bool HWPFile::Read4b(int &out)
@@ -171,38 +150,36 @@ bool HWPFile::Read4b(int &out)
     return true;
 }
 
-int HWPFile::Read1b(void *ptr, size_t nmemb)
+size_t HWPFile::Read1b(void *ptr, size_t nmemb)
 {
     return hiodev ? hiodev->read1b(ptr, nmemb) : 0;
 }
 
-int HWPFile::Read2b(void *ptr, size_t nmemb)
+size_t HWPFile::Read2b(void *ptr, size_t nmemb)
 {
     return hiodev ? hiodev->read2b(ptr, nmemb) : 0;
 }
 
-
-int HWPFile::Read4b(void *ptr, size_t nmemb)
+void HWPFile::Read4b(void *ptr, size_t nmemb)
 {
-    return hiodev ? hiodev->read4b(ptr, nmemb) : 0;
+    if (hiodev)
+        hiodev->read4b(ptr, nmemb);
 }
 
-
 size_t HWPFile::ReadBlock(void *ptr, size_t size)
 {
     return hiodev ? hiodev->readBlock(ptr, size) : 0;
 }
 
-
 size_t HWPFile::SkipBlock(size_t size)
 {
     return hiodev ? hiodev->skipBlock(size) : 0;
 }
 
-
-bool HWPFile::SetCompressed(bool flag)
+void HWPFile::SetCompressed(bool flag)
 {
-    return hiodev ? hiodev->setCompressed(flag) : false;
+    if (hiodev)
+        hiodev->setCompressed(flag);
 }
 
 
@@ -218,34 +195,69 @@ HIODev *HWPFile::SetIODevice(HIODev * new_hiodev)
 
 // end of HIODev wrapper
 
-bool HWPFile::InfoRead(void)
+void HWPFile::InfoRead()
 {
-    return _hwpInfo.Read(*this);
+    _hwpInfo.Read(*this);
 }
 
 
-bool HWPFile::FontRead(void)
+void HWPFile::FontRead()
 {
-    return _hwpFont.Read(*this);
+    _hwpFont.Read(*this);
 }
 
 
-bool HWPFile::StyleRead(void)
+void HWPFile::StyleRead()
 {
-    return _hwpStyle.Read(*this);
+    _hwpStyle.Read(*this);
 }
 
 
-bool HWPFile::ParaListRead(void)
+void HWPFile::ParaListRead()
 {
-    return ReadParaList(plist);
+    ReadParaList(plist);
 }
 
-bool HWPFile::ReadParaList(std::list < HWPPara* > &aplist, unsigned char flag)
+bool HWPFile::ReadParaList(std::vector < HWPPara* > &aplist)
 {
-    HWPPara *spNode = new HWPPara;
-     unsigned char tmp_etcflag;
-     unsigned char prev_etcflag = 0;
+    std::unique_ptr<HWPPara> spNode( new HWPPara );
+    unsigned char tmp_etcflag;
+    unsigned char prev_etcflag = 0;
+    while (spNode->Read(*this, 0))
+    {
+         if( !(spNode->etcflag & 0x04) ){
+          tmp_etcflag = spNode->etcflag;
+          spNode->etcflag = prev_etcflag;
+          prev_etcflag = tmp_etcflag;
+         }
+        if (spNode->nch && spNode->reuse_shape)
+        {
+            if (!aplist.empty()){
+                     spNode->pshape = aplist.back()->pshape;
+                }
+                else{
+                     spNode->nch = 0;
+                     spNode->reuse_shape = 0;
+                }
+        }
+        spNode->pshape->pagebreak = spNode->etcflag;
+        if (spNode->nch)
+            AddParaShape(spNode->pshape);
+
+        if (!aplist.empty())
+            aplist.back()->SetNext(spNode.get());
+        aplist.push_back(spNode.release());
+        spNode.reset( new HWPPara );
+    }
+
+    return true;
+}
+
+bool HWPFile::ReadParaList(std::vector< std::unique_ptr<HWPPara> > &aplist, unsigned char flag)
+{
+    std::unique_ptr<HWPPara> spNode( new HWPPara );
+    unsigned char tmp_etcflag;
+    unsigned char prev_etcflag = 0;
     while (spNode->Read(*this, flag))
     {
          if( !(spNode->etcflag & 0x04) ){
@@ -263,28 +275,27 @@ bool HWPFile::ReadParaList(std::list < HWPPara* > &aplist, unsigned char flag)
                      spNode->reuse_shape = 0;
                 }
         }
-          spNode->pshape.pagebreak = spNode->etcflag;
-          if( spNode->nch )
-                AddParaShape( &spNode->pshape );
+        spNode->pshape->pagebreak = spNode->etcflag;
+        if (spNode->nch)
+            AddParaShape(spNode->pshape);
 
         if (!aplist.empty())
-            aplist.back()->SetNext(spNode);
-        aplist.push_back(spNode);
-        spNode = new HWPPara;
+            aplist.back()->SetNext(spNode.get());
+        aplist.push_back(std::move(spNode));
+        spNode.reset( new HWPPara );
     }
-    delete spNode;
 
     return true;
 }
 
-void HWPFile::TagsRead(void)
+void HWPFile::TagsRead()
 {
     while (true)
     {
         uint tag;
         if (!Read4b(tag))
             return;
-        uint size;
+        int size;
         if (!Read4b(size))
             return;
         if (size <= 0 && tag > 0){
@@ -298,31 +309,32 @@ void HWPFile::TagsRead(void)
         {
             case FILETAG_EMBEDDED_PICTURE:
             {
-                EmPicture *emb = new EmPicture(size);
+                std::unique_ptr<EmPicture> emb(new EmPicture(size));
 
-                if (true == emb->Read(*this))
-                    emblist.push_back(emb);
-                else
-                    delete emb;
+                if (emb->Read(*this))
+                    emblist.push_back(std::move(emb));
             }
             break;
             case FILETAG_OLE_OBJECT:
-                if (oledata)
-                    delete oledata;
+                delete oledata;
                 oledata = new OlePicture(size);
                 oledata->Read(*this);
                 break;
             case FILETAG_HYPERTEXT:
             {
-                if( (size % 617) != 0 )
+                const int nRecordLen = 617;
+                if( (size % nRecordLen) != 0 )
                     SkipBlock( size );
                 else
                 {
-                    for( uint i = 0 ; i < size/617 ; i++)
+                    const int nRecords = size / nRecordLen;
+                    for (int i = 0 ; i < nRecords; ++i)
                     {
-                        HyperText *hypert = new HyperText;
-                        hypert->Read(*this);
-                        hyperlist.push_back(hypert);
+                        std::unique_ptr<HyperText> hypert(new HyperText);
+                        if (hypert->Read(*this))
+                            hyperlist.push_back(std::move(hypert));
+                        else
+                            break;
                     }
                 }
                 break;
@@ -351,8 +363,30 @@ void HWPFile::TagsRead(void)
                      if (!Read4b(_hwpInfo.back_info.size))
                         return;
 
-                     _hwpInfo.back_info.data = new char[(unsigned int)_hwpInfo.back_info.size];
-                     ReadBlock(_hwpInfo.back_info.data, _hwpInfo.back_info.size);
+                     if (_hwpInfo.back_info.size < 0)
+                     {
+                        _hwpInfo.back_info.size = 0;
+                        return;
+                     }
+
+                     _hwpInfo.back_info.data.clear();
+
+                     //read potentially compressed data in blocks as its more
+                     //likely large values are simply broken and we'll run out
+                     //of data before we need to realloc
+                     for (int i = 0; i < _hwpInfo.back_info.size; i+= SAL_MAX_UINT16)
+                     {
+                        int nOldSize = _hwpInfo.back_info.data.size();
+                        size_t nBlock = std::min<int>(SAL_MAX_UINT16, _hwpInfo.back_info.size - nOldSize);
+                        _hwpInfo.back_info.data.resize(nOldSize + nBlock);
+                        size_t nReadBlock = ReadBlock(_hwpInfo.back_info.data.data() + nOldSize, nBlock);
+                        if (nBlock != nReadBlock)
+                        {
+                            _hwpInfo.back_info.data.resize(nOldSize + nReadBlock);
+                            break;
+                        }
+                     }
+                     _hwpInfo.back_info.size = _hwpInfo.back_info.data.size();
 
                      if( _hwpInfo.back_info.size > 0 )
                           _hwpInfo.back_info.type = 2;
@@ -378,44 +412,32 @@ void HWPFile::TagsRead(void)
 
 ColumnDef *HWPFile::GetColumnDef(int num)
 {
-    std::list<ColumnInfo*>::iterator it = columnlist.begin();
-
-    for(int i = 0; it != columnlist.end() ; ++it, i++){
-        if( i == num )
-	  break;
-    }
-
-    if( it != columnlist.end() )
-        return (*it)->coldef;
+    if (static_cast<size_t>(num) < columnlist.size())
+        return columnlist[num]->xColdef.get();
     else
-        return 0;
+        return nullptr;
 }
-/* @return 인덱스는 1부터 시작한다. */
+
+/* Index of @return starts from 1 */
 int HWPFile::GetPageMasterNum(int page)
 {
-    std::list<ColumnInfo*>::iterator it = columnlist.begin();
-    ColumnInfo *now = 0;
-    int i;
-
-    for( i = 1 ; it != columnlist.end() ; ++it, i++){
-        now = *it;
-        if( page < now->start_page )
-            return i-1;
+    int i = 0;
+    for (auto const& column : columnlist)
+    {
+        if( page < column->start_page )
+            return i;
+        ++i;
     }
-    return i-1;
+    return i;
 }
 
 HyperText *HWPFile::GetHyperText()
 {
-    std::list<HyperText*>::iterator it = hyperlist.begin();
-
-    for( int i = 0; it != hyperlist.end(); ++it, i++ ){
-	if( i == currenthyper )
-	  break;
-    }
-
-    currenthyper++;
-    return it != hyperlist.end() ? *it : NULL;
+    ++currenthyper;
+    if (static_cast<size_t>(currenthyper) <= hyperlist.size())
+        return hyperlist[currenthyper-1].get();
+    else
+        return nullptr;
 }
 
 EmPicture *HWPFile::GetEmPicture(Picture * pic)
@@ -426,11 +448,10 @@ EmPicture *HWPFile::GetEmPicture(Picture * pic)
     name[1] = 'W';
     name[2] = 'P';
 
-    std::list < EmPicture* >::iterator it = emblist.begin();
-    for (; it != emblist.end(); ++it)
-        if (strcmp(name, (*it)->name) == 0)
-            return *it;
-    return 0;
+    for (auto const& emb : emblist)
+        if (strcmp(name, emb->name) == 0)
+            return emb.get();
+    return nullptr;
 }
 
 EmPicture *HWPFile::GetEmPictureByName(char * name)
@@ -439,137 +460,89 @@ EmPicture *HWPFile::GetEmPictureByName(char * name)
     name[1] = 'W';
     name[2] = 'P';
 
-    std::list < EmPicture* >::iterator it = emblist.begin();
-    for (; it != emblist.end(); ++it)
-        if (strcmp(name, (*it)->name) == 0)
-            return *it;
-    return 0;
+    for (auto const& emb : emblist)
+        if (strcmp(name, emb->name) == 0)
+            return emb.get();
+    return nullptr;
 }
 
-
 void HWPFile::AddBox(FBox * box)
 {
-// LATER if we don't use box->next(),
-// AddBox() and GetBoxHead() are useless;
-    if (!blist.empty())
-    {
-        box->prev = blist.back();
-        box->prev->next = box;
-    }
-    else
-        box->prev = 0;
     blist.push_back(box);
 }
 
-
 ParaShape *HWPFile::getParaShape(int index)
 {
-    std::list<ParaShape*>::iterator it = pslist.begin();
-
-    for( int i = 0; it != pslist.end(); ++it, i++ ){
-	if( i == index )
-	  break;
-    }
-
-    return it != pslist.end() ? *it : NULL;
+    if (index < 0 || static_cast<unsigned int>(index) >= pslist.size())
+        return nullptr;
+    return pslist[index].get();
 }
 
-
 CharShape *HWPFile::getCharShape(int index)
 {
-    std::list<CharShape*>::iterator it = cslist.begin();
-
-    for( int i = 0; it != cslist.end(); ++it, i++ ){
-	if( i == index )
-	  break;
-    }
-
-    return it != cslist.end() ? *it : 0;
+    if (index < 0 || static_cast<unsigned int>(index) >= cslist.size())
+        return nullptr;
+    return cslist[index].get();
 }
 
-
 FBoxStyle *HWPFile::getFBoxStyle(int index)
 {
-    std::list<FBoxStyle*>::iterator it = fbslist.begin();
-
-    for( int i = 0; it != fbslist.end(); ++it, i++ ){
-	if( i == index )
-	  break;
-    }
-
-    return it != fbslist.end() ? *it : 0;
+    if (index < 0 || static_cast<unsigned int>(index) >= fbslist.size())
+        return nullptr;
+    return fbslist[index];
 }
 
 DateCode *HWPFile::getDateCode(int index)
 {
-    std::list<DateCode*>::iterator it = datecodes.begin();
-
-    for( int i = 0; it != datecodes.end(); ++it, i++ ){
-	if( i == index )
-	  break;
-    }
-
-    return it != datecodes.end() ? *it : NULL;
+    if (index < 0 || static_cast<unsigned int>(index) >= datecodes.size())
+        return nullptr;
+    return datecodes[index];
 }
 
 HeaderFooter *HWPFile::getHeaderFooter(int index)
 {
-    std::list<HeaderFooter*>::iterator it = headerfooters.begin();
-
-    for( int i = 0; it != headerfooters.end(); ++it, i++ ){
-	if( i == index )
-	  break;
-    }
-
-    return it != headerfooters.end() ? *it : NULL;
+    if (index < 0 || static_cast<unsigned int>(index) >= headerfooters.size())
+        return nullptr;
+    return headerfooters[index];
 }
 
 ShowPageNum *HWPFile::getPageNumber(int index)
 {
-    std::list<ShowPageNum*>::iterator it = pagenumbers.begin();
-
-    for( int i = 0; it != pagenumbers.end(); ++it, i++ ){
-	if( i == index )
-	  break;
-    }
-
-    return it != pagenumbers.end() ? *it : NULL;
-
+    if (index < 0 || static_cast<unsigned int>(index) >= pagenumbers.size())
+        return nullptr;
+    return pagenumbers[index];
 }
 
 Table *HWPFile::getTable(int index)
 {
-    std::list<Table*>::iterator it = tables.begin();
-
-    for( int i = 0; it != tables.end(); ++it, i++ ){
-	if( i == index )
-	  break;
-    }
-
-    return it != tables.end() ? *it : NULL;
+    if (index < 0 || static_cast<unsigned int>(index) >= tables.size())
+        return nullptr;
+    return tables[index].get();
 }
 
-void HWPFile::AddParaShape(ParaShape * pshape)
+void HWPFile::AddParaShape(std::shared_ptr<ParaShape> const & pshape)
 {
     int nscount = 0;
     for(int j = 0 ; j < MAXTABS-1 ; j++)
     {
-          if( j > 0 && pshape->tabs[j].position == 0 )
-                break;
-          if( pshape->tabs[0].position == 0 ){
-                if( pshape->tabs[j].type || pshape->tabs[j].dot_continue ||
-                     (pshape->tabs[j].position != 1000 *j) )
-                          nscount = j;
-          }
-          else{
-                if( pshape->tabs[j].type || pshape->tabs[j].dot_continue ||
-                     (pshape->tabs[j].position != 1000 * (j + 1)) )
-                          nscount = j;
+        if( j > 0 && pshape->tabs[j].position == 0 )
+          break;
+        if( pshape->tabs[0].position == 0 ){
+            if( pshape->tabs[j].type || pshape->tabs[j].dot_continue ||
+                 (pshape->tabs[j].position != 1000 *j) )
+                      nscount = j;
+        }
+        else {
+            if( pshape->tabs[j].type || pshape->tabs[j].dot_continue ||
+                (pshape->tabs[j].position != 1000 * (j + 1)) )
+                    nscount = j;
           }
     }
     if( nscount )
         pshape->tabs[MAXTABS-1].type = sal::static_int_cast<char>(nscount);
-     int value = compareParaShape(pshape);
+
+    int value = compareParaShape(pshape.get());
+
     if( value == 0 || nscount )
     {
         pshape->index = ++pcount;
@@ -579,11 +552,10 @@ void HWPFile::AddParaShape(ParaShape * pshape)
         pshape->index = value;
 }
 
-
-void HWPFile::AddCharShape(CharShape * cshape)
+void HWPFile::AddCharShape(std::shared_ptr<CharShape> const & cshape)
 {
-    int value = compareCharShape(cshape);
-    if( value == 0 )
+    int value = compareCharShape(cshape.get());
+    if (value == 0)
     {
         cshape->index = ++ccount;
         cslist.push_back(cshape);
@@ -594,17 +566,16 @@ void HWPFile::AddCharShape(CharShape * cshape)
 
 void HWPFile::AddColumnInfo()
 {
-    ColumnInfo *cinfo = new ColumnInfo(m_nCurrentPage);
-    columnlist.push_back(cinfo);
+    columnlist.emplace_back(new ColumnInfo(m_nCurrentPage));
     setMaxSettedPage();
 }
 
-void HWPFile::SetColumnDef(ColumnDef *coldef)
+void HWPFile::SetColumnDef(const std::shared_ptr<ColumnDef>& rColdef)
 {
-    ColumnInfo *cinfo = columnlist.back();
+    ColumnInfo *cinfo = columnlist.back().get();
     if( cinfo->bIsSet )
         return;
-    cinfo->coldef = coldef;
+    cinfo->xColdef = rColdef;
     cinfo->bIsSet = true;
 }
 
@@ -624,9 +595,9 @@ void HWPFile::AddHeaderFooter(HeaderFooter * hbox)
     headerfooters.push_back(hbox);
 }
 
-void HWPFile::AddTable(Table * hbox)
+void HWPFile::AddTable(std::unique_ptr<Table> hbox)
 {
-    tables.push_back(hbox);
+    tables.push_back(std::move(hbox));
 }
 
 void HWPFile::AddFBoxStyle(FBoxStyle * fbstyle)
@@ -634,15 +605,14 @@ void HWPFile::AddFBoxStyle(FBoxStyle * fbstyle)
     fbslist.push_back(fbstyle);
 }
 
-int HWPFile::compareCharShape(CharShape *shape)
+int HWPFile::compareCharShape(CharShape const *shape)
 {
     int count = cslist.size();
     if( count > 0 )
     {
-        CharShape *cshape=0;
         for(int i = 0; i< count; i++)
         {
-            cshape = getCharShape(i);
+            CharShape *cshape = getCharShape(i);
 
             if( shape->size == cshape->size &&
                 shape->font[0] == cshape->font[0] &&
@@ -661,15 +631,14 @@ int HWPFile::compareCharShape(CharShape *shape)
 }
 
 
-int HWPFile::compareParaShape(ParaShape *shape)
+int HWPFile::compareParaShape(ParaShape const *shape)
 {
     int count = pslist.size();
     if( count > 0 )
     {
-        ParaShape *pshape=0;
         for(int i = 0; i< count; i++)
         {
-            pshape = getParaShape(i);
+            ParaShape *pshape = getParaShape(i);
             if( shape->left_margin == pshape->left_margin &&
                 shape->right_margin == pshape->right_margin &&
                 shape->pspacing_prev == pshape->pspacing_prev &&
@@ -699,7 +668,7 @@ int HWPFile::compareParaShape(ParaShape *shape)
 }
 
 
-HWPFile *GetCurrentDoc(void)
+HWPFile *GetCurrentDoc()
 {
     return HWPFile::cur_doc;
 }
