@@ -21,14 +21,15 @@
 #include <stdlib.h>
 #include <math.h>
 
-#include "calendar_hijri.hxx"
+#include <calendar_hijri.hxx>
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
+using namespace ::com::sun::star::i18n;
 
 #define GREGORIAN_CROSSOVER 2299161
 
-namespace com { namespace sun { namespace star { namespace i18n {
+namespace i18npool {
 
 // not used
 //static UErrorCode status; // status is shared in all calls to Calendar, it has to be reset for each call.
@@ -64,7 +65,7 @@ Calendar_hijri::Calendar_hijri()
 #define FIELDS  ((1 << CalendarFieldIndex::ERA) | (1 << CalendarFieldIndex::YEAR) | (1 << CalendarFieldIndex::MONTH) | (1 << CalendarFieldIndex::DAY_OF_MONTH))
 
 // map field value from hijri calendar to gregorian calendar
-void Calendar_hijri::mapToGregorian() throw(RuntimeException)
+void Calendar_hijri::mapToGregorian()
 {
     if (fieldSet & FIELDS) {
         sal_Int32 day = (sal_Int32)fieldSetValue[CalendarFieldIndex::DAY_OF_MONTH];
@@ -84,7 +85,7 @@ void Calendar_hijri::mapToGregorian() throw(RuntimeException)
 }
 
 // map field value from gregorian calendar to hijri calendar
-void Calendar_hijri::mapFromGregorian() throw(RuntimeException)
+void Calendar_hijri::mapFromGregorian()
 {
     sal_Int32 month, day, year;
 
@@ -316,17 +317,17 @@ Calendar_hijri::getJulianDay(sal_Int32 day, sal_Int32 month, sal_Int32 year)
     sal_Int32 intgr = (sal_Int32)((sal_Int32)(365.25 * jy) + (sal_Int32)(30.6001 * jm) + day + 1720995 );
 
     //check for switch to Gregorian calendar
-    double gregcal = 15 + 31 * ( 10 + 12 * 1582 );
+    double const gregcal = 15 + 31 * ( 10 + 12 * 1582 );
 
     if( day + 31 * (month + 12 * year) >= gregcal ) {
-    double ja;
-    ja = (sal_Int32)(0.01 * jy);
-    intgr += (sal_Int32)(2 - ja + (sal_Int32)(0.25 * ja));
+        double ja;
+        ja = (sal_Int32)(0.01 * jy);
+        intgr += (sal_Int32)(2 - ja + (sal_Int32)(0.25 * ja));
     }
 
     return (double) intgr;
 }
 
-}}}}
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
