@@ -22,12 +22,13 @@
 #include <sal/macros.h>
 #include <nativenumbersupplier.hxx>
 #include <localedata.hxx>
-#include <data/numberchar.h>
+#include "data/numberchar.h"
 #include <comphelper/string.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <memory>
 
 using namespace ::com::sun::star::uno;
+using namespace ::com::sun::star::i18n;
 using namespace ::com::sun::star::lang;
 
 typedef struct {
@@ -55,14 +56,15 @@ typedef struct {
 #define NUMBER_OMIT_ONE_67 (NUMBER_OMIT_ONE_6|NUMBER_OMIT_ONE_7)
 #define NUMBER_OMIT_ZERO_ONE_67 ( NUMBER_OMIT_ZERO|NUMBER_OMIT_ONE_67 )
 
-namespace com { namespace sun { namespace star { namespace i18n {
+namespace i18npool {
 
 OUString SAL_CALL getHebrewNativeNumberString(const OUString& aNumberString, bool useGeresh);
 
 OUString SAL_CALL getCyrillicNativeNumberString(const OUString& aNumberString);
 
+/// @throws RuntimeException
 OUString SAL_CALL AsciiToNativeChar( const OUString& inStr, sal_Int32 startPos, sal_Int32 nCount,
-        Sequence< sal_Int32 >& offset, bool useOffset, sal_Int16 number ) throw(RuntimeException)
+        Sequence< sal_Int32 >& offset, bool useOffset, sal_Int16 number )
 {
     const sal_Unicode *src = inStr.getStr() + startPos;
     rtl_uString *newStr = rtl_uString_alloc(nCount);
@@ -96,9 +98,8 @@ bool SAL_CALL AsciiToNative_numberMaker(const sal_Unicode *str, sal_Int32 begin,
     sal_Unicode multiChar = (multiChar_index == -1 ? 0 : number->multiplierChar[multiChar_index]);
     if ( len <= number->multiplierExponent[number->exponentCount-1] ) {
         if (number->multiplierExponent[number->exponentCount-1] > 1) {
-            sal_Int16 i;
             bool bNotZero = false;
-            for (i = 0; i < len; i++, begin++) {
+            for (sal_Int32 i = 0; i < len; i++, begin++) {
                 if (bNotZero || str[begin] != NUMBER_ZERO) {
                     dst[count] = numberChar[str[begin] - NUMBER_ZERO];
                     if (useOffset)
@@ -161,8 +162,9 @@ bool SAL_CALL AsciiToNative_numberMaker(const sal_Unicode *str, sal_Int32 begin,
     }
 }
 
+/// @throws RuntimeException
 OUString SAL_CALL AsciiToNative( const OUString& inStr, sal_Int32 startPos, sal_Int32 nCount,
-        Sequence< sal_Int32 >& offset, bool useOffset, const Number* number ) throw(RuntimeException)
+        Sequence< sal_Int32 >& offset, bool useOffset, const Number* number )
 {
     OUString aRet;
 
@@ -297,8 +299,9 @@ static void SAL_CALL NativeToAscii_numberMaker(sal_Int16 max, sal_Int16 prev, co
     }
 }
 
+/// @throws RuntimeException
 static OUString SAL_CALL NativeToAscii(const OUString& inStr,
-        sal_Int32 startPos, sal_Int32 nCount, Sequence< sal_Int32 >& offset, bool useOffset ) throw(RuntimeException)
+        sal_Int32 startPos, sal_Int32 nCount, Sequence< sal_Int32 >& offset, bool useOffset )
 {
     OUString aRet;
 
@@ -521,7 +524,7 @@ static sal_Int16 SAL_CALL getLanguageNumber( const Locale& rLocale)
 }
 
 OUString SAL_CALL NativeNumberSupplierService::getNativeNumberString(const OUString& aNumberString, const Locale& rLocale,
-                sal_Int16 nNativeNumberMode, Sequence< sal_Int32 >& offset) throw (RuntimeException)
+                sal_Int16 nNativeNumberMode, Sequence< sal_Int32 >& offset)
 {
     if (!isValidNatNum(rLocale, nNativeNumberMode))
         return aNumberString;
@@ -575,10 +578,10 @@ OUString SAL_CALL NativeNumberSupplierService::getNativeNumberString(const OUStr
     }
 
     if (number || num >= 0) {
-        if (!aLocale.Language.equals(rLocale.Language) ||
-                !aLocale.Country.equals(rLocale.Country) ||
-                !aLocale.Variant.equals(rLocale.Variant)) {
-            LocaleDataItem item = LocaleDataImpl().getLocaleItem( rLocale );
+        if (aLocale.Language != rLocale.Language ||
+                aLocale.Country != rLocale.Country ||
+                aLocale.Variant != rLocale.Variant) {
+            LocaleDataItem item = LocaleDataImpl::get()->getLocaleItem( rLocale );
             aLocale = rLocale;
             DecimalChar[NumberChar_HalfWidth]=item.decimalSeparator.toChar();
             if (DecimalChar[NumberChar_HalfWidth] > 0x7E || DecimalChar[NumberChar_HalfWidth] < 0x21)
@@ -606,13 +609,13 @@ OUString SAL_CALL NativeNumberSupplierService::getNativeNumberString(const OUStr
 }
 
 OUString SAL_CALL NativeNumberSupplierService::getNativeNumberString(const OUString& aNumberString, const Locale& rLocale,
-                sal_Int16 nNativeNumberMode) throw (RuntimeException, std::exception)
+                sal_Int16 nNativeNumberMode)
 {
     Sequence< sal_Int32 > offset;
     return getNativeNumberString(aNumberString, rLocale, nNativeNumberMode, offset);
 }
 
-sal_Unicode SAL_CALL NativeNumberSupplierService::getNativeNumberChar( const sal_Unicode inChar, const Locale& rLocale, sal_Int16 nNativeNumberMode ) throw(css::uno::RuntimeException)
+sal_Unicode SAL_CALL NativeNumberSupplierService::getNativeNumberChar( const sal_Unicode inChar, const Locale& rLocale, sal_Int16 nNativeNumberMode )
 {
     if (nNativeNumberMode == NativeNumberMode::NATNUM0) { // Ascii
         for (const auto & i : NumberChar)
@@ -656,7 +659,7 @@ sal_Unicode SAL_CALL NativeNumberSupplierService::getNativeNumberChar( const sal
     return inChar;
 }
 
-sal_Bool SAL_CALL NativeNumberSupplierService::isValidNatNum( const Locale& rLocale, sal_Int16 nNativeNumberMode ) throw (RuntimeException, std::exception)
+sal_Bool SAL_CALL NativeNumberSupplierService::isValidNatNum( const Locale& rLocale, sal_Int16 nNativeNumberMode )
 {
     sal_Int16 langnum = getLanguageNumber(rLocale);
 
@@ -684,7 +687,7 @@ sal_Bool SAL_CALL NativeNumberSupplierService::isValidNatNum( const Locale& rLoc
     return false;
 }
 
-NativeNumberXmlAttributes SAL_CALL NativeNumberSupplierService::convertToXmlAttributes( const Locale& rLocale, sal_Int16 nNativeNumberMode ) throw (RuntimeException, std::exception)
+NativeNumberXmlAttributes SAL_CALL NativeNumberSupplierService::convertToXmlAttributes( const Locale& rLocale, sal_Int16 nNativeNumberMode )
 {
     static const sal_Int16 attShort         = 0;
     static const sal_Int16 attMedium        = 1;
@@ -763,7 +766,7 @@ static bool natNumIn(sal_Int16 num, const sal_Int16 natnum[], sal_Int16 len)
     return false;
 }
 
-sal_Int16 SAL_CALL NativeNumberSupplierService::convertFromXmlAttributes( const NativeNumberXmlAttributes& aAttr ) throw (RuntimeException, std::exception)
+sal_Int16 SAL_CALL NativeNumberSupplierService::convertFromXmlAttributes( const NativeNumberXmlAttributes& aAttr )
 {
     sal_Unicode numberChar[NumberChar_Count];
     for (sal_Int16 i = 0; i < NumberChar_Count; i++)
@@ -813,7 +816,7 @@ sal_Int16 SAL_CALL NativeNumberSupplierService::convertFromXmlAttributes( const
 struct HebrewNumberChar {
     sal_Unicode code;
     sal_Int16 value;
-} HebrewNumberCharArray[] = {
+} const HebrewNumberCharArray[] = {
     { 0x05ea, 400 },
     { 0x05ea, 400 },
     { 0x05e9, 300 },
@@ -839,13 +842,11 @@ struct HebrewNumberChar {
     { 0x05d0, 1 }
 };
 
-static sal_Int16 nbOfHebrewNumberChar = sizeof(HebrewNumberCharArray)/sizeof(HebrewNumberChar);
-
-static sal_Unicode thousand[] = {0x05d0, 0x05dc, 0x05e3, 0x0};
-static sal_Unicode thousands[] = {0x05d0, 0x05dc, 0x05e4, 0x05d9, 0x0};
-static sal_Unicode thousands_last[] = {0x05d0, 0x05dc, 0x05e4, 0x05d9, 0x05dd, 0x0};
-static sal_Unicode geresh = 0x05f3;
-static sal_Unicode gershayim = 0x05f4;
+static const sal_Unicode thousand[] = {0x05d0, 0x05dc, 0x05e3, 0x0};
+static const sal_Unicode thousands[] = {0x05d0, 0x05dc, 0x05e4, 0x05d9, 0x0};
+static const sal_Unicode thousands_last[] = {0x05d0, 0x05dc, 0x05e4, 0x05d9, 0x05dd, 0x0};
+static const sal_Unicode geresh = 0x05f3;
+static const sal_Unicode gershayim = 0x05f4;
 
 void makeHebrewNumber(sal_Int64 value, OUStringBuffer& output, bool isLast, bool useGeresh)
 {
@@ -859,11 +860,14 @@ void makeHebrewNumber(sal_Int64 value, OUStringBuffer& output, bool isLast, bool
         output.append(value == 1000 ? thousand : isLast ? thousands_last : thousands);
     } else {
         sal_Int16 nbOfChar = 0;
-        for (sal_Int32 j = 0; num > 0 && j < nbOfHebrewNumberChar; j++) {
+        for (sal_Int32 j = 0; num > 0 && j < sal_Int32(SAL_N_ELEMENTS(HebrewNumberCharArray)); j++) {
             if (num - HebrewNumberCharArray[j].value >= 0) {
                 nbOfChar++;
+                // https://en.wikipedia.org/wiki/Hebrew_numerals#Key_exceptions
+                // By convention, the numbers 15 and 16 are represented as 9 + 6 and 9 + 7
                 if (num == 15 || num == 16) // substitution for 15 and 16
                     j++;
+                assert(j < sal_Int32(SAL_N_ELEMENTS(HebrewNumberCharArray)));
                 num = sal::static_int_cast<sal_Int16>( num - HebrewNumberCharArray[j].value );
                 output.append(HebrewNumberCharArray[j].code);
             }
@@ -920,7 +924,7 @@ static sal_Unicode cyrillicTen = 0x0456;
 struct CyrillicNumberChar {
     sal_Unicode code;
     sal_Int16 value;
-} CyrillicNumberCharArray[] = {
+} const CyrillicNumberCharArray[] = {
     { 0x0446, 900 },
     { 0x047f, 800 },
     { 0x0471, 700 },
@@ -950,8 +954,6 @@ struct CyrillicNumberChar {
     { 0x0430, 1 }
 };
 
-static sal_Int16 nbOfCyrillicNumberChar = sizeof(CyrillicNumberCharArray)/sizeof(CyrillicNumberChar);
-
 void makeCyrillicNumber(sal_Int64 value, OUStringBuffer& output, bool addTitlo)
 {
     sal_Int16 num = sal::static_int_cast<sal_Int16>(value % 1000);
@@ -965,7 +967,7 @@ void makeCyrillicNumber(sal_Int64 value, OUStringBuffer& output, bool addTitlo)
             addTitlo = false;
     }
 
-    for (sal_Int32 j = 0; num > 0 && j < nbOfCyrillicNumberChar; j++) {
+    for (sal_Int32 j = 0; num > 0 && j < sal_Int32(SAL_N_ELEMENTS(CyrillicNumberCharArray)); j++) {
         if (num < 20 && num > 10) {
             num -= 10;
             makeCyrillicNumber(num, output, false);
@@ -1030,34 +1032,34 @@ OUString SAL_CALL getCyrillicNativeNumberString(const OUString& aNumberString)
         return aNumberString;
 }
 
-static const sal_Char* implementationName = "com.sun.star.i18n.NativeNumberSupplier";
+static const sal_Char implementationName[] = "com.sun.star.i18n.NativeNumberSupplier";
 
-OUString SAL_CALL NativeNumberSupplierService::getImplementationName() throw( RuntimeException, std::exception )
+OUString SAL_CALL NativeNumberSupplierService::getImplementationName()
 {
-    return OUString::createFromAscii( implementationName );
+    return OUString(implementationName);
 }
 
 sal_Bool SAL_CALL
-NativeNumberSupplierService::supportsService(const OUString& rServiceName) throw( RuntimeException, std::exception )
+NativeNumberSupplierService::supportsService(const OUString& rServiceName)
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 Sequence< OUString > SAL_CALL
-NativeNumberSupplierService::getSupportedServiceNames() throw( RuntimeException, std::exception )
+NativeNumberSupplierService::getSupportedServiceNames()
 {
-    Sequence< OUString > aRet { OUString::createFromAscii( implementationName ) };
+    Sequence< OUString > aRet {implementationName};
     return aRet;
 }
 
-} } } }
+}
 
 extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
 com_sun_star_i18n_NativeNumberSupplier_get_implementation(
     css::uno::XComponentContext *,
     css::uno::Sequence<css::uno::Any> const &)
 {
-    return cppu::acquire(new css::i18n::NativeNumberSupplierService());
+    return cppu::acquire(new i18npool::NativeNumberSupplierService());
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
