@@ -17,9 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#define Line MacOSLine
 #define Point MacOSPoint
-#define Polygon MacOSPolygon
 #define Size MacOSSize
 #define TimeValue MacOSTimeValue
 
