@@ -20,24 +20,17 @@
 #ifndef INCLUDED_SAL_TYPES_H
 #define INCLUDED_SAL_TYPES_H
 
-#include <sal/config.h>
-#include <sal/macros.h>
+#include "sal/config.h"
 
-#include <sal/typesizes.h>
+#include <stddef.h>
+
+#include "sal/macros.h"
+#include "sal/typesizes.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#if defined ( __MINGW32__ ) && !defined ( __USE_MINGW_ANSI_STDIO )
-/* Define to use the C99 formatting string for coherence reasons.
- * In mingw-w64 some functions are ported to the ms formatting string
- * some are not yet. This is the only way to make the formatting
- * strings work all the time
- */
-#define __USE_MINGW_ANSI_STDIO 1
-#endif
-
 /********************************************************************************/
 /* Data types
 */
@@ -118,7 +111,7 @@ typedef unsigned char       sal_uInt8;
         #error "Could not find 64-bit type, add support for your architecture"
     #endif
 #else
-    #error "Please define the 64-bit types for your architecture/compiler in sal/inc/sal/types.h"
+    #error "Please define the 64-bit types for your architecture/compiler in include/sal/types.h"
 #endif
 
 /** A legacy synonym for `char`.
@@ -139,15 +132,14 @@ typedef signed char sal_sChar;
 */
 typedef unsigned char sal_uChar;
 
-#if ( defined(SAL_W32) && !defined(__MINGW32__) )
-    // http://msdn.microsoft.com/en-us/library/s3f49ktz%28v=vs.80%29.aspx
-    // "By default wchar_t is a typedef for unsigned short."
-    // But MinGW has a native wchar_t, and on many places, we cannot deal with
-    // that, so sal_Unicode has to be explicitly typedef'd as sal_uInt16 there.
-    typedef wchar_t             sal_Unicode;
+#if defined LIBO_INTERNAL_ONLY && defined __cplusplus
+    #define SAL_UNICODE_NOTEQUAL_WCHAR_T
+    typedef char16_t sal_Unicode;
+#elif defined(SAL_W32)
+    typedef wchar_t sal_Unicode;
 #else
     #define SAL_UNICODE_NOTEQUAL_WCHAR_T
-    typedef sal_uInt16          sal_Unicode;
+    typedef sal_uInt16 sal_Unicode;
 #endif
 
 typedef void *                   sal_Handle;
@@ -225,44 +217,49 @@ typedef void *                   sal_Handle;
 #define SAL_MAX_INT64         ((sal_Int64)  SAL_CONST_INT64(0x7FFFFFFFFFFFFFFF))
 #define SAL_MAX_UINT64        ((sal_uInt64) SAL_CONST_UINT64(0xFFFFFFFFFFFFFFFF))
 
-#if SAL_TYPES_SIZEOFLONG == 4
+#if SAL_TYPES_SIZEOFPOINTER == 4
 #define SAL_MAX_SSIZE       SAL_MAX_INT32
 #define SAL_MAX_SIZE        SAL_MAX_UINT32
-#elif SAL_TYPES_SIZEOFLONG == 8
+#elif SAL_TYPES_SIZEOFPOINTER == 8
 #define SAL_MAX_SSIZE       SAL_MAX_INT64
 #define SAL_MAX_SIZE        SAL_MAX_UINT64
 #endif
 
-#if defined(SAL_W32) || defined(SAL_UNX)
-#   define SAL_MAX_ENUM 0x7fffffff
-#endif
+#define SAL_MAX_ENUM 0x7fffffff
 
-#if defined(_MSC_VER) || defined(__MINGW32__)
+#if defined(_MSC_VER)
 #   define SAL_DLLPUBLIC_EXPORT    __declspec(dllexport)
 #   define SAL_JNI_EXPORT          __declspec(dllexport)
-#if defined(_MSC_VER)
 #   define SAL_DLLPUBLIC_IMPORT    __declspec(dllimport)
-#else
-#   define SAL_DLLPUBLIC_IMPORT
-#endif // defined(_MSC_VER)
 #   define SAL_DLLPRIVATE
 #   define SAL_DLLPUBLIC_TEMPLATE
+#   define SAL_DLLPUBLIC_RTTI
 #   define SAL_CALL         __cdecl
 #   define SAL_CALL_ELLIPSE __cdecl
 #elif defined SAL_UNX
-#   if defined(__GNUC__) && defined(HAVE_GCC_VISIBILITY_FEATURE)
+#   if defined(__GNUC__)
 #     if defined(DISABLE_DYNLOADING)
 #       define SAL_DLLPUBLIC_EXPORT  __attribute__ ((visibility("hidden")))
 #       define SAL_JNI_EXPORT        __attribute__ ((visibility("default")))
 #       define SAL_DLLPUBLIC_IMPORT  __attribute__ ((visibility("hidden")))
 #       define SAL_DLLPRIVATE        __attribute__ ((visibility("hidden")))
 #       define SAL_DLLPUBLIC_TEMPLATE __attribute__ ((visibility("hidden")))
+#       define SAL_DLLPUBLIC_RTTI
 #     else
 #       define SAL_DLLPUBLIC_EXPORT  __attribute__ ((visibility("default")))
 #       define SAL_JNI_EXPORT        __attribute__ ((visibility("default")))
 #       define SAL_DLLPUBLIC_IMPORT  __attribute__ ((visibility("default")))
 #       define SAL_DLLPRIVATE        __attribute__ ((visibility("hidden")))
 #       define SAL_DLLPUBLIC_TEMPLATE __attribute__ ((visibility("default")))
+#       if defined __clang__
+#         if __has_attribute(type_visibility)
+#           define SAL_DLLPUBLIC_RTTI  __attribute__ ((type_visibility("default")))
+#         else
+#           define SAL_DLLPUBLIC_RTTI  __attribute__ ((visibility("default")))
+#         endif
+#       else
+#         define SAL_DLLPUBLIC_RTTI
+#       endif
 #     endif
 #   else
 #     define SAL_DLLPUBLIC_EXPORT
@@ -270,6 +267,7 @@ typedef void *                   sal_Handle;
 #     define SAL_DLLPUBLIC_IMPORT
 #     define SAL_DLLPRIVATE
 #     define SAL_DLLPUBLIC_TEMPLATE
+#     define SAL_DLLPUBLIC_RTTI
 #   endif
 #   define SAL_CALL
 #   define SAL_CALL_ELLIPSE
@@ -283,7 +281,7 @@ typedef void *                   sal_Handle;
    These macros are used for inline declarations of exception classes, as in
    rtl/malformeduriexception.hxx.
 */
-#if defined(__GNUC__) && ! defined(__MINGW32__)
+#if defined(__GNUC__)
 #   if defined(DISABLE_DYNLOADING)
 #      define SAL_EXCEPTION_DLLPUBLIC_EXPORT __attribute__((visibility("default")))
 #    else
@@ -301,7 +299,9 @@ typedef void *                   sal_Handle;
     Compilers that support a construct of this nature will emit a compile
     time warning on unchecked return value.
 */
-#if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 1))
+#if (defined __GNUC__ \
+     && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 1))) \
+    || defined __clang__
 #   define SAL_WARN_UNUSED_RESULT __attribute__((warn_unused_result))
 #else
 #   define SAL_WARN_UNUSED_RESULT
@@ -337,7 +337,7 @@ typedef struct _sal_Sequence
     char                elements[1];
 } sal_Sequence;
 
-#define SAL_SEQUENCE_HEADER_SIZE ((sal_Size)&((sal_Sequence *)0)->elements)
+#define SAL_SEQUENCE_HEADER_SIZE ((sal_Size) offsetof(sal_Sequence,elements))
 
 #if defined( SAL_W32)
 #pragma pack(pop)
@@ -345,32 +345,24 @@ typedef struct _sal_Sequence
 
 #if defined __cplusplus
 
-/** Exception specification documentation.
-
-    The original intent of this macro was to control whether or not actual
-    exception specifications are emitted, based on how much they impact code
-    size etc. in a specific scenario.  But it ended up always being disabled
-    (except for MSVC, which effectively ignored it even though being enabled),
-    and used in ways that would make enabling it illegal (e.g., in the
-    cppu::ComponentFactoryFunc typedef, or with necessarily incomplete
-    com::sun::star::uno::RuntimeException in com/sun/star/uno/Reference.h), so
-    has officially been demoted to pure documentation now.
-
-    @deprecated do not use in new code.
-*/
-#define SAL_THROW(x)
-
 /** Nothrow specification for C functions.
 
     This is a macro so it can expand to nothing in C code.
 */
 #define SAL_THROW_EXTERN_C() throw ()
 
+/** To markup destructors that coverity warns might throw exceptions
+    which won't throw in practice, or where std::terminate is
+    an acceptable response if they do
+*/
+#if defined(LIBO_INTERNAL_ONLY) && defined(__COVERITY__)
+#   define COVERITY_NOEXCEPT_FALSE noexcept(false)
+#else
+#   define COVERITY_NOEXCEPT_FALSE
+#endif
+
 #else
 
-/* SAL_THROW() must not be used in C code, only SAL_THROW_EXTERN_C() is defined
-   there:
-*/
 #define SAL_THROW_EXTERN_C()
 
 #endif
@@ -398,13 +390,13 @@ namespace css = ::com::sun::star;
 
 /** C++11 "= delete" feature.
 
-    With HAVE_CXX11_DELETE, calling a deleted function will cause a compile-time
+    For LIBO_INTERNAL_ONLY, calling a deleted function will cause a compile-time
     error, while otherwise it will only cause a link-time error as the declared
     function is not defined.
 
     @since LibreOffice 4.1
 */
-#if HAVE_CXX11_DELETE
+#if defined LIBO_INTERNAL_ONLY
 #define SAL_DELETED_FUNCTION = delete
 #else
 #define SAL_DELETED_FUNCTION
@@ -412,12 +404,12 @@ namespace css = ::com::sun::star;
 
 /** C++11 "override" feature.
 
-    With HAVE_CXX11_OVERRIDE, force the method to override a existing method in
+    For LIBO_INTERNAL_ONLY, force the method to override a existing method in
     parent, error out if the method with the correct signature does not exist.
 
     @since LibreOffice 4.1
 */
-#if HAVE_CXX11_OVERRIDE
+#if defined LIBO_INTERNAL_ONLY
 #define SAL_OVERRIDE override
 #else
 #define SAL_OVERRIDE
@@ -425,16 +417,26 @@ namespace css = ::com::sun::star;
 
 /** C++11 "final" feature.
 
-    With HAVE_CXX11_FINAL, mark a class as non-derivable or a method as non-overridable.
+    For LIBO_INTERNAL_ONLY, mark a class as non-derivable or a method as non-overridable.
 
     @since LibreOffice 4.1
 */
-#if HAVE_CXX11_FINAL
+#if defined LIBO_INTERNAL_ONLY
 #define SAL_FINAL final
 #else
 #define SAL_FINAL
 #endif
 
+#if defined LIBO_INTERNAL_ONLY
+#if defined __clang__
+#define SAL_FALLTHROUGH [[clang::fallthrough]]
+#elif defined __GNUC__ && __GNUC__ >= 7
+#define SAL_FALLTHROUGH [[fallthrough]]
+#else
+#define SAL_FALLTHROUGH
+#endif
+#endif
+
 #endif /* __cplusplus */
 
 #ifdef __cplusplus
@@ -478,12 +480,12 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
 
 /**
     Use as follows:
-        SAL_DEPRECATED("Dont use, its evil.") void doit(int nPara);
+        SAL_DEPRECATED("Don't use, it's evil.") void doit(int nPara);
 */
 
 #if HAVE_GCC_DEPRECATED_MESSAGE
 #    define SAL_DEPRECATED(message) __attribute__((deprecated(message)))
-#elif (__GNUC__)
+#elif defined __GNUC__ || defined __clang__
 #    define SAL_DEPRECATED(message) __attribute__((deprecated))
 #elif defined(_MSC_VER)
 #    define SAL_DEPRECATED(message) __declspec(deprecated(message))
@@ -492,13 +494,15 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
 #endif
 
 /**
-   This macro is used to tag interfaces that are deprecated for both
-   internal and external API users, but where we are still writing
-   out the internal usage. Ultimately these should be replaced by
-   SAL_DEPRECATED, and then removed.
+   This macro is used in cppumaker-generated include files, to tag entities that
+   are marked as @deprecated in UNOIDL.
 
-   Use as follows:
-        SAL_DEPRECATED_INTERNAL("Dont use, its evil.") void doit(int nPara);
+   It causes deprecation warnings to be generated in external code, but for now
+   is silenced in internal code.  It would need some substantial clean-up of
+   internal code to fix all warnings/errors generated by it.  (Once that is
+   done, it can become a synonym for SAL_DEPRECATED under LIBO_INTERNAL_ONLY,
+   too.  Completely removing the macro then would be incompatible, in case there
+   are include files still around generated with a cppumaker that emitted it.)
  */
 #ifdef LIBO_INTERNAL_ONLY
 #    define SAL_DEPRECATED_INTERNAL(message)
@@ -513,7 +517,7 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
         SAL_WNODEPRECATED_DECLARATIONS_POP
 */
 
-#if HAVE_GCC_PRAGMA_DIAGNOSTIC_MODIFY && HAVE_GCC_PRAGMA_DIAGNOSTIC_SCOPE && HAVE_GCC_PRAGMA_OPERATOR
+#if HAVE_GCC_PRAGMA_OPERATOR
 #define SAL_WNODEPRECATED_DECLARATIONS_PUSH \
     _Pragma(SAL_STRINGIFY_ARG(GCC diagnostic push)) \
     _Pragma(SAL_STRINGIFY_ARG(GCC diagnostic ignored "-Wdeprecated-declarations"))
@@ -535,7 +539,7 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
 
    Useful in cases where the compiler is "too clever" like when doing
    link-time code generation, and noticing that a called function
-   always throws, and fixing the problem cleanly so that it produceds
+   always throws, and fixing the problem cleanly so that it produces
    no warnings in normal non-LTO compilations either is not easy.
 
 */
@@ -543,7 +547,8 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
 #ifdef _MSC_VER
 #define SAL_WNOUNREACHABLE_CODE_PUSH \
     __pragma(warning(push)) \
-    __pragma(warning(disable:4702))
+    __pragma(warning(disable:4702)) \
+    __pragma(warning(disable:4722))
 #define SAL_WNOUNREACHABLE_CODE_POP \
     __pragma(warning(pop))
 #else
@@ -576,7 +581,7 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
     @since LibreOffice 3.6
  */
 #if defined __cplusplus
-#if defined __GNUC__
+#if defined __GNUC__ || defined __clang__
 #define SAL_UNUSED_PARAMETER __attribute__ ((unused))
 #else
 #define SAL_UNUSED_PARAMETER
@@ -597,12 +602,105 @@ template< typename T1, typename T2 > inline T1 static_int_cast(T2 n) {
 
 #if HAVE_GCC_ATTRIBUTE_WARN_UNUSED
 #define SAL_WARN_UNUSED __attribute__((warn_unused))
-#elif defined __clang__
-#define SAL_WARN_UNUSED __attribute__((annotate("lo_warn_unused")))
 #else
 #define SAL_WARN_UNUSED
 #endif
 
+/// @cond INTERNAL
+
+#if defined __GNUC__ || defined __clang__
+// Macro to try to catch and warn on assignments inside expr.
+#    define SAL_DETAIL_BOOLEAN_EXPR(expr)   \
+        __extension__ ({                    \
+            int sal_boolean_var_;           \
+            if (expr)                       \
+               sal_boolean_var_ = 1;        \
+            else                            \
+               sal_boolean_var_ = 0;        \
+            sal_boolean_var_;               \
+        })
+
+/** An optimization annotation: denotes that expression is likely to be true.
+
+    Use it to annotate paths that we think are likely eg.
+    if (SAL_LIKELY(ptr != nullptr))
+       // this path is the one that is ~always taken.
+
+    @since LibreOffice 5.2
+
+    Returns: the boolean value of expr (expressed as either int 1 or 0)
+ */
+#    define SAL_LIKELY(expr) __builtin_expect(SAL_DETAIL_BOOLEAN_EXPR((expr)), 1)
+
+/** An optimization annotation: denotes that expression is unlikely to be true.
+
+    Use it to annotate paths that we think are likely eg.
+    if (SAL_UNLIKELY(ptr != nullptr))
+       // this path is the one that is ~never taken.
+
+    @since LibreOffice 5.2
+
+    Returns: the boolean value of expr (expressed as either int 1 or 0)
+ */
+#    define SAL_UNLIKELY(expr) __builtin_expect(SAL_DETAIL_BOOLEAN_EXPR((expr)), 0)
+
+/** An optimization annotation: tells the compiler to work harder at this code
+
+    If the SAL_HOT annotation is present on a function or a label then
+    subsequent code statements may have more aggressive compiler
+    optimization and in-lining work performed on them.
+
+    In addition this code can end up in a special section, to be
+    grouped with other frequently used code.
+
+    @since LibreOffice 5.2
+ */
+#    define SAL_HOT __attribute__((hot))
+
+/** An optimization annotation: tells the compiler to work less on this code
+
+    If the SAL_COLD annotation is present on a function or a label then
+    subsequent code statements are unlikely to be performed except in
+    exceptional circumstances, and optimizing for code-size rather
+    than performance is preferable.
+
+    In addition this code can end up in a special section, to be grouped
+    with (and away from) other more frequently used code, to improve
+    locality of reference.
+
+    @since LibreOffice 5.2
+ */
+#    define SAL_COLD __attribute__((cold))
+#else
+#    define SAL_LIKELY(expr) (expr)
+#    define SAL_UNLIKELY(expr) (expr)
+#    define SAL_HOT
+#    define SAL_COLD
+#endif
+
+/// @endcond
+
+/// @cond INTERNAL
+/** Annotate pointer-returning functions to indicate that such a pointer
+    is never nullptr.
+
+    Note that MSVC supports this feature via it's SAL _Ret_notnull_
+    annotation, but since it's in a completely different place on
+    the function declaration, it's a little hard to support both.
+
+    @since LibreOffice 5.5
+*/
+#ifndef __has_attribute
+#define __has_attribute(x) 0
+#endif
+
+#if defined LIBO_INTERNAL_ONLY && ((defined __GNUC__ && __GNUC__ > 4) || (defined __clang__ && __has_attribute(returns_nonnull)))
+#define SAL_RETURNS_NONNULL  __attribute__((returns_nonnull))
+#else
+#define SAL_RETURNS_NONNULL
+#endif
+/// @endcond
+
 #endif // INCLUDED_SAL_TYPES_H
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
