@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
 #include <fstream>
 #include <functional>
@@ -28,23 +28,26 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "helpmerge.hxx"
+#include <helpmerge.hxx>
 #include <algorithm>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <iostream>
 #include <vector>
 #include <rtl/strbuf.hxx>
-#ifdef WNT
+#ifdef _WIN32
+#if !defined WIN32_LEAN_AND_MEAN
+# define WIN32_LEAN_AND_MEAN
+#endif
 #include <windows.h>
 #undef CopyFile
 #include <direct.h>
 #endif
 
-#include "export.hxx"
-#include "common.hxx"
-#include "helper.hxx"
-#include "po.hxx"
+#include <export.hxx>
+#include <common.hxx>
+#include <helper.hxx>
+#include <po.hxx>
 
 #if OSL_DEBUG_LEVEL > 2
 void HelpParser::Dump(XMLHashMap* rElem_in)
@@ -126,12 +129,14 @@ bool HelpParser::CreatePO(
 
             common::writePoEntry(
                 "Helpex", aPoOutput, sHelpFile, rGsi1,
-                posm->first, pXMLElement->GetOldref(), OString(), data);
+                posm->first, OString(), OString(), data);
 
             pXMLElement=nullptr;
         }
         else
         {
+            // If this is something totally unexpected, wouldn't an assert() be in order?
+            // On the other hand, if this is expected, why the printf?
             fprintf(stdout,"\nDBG: NullPointer in HelpParser::CreatePO, File %s\n", sHelpFile.getStr());
         }
     }
@@ -140,17 +145,14 @@ bool HelpParser::CreatePO(
     return true;
 }
 
-bool HelpParser::Merge( const OString &rPOFile, const OString &rDestinationFile,
+bool HelpParser::Merge( const OString &rDestinationFile,
     const OString& rLanguage , MergeDataFile* pMergeDataFile )
 {
-
-    (void) rPOFile;
-
     SimpleXMLParser aParser;
 
     //TODO: explicit BOM handling?
 
-    XMLFile* xmlfile = ( aParser.Execute( sHelpFile, new XMLFile( OString('0') ) ) );
+    XMLFile* xmlfile = aParser.Execute( sHelpFile, new XMLFile( OString('0') ) );
     if (!xmlfile)
     {
         SAL_WARN("l10ntools", "could not parse " << sHelpFile);
@@ -167,8 +169,8 @@ bool HelpParser::MergeSingleFile( XMLFile* file , MergeDataFile* pMergeDataFile
     file->Extract();
 
     XMLHashMap* aXMLStrHM = file->GetStrings();
-    static  ResData pResData("","");
-    pResData.sResTyp   = "help";
+    static ResData s_ResData("","");
+    s_ResData.sResTyp   = "help";
 
     std::vector<OString> order = file->getOrder();
     std::vector<OString>::iterator pos;
@@ -184,24 +186,22 @@ bool HelpParser::MergeSingleFile( XMLFile* file , MergeDataFile* pMergeDataFile
         printf("DBG: sHelpFile = %s\n",sHelpFile.getStr() );
 #endif
 
-        pResData.sGId      =  posm->first;
-        pResData.sFilename  =  sHelpFile;
+        s_ResData.sGId      =  posm->first;
+        s_ResData.sFilename  =  sHelpFile;
 
-        ProcessHelp( aLangHM , sLanguage, &pResData , pMergeDataFile );
+        ProcessHelp( aLangHM , sLanguage, &s_ResData , pMergeDataFile );
      }
 
     file->Write(sPath);
     return true;
 }
 
-/* ProcessHelp Methode: search for en-US entry and replace it with the current language*/
+/* ProcessHelp method: search for en-US entry and replace it with the current language*/
 void HelpParser::ProcessHelp( LangHashMap* aLangHM , const OString& sCur , ResData *pResData , MergeDataFile* pMergeDataFile ){
 
     XMLElement*   pXMLElement = nullptr;
     MergeEntrys   *pEntrys    = nullptr;
 
-    OString sLId;
-
     pEntrys = nullptr;
 
     if( !sCur.equalsIgnoreAsciiCase("en-US") ){
@@ -212,9 +212,6 @@ void HelpParser::ProcessHelp( LangHashMap* aLangHM , const OString& sCur , ResDa
         }
         if( pXMLElement != nullptr )
         {
-            sLId    = pXMLElement->GetOldref();
-            pResData->sId     =  sLId;
-
             OString sNewText;
             OString sNewdata;
             OString sSourceText(
@@ -229,7 +226,7 @@ void HelpParser::ProcessHelp( LangHashMap* aLangHM , const OString& sCur , ResDa
             // important for indentation of Basic code examples
             sal_Int32 nPreSpaces = 0;
             sal_Int32 nLen = sSourceText.getLength();
-            while ( (nPreSpaces < nLen) && (*(sSourceText.getStr()+nPreSpaces) == ' ') )
+            while ( (nPreSpaces < nLen) && (sSourceText[nPreSpaces] == ' ') )
                 nPreSpaces++;
             if( sCur == "qtz" )
             {
@@ -241,7 +238,7 @@ void HelpParser::ProcessHelp( LangHashMap* aLangHM , const OString& sCur , ResDa
                 pEntrys = pMergeDataFile->GetMergeEntrys( pResData );
                 if( pEntrys != nullptr)
                 {
-                    pEntrys->GetText( sNewText, STRING_TYP_TEXT, sCur, true );
+                    pEntrys->GetText( sNewText, sCur, true );
                     if (helper::isWellFormedXML(XMLUtil::QuotHTML(sNewText)))
                     {
                         sNewdata = sSourceText.copy(0,nPreSpaces) + sNewText;
@@ -262,8 +259,7 @@ void HelpParser::ProcessHelp( LangHashMap* aLangHM , const OString& sCur , ResDa
             {
                 SAL_WARN(
                     "l10ntools",
-                    "Can't find GID=" << pResData->sGId.getStr() << " LID="
-                        << pResData->sId.getStr() << " TYP=" << pResData->sResTyp.getStr());
+                    "Can't find GID=" << pResData->sGId << " TYP=" << pResData->sResTyp);
             }
             pXMLElement->ChangeLanguageTag(sCur);
         }
