@@ -14,10 +14,10 @@
 #include <rtl/string.hxx>
 #include <rtl/ustring.hxx>
 #include <osl/file.hxx>
-#include "po.hxx"
+#include <po.hxx>
 
 // Translated style names must be unique
-static void checkStyleNames(OString aLanguage)
+static void checkStyleNames(const OString& aLanguage)
 {
     std::map<OString,sal_uInt16> aLocalizedStyleNames;
     std::map<OString,sal_uInt16> aLocalizedNumStyleNames;
@@ -130,11 +130,11 @@ static void checkStyleNames(OString aLanguage)
 }
 
 // Translated spreadsheet function names must be unique
-static void checkFunctionNames(OString aLanguage)
+static void checkFunctionNames(const OString& aLanguage)
 {
     std::map<OString,sal_uInt16> aLocalizedFunctionNames;
     std::map<OString,sal_uInt16> aLocalizedCoreFunctionNames;
-    //
+
     std::list<PoEntry> repeatedEntries;
 
     OString aPoPaths[4];
@@ -272,12 +272,14 @@ static void checkFunctionNames(OString aLanguage)
     {
         if( it->second > 1 )
         {
-            std::cout << "ERROR: Spreadsheet function name translations must be unique.\n" <<
-                "Language: " << aLanguage <<
-                "\nDuplicated translation is: " << it->first << "\n\n";
+            std::cout
+                << ("ERROR: Spreadsheet function name translations must be"
+                    " unique.\nLanguage: ")
+                << aLanguage << "\nDuplicated translation is: " << it->first
+                << "\n\n";
         }
     }
-    //
+
     for (int i=0;i<4;i++)
     {
         aPoInput.open(aPoPaths[i]);
@@ -352,7 +354,7 @@ static void checkFunctionNames(OString aLanguage)
 // In instsetoo_native/inc_openoffice/windows/msi_languages.po
 // where an en-US string ends with '|', translation must end
 // with '|', too.
-static void checkVerticalBar(OString aLanguage)
+static void checkVerticalBar(const OString& aLanguage)
 {
     OString aPoPath = OString(getenv("SRC_ROOT")) +
                       "/translations/source/" +
@@ -377,12 +379,14 @@ static void checkVerticalBar(OString aLanguage)
         if( !aPoEntry.isFuzzy() && aPoEntry.getMsgId().endsWith("|") &&
             !aPoEntry.getMsgStr().isEmpty() && !aPoEntry.getMsgStr().endsWith("|") )
         {
-            std::cout << "ERROR: Missing '|' character at the end of translated string.\n" <<
-                "It causes runtime error in installer.\n" <<
-                "File: " << aPoPath << std::endl <<
-                "Language: " << aLanguage << std::endl <<
-                "English:   " << aPoEntry.getMsgId() << std::endl <<
-                "Localized: " << aPoEntry.getMsgStr() << std::endl << std::endl;
+            std::cout
+                << ("ERROR: Missing '|' character at the end of translated"
+                    " string.\nIt causes runtime error in installer.\nFile: ")
+                << aPoPath << std::endl
+                << "Language: " << aLanguage << std::endl
+                << "English:   " << aPoEntry.getMsgId() << std::endl
+                << "Localized: " << aPoEntry.getMsgStr() << std::endl
+                << std::endl;
             bError = true;
         }
         else
@@ -400,7 +404,7 @@ static void checkVerticalBar(OString aLanguage)
 
 // In starmath/source.po Math symbol names (from symbol.src)
 // must not contain spaces
-static void checkMathSymbolNames(OString aLanguage)
+static void checkMathSymbolNames(const OString& aLanguage)
 {
     OString aPoPath = OString(getenv("SRC_ROOT")) +
                       "/translations/source/" +
@@ -425,11 +429,13 @@ static void checkMathSymbolNames(OString aLanguage)
         if( !aPoEntry.isFuzzy() && aPoEntry.getGroupId() == "RID_UI_SYMBOL_NAMES" &&
             !aPoEntry.getMsgStr().isEmpty() && (aPoEntry.getMsgStr().indexOf(" ") != -1) )
         {
-            std::cout << "ERROR: Math symbol names must not contain spaces.\n" <<
-                "File: " << aPoPath << std::endl <<
-                "Language: " << aLanguage << std::endl <<
-                "English:   " << aPoEntry.getMsgId() << std::endl <<
-                "Localized: " << aPoEntry.getMsgStr() << std::endl << std::endl;
+            std::cout
+                << "ERROR: Math symbol names must not contain spaces.\nFile: "
+                << aPoPath << std::endl
+                << "Language: " << aLanguage << std::endl
+                << "English:   " << aPoEntry.getMsgId() << std::endl
+                << "Localized: " << aPoEntry.getMsgStr() << std::endl
+                << std::endl;
             bError = true;
         }
         else
@@ -447,25 +453,33 @@ static void checkMathSymbolNames(OString aLanguage)
 
 int main()
 {
-    OString aLanguages(getenv("ALL_LANGS"));
-    if( aLanguages.isEmpty() )
+    try
     {
-        std::cerr << "Usage: make cmd cmd=solver/*/bin/pocheck\n";
+        OString aLanguages(getenv("ALL_LANGS"));
+        if( aLanguages.isEmpty() )
+        {
+            std::cerr << "Usage: bin/run pocheck\n";
+            return 1;
+        }
+        for(sal_Int32 i = 1;;++i) // skip en-US
+        {
+             OString aLanguage = aLanguages.getToken(i,' ');
+             if( aLanguage.isEmpty() )
+                 break;
+             if( aLanguage == "qtz" )
+                 continue;
+             checkStyleNames(aLanguage);
+             checkFunctionNames(aLanguage);
+             checkVerticalBar(aLanguage);
+             checkMathSymbolNames(aLanguage);
+        }
+        return 0;
+    }
+    catch (std::exception& e)
+    {
+        std::cerr << "pocheck: exception " << e.what() << std::endl;
         return 1;
     }
-    for(sal_Int32 i = 1;;++i) // skip en-US
-    {
-         OString aLanguage = aLanguages.getToken(i,' ');
-         if( aLanguage.isEmpty() )
-             break;
-         if( aLanguage == "qtz" )
-             continue;
-         checkStyleNames(aLanguage);
-         checkFunctionNames(aLanguage);
-         checkVerticalBar(aLanguage);
-         checkMathSymbolNames(aLanguage);
-    }
-    return 0;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
