@@ -56,7 +56,7 @@ static const int nCHCount = SAL_N_ELEMENTS(aCH);
 
 PropertyChgHelper::PropertyChgHelper(
         const Reference< XInterface > &rxSource,
-        Reference< XLinguProperties > &rxPropSet,
+        Reference< XLinguProperties > const &rxPropSet,
         int nAllowedEvents ) :
     PropertyChgHelperBase(),
     aPropNames          (nCHCount),
@@ -216,7 +216,6 @@ bool PropertyChgHelper::propertyChange_Impl( const PropertyChangeEvent& rEvt )
 
 void SAL_CALL
     PropertyChgHelper::propertyChange( const PropertyChangeEvent& rEvt )
-        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
     propertyChange_Impl( rEvt );
@@ -259,7 +258,6 @@ void PropertyChgHelper::LaunchEvent( const LinguServiceEvent &rEvt )
 
 
 void SAL_CALL PropertyChgHelper::disposing( const EventObject& rSource )
-        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
     if (rSource.Source == xPropSet)
@@ -274,7 +272,6 @@ void SAL_CALL PropertyChgHelper::disposing( const EventObject& rSource )
 sal_Bool SAL_CALL
     PropertyChgHelper::addLinguServiceEventListener(
             const Reference< XLinguServiceEventListener >& rxListener )
-        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
@@ -291,7 +288,6 @@ sal_Bool SAL_CALL
 sal_Bool SAL_CALL
     PropertyChgHelper::removeLinguServiceEventListener(
             const Reference< XLinguServiceEventListener >& rxListener )
-        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
 
@@ -307,7 +303,7 @@ sal_Bool SAL_CALL
 
 PropertyHelper_Thes::PropertyHelper_Thes(
         const Reference< XInterface > &rxSource,
-        Reference< XLinguProperties > &rxPropSet ) :
+        Reference< XLinguProperties > const &rxPropSet ) :
     PropertyChgHelper   ( rxSource, rxPropSet, 0 )
 {
     SetDefaultValues();
@@ -322,7 +318,6 @@ PropertyHelper_Thes::~PropertyHelper_Thes()
 
 void SAL_CALL
     PropertyHelper_Thes::propertyChange( const PropertyChangeEvent& rEvt )
-        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
     PropertyChgHelper::propertyChange_Impl( rEvt );
@@ -341,14 +336,12 @@ static const char *aSP[] =
 
 PropertyHelper_Spell::PropertyHelper_Spell(
         const Reference< XInterface > & rxSource,
-        Reference< XLinguProperties > &rxPropSet ) :
+        Reference< XLinguProperties > const &rxPropSet ) :
     PropertyChgHelper   ( rxSource, rxPropSet, AE_SPELLCHECKER )
 {
     AddPropNames( aSP, SAL_N_ELEMENTS(aSP) );
     SetDefaultValues();
     GetCurrentValues();
-
-    nResMaxNumberOfSuggestions = GetDefaultNumberOfSuggestions();
 }
 
 
@@ -440,7 +433,7 @@ bool PropertyHelper_Spell::propertyChange_Impl( const PropertyChangeEvent& rEvt
                 break;
             }
             default:
-                DBG_ASSERT( false, "unknown property" );
+                SAL_WARN( "linguistic", "unknown property" );
         }
         if (pbVal)
             rEvt.NewValue >>= *pbVal;
@@ -467,7 +460,6 @@ bool PropertyHelper_Spell::propertyChange_Impl( const PropertyChangeEvent& rEvt
 
 void SAL_CALL
     PropertyHelper_Spell::propertyChange( const PropertyChangeEvent& rEvt )
-        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
     propertyChange_Impl( rEvt );
@@ -480,7 +472,6 @@ void PropertyHelper_Spell::SetTmpPropVals( const PropertyValues &rPropVals )
 
     // return value is default value unless there is an explicitly supplied
     // temporary value
-    nResMaxNumberOfSuggestions  = GetDefaultNumberOfSuggestions();
     bResIsSpellWithDigits       = bIsSpellWithDigits;
     bResIsSpellCapitalization   = bIsSpellCapitalization;
     bResIsSpellUpperCase        = bIsSpellUpperCase;
@@ -493,7 +484,7 @@ void PropertyHelper_Spell::SetTmpPropVals( const PropertyValues &rPropVals )
         {
             if ( pVal[i].Name == UPN_MAX_NUMBER_OF_SUGGESTIONS )
             {
-                pVal[i].Value >>= nResMaxNumberOfSuggestions;
+                // special value that is not part of the property set and thus needs to be handled differently
             }
             else
             {
@@ -504,7 +495,7 @@ void PropertyHelper_Spell::SetTmpPropVals( const PropertyValues &rPropVals )
                     case UPH_IS_SPELL_WITH_DIGITS    : pbResVal = &bResIsSpellWithDigits; break;
                     case UPH_IS_SPELL_CAPITALIZATION : pbResVal = &bResIsSpellCapitalization; break;
                     default:
-                        DBG_ASSERT( false, "unknown property" );
+                        SAL_WARN( "linguistic", "unknown property" );
                 }
                 if (pbResVal)
                     pVal[i].Value >>= *pbResVal;
@@ -523,7 +514,7 @@ static const char *aHP[] =
 
 PropertyHelper_Hyphen::PropertyHelper_Hyphen(
         const Reference< XInterface > & rxSource,
-        Reference< XLinguProperties > &rxPropSet ) :
+        Reference< XLinguProperties > const &rxPropSet ) :
     PropertyChgHelper   ( rxSource, rxPropSet, AE_HYPHENATOR )
 {
     AddPropNames( aHP, SAL_N_ELEMENTS(aHP) );
@@ -601,7 +592,7 @@ bool PropertyHelper_Hyphen::propertyChange_Impl( const PropertyChangeEvent& rEvt
             case UPH_HYPH_MIN_TRAILING    : pnVal = &nHyphMinTrailing; break;
             case UPH_HYPH_MIN_WORD_LENGTH : pnVal = &nHyphMinWordLength; break;
             default:
-                DBG_ASSERT( false, "unknown property" );
+                SAL_WARN( "linguistic", "unknown property" );
         }
         if (pnVal)
             rEvt.NewValue >>= *pnVal;
@@ -623,7 +614,6 @@ bool PropertyHelper_Hyphen::propertyChange_Impl( const PropertyChangeEvent& rEvt
 
 void SAL_CALL
     PropertyHelper_Hyphen::propertyChange( const PropertyChangeEvent& rEvt )
-        throw(RuntimeException, std::exception)
 {
     MutexGuard  aGuard( GetLinguMutex() );
     propertyChange_Impl( rEvt );
@@ -666,7 +656,7 @@ void PropertyHelper_Hyphen::SetTmpPropVals( const PropertyValues &rPropVals )
 
 PropertyHelper_Thesaurus::PropertyHelper_Thesaurus(
             const css::uno::Reference< css::uno::XInterface > &rxSource,
-            css::uno::Reference< css::linguistic2::XLinguProperties > &rxPropSet )
+            css::uno::Reference< css::linguistic2::XLinguProperties > const &rxPropSet )
 {
     pInst = new PropertyHelper_Thes( rxSource, rxPropSet );
     xPropHelper = pInst;
@@ -693,7 +683,7 @@ void PropertyHelper_Thesaurus::SetTmpPropVals( const css::beans::PropertyValues
 
 PropertyHelper_Hyphenation::PropertyHelper_Hyphenation(
             const css::uno::Reference< css::uno::XInterface > &rxSource,
-            css::uno::Reference< css::linguistic2::XLinguProperties > &rxPropSet)
+            css::uno::Reference< css::linguistic2::XLinguProperties > const &rxPropSet)
 {
     pInst = new PropertyHelper_Hyphen( rxSource, rxPropSet );
     xPropHelper = pInst;
@@ -735,21 +725,19 @@ sal_Int16 PropertyHelper_Hyphenation::GetMinWordLength() const
 
 bool PropertyHelper_Hyphenation::addLinguServiceEventListener(
                 const css::uno::Reference< css::linguistic2::XLinguServiceEventListener >& rxListener )
-            throw(css::uno::RuntimeException)
 {
     return pInst->addLinguServiceEventListener( rxListener );
 }
 
 bool PropertyHelper_Hyphenation::removeLinguServiceEventListener(
                 const css::uno::Reference< css::linguistic2::XLinguServiceEventListener >& rxListener )
-            throw(css::uno::RuntimeException)
 {
     return pInst->removeLinguServiceEventListener( rxListener );
 }
 
 PropertyHelper_Spelling::PropertyHelper_Spelling(
             const css::uno::Reference< css::uno::XInterface > &rxSource,
-            css::uno::Reference< css::linguistic2::XLinguProperties > &rxPropSet )
+            css::uno::Reference< css::linguistic2::XLinguProperties > const &rxPropSet )
 {
     pInst = new PropertyHelper_Spell( rxSource, rxPropSet );
     xPropHelper = pInst;
@@ -792,7 +780,6 @@ bool PropertyHelper_Spelling::IsSpellCapitalization() const
 bool PropertyHelper_Spelling::addLinguServiceEventListener(
                 const css::uno::Reference<
                     css::linguistic2::XLinguServiceEventListener >& rxListener )
-            throw(css::uno::RuntimeException)
 {
     return pInst->addLinguServiceEventListener( rxListener );
 }
@@ -800,7 +787,6 @@ bool PropertyHelper_Spelling::addLinguServiceEventListener(
 bool PropertyHelper_Spelling::removeLinguServiceEventListener(
                 const css::uno::Reference<
                     css::linguistic2::XLinguServiceEventListener >& rxListener )
-            throw(css::uno::RuntimeException)
 {
     return pInst->removeLinguServiceEventListener( rxListener );
 }
