@@ -53,7 +53,7 @@
  *
  *
  ************************************************************************/
-#include "lwpglobalmgr.hxx"
+#include <lwpglobalmgr.hxx>
 #include "lwpdoc.hxx"
 #include "lwpfootnote.hxx"
 #include "lwppagehint.hxx"
@@ -65,10 +65,11 @@
 #include "lwpsilverbullet.hxx"
 #include "lwplayout.hxx"
 #include "lwppagelayout.hxx"
-#include "xfilter/xfstylemanager.hxx"
+#include "lwpverdocument.hxx"
+#include <xfilter/xfstylemanager.hxx>
 #include <osl/thread.h>
 
-LwpDocument::LwpDocument(LwpObjectHeader& objHdr, LwpSvStream* pStrm)
+LwpDocument::LwpDocument(LwpObjectHeader const & objHdr, LwpSvStream* pStrm)
     : LwpDLNFPVList(objHdr, pStrm)
     , m_pOwnedFoundry(nullptr)
     , m_bGettingFirstDivisionWithContentsThatIsNotOLE(false)
@@ -80,14 +81,8 @@ LwpDocument::LwpDocument(LwpObjectHeader& objHdr, LwpSvStream* pStrm)
 
 LwpDocument::~LwpDocument()
 {
-    if(m_pLnOpts)
-    {
-        delete m_pLnOpts;
-    }
-    if(m_pOwnedFoundry)
-    {
-        delete m_pOwnedFoundry;
-    }
+    delete m_pLnOpts;
+    delete m_pOwnedFoundry;
 }
 /**
  * @descr   Read VO_Document from object stream
@@ -102,43 +97,43 @@ void LwpDocument::Read()
 
     //Skip the SortOption and UIDocument
     {
-        LwpSortOption m_DocSort( m_pObjStrm );
-        LwpUIDocument m_UIDoc( m_pObjStrm );
+        LwpSortOption aDocSort( m_pObjStrm.get() );
+        LwpUIDocument aUIDoc( m_pObjStrm.get() );
     }
 
-    m_pLnOpts = new LwpLineNumberOptions(m_pObjStrm);
+    m_pLnOpts = new LwpLineNumberOptions(m_pObjStrm.get());
 
     //Skip LwpUserDictFiles
     {
-        LwpUserDictFiles m_UsrDicts( m_pObjStrm );
+        LwpUserDictFiles aUsrDicts( m_pObjStrm.get() );
     }
 
     if( !IsChildDoc())
     {
         //Skip LwpPrinterInfo
-        LwpPrinterInfo m_PrtInfo( m_pObjStrm );
+        LwpPrinterInfo aPrtInfo( m_pObjStrm.get() );
     }
 
-    m_pFoundry = m_pOwnedFoundry = new LwpFoundry(m_pObjStrm, this);
+    m_pFoundry = m_pOwnedFoundry = new LwpFoundry(m_pObjStrm.get(), this);
 
-    m_DivOpts.ReadIndexed(m_pObjStrm);
+    m_DivOpts.ReadIndexed(m_pObjStrm.get());
 
     if(!IsChildDoc())
     {
-        m_FootnoteOpts.ReadIndexed(m_pObjStrm);
-        m_DocData.ReadIndexed(m_pObjStrm);
+        m_FootnoteOpts.ReadIndexed(m_pObjStrm.get());
+        m_DocData.ReadIndexed(m_pObjStrm.get());
     }
     else
     {
         //Skip the docdata used in old version
         LwpObjectID dummyDocData;
-        dummyDocData.ReadIndexed(m_pObjStrm);
+        dummyDocData.ReadIndexed(m_pObjStrm.get());
     }
-    m_DivInfo.ReadIndexed(m_pObjStrm);
-    m_Epoch.Read(m_pObjStrm);
-    m_WYSIWYGPageHints.ReadIndexed(m_pObjStrm);
-    m_VerDoc.ReadIndexed(m_pObjStrm);
-    m_STXInfo.ReadIndexed(m_pObjStrm);
+    m_DivInfo.ReadIndexed(m_pObjStrm.get());
+    m_Epoch.Read(m_pObjStrm.get());
+    m_WYSIWYGPageHints.ReadIndexed(m_pObjStrm.get());
+    m_VerDoc.ReadIndexed(m_pObjStrm.get());
+    m_STXInfo.ReadIndexed(m_pObjStrm.get());
 }
 
 /**
@@ -146,7 +141,7 @@ void LwpDocument::Read()
  **/
 void LwpDocument::ReadPlug()
 {
-    m_DocSockID.ReadIndexed(m_pObjStrm);
+    m_DocSockID.ReadIndexed(m_pObjStrm.get());
     m_nFlags = m_pObjStrm->QuickReaduInt16();
     m_pObjStrm->SkipExtra();
 }
@@ -308,12 +303,12 @@ void LwpDocument::RegisterBulletStyles()
     if (!m_pFoundry)
         return;
     //Register bullet styles
-    LwpDLVListHeadHolder* mBulletHead = dynamic_cast<LwpDLVListHeadHolder*>
+    LwpDLVListHeadHolder* pBulletHead = dynamic_cast<LwpDLVListHeadHolder*>
         (m_pFoundry->GetBulletManagerID().obj(VO_HEADHOLDER).get());
-    if (!mBulletHead)
+    if (!pBulletHead)
         return;
     LwpSilverBullet* pBullet = dynamic_cast<LwpSilverBullet*>
-                        (mBulletHead->GetHeadID().obj().get());
+                        (pBulletHead->GetHeadID().obj().get());
     while(pBullet)
     {
         pBullet->SetFoundry(m_pFoundry);
@@ -385,7 +380,6 @@ void LwpDocument::RegisterFootnoteStyles()
 /**
 * @descr   Register default para styles
 */
-#include "lwpverdocument.hxx"
 void LwpDocument::RegisterDefaultParaStyles()
 {
     if(!IsChildDoc())
@@ -613,7 +607,10 @@ LwpDocument* LwpDocument::GetPreviousDivision()
     {
         if(!pRoot->IsChildDoc())
             return pRoot;
-        pRoot = pRoot->GetParentDivision();
+        LwpDocument* pNextRoot = pRoot->GetParentDivision();
+        if (pNextRoot == pRoot)
+            throw std::runtime_error("loop in ParentDivision");
+        pRoot = pNextRoot;
     }
     return nullptr;
 }
@@ -719,23 +716,21 @@ sal_uInt16 LwpDocument::GetNumberOfPagesBefore()
         pDivision = pDivision->GetNextDivision();
     }
 }
-  /**
+
+ /**
  * @descr    Parse the frame which anchor is to page before parse other contents,
- *          This method is called when the document is root document.
+ *           This method is called when the document is root document.
  */
 void LwpDocument::ParseFrameInPage(IXFStream * pOutputStream)
 {
-    if(IsChildDoc())
+    if (IsChildDoc())
         return;
 
-    XFContentContainer* pXFContainer = new XFContentContainer;
-
-    XFConvertFrameInPage(pXFContainer);
-
-    pXFContainer->ToXml(pOutputStream);
-    delete pXFContainer;
-    pXFContainer = nullptr;
+    rtl::Reference<XFContentContainer> xXFContainer(new XFContentContainer);
+    XFConvertFrameInPage(xXFContainer.get());
+    xXFContainer->ToXml(pOutputStream);
 }
+
  /**
  * @descr    Parse the frame which anchor is to page in the entire document
  */
@@ -772,7 +767,7 @@ void LwpDocument::ChangeStyleName()
         pStyle->SetStyleName("Placeholder");
     }
 }
-LwpDocSock::LwpDocSock(LwpObjectHeader& objHdr, LwpSvStream* pStrm)
+LwpDocSock::LwpDocSock(LwpObjectHeader const & objHdr, LwpSvStream* pStrm)
     :LwpDLNFVList(objHdr, pStrm)
 {}
 
@@ -782,7 +777,7 @@ LwpDocSock::LwpDocSock(LwpObjectHeader& objHdr, LwpSvStream* pStrm)
 void LwpDocSock::Read()
 {
     LwpDLNFVList::Read();
-    m_Doc.ReadIndexed(m_pObjStrm);
+    m_Doc.ReadIndexed(m_pObjStrm.get());
     m_pObjStrm->SkipExtra();
 }
  /**
