@@ -59,28 +59,28 @@
  *  and so on.
  */
 #include <osl/thread.h>
-#include "lwpglobalmgr.hxx"
+#include <lwpglobalmgr.hxx>
 #include "lwpdrawobj.hxx"
-#include "lwptools.hxx"
+#include <lwptools.hxx>
 #include <tools/stream.hxx>
 
-#include "xfilter/xfframe.hxx"
+#include <xfilter/xfframe.hxx>
 
-#include "xfilter/xfstylemanager.hxx"
-#include "xfilter/xfdrawstyle.hxx"
-#include "xfilter/xftextstyle.hxx"
-#include "xfilter/xfparastyle.hxx"
-#include "xfilter/xfimagestyle.hxx"
-#include "xfilter/xftextboxstyle.hxx"
-#include "xfilter/xfparagraph.hxx"
-#include "xfilter/xftextspan.hxx"
-#include "xfilter/xffont.hxx"
+#include <xfilter/xfstylemanager.hxx>
+#include <xfilter/xfdrawstyle.hxx>
+#include <xfilter/xftextstyle.hxx>
+#include <xfilter/xfparastyle.hxx>
+#include <xfilter/xfimagestyle.hxx>
+#include <xfilter/xftextboxstyle.hxx>
+#include <xfilter/xfparagraph.hxx>
+#include <xfilter/xftextspan.hxx>
+#include <xfilter/xffont.hxx>
 
-#include "xfilter/xfdrawrect.hxx"
-#include "xfilter/xfdrawpath.hxx"
-#include "xfilter/xfdrawline.hxx"
-#include "xfilter/xfdrawpolygon.hxx"
-#include "xfilter/xfimage.hxx"
+#include <xfilter/xfdrawrect.hxx>
+#include <xfilter/xfdrawpath.hxx>
+#include <xfilter/xfdrawline.hxx>
+#include <xfilter/xfdrawpolygon.hxx>
+#include <xfilter/xfimage.hxx>
 
 #include "lwpcharsetmgr.hxx"
 #include "lwpsdwrect.hxx"
@@ -978,7 +978,7 @@ LwpDrawTextBox::~LwpDrawTextBox()
     }
 }
 
-void LwpDrawTextBox::SetFontStyle(rtl::Reference<XFFont> const & pFont, SdwTextBoxRecord* pRec)
+void LwpDrawTextBox::SetFontStyle(rtl::Reference<XFFont> const & pFont, SdwTextBoxRecord const * pRec)
 {
     // color
     XFColor aXFColor(pRec->aTextColor.nR, pRec->aTextColor.nG,
@@ -987,9 +987,9 @@ void LwpDrawTextBox::SetFontStyle(rtl::Reference<XFFont> const & pFont, SdwTextB
     //size
     pFont->SetFontSize(pRec->nTextSize/20);
     // bold
-    pFont->SetBold(((pRec->nTextAttrs & TA_BOLD) != 0));
+    pFont->SetBold((pRec->nTextAttrs & TA_BOLD) != 0);
     // italic
-    pFont->SetItalic(((pRec->nTextAttrs & TA_ITALIC) != 0));
+    pFont->SetItalic((pRec->nTextAttrs & TA_ITALIC) != 0);
     // strike-through
     if (pRec->nTextAttrs & TA_STRIKETHRU)
     {
@@ -1073,9 +1073,8 @@ OUString LwpDrawTextBox::RegisterStyle()
     // the pFont need to be deleted myself?
     rtl::Reference<XFFont> pFont = new XFFont();
 
-    rtl_TextEncoding aEncoding =  RTL_TEXTENCODING_MS_1252;
     OUString aFontName = OUString(reinterpret_cast<char*>(m_aTextRec.tmpTextFaceName),
-        strlen(reinterpret_cast<char*>(m_aTextRec.tmpTextFaceName)), aEncoding);
+        strlen(reinterpret_cast<char*>(m_aTextRec.tmpTextFaceName)), RTL_TEXTENCODING_MS_1252);
     pFont->SetFontName(aFontName);
 
     SetFontStyle(pFont, &m_aTextRec);
@@ -1278,9 +1277,8 @@ OUString LwpDrawTextArt::RegisterStyle()
     // the pFont need to be deleted myself?
     rtl::Reference<XFFont> pFont = new XFFont();
 
-    rtl_TextEncoding aEncoding =  RTL_TEXTENCODING_MS_1252;
     OUString aFontName = OUString(reinterpret_cast<char*>(m_aTextArtRec.tmpTextFaceName),
-        strlen(reinterpret_cast<char*>(m_aTextArtRec.tmpTextFaceName)), aEncoding);
+        strlen(reinterpret_cast<char*>(m_aTextArtRec.tmpTextFaceName)), RTL_TEXTENCODING_MS_1252);
     pFont->SetFontName(aFontName);
 
     LwpDrawTextBox::SetFontStyle(pFont, &m_aTextArtRec);
