@@ -59,23 +59,23 @@
  ************************************************************************/
 
 #include "lwpfribmark.hxx"
-#include "lwptools.hxx"
-#include "lwpglobalmgr.hxx"
+#include <lwptools.hxx>
+#include <lwpglobalmgr.hxx>
 #include "lwpdoc.hxx"
 #include "lwpdivinfo.hxx"
-#include "xfilter/xfstylemanager.hxx"
-#include "xfilter/xftextspan.hxx"
-#include "xfilter/xfbookmark.hxx"
-#include "xfilter/xfentry.hxx"
-#include "xfilter/xftextcontent.hxx"
-#include "xfilter/xfcrossref.hxx"
-#include "xfilter/xfdocfield.hxx"
-#include "xfilter/xfdatestyle.hxx"
-#include "xfilter/xftimestyle.hxx"
-#include "xfilter/xfdate.hxx"
-#include "xfilter/xfruby.hxx"
-#include "lwpchangemgr.hxx"
-#include "xfilter/xfchange.hxx"
+#include <xfilter/xfstylemanager.hxx>
+#include <xfilter/xftextspan.hxx>
+#include <xfilter/xfbookmark.hxx>
+#include <xfilter/xfentry.hxx>
+#include <xfilter/xftextcontent.hxx>
+#include <xfilter/xfcrossref.hxx>
+#include <xfilter/xfdocfield.hxx>
+#include <xfilter/xfdatestyle.hxx>
+#include <xfilter/xftimestyle.hxx>
+#include <xfilter/xfdate.hxx>
+#include <xfilter/xfruby.hxx>
+#include <lwpchangemgr.hxx>
+#include <xfilter/xfchange.hxx>
 
 /**
  * @short:   Read hyperlink frib and Click here block
@@ -86,17 +86,12 @@ void LwpFribCHBlock::Read(LwpObjectStream* pObjStrm, sal_uInt16 /*len*/)
     m_nType = pObjStrm->QuickReaduInt8();
 }
 
-LwpCHBlkMarker* LwpFribCHBlock::GetMarker()
-{
-    return dynamic_cast<LwpCHBlkMarker*>(m_objMarker.obj().get());
-}
-
 void LwpFribCHBlock::XFConvert(XFContentContainer* pXFPara,LwpStory* pStory)
 {
     sal_uInt8 type = GetType();
     if (!pStory)
         return;
-    LwpCHBlkMarker* pMarker = GetMarker();
+    LwpCHBlkMarker* pMarker = dynamic_cast<LwpCHBlkMarker*>(m_objMarker.obj().get());
 
     if (!pMarker)
         return;
@@ -151,27 +146,25 @@ void  LwpFribBookMark::RegisterStyle(LwpFoundry* pFoundry)
     LwpBookmarkMgr* pMarkMgr = pGlobal->GetLwpBookmarkMgr();
     if (type == MARKER_START)
     {
-        XFBookmarkStart* pMarkStart = new XFBookmarkStart;
-        pMarkStart->SetDivision(sDivision);
-        pMarkStart->SetName(name);
-        pMarkMgr->AddXFBookmarkStart(name,pMarkStart);//add to map
-        m_pStart = pMarkStart;
+        rtl::Reference<XFBookmarkStart> xMarkStart(new XFBookmarkStart);
+        xMarkStart->SetDivision(sDivision);
+        xMarkStart->SetName(name);
+        pMarkMgr->AddXFBookmarkStart(name, xMarkStart.get());//add to map
+        m_xStart = xMarkStart;
     }
     else if(type == MARKER_END)
     {
-        XFBookmarkEnd* pMarkEnd = new XFBookmarkEnd;
-        pMarkEnd->SetDivision(sDivision);
-        pMarkEnd->SetName(name);
-        pMarkMgr->AddXFBookmarkEnd(name,pMarkEnd);  //add to map
-        m_pEnd = pMarkEnd;
+        rtl::Reference<XFBookmarkEnd> xMarkEnd(new XFBookmarkEnd);
+        xMarkEnd->SetDivision(sDivision);
+        xMarkEnd->SetName(name);
+        pMarkMgr->AddXFBookmarkEnd(name, xMarkEnd.get());  //add to map
+        m_xEnd = xMarkEnd;
     }
 }
 
 LwpFribBookMark::LwpFribBookMark(LwpPara* pPara )
     : LwpFrib(pPara)
     , m_nType(0)
-    , m_pStart(nullptr)
-    , m_pEnd(nullptr)
 {
 }
 
@@ -190,13 +183,13 @@ void LwpFribBookMark::XFConvert(XFContentContainer* pXFPara)
 {
     sal_uInt8 type = GetType();
 
-    if (type == MARKER_START && m_pStart)
+    if (type == MARKER_START && m_xStart)
     {
-        pXFPara->Add(m_pStart);
+        pXFPara->Add(m_xStart.get());
     }
-    else if(type == MARKER_END && m_pEnd)
+    else if(type == MARKER_END && m_xEnd)
     {
-        pXFPara->Add(m_pEnd);
+        pXFPara->Add(m_xEnd.get());
     }
 }
 
@@ -375,16 +368,13 @@ void LwpFribField::RegisterTimeField(LwpFieldMark* pFieldMark)
         RegisterTotalTimeStyle();
     else
     {
-        sal_Int32 index;
-        sal_Unicode ch1(0x0020);//space
-        OUString tag;
-        index = sFormula.indexOf(ch1);
+        sal_Int32 index = sFormula.indexOf(0x20); //space
         if (index < 0)
             return;
 
-        tag = sFormula.copy(0,index);
+        OUString tag = sFormula.copy(0,index);
         if (tag == "Now()" || tag == "CreateDate" ||  tag == "EditDate")
-            RegisterDateTimeStyle(sFormula.copy(index+1,sFormula.getLength()-index-1));
+            RegisterDateTimeStyle(sFormula.copy(index+1));
     }
 }
 
@@ -436,7 +426,7 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pDateStyle->AddText(":");
             pDateStyle->AddMinute();
             pDateStyle->AddText(":");
-            pDateStyle->AddSecond(true,0);
+            pDateStyle->AddSecond();
         }
         else if (sFormula == "%FLM/D/YY")
         {
@@ -652,13 +642,13 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pDateStyle = new XFDateStyle;
             OUString sText;
             pDateStyle->AddYear();
-            sText = OUString(sal_Unicode(0x5e74));
+            sText = OUString(u'\x5e74');
             pDateStyle->AddText(sText);
             pDateStyle->AddMonth(false);
-            sText = OUString(sal_Unicode(0x6708));
+            sText = OUString(u'\x6708');
             pDateStyle->AddText(sText);
             pDateStyle->AddMonthDay(false);
-            sText = OUString(sal_Unicode(0x65e5));
+            sText = OUString(u'\x65e5');
             pDateStyle->AddText(sText);
         }
         else if (sFormula == "%FLoa" || sFormula == "%FLooaa" || sFormula == "%FLOA" )
@@ -666,10 +656,10 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pDateStyle = new XFDateStyle;
             OUString sText;
             pDateStyle->AddMonth(false);
-            sText = OUString(sal_Unicode(0x6708));
+            sText = OUString(u'\x6708');
             pDateStyle->AddText(sText);
             pDateStyle->AddMonthDay(false);
-            sText = OUString(sal_Unicode(0x65e5));
+            sText = OUString(u'\x65e5');
             pDateStyle->AddText(sText);
         }
         else if (sFormula == "%FLYYYY/M/D" || sFormula == "%FLGGGG/od/ad")
@@ -887,7 +877,7 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pTimeStyle->AddText(":");
             pTimeStyle->AddMinute();
             pTimeStyle->AddText(":");
-            pTimeStyle->AddSecond(true,0);
+            pTimeStyle->AddSecond();
         }
         else if (sFormula == "%FLH:mm ampm")
         {
@@ -912,7 +902,7 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pTimeStyle->AddText(":");
             pTimeStyle->AddMinute();
             pTimeStyle->AddText(":");
-            pTimeStyle->AddSecond(true,0);
+            pTimeStyle->AddSecond();
             pTimeStyle->AddText(" ");
             pTimeStyle->SetAmPm(true);
         }
@@ -923,7 +913,7 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pTimeStyle->AddText(":");
             pTimeStyle->AddMinute();
             pTimeStyle->AddText(":");
-            pTimeStyle->AddSecond(true,0);
+            pTimeStyle->AddSecond();
         }
         else if (sFormula == "%FLH ampm")
         {
@@ -945,7 +935,7 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
         else if (sFormula == "%FLSS")
         {
             pTimeStyle = new XFTimeStyle;
-            pTimeStyle->AddSecond(true,0);
+            pTimeStyle->AddSecond();
         }
         else if (sFormula == "%FLampm")
         {
@@ -959,10 +949,10 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pTimeStyle = new XFTimeStyle;
             pTimeStyle->AddHour(false);
             OUString sText;
-            sText = OUString(sal_Unicode(0x70b9));
+            sText = OUString(u'\x70b9');
             pTimeStyle->AddText(sText);
             pTimeStyle->AddMinute(false);
-            sText = OUString(sal_Unicode(0x5206));
+            sText = OUString(u'\x5206');
             pTimeStyle->AddText(sText);
         }
         else if (sFormula == "%FLjjjF" || sFormula == "%FLJJJFF" )
@@ -971,10 +961,10 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pTimeStyle->SetAmPm(true);
             pTimeStyle->AddHour(false);
             OUString sText;
-            sText = OUString(sal_Unicode(0x70b9));
+            sText = OUString(u'\x70b9');
             pTimeStyle->AddText(sText);
             pTimeStyle->AddMinute(false);
-            sText = OUString(sal_Unicode(0x5206));
+            sText = OUString(u'\x5206');
             pTimeStyle->AddText(sText);
         }
         //chinese version end
@@ -1002,7 +992,7 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pTimeStyle->AddText(":");
             pTimeStyle->AddMinute();
             pTimeStyle->AddText(":");
-            pTimeStyle->AddSecond(true,0);
+            pTimeStyle->AddSecond();
             pTimeStyle->AddText(" ");
             pTimeStyle->SetAmPm(true);
         }
@@ -1020,7 +1010,7 @@ void LwpFribField::RegisterDateTimeStyle(const OUString& sFormula)
             pTimeStyle->AddText(":");
             pTimeStyle->AddMinute();
             pTimeStyle->AddText(":");
-            pTimeStyle->AddSecond(true,0);
+            pTimeStyle->AddSecond();
         }
         //other version end
     }
@@ -1369,7 +1359,7 @@ void LwpFribField::ConvertCrossRefStart(XFContentContainer* pXFPara,LwpFieldMark
     XFCrossRefStart* pRef = new XFCrossRefStart;
     pRef->SetRefType(m_nCrossRefType);
     pRef->SetMarkName(m_sFormula);
-//  pFieldMark->SetStart(sal_True);//for some disnormal cases
+//  pFieldMark->SetStart(sal_True);//for some unusual cases
     if (m_ModFlag)
     {
         XFTextSpanStart* pSpan = new XFTextSpanStart;
@@ -1401,11 +1391,6 @@ LwpFribRubyMarker::LwpFribRubyMarker( LwpPara* pPara )
 {
 }
 
-LwpRubyMarker* LwpFribRubyMarker::GetMarker()
-{
-    return dynamic_cast<LwpRubyMarker*>(m_objMarker.obj(VO_RUBYMARKER).get());
-}
-
 void LwpFribRubyMarker::Read(LwpObjectStream* pObjStrm, sal_uInt16 /*len*/)
 {
     m_objMarker.ReadIndexed(pObjStrm);
@@ -1415,7 +1400,7 @@ void LwpFribRubyMarker::Read(LwpObjectStream* pObjStrm, sal_uInt16 /*len*/)
 void LwpFribRubyMarker::XFConvert(XFContentContainer* pXFPara)
 {
     sal_uInt8 type = GetType();
-    LwpRubyMarker* pMarker = GetMarker();
+    LwpRubyMarker* pMarker = dynamic_cast<LwpRubyMarker*>(m_objMarker.obj(VO_RUBYMARKER).get());
 
     if (type == MARKER_START)
     {
