@@ -58,10 +58,12 @@
  *  For LWP filter architecture prototype
  ************************************************************************/
 
+#include <memory>
 #include "lwplayout.hxx"
 #include "lwpusewhen.hxx"
-#include "lwptools.hxx"
-#include "xfilter/xfcolumns.hxx"
+#include <lwptools.hxx>
+#include "lwplaypiece.hxx"
+#include <xfilter/xfcolumns.hxx>
 #include "lwpstory.hxx"
 #include "lwpparastyle.hxx"
 #include "lwpholder.hxx"
@@ -71,14 +73,20 @@
 #include "lwpgrfobj.hxx"
 #include <osl/thread.h>
 
-LwpVirtualLayout::LwpVirtualLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
+LwpVirtualLayout::LwpVirtualLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
     : LwpDLNFPVList(objHdr, pStrm)
     , m_bGettingHonorProtection(false)
     , m_bGettingMarginsSameAsParent(false)
     , m_bGettingHasProtection(false)
     , m_bGettingIsProtected(false)
+    , m_bGettingIsAutoGrowDown(false)
     , m_bGettingMarginsValue(false)
     , m_bGettingExtMarginsValue(false)
+    , m_bGettingUsePrinterSettings(false)
+    , m_bGettingScaleCenter(false)
+    , m_bGettingBorderStuff(false)
+    , m_bGettingUseWhen(false)
+    , m_bGettingStyleLayout(false)
     , m_nAttributes(0)
     , m_nAttributes2(0)
     , m_nAttributes3(0)
@@ -92,7 +100,7 @@ void LwpVirtualLayout::Read()
 {
     LwpDLNFPVList::Read();
 
-    LwpObjectStream* pStrm = m_pObjStrm;
+    LwpObjectStream* pStrm = m_pObjStrm.get();
     m_nAttributes = pStrm->QuickReaduInt32();
     m_nAttributes2 = pStrm->QuickReaduInt32();
     m_nAttributes3 = pStrm->QuickReaduInt32();
@@ -224,6 +232,12 @@ bool LwpVirtualLayout::IsComplex()
 */
 LwpUseWhen* LwpVirtualLayout::GetUseWhen()
 {
+    if (m_bGettingUseWhen)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingUseWhen= true;
+
+    LwpUseWhen* pRet = nullptr;
+
     /*
         If we have a parent, and I'm not a page layout,
         use my parents information.
@@ -233,11 +247,16 @@ LwpUseWhen* LwpVirtualLayout::GetUseWhen()
         //get parent
         rtl::Reference<LwpVirtualLayout> xParent(dynamic_cast<LwpVirtualLayout*>(GetParent().obj().get()));
         if (xParent.is() && !xParent->IsHeader() && (xParent->GetLayoutType() != LWP_PAGE_LAYOUT))
-            return xParent->GetUseWhen();
+            pRet = xParent->GetUseWhen();
 
     }
 
-    return VirtualGetUseWhen();
+    if (!pRet)
+        pRet = VirtualGetUseWhen();
+
+    m_bGettingUseWhen = false;
+
+    return pRet;
 }
 /**
  * @descr:  Whether this layout is page layout or not
@@ -337,7 +356,7 @@ void LwpVirtualLayout::RegisterChildStyle()
     while (xLayout.is())
     {
         xLayout->SetFoundry(m_pFoundry);
-        xLayout->RegisterStyle();
+        xLayout->DoRegisterStyle();
         xLayout.set(dynamic_cast<LwpVirtualLayout*>(xLayout->GetNext().obj().get()));
     }
 }
@@ -349,13 +368,22 @@ bool LwpVirtualLayout::NoContentReference()
 
 bool LwpVirtualLayout::IsStyleLayout()
 {
-    if (m_nAttributes3 & STYLE3_STYLELAYOUT)
-        return true;
+    if (m_bGettingStyleLayout)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingStyleLayout = true;
 
-    rtl::Reference<LwpVirtualLayout> xParent(dynamic_cast<LwpVirtualLayout*>(GetParent().obj().get()));
-    if (xParent.is())
-        return xParent->IsStyleLayout();
-    return false;
+    bool bRet = false;
+    if (m_nAttributes3 & STYLE3_STYLELAYOUT)
+        bRet = true;
+    else
+    {
+        rtl::Reference<LwpVirtualLayout> xParent(dynamic_cast<LwpVirtualLayout*>(GetParent().obj().get()));
+        if (xParent.is())
+            bRet = xParent->IsStyleLayout();
+    }
+
+    m_bGettingStyleLayout = false;
+    return bRet;
 }
 
 /**
@@ -365,19 +393,25 @@ bool LwpVirtualLayout::IsStyleLayout()
 LwpVirtualLayout* LwpVirtualLayout::FindChildByType(LWP_LAYOUT_TYPE eType)
 {
     LwpObjectID& rID = GetChildHead();
+    LwpVirtualLayout* pPrevLayout = nullptr;
 
     while(!rID.IsNull())
     {
         LwpVirtualLayout * pLayout = dynamic_cast<LwpVirtualLayout *>(rID.obj().get());
-        if(!pLayout)
+        if (!pLayout)
+            break;
+
+        if (pPrevLayout && pLayout == pPrevLayout)
         {
+            SAL_WARN("lwp", "loop in layout");
             break;
         }
 
-        if (pLayout && pLayout->GetLayoutType() == eType)
-        {
+        pPrevLayout = pLayout;
+
+        if (pLayout->GetLayoutType() == eType)
             return pLayout;
-        }
+
         rID = pLayout->GetNext();
     }
 
@@ -390,7 +424,7 @@ LwpVirtualLayout* LwpVirtualLayout::FindChildByType(LWP_LAYOUT_TYPE eType)
 */
 bool LwpVirtualLayout::IsFitGraphic()
 {
-    return IsAutoGrowRight() && !IsAutoGrowLeft() && IsAutoGrowDown();
+    return IsAutoGrowRight() && !IsAutoGrowLeft() && GetIsAutoGrowDown();
 }
 
 /**
@@ -422,7 +456,7 @@ void LwpAssociatedLayouts::Read(LwpObjectStream* pStrm)
 * @descr:   Looking for the layout which follows the pStartLayout
 * @param:   pStartLayout - the layout which is used for looking for its following layout
 */
-rtl::Reference<LwpVirtualLayout> LwpAssociatedLayouts::GetLayout(LwpVirtualLayout *pStartLayout)
+rtl::Reference<LwpVirtualLayout> LwpAssociatedLayouts::GetLayout(LwpVirtualLayout const *pStartLayout)
 {
     if (!pStartLayout && !m_OnlyLayout.IsNull())
         /* Looking for the first layout and there's only one layout in  the list.*/
@@ -458,7 +492,7 @@ rtl::Reference<LwpVirtualLayout> LwpAssociatedLayouts::GetLayout(LwpVirtualLayou
     return rtl::Reference<LwpVirtualLayout>();
 }
 
-LwpHeadLayout::LwpHeadLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
+LwpHeadLayout::LwpHeadLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
     : LwpVirtualLayout(objHdr, pStrm)
 {}
 
@@ -525,7 +559,6 @@ LwpLayoutStyle::LwpLayoutStyle()
 
 LwpLayoutStyle::~LwpLayoutStyle()
 {
-    delete m_pDescription;
 }
 
 void LwpLayoutStyle::Read(LwpObjectStream* pStrm)
@@ -540,49 +573,36 @@ void LwpLayoutStyle::Read(LwpObjectStream* pStrm)
 }
 
 LwpLayoutMisc::LwpLayoutMisc() :
-m_nGridDistance(0), m_nGridType(0),
-m_pContentStyle(new LwpAtomHolder)
+m_nGridDistance(0), m_nGridType(0)
 {
 }
 
 LwpLayoutMisc::~LwpLayoutMisc()
 {
-    if (m_pContentStyle)
-    {
-        delete m_pContentStyle;
-    }
 }
 
 void LwpLayoutMisc::Read(LwpObjectStream* pStrm)
 {
     m_nGridType = pStrm->QuickReaduInt16();
     m_nGridDistance = pStrm->QuickReadInt32();
-    m_pContentStyle->Read(pStrm);
+    m_aContentStyle.Read(pStrm);
     pStrm->SkipExtra();
 }
 
-LwpMiddleLayout::LwpMiddleLayout( LwpObjectHeader &objHdr, LwpSvStream* pStrm )
+LwpMiddleLayout::LwpMiddleLayout( LwpObjectHeader const &objHdr, LwpSvStream* pStrm )
     : LwpVirtualLayout(objHdr, pStrm)
-    , m_pStyleStuff(new LwpLayoutStyle)
-    , m_pMiscStuff(new LwpLayoutMisc)
     , m_bGettingGeometry(false)
+    , m_bGettingBackgroundStuff(false)
 {
 }
 
 LwpMiddleLayout::~LwpMiddleLayout()
 {
-    if (m_pStyleStuff)
-    {
-        delete m_pStyleStuff;
-    }
-    if (m_pMiscStuff)
-    {
-        delete m_pMiscStuff;
-    }
 }
+
 void LwpMiddleLayout::Read()
 {
-    LwpObjectStream* pStrm = m_pObjStrm;
+    LwpObjectStream* pStrm = m_pObjStrm.get();
 
     LwpVirtualLayout::Read();
 
@@ -605,11 +625,11 @@ void LwpMiddleLayout::Read()
 
     if (nWhatsItGot & DISK_GOT_STYLE_STUFF)
     {
-        m_pStyleStuff->Read(pStrm);
+        m_aStyleStuff.Read(pStrm);
     }
     if (nWhatsItGot & DISK_GOT_MISC_STUFF)
     {
-        m_pMiscStuff->Read(pStrm);
+        m_aMiscStuff.Read(pStrm);
     }
 
     m_LayGeometry.ReadIndexed(pStrm);
@@ -636,27 +656,32 @@ rtl::Reference<LwpObject> LwpMiddleLayout::GetBasedOnStyle()
     return xRet;
 }
 
-#include "lwplaypiece.hxx"
-
 /**
 * @descr:   Get the geometry of current layout
 *
 */
-LwpLayoutGeometry* LwpMiddleLayout::Geometry()
+LwpLayoutGeometry* LwpMiddleLayout::GetGeometry()
 {
+    if (m_bGettingGeometry)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingGeometry = true;
+
+    LwpLayoutGeometry* pRet = nullptr;
     if( !m_LayGeometry.IsNull() )
     {
-        return ( dynamic_cast<LwpLayoutGeometry*> (m_LayGeometry.obj().get()) );
+        pRet = dynamic_cast<LwpLayoutGeometry*> (m_LayGeometry.obj().get());
     }
     else
     {
         rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
         if (LwpMiddleLayout* pLay = dynamic_cast<LwpMiddleLayout*>(xBase.get()))
         {
-            return pLay->GetGeometry();
+            pRet = pLay->GetGeometry();
         }
     }
-    return nullptr;
+
+    m_bGettingGeometry = false;
+    return pRet;
 }
 
 /**
@@ -668,7 +693,7 @@ double LwpMiddleLayout::GetGeometryHeight()
     LwpLayoutGeometry* pGeo = GetGeometry();
     if(pGeo)
     {
-        return ( LwpTools::ConvertFromUnitsToMetric( pGeo->GetHeight() ) );
+        return LwpTools::ConvertFromUnitsToMetric( pGeo->GetHeight() );
     }
     else
         return -1;
@@ -683,7 +708,7 @@ double LwpMiddleLayout::GetGeometryWidth()
     LwpLayoutGeometry* pGeo = GetGeometry();
     if(pGeo)
     {
-        return ( LwpTools::ConvertFromUnitsToMetric( pGeo->GetWidth() ) );
+        return LwpTools::ConvertFromUnitsToMetric( pGeo->GetWidth() );
     }
     else
         return -1;
@@ -711,7 +736,7 @@ bool LwpMiddleLayout::MarginsSameAsParent()
 * @descr:   Get margin
 * @param:   nWhichSide - 0: left, 1: right, 2:top, 3: bottom
 */
-double LwpMiddleLayout::MarginsValue(const sal_uInt8 &nWhichSide)
+double LwpMiddleLayout::MarginsValue(sal_uInt8 nWhichSide)
 {
     double fValue = 0;
     if((nWhichSide==MARGIN_LEFT)||(nWhichSide==MARGIN_RIGHT))
@@ -751,7 +776,7 @@ double LwpMiddleLayout::MarginsValue(const sal_uInt8 &nWhichSide)
  * @param:
  * @return:
 */
-double LwpMiddleLayout::ExtMarginsValue(const sal_uInt8 &nWhichSide)
+double LwpMiddleLayout::ExtMarginsValue(sal_uInt8 nWhichSide)
 {
     double fValue = 0;
     if(m_nOverrideFlag & OVER_MARGINS)
@@ -776,20 +801,28 @@ double LwpMiddleLayout::ExtMarginsValue(const sal_uInt8 &nWhichSide)
 */
 LwpBorderStuff* LwpMiddleLayout::GetBorderStuff()
 {
+    if (m_bGettingBorderStuff)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingBorderStuff = true;
+
+    LwpBorderStuff* pRet = nullptr;
+
     if(m_nOverrideFlag & OVER_BORDERS)
     {
         LwpLayoutBorder* pLayoutBorder = dynamic_cast<LwpLayoutBorder*>(m_LayBorderStuff.obj().get());
-        return pLayoutBorder ? &pLayoutBorder->GetBorderStuff() : nullptr;
+        pRet = pLayoutBorder ? &pLayoutBorder->GetBorderStuff() : nullptr;
     }
     else
     {
         rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
         if (LwpMiddleLayout* pLay = dynamic_cast<LwpMiddleLayout*>(xBase.get()))
         {
-            return pLay->GetBorderStuff();
+            pRet = pLay->GetBorderStuff();
         }
     }
-    return nullptr;
+
+    m_bGettingBorderStuff= false;
+    return pRet;
 }
 
 /**
@@ -797,21 +830,30 @@ LwpBorderStuff* LwpMiddleLayout::GetBorderStuff()
 */
 LwpBackgroundStuff* LwpMiddleLayout::GetBackgroundStuff()
 {
+    if (m_bGettingBackgroundStuff)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingBackgroundStuff = true;
+
+    LwpBackgroundStuff* pRet = nullptr;
+
     if(m_nOverrideFlag & OVER_BACKGROUND)
     {
         LwpLayoutBackground* pLayoutBackground = dynamic_cast<LwpLayoutBackground*>(m_LayBackgroundStuff.obj().get());
-        return pLayoutBackground ? &pLayoutBackground->GetBackgoudStuff() : nullptr;
+        pRet = pLayoutBackground ? &pLayoutBackground->GetBackgoudStuff() : nullptr;
     }
     else
     {
         rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
         if (LwpMiddleLayout* pLay = dynamic_cast<LwpMiddleLayout*>(xBase.get()))
         {
-            return pLay->GetBackgroundStuff();
+            pRet = pLay->GetBackgroundStuff();
         }
     }
-    return nullptr;
+
+    m_bGettingBackgroundStuff = false;
+    return pRet;
 }
+
 /**
  * @descr:  create xfborder.
 */
@@ -823,10 +865,10 @@ XFBorders* LwpMiddleLayout::GetXFBorders()
         //copy from lwpparastyle.
         XFBorders   *pXFBorders = new XFBorders();
         // apply 4 borders respectively
-        LwpBorderStuff::BorderType pType[] = { LwpBorderStuff::LEFT, LwpBorderStuff::RIGHT,
+        LwpBorderStuff::BorderType const pType[] = { LwpBorderStuff::LEFT, LwpBorderStuff::RIGHT,
             LwpBorderStuff::TOP, LwpBorderStuff::BOTTOM };
 
-        for (LwpBorderStuff::BorderType & nC : pType)
+        for (LwpBorderStuff::BorderType nC : pType)
         {
             if (pBorderStuff->HasSide(nC))
             {
@@ -942,16 +984,26 @@ sal_uInt16 LwpMiddleLayout::GetScaleTile()
 
 sal_uInt16 LwpMiddleLayout::GetScaleCenter()
 {
+    if (m_bGettingScaleCenter)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingScaleCenter = true;
+
+    sal_uInt16 nRet = 0;
+
     if ((m_nOverrideFlag & OVER_SCALING) && m_LayScale.obj().is() && GetLayoutScale())
     {
-        return (GetLayoutScale()->GetPlacement() & LwpLayoutScale::CENTERED)
+        nRet = (GetLayoutScale()->GetPlacement() & LwpLayoutScale::CENTERED)
             ? 1 : 0;
     }
-    rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
-    if (xBase.is())
-        return dynamic_cast<LwpMiddleLayout&>(*xBase.get()).GetScaleCenter();
     else
-        return 0;
+    {
+        rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
+        if (xBase.is())
+            nRet = dynamic_cast<LwpMiddleLayout&>(*xBase.get()).GetScaleCenter();
+    }
+
+    m_bGettingScaleCenter = false;
+    return nRet;
 }
 
 sal_uInt32 LwpMiddleLayout::GetScalePercentage()
@@ -990,12 +1042,8 @@ bool LwpMiddleLayout::CanSizeRight()
 {
     sal_uInt8 RelType = GetRelativeType();
 
-    if (RelType == LwpLayoutRelativityGuts::LAY_INLINE || RelType == LwpLayoutRelativityGuts::LAY_PARA_RELATIVE
-    || RelType == LwpLayoutRelativityGuts::LAY_INLINE_VERTICAL)
-    {
-        return false;
-    }
-    return true;
+    return !(RelType == LwpLayoutRelativityGuts::LAY_INLINE || RelType == LwpLayoutRelativityGuts::LAY_PARA_RELATIVE
+             || RelType == LwpLayoutRelativityGuts::LAY_INLINE_VERTICAL);
 }
 sal_Int32 LwpMiddleLayout::GetMinimumWidth()
 {
@@ -1176,7 +1224,7 @@ bool LwpMiddleLayout::IsAutoGrowDown()
         rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
         if (LwpMiddleLayout* pLay = dynamic_cast<LwpMiddleLayout*>(xBase.get()))
         {
-            return pLay->IsAutoGrowDown();
+            return pLay->GetIsAutoGrowDown();
         }
     }
     return LwpVirtualLayout::IsAutoGrowDown();
@@ -1372,7 +1420,13 @@ rtl::Reference<LwpVirtualLayout> LwpMiddleLayout::GetWaterMarkLayout()
         {
             return xLay;
         }
-        xLay.set(dynamic_cast<LwpVirtualLayout*>(xLay->GetNext().obj().get()));
+        rtl::Reference<LwpVirtualLayout> xNext(dynamic_cast<LwpVirtualLayout*>(xLay->GetNext().obj().get()));
+        if (xNext == xLay)
+        {
+            SAL_WARN("lwp", "loop in layout");
+            break;
+        }
+        xLay = xNext;
     }
     return rtl::Reference<LwpVirtualLayout>();
 }
@@ -1444,45 +1498,50 @@ XFBGImage* LwpMiddleLayout::GetXFBGImage()
 */
 bool LwpMiddleLayout::GetUsePrinterSettings()
 {
+    if (m_bGettingUsePrinterSettings)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingUsePrinterSettings = true;
+
+    bool bRet = false;
+
     if(m_nOverrideFlag & OVER_SIZE)
     {
-        return (m_nAttributes3 & STYLE3_USEPRINTERSETTINGS) != 0;
+        bRet = (m_nAttributes3 & STYLE3_USEPRINTERSETTINGS) != 0;
     }
     else
     {
         rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
         if (LwpMiddleLayout* pLay = dynamic_cast<LwpMiddleLayout*>(xBase.get()))
         {
-            return pLay->GetUsePrinterSettings();
+            bRet = pLay->GetUsePrinterSettings();
         }
     }
-    return false;
+
+    m_bGettingUsePrinterSettings = false;
+    return bRet;
 }
 
 //Check whether there are contents in the layout
 bool LwpMiddleLayout::HasContent()
 {
     rtl::Reference<LwpObject> content = m_Content.obj();
-    if(content.is())
-        return true;
-    return false;
+    return content.is();
 }
 
-LwpLayout::LwpLayout( LwpObjectHeader &objHdr, LwpSvStream* pStrm ) :
-    LwpMiddleLayout(objHdr, pStrm), m_pUseWhen(new LwpUseWhen)
-{}
+LwpLayout::LwpLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
+    : LwpMiddleLayout(objHdr, pStrm)
+    , m_bGettingShadow(false)
+    , m_bGettingNumCols(false)
+{
+}
 
 LwpLayout::~LwpLayout()
 {
-    if (m_pUseWhen)
-    {
-        delete m_pUseWhen;
-    }
 }
 
 void LwpLayout::Read()
 {
-    LwpObjectStream* pStrm = m_pObjStrm;
+    LwpObjectStream* pStrm = m_pObjStrm.get();
 
     LwpMiddleLayout::Read();
     if (LwpFileHeader::m_nFileRevision < 0x000B)
@@ -1495,7 +1554,7 @@ void LwpLayout::Read()
 
         if (!nSimple)
         {
-            m_pUseWhen->Read(pStrm);
+            m_aUseWhen.Read(pStrm);
 
             sal_uInt8 nFlag = pStrm->QuickReaduInt8();
             if (nFlag)
@@ -1521,24 +1580,24 @@ void LwpLayout::Read()
 */
 sal_uInt16 LwpLayout::GetNumCols()
 {
-    if(m_nOverrideFlag & OVER_COLUMNS)
+    if (m_bGettingNumCols)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingNumCols = true;
+
+    sal_uInt16 nRet = 0;
+    LwpLayoutColumns* pLayColumns = (m_nOverrideFlag & OVER_COLUMNS) ? dynamic_cast<LwpLayoutColumns*>(m_LayColumns.obj().get()) : nullptr;
+    if (pLayColumns)
     {
-        LwpLayoutColumns* pLayColumns = dynamic_cast<LwpLayoutColumns*>(m_LayColumns.obj().get());
-        if(pLayColumns)
-        {
-            return pLayColumns->GetNumCols();
-        }
+        nRet = pLayColumns->GetNumCols();
     }
-
-    rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
-    LwpVirtualLayout* pStyle = dynamic_cast<LwpVirtualLayout*>(xBase.get());
-    if (pStyle)
+    else
     {
-        return pStyle->GetNumCols();
+        rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
+        LwpVirtualLayout* pStyle = dynamic_cast<LwpVirtualLayout*>(xBase.get());
+        nRet = pStyle ? pStyle->GetNumCols() : LwpVirtualLayout::GetNumCols();
     }
-
-    return LwpVirtualLayout::GetNumCols();
-
+    m_bGettingNumCols = false;
+    return nRet;
 }
 
 /**
@@ -1745,7 +1804,7 @@ LwpUseWhen* LwpLayout::VirtualGetUseWhen()
 {
     if(m_nOverrideFlag & OVER_PLACEMENT)
     {
-        return m_pUseWhen;
+        return &m_aUseWhen;
     }
     else
     {
@@ -1863,20 +1922,25 @@ bool LwpLayout::IsUseOnPage()
 */
 LwpShadow* LwpLayout::GetShadow()
 {
+    if (m_bGettingShadow)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingShadow = true;
+    LwpShadow* pRet = nullptr;
     if(m_nOverrideFlag & OVER_SHADOW)
     {
         LwpLayoutShadow* pLayoutShadow = dynamic_cast<LwpLayoutShadow*>(m_LayShadow.obj().get());
-        return pLayoutShadow ? &pLayoutShadow->GetShadow() : nullptr;
+        pRet = pLayoutShadow ? &pLayoutShadow->GetShadow() : nullptr;
     }
     else
     {
         rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
         if (LwpLayout* pLay = dynamic_cast<LwpLayout*>(xBase.get()))
         {
-            return pLay->GetShadow();
+            pRet = pLay->GetShadow();
         }
     }
-    return nullptr;
+    m_bGettingShadow = false;
+    return pRet;
 }
 
 /**
@@ -1949,8 +2013,10 @@ rtl::Reference<LwpVirtualLayout> LwpLayout::GetContainerLayout()
     return GetParentLayout();
 }
 
-LwpPlacableLayout::LwpPlacableLayout( LwpObjectHeader &objHdr, LwpSvStream* pStrm )
+LwpPlacableLayout::LwpPlacableLayout( LwpObjectHeader const &objHdr, LwpSvStream* pStrm )
     : LwpLayout(objHdr, pStrm)
+    , m_bGettingWrapType(false)
+    , m_bGettingLayoutRelativity(false)
     , m_nWrapType(0)
     , m_nBuoyancy(0)
     , m_nBaseLineOffset(0)
@@ -1961,7 +2027,7 @@ LwpPlacableLayout::~LwpPlacableLayout()
 
 void LwpPlacableLayout::Read()
 {
-    LwpObjectStream* pStrm = m_pObjStrm;
+    LwpObjectStream* pStrm = m_pObjStrm.get();
     LwpLayout::Read();
     if(LwpFileHeader::m_nFileRevision < 0x000B)
     {
@@ -2006,30 +2072,39 @@ void LwpPlacableLayout::Read()
 */
 sal_uInt8 LwpPlacableLayout::GetWrapType()
 {
-    if(m_nOverrideFlag & OVER_PLACEMENT)
+    if (m_bGettingWrapType)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingWrapType = true;
+    sal_uInt8 nWrapType = LAY_WRAP_AROUND;
+    if (m_nOverrideFlag & OVER_PLACEMENT)
     {
-        return m_nWrapType;
+        nWrapType = m_nWrapType;
     }
     else
     {
         rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
         if (LwpPlacableLayout* pLay = dynamic_cast<LwpPlacableLayout*>(xBase.get()))
         {
-            return pLay->GetWrapType();
+            nWrapType = pLay->GetWrapType();
         }
     }
-    return LAY_WRAP_AROUND;
+    m_bGettingWrapType = false;
+    return nWrapType;
 }
 /**
  * @descr:  get LayoutRelativity
 */
 LwpLayoutRelativity* LwpPlacableLayout::GetRelativityPiece()
 {
-    if(!m_LayRelativity.IsNull())
+    if (m_bGettingLayoutRelativity)
+        throw std::runtime_error("recursion in layout");
+    m_bGettingLayoutRelativity = true;
+    LwpLayoutRelativity* pRet = nullptr;
+    if (!m_LayRelativity.IsNull())
     {
-        if(m_nOverrideFlag & OVER_PLACEMENT)
+        if (m_nOverrideFlag & OVER_PLACEMENT)
         {
-            return dynamic_cast<LwpLayoutRelativity*>(m_LayRelativity.obj().get());
+            pRet = dynamic_cast<LwpLayoutRelativity*>(m_LayRelativity.obj().get());
         }
     }
     else
@@ -2037,10 +2112,11 @@ LwpLayoutRelativity* LwpPlacableLayout::GetRelativityPiece()
         rtl::Reference<LwpObject> xBase(GetBasedOnStyle());
         if (LwpPlacableLayout* pLay = dynamic_cast<LwpPlacableLayout*>(xBase.get()))
         {
-            return pLay->GetRelativityPiece();
+            pRet = pLay->GetRelativityPiece();
         }
     }
-    return nullptr;
+    m_bGettingLayoutRelativity = false;
+    return pRet;
 }
 /**
 * @descr:   Get relative type
@@ -2098,11 +2174,7 @@ bool LwpPlacableLayout::IsAnchorPage()
         return false;
 
     rtl::Reference<LwpVirtualLayout> xLayout = GetParentLayout();
-    if (xLayout.is() && (xLayout->IsPage() || xLayout->IsHeader() || xLayout->IsFooter()))
-    {
-        return true;
-    }
-    return false;
+    return xLayout.is() && (xLayout->IsPage() || xLayout->IsHeader() || xLayout->IsFooter());
 }
 /**
 * @descr:   whether the parent layout is frame layout
@@ -2114,11 +2186,7 @@ bool LwpPlacableLayout::IsAnchorFrame()
         return false;
 
     rtl::Reference<LwpVirtualLayout> xLayout = GetParentLayout();
-    if (xLayout.is() && (xLayout->IsFrame() || xLayout->IsGroupHead()))
-    {
-        return true;
-    }
-    return false;
+    return xLayout.is() && (xLayout->IsFrame() || xLayout->IsGroupHead());
 }
 /**
 * @descr:   whether the parent layout is cell layout
@@ -2130,11 +2198,7 @@ bool LwpPlacableLayout::IsAnchorCell()
         return false;
 
     rtl::Reference<LwpVirtualLayout> xLayout = GetParentLayout();
-    if (xLayout.is() && xLayout->IsCell())
-    {
-        return true;
-    }
-    return false;
+    return xLayout.is() && xLayout->IsCell();
 }
 
 /**
