@@ -59,25 +59,25 @@
  ************************************************************************/
 
 #include "lwppara.hxx"
-#include "lwpglobalmgr.hxx"
-#include "lwpfilehdr.hxx"
+#include <lwpglobalmgr.hxx>
+#include <lwpfilehdr.hxx>
 #include "lwpparaproperty.hxx"
-#include "lwptools.hxx"
+#include <lwptools.hxx>
 #include "lwpparastyle.hxx"
-#include "xfilter/xffont.hxx"
-#include "xfilter/xftextstyle.hxx"
-#include "xfilter/xfstylemanager.hxx"
-#include "xfilter/xfparagraph.hxx"
-#include "xfilter/xftextcontent.hxx"
-#include "xfilter/xftextspan.hxx"
-#include "xfilter/xfmargins.hxx"
-#include "xfilter/xftabstop.hxx"
-#include "xfilter/xflinebreak.hxx"
-#include "xfilter/xfsection.hxx"
-#include "xfilter/xfsectionstyle.hxx"
-#include "xfilter/xfcolor.hxx"
-#include "xfilter/xfhyperlink.hxx"
-#include "xfilter/xfliststyle.hxx"
+#include <xfilter/xffont.hxx>
+#include <xfilter/xftextstyle.hxx>
+#include <xfilter/xfstylemanager.hxx>
+#include <xfilter/xfparagraph.hxx>
+#include <xfilter/xftextcontent.hxx>
+#include <xfilter/xftextspan.hxx>
+#include <xfilter/xfmargins.hxx>
+#include <xfilter/xftabstop.hxx>
+#include <xfilter/xflinebreak.hxx>
+#include <xfilter/xfsection.hxx>
+#include <xfilter/xfsectionstyle.hxx>
+#include <xfilter/xfcolor.hxx>
+#include <xfilter/xfhyperlink.hxx>
+#include <xfilter/xfliststyle.hxx>
 #include "lwpcharsetmgr.hxx"
 #include "lwpsection.hxx"
 #include "lwplayout.hxx"
@@ -85,18 +85,19 @@
 #include "lwpbulletstylemgr.hxx"
 #include "lwpstory.hxx"
 #include "lwpsilverbullet.hxx"
-#include "xfilter/xflist.hxx"
-#include "xfilter/xfframe.hxx"
+#include <xfilter/xflist.hxx>
+#include <xfilter/xfframe.hxx>
 
 #include "lwpdivinfo.hxx"
 #include "lwpdoc.hxx"
 #include "lwpholder.hxx"
 #include "lwppagehint.hxx"
 
-#include "lwpdropcapmgr.hxx"
+#include <lwpdropcapmgr.hxx>
 #include "lwptable.hxx"
+#include <memory>
 
-LwpPara::LwpPara(LwpObjectHeader& objHdr, LwpSvStream* pStrm)
+LwpPara::LwpPara(LwpObjectHeader const & objHdr, LwpSvStream* pStrm)
     : LwpDLVList(objHdr, pStrm)
     , m_nOrdinal(0)
     , m_nFlags(0)
@@ -122,27 +123,18 @@ LwpPara::LwpPara(LwpObjectHeader& objHdr, LwpSvStream* pStrm)
 
 LwpPara::~LwpPara()
 {
-
     if (m_pBreaks)
     {
         delete m_pBreaks;
         m_pBreaks = nullptr;
     }
-/*  if (m_pParaNumbering)
-    {
-        delete m_pParaNumbering;
-        m_pParaNumbering = NULL;
-    }*/
 
     if (m_pBullOver)
     {
         delete m_pBullOver;
         m_pBullOver = nullptr;
     }
-    if(m_pIndentOverride)
-    {
-        delete m_pIndentOverride;
-    }
+    delete m_pIndentOverride;
 
     LwpParaProperty* pNextProp;
     while(m_pProps)
@@ -194,10 +186,9 @@ void LwpPara::Read()
         {
             if (Notify)
             {
-                LwpForked3NotifyList* pNotifyList = new LwpForked3NotifyList();
-                pNotifyList->GetExtraList().Read(m_pObjStrm);
-                pNotifyList->Read(m_pObjStrm);
-                delete pNotifyList;
+                std::unique_ptr<LwpForked3NotifyList> pNotifyList( new LwpForked3NotifyList );
+                pNotifyList->GetExtraList().Read(m_pObjStrm.get());
+                pNotifyList->Read(m_pObjStrm.get());
             }
         }
     }
@@ -205,14 +196,14 @@ void LwpPara::Read()
         m_nOrdinal = 0x0001;
 
     m_nFlags = m_pObjStrm->QuickReaduInt16();
-    m_ParaStyle.ReadIndexed(m_pObjStrm);
+    m_ParaStyle.ReadIndexed(m_pObjStrm.get());
 
     if(!Simple)
     {
-        m_Hint.Read(m_pObjStrm);
+        m_Hint.Read(m_pObjStrm.get());
     }
 
-    m_Story.ReadIndexed(m_pObjStrm);
+    m_Story.ReadIndexed(m_pObjStrm.get());
     if(!Simple)
     {
         if(LwpFileHeader::m_nFileRevision<0x000B)
@@ -238,9 +229,9 @@ void LwpPara::Read()
         m_nLevel = 0x0001;
 
     m_Fribs.SetPara(this);// for silver bullet
-    m_Fribs.ReadPara(m_pObjStrm);
+    m_Fribs.ReadPara(m_pObjStrm.get());
 
-    m_pProps = LwpParaProperty::ReadPropertyList(m_pObjStrm,this);
+    ReadPropertyList(m_pObjStrm.get());
 }
 
 void LwpPara::Parse(IXFStream* pOutputStream)
@@ -295,7 +286,7 @@ void LwpPara::XFConvert(XFContentContainer* pCont)
     }
     else if (m_pXFContainer)
     {
-        LwpBulletStyleMgr* pBulletStyleMgr = this->GetBulletStyleMgr();
+        LwpBulletStyleMgr* pBulletStyleMgr = GetBulletStyleMgr();
         if (pBulletStyleMgr)
         {
             pBulletStyleMgr->SetCurrentSilverBullet(LwpObjectID());
@@ -311,9 +302,8 @@ void LwpPara::XFConvert(XFContentContainer* pCont)
         AddBreakAfter(m_pXFContainer);
 }
 
-bool LwpPara::RegisterMasterPage(XFParaStyle* pBaseStyle)
+void LwpPara::RegisterMasterPage(XFParaStyle const * pBaseStyle)
 {
-    bool bSuccess = false;
     //get story
     LwpStory* pStory = dynamic_cast<LwpStory*>(m_Story.obj().get());
     //if pagelayout is modified, register the pagelayout
@@ -326,7 +316,6 @@ bool LwpPara::RegisterMasterPage(XFParaStyle* pBaseStyle)
             RegisterNewSectionStyle(pLayout);
         }
 
-        bSuccess = true;
         //register master page style
         XFParaStyle* pOverStyle = new XFParaStyle();
         *pOverStyle = *pBaseStyle;
@@ -337,7 +326,6 @@ bool LwpPara::RegisterMasterPage(XFParaStyle* pBaseStyle)
         XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
         m_StyleName = pXFStyleManager->AddStyle(pOverStyle).m_pStyle->GetStyleName();
     }
-    return bSuccess;
 }
 /**
  * @short   register paragraph style
@@ -533,7 +521,7 @@ void LwpPara::RegisterStyle()
     OverrideParaNumbering(pNumberingProps);
 
     //register bullet style
-    LwpBulletStyleMgr* pBulletStyleMgr = this->GetBulletStyleMgr();
+    LwpBulletStyleMgr* pBulletStyleMgr = GetBulletStyleMgr();
     if (pBulletStyleMgr)
     {
         // if has bullet or numbering
@@ -555,7 +543,7 @@ void LwpPara::RegisterStyle()
                 if (m_pSilverBullet->IsBulletOrdered())
                 {
                     OUString aPreBullStyleName;
-                    LwpNumberingOverride* pNumbering = this->GetParaNumbering();
+                    LwpNumberingOverride* pNumbering = GetParaNumbering();
                     sal_uInt16 nPosition = pNumbering->GetPosition();
                     bool bLesser = m_pSilverBullet->IsLesserLevel(nPosition);
                     LwpPara* pPara = this;
@@ -582,7 +570,7 @@ void LwpPara::RegisterStyle()
                         LwpSilverBullet* pParaSilverBullet = pPara->GetSilverBullet();
                         pNumbering = pPara->GetParaNumbering();
 
-                        if (pPara->GetObjectID() != this->GetObjectID())
+                        if (pPara->GetObjectID() != GetObjectID())
                         {
                             if (!pParaSilverBullet)
                             {
@@ -691,7 +679,7 @@ void LwpPara::RegisterStyle()
                     else
                     {
                         m_bBullContinue = false;
-                        if (this->IsInCell())
+                        if (IsInCell())
                         {
                             XFListStyle* pOldStyle = static_cast<XFListStyle*>(pXFStyleManager->FindStyle(m_aBulletStyleName));
                             if (pOldStyle)
@@ -702,7 +690,7 @@ void LwpPara::RegisterStyle()
                         }
                     }
 
-                    LwpStory* pMyStory = this->GetStory();
+                    LwpStory* pMyStory = GetStory();
                     if (pMyStory)
                     {
                         if (pMyStory->IsBullStyleUsedBefore(m_aBulletStyleName, m_pParaNumbering->GetPosition()))
@@ -742,7 +730,7 @@ void LwpPara::RegisterStyle()
         XFParaStyle* pNewParaStyle = new XFParaStyle;
         *pNewParaStyle = *GetXFParaStyle();
         //pOverStyle->SetStyleName("");
-        this->RegisterTabStyle(pNewParaStyle);
+        RegisterTabStyle(pNewParaStyle);
         if (!m_ParentStyleName.isEmpty())
                     pNewParaStyle->SetParentStyleName(m_ParentStyleName);
         m_StyleName = pXFStyleManager->AddStyle(pNewParaStyle).m_pStyle->GetStyleName();
@@ -751,7 +739,7 @@ void LwpPara::RegisterStyle()
     //register master page;
     RegisterMasterPage(GetXFParaStyle());
 
-    // reg auto style,lay here for pagebreak need overrided para style
+    // reg auto style,lay here for pagebreak need overridden para style
     m_Fribs.SetPara(this);
     m_Fribs.RegisterStyle();
 
@@ -916,8 +904,8 @@ XFContentContainer* LwpPara::AddBulletList(XFContentContainer* pCont)
         m_nLevel = nLevel;//for get para level
     }
 
-    return ( pBulletStyleMgr->AddBulletList(pCont, bOrdered, m_aBulletStyleName,
-            nLevel, m_pBullOver->IsSkip()) );
+    return pBulletStyleMgr->AddBulletList(pCont, bOrdered, m_aBulletStyleName,
+            nLevel, m_pBullOver->IsSkip());
 }
 
 LwpNumberingOverride* LwpPara::GetParaNumbering()
