@@ -63,24 +63,24 @@
 #include <boost/cast.hpp>
 
 #include "lwppara.hxx"
-#include "lwpglobalmgr.hxx"
-#include "lwpfilehdr.hxx"
+#include <lwpglobalmgr.hxx>
+#include <lwpfilehdr.hxx>
 #include "lwpparaproperty.hxx"
-#include "lwptools.hxx"
+#include <lwptools.hxx>
 #include "lwpparastyle.hxx"
-#include "xfilter/xffont.hxx"
-#include "xfilter/xftextstyle.hxx"
-#include "xfilter/xfstylemanager.hxx"
-#include "xfilter/xfparagraph.hxx"
-#include "xfilter/xftextcontent.hxx"
-#include "xfilter/xftextspan.hxx"
-#include "xfilter/xfmargins.hxx"
-#include "xfilter/xftabstop.hxx"
-#include "xfilter/xflinebreak.hxx"
-#include "xfilter/xfsection.hxx"
-#include "xfilter/xfsectionstyle.hxx"
-#include "xfilter/xfcolor.hxx"
-#include "xfilter/xfhyperlink.hxx"
+#include <xfilter/xffont.hxx>
+#include <xfilter/xftextstyle.hxx>
+#include <xfilter/xfstylemanager.hxx>
+#include <xfilter/xfparagraph.hxx>
+#include <xfilter/xftextcontent.hxx>
+#include <xfilter/xftextspan.hxx>
+#include <xfilter/xfmargins.hxx>
+#include <xfilter/xftabstop.hxx>
+#include <xfilter/xflinebreak.hxx>
+#include <xfilter/xfsection.hxx>
+#include <xfilter/xfsectionstyle.hxx>
+#include <xfilter/xfcolor.hxx>
+#include <xfilter/xfhyperlink.hxx>
 #include "lwpcharsetmgr.hxx"
 #include "lwpsection.hxx"
 #include "lwplayout.hxx"
@@ -89,15 +89,15 @@
 #include "lwpbulletstylemgr.hxx"
 #include "lwpstory.hxx"
 #include "lwpsilverbullet.hxx"
-#include "xfilter/xflist.hxx"
-#include "xfilter/xfframe.hxx"
+#include <xfilter/xflist.hxx>
+#include <xfilter/xfframe.hxx>
 
 #include "lwpdivinfo.hxx"
 #include "lwpdoc.hxx"
 #include "lwpholder.hxx"
 #include "lwppagehint.hxx"
 
-#include "lwpdropcapmgr.hxx"
+#include <lwpdropcapmgr.hxx>
 #include "lwptable.hxx"
 #include "lwpcelllayout.hxx"
 #include "lwpframelayout.hxx"
@@ -511,7 +511,7 @@ void LwpPara::OverrideParaBullet(LwpParaProperty* pProps)
  * @short:   Override paranumbering properties.
  * @param:   pProps pointer to the LwpParaProperty and we can get local paranumbering through it.
  */
-void LwpPara::OverrideParaNumbering(LwpParaProperty* pProps)
+void LwpPara::OverrideParaNumbering(LwpParaProperty const * pProps)
 {
     // get numbering override in parastyle
     LwpParaStyle* pParaStyle = GetParaStyle();
@@ -525,7 +525,7 @@ void LwpPara::OverrideParaNumbering(LwpParaProperty* pProps)
     //Override with the local numbering, if any
     if (pProps)
     {
-        LwpNumberingOverride* pPropNumbering = static_cast<LwpParaNumberingProperty*>(pProps)->GetLocalNumbering();
+        LwpNumberingOverride* pPropNumbering = static_cast<LwpParaNumberingProperty const *>(pProps)->GetLocalNumbering();
         if (pPropNumbering)
         {
             pOver.reset(pPropNumbering->clone());
@@ -593,7 +593,7 @@ LwpTabOverride* LwpPara::GetLocalTabOverride()
 * @descr:   Determined which para is earlier in position
 *
 */
-bool LwpPara::operator< (LwpPara& Other)
+bool LwpPara::operator< (LwpPara const & Other)
 {
     return m_nOrdinal < Other.m_nOrdinal;
 }
@@ -602,7 +602,7 @@ bool LwpPara::operator< (LwpPara& Other)
 * @descr:  If the two layouts in the same para, compare which layout is earlied according to frib order
 *
 */
-bool LwpPara::ComparePagePosition(LwpVirtualLayout * pPreLayout, LwpVirtualLayout * pNextLayout)
+bool LwpPara::ComparePagePosition(LwpVirtualLayout const * pPreLayout, LwpVirtualLayout const * pNextLayout)
 {
     m_Fribs.SetPara(this);
     return m_Fribs.ComparePagePosition(pPreLayout, pNextLayout);
