@@ -57,26 +57,22 @@
  * @file
  *  For LWP filter architecture prototype
  ************************************************************************/
-/*************************************************************************
- * Change History
- Jan 2005           Created
- ************************************************************************/
 
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 #include "lwpparastyle.hxx"
-#include "lwpfilehdr.hxx"
-#include "lwpoverride.hxx"
+#include <lwpfilehdr.hxx>
+#include <lwpoverride.hxx>
 #include "lwpparaborderoverride.hxx"
 #include "lwpbreaksoverride.hxx"
 #include "lwpnumberingoverride.hxx"
 #include "lwptaboverride.hxx"
 #include "lwpbackgroundoverride.hxx"
-#include "xfilter/xfdefs.hxx"
-#include "xfilter/xfparastyle.hxx"
-#include "xfilter/xfborders.hxx"
-#include "lwpfont.hxx"
-#include "lwpfoundry.hxx"
+#include <xfilter/xfdefs.hxx>
+#include <xfilter/xfparastyle.hxx>
+#include <xfilter/xfborders.hxx>
+#include <lwpfont.hxx>
+#include <lwpfoundry.hxx>
 #include "lwppiece.hxx"
 #include "lwpshadow.hxx"
 #include "lwpborderstuff.hxx"
@@ -85,23 +81,13 @@
 
 #include "lwpsilverbullet.hxx"
 
-LwpParaStyle::LwpParaStyle(LwpObjectHeader& objHdr, LwpSvStream* pStrm) :
-LwpTextStyle(objHdr, pStrm), m_pKinsokuOptsOverride(new LwpKinsokuOptsOverride),
-m_pBulletOverride(new LwpBulletOverride)
+LwpParaStyle::LwpParaStyle(LwpObjectHeader const & objHdr, LwpSvStream* pStrm) :
+LwpTextStyle(objHdr, pStrm)
 {
 }
 
 LwpParaStyle::~LwpParaStyle()
 {
-    if (m_pKinsokuOptsOverride)
-    {
-        delete m_pKinsokuOptsOverride;
-    }
-
-    if (m_pBulletOverride)
-    {
-        delete m_pBulletOverride;
-    }
 }
 
 void LwpParaStyle::Read()
@@ -112,43 +98,43 @@ void LwpParaStyle::Read()
     {
         // read many overrides
         LwpAlignmentOverride    aAlignOverride;
-        aAlignOverride.Read(m_pObjStrm);
+        aAlignOverride.Read(m_pObjStrm.get());
 
         LwpSpacingOverride  aSpacingOverride;
-        aSpacingOverride.Read(m_pObjStrm);
+        aSpacingOverride.Read(m_pObjStrm.get());
 
         LwpIndentOverride       aIndentOverride;
-        aIndentOverride.Read(m_pObjStrm);
+        aIndentOverride.Read(m_pObjStrm.get());
 
         LwpParaBorderOverride   aPBOverride;
-        aPBOverride.Read(m_pObjStrm);
+        aPBOverride.Read(m_pObjStrm.get());
 
         LwpBreaksOverride   aBreaksOverride;
-        aBreaksOverride.Read(m_pObjStrm);
+        aBreaksOverride.Read(m_pObjStrm.get());
 
         LwpNumberingOverride    aNumberingOverride;
-        aNumberingOverride.Read(m_pObjStrm);
+        aNumberingOverride.Read(m_pObjStrm.get());
 
         LwpTabOverride      aTabOverride;
-        aTabOverride.Read(m_pObjStrm);
+        aTabOverride.Read(m_pObjStrm.get());
 
     }
     else
     {
-        m_AlignmentStyle.ReadIndexed(m_pObjStrm);
-        m_SpacingStyle.ReadIndexed(m_pObjStrm);
-        m_IndentStyle.ReadIndexed(m_pObjStrm);
-        m_BorderStyle.ReadIndexed(m_pObjStrm);
-        m_BreaksStyle.ReadIndexed(m_pObjStrm);
-        m_NumberingStyle.ReadIndexed(m_pObjStrm);
-        m_TabStyle.ReadIndexed(m_pObjStrm);
+        m_AlignmentStyle.ReadIndexed(m_pObjStrm.get());
+        m_SpacingStyle.ReadIndexed(m_pObjStrm.get());
+        m_IndentStyle.ReadIndexed(m_pObjStrm.get());
+        m_BorderStyle.ReadIndexed(m_pObjStrm.get());
+        m_BreaksStyle.ReadIndexed(m_pObjStrm.get());
+        m_NumberingStyle.ReadIndexed(m_pObjStrm.get());
+        m_TabStyle.ReadIndexed(m_pObjStrm.get());
 
-        m_pKinsokuOptsOverride->Read(m_pObjStrm);
-        m_pBulletOverride->Read(m_pObjStrm);
+        m_KinsokuOptsOverride.Read(m_pObjStrm.get());
+        m_BulletOverride.Read(m_pObjStrm.get());
 
         if (m_pObjStrm->CheckExtra())
         {
-            m_BackgroundStyle.ReadIndexed(m_pObjStrm);
+            m_BackgroundStyle.ReadIndexed(m_pObjStrm.get());
             m_pObjStrm->SkipExtra();
         }
 
@@ -159,7 +145,7 @@ void LwpParaStyle::Apply(XFParaStyle *pParaStyle)
 {
     assert(pParaStyle);
 
-    LwpVirtualPiece *pPiece = NULL;
+    LwpVirtualPiece *pPiece = nullptr;
     //alignment:
     pPiece = dynamic_cast<LwpVirtualPiece*>(m_AlignmentStyle.obj().get());
     if( pPiece )
@@ -176,15 +162,15 @@ void LwpParaStyle::Apply(XFParaStyle *pParaStyle)
         LwpIndentOverride   *pIndent = dynamic_cast<LwpIndentOverride*>(pPiece->GetOverride());
         if( pIndent )
         {
-            if (!m_pBulletOverride->IsInValid())//Add by ,for remove bullet indent in named bullet style
+            if (!m_BulletOverride.IsInValid())// for remove bullet indent in named bullet style
             {
-                boost::scoped_ptr<LwpIndentOverride> pNewIndent(pIndent->clone());
+                std::unique_ptr<LwpIndentOverride> pNewIndent(pIndent->clone());
                 pNewIndent->SetMFirst(0);
                 pNewIndent->SetMRest(0);
-                ApplyIndent(NULL, pParaStyle, pNewIndent.get());
+                ApplyIndent(nullptr, pParaStyle, pNewIndent.get());
             }
             else
-                ApplyIndent(NULL,pParaStyle,pIndent);
+                ApplyIndent(nullptr,pParaStyle,pIndent);
         }
     }
     //shadow & borders.
@@ -203,7 +189,7 @@ void LwpParaStyle::Apply(XFParaStyle *pParaStyle)
     {
         LwpSpacingOverride *pSpacing = dynamic_cast<LwpSpacingOverride*>(pPiece->GetOverride());
         if( pSpacing)
-            ApplySpacing(NULL,pParaStyle,pSpacing);
+            ApplySpacing(nullptr,pParaStyle,pSpacing);
     }
 
     //paragraph background.
@@ -275,20 +261,20 @@ void LwpParaStyle::ApplySubBorder(LwpBorderStuff* pBorderStuff, LwpBorderStuff::
         break;
     case 0x15: //double , fall through!
     case 0x16: //thick double
-        pXFBorders->SetDoubleLine(eXFBorderSide, true, false);
+        pXFBorders->SetDoubleLine(eXFBorderSide);
         pXFBorders->SetWidthOuter(eXFBorderSide, static_cast<float>(fWidth*0.333));
         pXFBorders->SetWidthSpace(eXFBorderSide, static_cast<float>(fWidth*0.334));
         pXFBorders->SetWidthInner(eXFBorderSide, static_cast<float>(fWidth*0.333));
 //      pXFBorders->SetWidth(eXFBorderSide, fWidth);
         break;
     case 0x18: //thick-thin
-        pXFBorders->SetDoubleLine(eXFBorderSide, true, false);
+        pXFBorders->SetDoubleLine(eXFBorderSide);
         pXFBorders->SetWidthOuter(eXFBorderSide, static_cast<float>(fWidth*0.5));
         pXFBorders->SetWidthInner(eXFBorderSide, static_cast<float>(fWidth*0.25));
         pXFBorders->SetWidthSpace(eXFBorderSide, static_cast<float>(fWidth*0.25));
         break;
     case 0x19: //thin-thick
-        pXFBorders->SetDoubleLine(eXFBorderSide, true, false);
+        pXFBorders->SetDoubleLine(eXFBorderSide);
         pXFBorders->SetWidthInner(eXFBorderSide, static_cast<float>(fWidth*0.7));
         pXFBorders->SetWidthOuter(eXFBorderSide, static_cast<float>(fWidth*0.15));
         pXFBorders->SetWidthSpace(eXFBorderSide, static_cast<float>(fWidth*0.15));
@@ -350,7 +336,7 @@ void LwpParaStyle::ApplyParaBorder(XFParaStyle* pParaStyle, LwpParaBorderOverrid
         // apply 4 borders respectively
         LwpBorderStuff::BorderType pType[] = { LwpBorderStuff::LEFT, LwpBorderStuff::RIGHT,
             LwpBorderStuff::TOP, LwpBorderStuff::BOTTOM };
-        float pMarginValue[4];
+        float pMarginValue[4] = { 0.0, 0.0, 0.0, 0.0 };
 
         for (sal_uInt8 nC = 0; nC < 4; nC++)
         {
@@ -438,7 +424,7 @@ void LwpParaStyle::ApplyIndent(LwpPara* pPara, XFParaStyle* pParaStyle, LwpInden
     if (pPara)
         pParentPara = pPara->GetParent();
     else
-        pParentPara = NULL;
+        pParentPara = nullptr;
 
     std::unique_ptr<LwpIndentOverride> pTotalIndent(new LwpIndentOverride);
     if (pIndent->IsUseRelative() && pParentPara)
@@ -448,7 +434,7 @@ void LwpParaStyle::ApplyIndent(LwpPara* pPara, XFParaStyle* pParaStyle, LwpInden
             return;
         pTotalIndent.reset(pIndent->clone());
 
-        //add by ,for bullet only
+        //for bullet only
         if (pPara)
         {
             if (pPara->GetBulletFlag())
@@ -461,7 +447,6 @@ void LwpParaStyle::ApplyIndent(LwpPara* pPara, XFParaStyle* pParaStyle, LwpInden
                 return;
             }
         }
-        //end add
         sal_uInt16 relative = pParentIndent->GetRelative();
 
         sal_Int32 Amount = pParentIndent->GetMAll();
@@ -481,19 +466,16 @@ void LwpParaStyle::ApplyIndent(LwpPara* pPara, XFParaStyle* pParaStyle, LwpInden
     else
     {
         pTotalIndent.reset(pIndent->clone());
-        //add by
         if (pPara)
         {
             if (pPara->GetBulletFlag())
             {
-//              pParaStyle->SetIndent(LwpTools::ConvertFromUnits(pIndent->GetMAll()));
                 pParaStyle->SetMargins(LwpTools::ConvertToMetric(
                     LwpTools::ConvertFromUnits(pIndent->GetMAll())), pIndent->GetRight());
                 pPara->SetIndent(pTotalIndent.release());
                 return;
             }
         }
-        //end add
 
         pParaStyle->SetIndent(pIndent->GetFirst());
         pParaStyle->SetMargins(pIndent->GetLeft(), pIndent->GetRight());
@@ -552,7 +534,6 @@ void LwpParaStyle::ApplySpacing(LwpPara* pPara, XFParaStyle* pParaStyle, LwpSpac
     switch(type)
     {
     case LwpSpacingCommonOverride::SPACING_DYNAMIC:
-//        above_val = LINE_HEIGHT*float(multiple)/65536L*100; //TO DO:  1-26
         break;
     case LwpSpacingCommonOverride::SPACING_LEADING:
         break;
@@ -570,7 +551,6 @@ void LwpParaStyle::ApplySpacing(LwpPara* pPara, XFParaStyle* pParaStyle, LwpSpac
     switch(type)
     {
     case LwpSpacingCommonOverride::SPACING_DYNAMIC:
-//        below_val = LINE_HEIGHT*float(multiple)/65536L*100;//TO DO:  1-26
         break;
     case LwpSpacingCommonOverride::SPACING_LEADING:
         break;
@@ -595,13 +575,7 @@ void LwpParaStyle::ApplySpacing(LwpPara* pPara, XFParaStyle* pParaStyle, LwpSpac
     }
     pParaStyle->SetMargins(-1,-1,above_val,below_val);
 }
-/**************************************************************************
- * @short:
- * @descr:
- * @param:
- * @param:
- * @return:
-**************************************************************************/
+
 void LwpParaStyle::ApplyTab(XFParaStyle *pParaStyle, LwpTabOverride *pTabOverRide)
 {
     LwpObjectID& rTabRackID = pTabOverRide->GetTabRackID();
@@ -682,107 +656,100 @@ void LwpParaStyle::RegisterStyle()
     if (!m_pFoundry)
         throw std::runtime_error("missing Foundry");
 
-    XFParaStyle* pStyle = new XFParaStyle();
+    std::unique_ptr<XFParaStyle> xStyle(new XFParaStyle());
 
     //Set name
     OUString styleName = GetName().str();
-    pStyle->SetStyleName(styleName);
+    xStyle->SetStyleName(styleName);
 
     //Create font
     LwpFontManager& rFontMgr = m_pFoundry->GetFontManger();
     rtl::Reference<XFFont> pFont = rFontMgr.CreateFont(m_nFinalFontID);
-    pStyle->SetFont(pFont);
+    xStyle->SetFont(pFont);
 
     //Set other paragraph properties...
 
-    Apply(pStyle);
+    Apply(xStyle.get());
     //Add style
     LwpStyleManager* pStyleMgr = m_pFoundry->GetStyleManager();
-    pStyleMgr->AddStyle(GetObjectID(), pStyle);
+    pStyleMgr->AddStyle(GetObjectID(), xStyle.release());
 }
 
 LwpAlignmentOverride* LwpParaStyle::GetAlignment()
 {
-    if (m_AlignmentStyle.obj() == NULL)
-        return NULL;
+    if (m_AlignmentStyle.obj() == nullptr)
+        return nullptr;
 
     LwpAlignmentPiece *pPiece = dynamic_cast<LwpAlignmentPiece*>(m_AlignmentStyle.obj().get());
     if (pPiece)
         return dynamic_cast<LwpAlignmentOverride*>(pPiece->GetOverride());
-    return NULL;
+    return nullptr;
 }
 
 LwpIndentOverride* LwpParaStyle::GetIndent()
 {
-    if (m_IndentStyle.obj() == NULL)
-        return NULL;
+    if (m_IndentStyle.obj() == nullptr)
+        return nullptr;
 
     LwpIndentPiece *pPiece = dynamic_cast<LwpIndentPiece*>(m_IndentStyle.obj().get());
     if (pPiece)
         return dynamic_cast<LwpIndentOverride*>(pPiece->GetOverride());
-    return NULL;
+    return nullptr;
 }
 
 LwpSpacingOverride* LwpParaStyle::GetSpacing()
 {
-    if (m_SpacingStyle.obj() == NULL)
-        return NULL;
+    if (m_SpacingStyle.obj() == nullptr)
+        return nullptr;
 
     LwpSpacingPiece *pPiece = dynamic_cast<LwpSpacingPiece*>(m_SpacingStyle.obj().get());
     if (pPiece)
         return dynamic_cast<LwpSpacingOverride*>(pPiece->GetOverride());
-    return NULL;
+    return nullptr;
 }
 
 LwpParaBorderOverride* LwpParaStyle::GetParaBorder() const
 {
     if(m_BorderStyle.IsNull())
-        return NULL;
+        return nullptr;
 
     LwpParaBorderPiece *pPiece = dynamic_cast<LwpParaBorderPiece*>(m_BorderStyle.obj(VO_PARABORDERPIECE).get());
     if (pPiece)
         return dynamic_cast<LwpParaBorderOverride*>(pPiece->GetOverride());
-    return NULL;
+    return nullptr;
 }
 
 LwpBreaksOverride* LwpParaStyle::GetBreaks() const
 {
     if(m_BreaksStyle.IsNull())
-        return NULL;
+        return nullptr;
 
     LwpBreaksPiece *pPiece = dynamic_cast<LwpBreaksPiece*>(m_BreaksStyle.obj(VO_BREAKSPIECE).get());
     if (pPiece)
         return dynamic_cast<LwpBreaksOverride*>(pPiece->GetOverride());
-    return NULL;
+    return nullptr;
 }
 
 
 LwpNumberingOverride* LwpParaStyle::GetNumberingOverride() const
 {
     if(m_NumberingStyle.IsNull())
-        return NULL;
+        return nullptr;
 
     LwpNumberingPiece *pPiece = dynamic_cast<LwpNumberingPiece*>(m_NumberingStyle.obj(VO_NUMBERINGPIECE).get());
     if (pPiece)
         return dynamic_cast<LwpNumberingOverride*>(pPiece->GetOverride());
-    return NULL;
+    return nullptr;
 }
 
-/**************************************************************************
- * @short:
- * @descr:
- * @param:
- * @param:
- * @return:
-**************************************************************************/
 LwpTabOverride* LwpParaStyle::GetTabOverride() const
 {
-    if(m_TabStyle.obj() == NULL)
-        return NULL;
+    if(m_TabStyle.obj() == nullptr)
+        return nullptr;
     LwpTabPiece *pPiece = dynamic_cast<LwpTabPiece*>(m_TabStyle.obj().get());
     if (pPiece)
         return dynamic_cast<LwpTabOverride*>(pPiece->GetOverride());
-    return NULL;
+    return nullptr;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
