@@ -59,45 +59,39 @@
         1. Word Pro object for paragraph list;
         2. the content of layout object
  ************************************************************************/
-/*************************************************************************
- * Change History
- Jan 2005           Created
- ************************************************************************/
-#include "lwpglobalmgr.hxx"
-#include "lwpstory.hxx"
-#include "xfilter/xfstylemanager.hxx"
 
-LwpStory::LwpStory(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
+#include <lwpglobalmgr.hxx>
+#include "lwpstory.hxx"
+#include <xfilter/xfstylemanager.hxx>
+#include "lwppara.hxx"
+#include <lwpobjfactory.hxx>
+#include "lwppagelayout.hxx"
+
+
+LwpStory::LwpStory(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
     : LwpContent(objHdr, pStrm)
     , m_bPMModified(false)
-    , m_pCurrentLayout(NULL)
-    , m_pTabLayout(NULL)
+    , m_pCurrentLayout(nullptr)
+    , m_pTabLayout(nullptr)
     , m_bDropcap(false)
     , m_pHyperlinkMgr(new LwpHyperlinkMgr)
-    , m_pXFContainer(NULL)
 {
 }
 
 LwpStory::~LwpStory()
 {
-    delete m_pHyperlinkMgr;
 }
 
 void LwpStory::Read()
 {
     LwpContent::Read();
-    m_ParaList.Read(m_pObjStrm);
-    m_FirstParaStyle.ReadIndexed(m_pObjStrm);
+    m_ParaList.Read(m_pObjStrm.get());
+    m_FirstParaStyle.ReadIndexed(m_pObjStrm.get());
     m_pObjStrm->SkipExtra();
 }
 
-#include "lwppara.hxx"
-#include "lwpobjfactory.hxx"
 /**************************************************************************
  * @descr:   Convert all the contents in current story
- * @param:
- * @param:
- * @return:
 **************************************************************************/
 void LwpStory::XFConvert(XFContentContainer* pCont)
 {
@@ -138,6 +132,8 @@ void LwpStory::RegisterStyle()
     rtl::Reference<LwpPara> xPara(dynamic_cast<LwpPara*>(GetFirstPara().obj().get()));
     while (xPara.is())
     {
+        if (xPara->GetFoundry())
+            throw std::runtime_error("loop in register style");
         xPara->SetFoundry(m_pFoundry);
         xPara->DoRegisterStyle();
         xPara.set(dynamic_cast<LwpPara*>(xPara->GetNext().obj().get()));
@@ -146,20 +142,15 @@ void LwpStory::RegisterStyle()
 
 void LwpStory::Parse(IXFStream* pOutputStream)
 {
-    m_pXFContainer = new XFContentContainer;
-    XFConvert(m_pXFContainer);
-    m_pXFContainer->ToXml(pOutputStream);
-    delete m_pXFContainer;
-    m_pXFContainer = nullptr;
+    m_xXFContainer.set(new XFContentContainer);
+    XFConvert(m_xXFContainer.get());
+    m_xXFContainer->ToXml(pOutputStream);
+    m_xXFContainer.clear();
 }
 
-#include "lwppagelayout.hxx"
 /**************************************************************************
- * @descr:   Set current page layout. If pPageLayout is a mirro page layout,
+ * @descr:   Set current page layout. If pPageLayout is a mirror page layout,
              use odd child page layout as current page layout.
- * @param:
- * @param:
- * @return:
 **************************************************************************/
 void LwpStory::SetCurrentLayout(LwpPageLayout *pPageLayout)
 {
@@ -183,9 +174,6 @@ void LwpStory::AddPageLayout(LwpPageLayout * pObject)
 }
 /**************************************************************************
  * @descr:   Get the next page layout relative to m_pCurrentLayout
- * @param:
- * @param:
- * @return:
 **************************************************************************/
 LwpPageLayout* LwpStory::GetNextPageLayout()
 {
@@ -200,13 +188,10 @@ LwpPageLayout* LwpStory::GetNextPageLayout()
             }
         }
     }
-    return NULL;
+    return nullptr;
 }
 /**************************************************************************
  * @descr:   Sort the pagelayout according to their position
- * @param:
- * @param:
- * @return:
 **************************************************************************/
 void LwpStory::SortPageLayout()
 {
@@ -263,9 +248,6 @@ void LwpStory::SortPageLayout()
 
 /**************************************************************************
  * @descr:  whether need create a new section and reset column in current page layout
- * @param:
- * @param:
- * @return:  sal_True if need create a new section
 **************************************************************************/
 bool LwpStory::IsNeedSection()
 {
@@ -315,9 +297,6 @@ bool LwpStory::IsNeedSection()
 }
 /**************************************************************************
  * @descr:  process frame which anchor type is to cell
- * @param:
- * @param:
- * @return:
 **************************************************************************/
 void LwpStory::XFConvertFrameInCell(XFContentContainer* pCont)
 {
@@ -344,9 +323,6 @@ void LwpStory::XFConvertFrameInCell(XFContentContainer* pCont)
 
 /**************************************************************************
  * @descr:  process frame which anchor type is to page
- * @param:
- * @param:
- * @return:
 **************************************************************************/
 void LwpStory::XFConvertFrameInPage(XFContentContainer* pCont)
 {
@@ -356,10 +332,10 @@ void LwpStory::XFConvertFrameInPage(XFContentContainer* pCont)
         rtl::Reference<LwpVirtualLayout> xFrameLayout(dynamic_cast<LwpVirtualLayout*>(xLayout->GetChildHead().obj().get()));
         while (xFrameLayout.is())
         {
-            if((xFrameLayout->IsAnchorPage()
-                &&(xFrameLayout->IsFrame()
-                      || xFrameLayout->IsSuperTable()
-                      || xFrameLayout->IsGroupHead())))
+            if( xFrameLayout->IsAnchorPage()
+                && (xFrameLayout->IsFrame()
+                    || xFrameLayout->IsSuperTable()
+                    || xFrameLayout->IsGroupHead()) )
             {
                 xFrameLayout->DoXFConvert(pCont);
             }
@@ -370,9 +346,6 @@ void LwpStory::XFConvertFrameInPage(XFContentContainer* pCont)
 }
 /**************************************************************************
  * @descr:  process frame which anchor type is to frame
- * @param:
- * @param:
- * @return:
 **************************************************************************/
 void LwpStory::XFConvertFrameInFrame(XFContentContainer* pCont)
 {
@@ -393,9 +366,6 @@ void LwpStory::XFConvertFrameInFrame(XFContentContainer* pCont)
 }
 /**************************************************************************
  * @descr:  process frame which anchor type is to page and the frame is contained by header or footer
- * @param:
- * @param:
- * @return:
 **************************************************************************/
 void LwpStory::XFConvertFrameInHeaderFooter(XFContentContainer* pCont)
 {
@@ -422,33 +392,27 @@ void LwpStory::XFConvertFrameInHeaderFooter(XFContentContainer* pCont)
 
 void LwpStory::AddXFContent(XFContent* pContent)
 {
-    if(m_pXFContainer)
-        m_pXFContainer->Add(pContent);
+    if (m_xXFContainer)
+        m_xXFContainer->Add(pContent);
 }
 
 XFContentContainer* LwpStory::GetXFContent()
 {
-    if(m_pXFContainer)
-        return m_pXFContainer;
-    else
-        return NULL;
+    return m_xXFContainer.get();
 }
 
 LwpPara* LwpStory::GetLastParaOfPreviousStory()
 {
-    rtl::Reference<LwpVirtualLayout> xVLayout(this->GetLayout(nullptr));
+    rtl::Reference<LwpVirtualLayout> xVLayout(GetLayout(nullptr));
     if (xVLayout.is())
     {
         return xVLayout->GetLastParaOfPreviousStory();
     }
 
-    return NULL;
+    return nullptr;
 }
 /**************************************************************************
  * @descr:  get text from story
- * @param:
- * @param:
- * @return:
 **************************************************************************/
 OUString LwpStory::GetContentText(bool bAllText)
 {
@@ -471,12 +435,12 @@ OUString LwpStory::GetContentText(bool bAllText)
         if(pObj.is())
         {
             LwpPara* pPara = dynamic_cast<LwpPara*>(pObj.get());
-            if (!pPara || pPara->GetNext().obj() != NULL)
-                return OUString("");
+            if (!pPara || pPara->GetNext().obj() != nullptr)
+                return OUString();
             pPara->SetFoundry(m_pFoundry);
             return pPara->GetContentText();
         }
-        return  OUString("");
+        return  OUString();
     }
 
 }
@@ -484,15 +448,15 @@ OUString LwpStory::RegisterFirstFribStyle()
 {
     LwpPara* pPara = dynamic_cast<LwpPara*>(GetFirstPara().obj().get());
     if (!pPara)
-        return OUString("");
+        return OUString();
     pPara->SetFoundry(m_pFoundry);
     LwpFribPtr& rFribs = pPara->GetFribs();
     LwpFrib* pFirstFrib = rFribs.GetFribs();
     pFirstFrib->RegisterStyle(m_pFoundry);
     XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
     XFTextStyle* pBaseStyle = pXFStyleManager->FindTextStyle(pFirstFrib->GetStyleName());
-    if (pBaseStyle == NULL)
-        return OUString("");
+    if (pBaseStyle == nullptr)
+        return OUString();
     XFTextStyle* pStyle = new XFTextStyle;
     *pStyle = *pBaseStyle;
     OUString sName = "Ruby" + pFirstFrib->GetStyleName();
@@ -501,7 +465,7 @@ OUString LwpStory::RegisterFirstFribStyle()
     return sName;
 }
 
-bool LwpStory::IsBullStyleUsedBefore(const OUString& rStyleName, const sal_uInt8& nPos)
+bool LwpStory::IsBullStyleUsedBefore(const OUString& rStyleName, sal_uInt8 nPos)
 {
     std::vector <NamePosPair>::reverse_iterator rIter;
     for (rIter = m_vBulletStyleNameList.rbegin(); rIter != m_vBulletStyleNameList.rend(); ++rIter)
