@@ -53,7 +53,7 @@
  *
  *
  ************************************************************************/
-#include "lwpsvstream.hxx"
+#include <lwpsvstream.hxx>
 #include <tools/stream.hxx>
 
 const sal_uInt32 LwpSvStream::LWP_STREAM_BASE = 0x0010;
@@ -68,7 +68,7 @@ LwpSvStream::LwpSvStream(SvStream* pStream, LwpSvStream * pCompressed)
 */
 sal_Int32 LwpSvStream::Read(void* buf, sal_Int32 nBytesToRead)
 {
-    return m_pStream->Read(buf,nBytesToRead);
+    return m_pStream->ReadBytes(buf, nBytesToRead);
 }
 
 LwpSvStream& LwpSvStream::ReadUInt8( sal_uInt8& rUInt8 )
@@ -92,9 +92,9 @@ LwpSvStream& LwpSvStream::ReadUInt32( sal_uInt32& rUInt32 )
 /**
  * @descr       SeekRel in stream
 */
-sal_Int64 LwpSvStream::SeekRel(sal_Int64 pos)
+void LwpSvStream::SeekRel(sal_Int64 pos)
 {
-    return m_pStream->SeekRel(pos);
+    m_pStream->SeekRel(pos);
 }
 /**
  * @descr       Get the current position in stream
