@@ -57,7 +57,7 @@
  * @file
  * Date style. The date format for date field.
  ************************************************************************/
-#include "xfdatestyle.hxx"
+#include <xfilter/xfdatestyle.hxx>
 
 XFDatePart::XFDatePart()
 {
@@ -159,8 +159,6 @@ void    XFDatePart::ToXml(IXFStream *pStrm)
 
 XFDateStyle::XFDateStyle()
 {
-    m_bFixed = false;
-    m_bAutoOrder = false;
 }
 
 XFDateStyle::~XFDateStyle()
