@@ -1,5 +1,5 @@
 /* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*************************************************************************
+/*
  *
  *  The Contents of this file are made available subject to the terms of
  *  either of the following licenses
@@ -52,12 +52,12 @@
  *  Contributor(s): _______________________________________
  *
  *
- ************************************************************************/
+ */
 /*
  * @file
  * Polygon object.
  */
-#include "xfdrawpolygon.hxx"
+#include <xfilter/xfdrawpolygon.hxx>
 
 XFDrawPolygon::XFDrawPolygon()
 {
