@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include "mysqlc_connection.hxx"
 #include "mysqlc_databasemetadata.hxx"
 
@@ -64,36 +65,26 @@ OConnection::OConnection(MysqlCDriver& _rDriver, sql::Driver * _cppDriver)
     :OMetaConnection_BASE(m_aMutex)
     ,OSubComponent<OConnection, OConnection_BASE>(static_cast<cppu::OWeakObject*>(&_rDriver), this)
     ,m_xMetaData(nullptr)
-    ,m_rDriver(_rDriver)
+    ,m_xDriver(&_rDriver)
     ,cppDriver(_cppDriver)
-    ,m_bClosed(false)
-    ,m_bUseCatalog(false)
-    ,m_bUseOldDateFormat(false)
 {
-    OSL_TRACE("OConnection::OConnection");
-    m_rDriver.acquire();
 }
 
 OConnection::~OConnection()
 {
-    OSL_TRACE("OConnection::~OConnection");
     if (!isClosed()) {
         close();
     }
-    m_rDriver.release();
 }
 
 void SAL_CALL OConnection::release()
     throw()
 {
-    OSL_TRACE("OConnection::release");
-    relase_ChildImpl();
+    release_ChildImpl();
 }
 
 void OConnection::construct(const rtl::OUString& url, const Sequence< PropertyValue >& info)
-    throw(SQLException)
 {
-    OSL_TRACE("OConnection::construct");
     MutexGuard aGuard(m_aMutex);
 
     sal_Int32 nIndex;
@@ -104,7 +95,6 @@ void OConnection::construct(const rtl::OUString& url, const Sequence< PropertyVa
     rtl::OUString aDbName;
 
     m_settings.encoding = MysqlCDriver::getDefaultEncoding();
-    m_settings.quoteIdentifier.clear();
 
     // parse url. Url has the following format:
     // external server: sdbc:mysqlc:[hostname]:[port]/[dbname]
@@ -171,7 +161,7 @@ void OConnection::construct(const rtl::OUString& url, const Sequence< PropertyVa
             connProps["userName"] = sql::ConnectPropertyVal(user_str);
             connProps["password"] = sql::ConnectPropertyVal(pass_str);
             connProps["schema"] = sql::ConnectPropertyVal(schema_str);
-            connProps["port"] = sql::ConnectPropertyVal((int)(nPort));
+            connProps["port"] = sql::ConnectPropertyVal((int)nPort);
             if (unixSocketPassed) {
                 sql::SQLString socket_str = rtl::OUStringToOString(sUnixSocket, m_settings.encoding).getStr();
                 connProps["socket"] = socket_str;
@@ -180,12 +170,6 @@ void OConnection::construct(const rtl::OUString& url, const Sequence< PropertyVa
                 connProps["socket"] = pipe_str;
             }
 
-            OSL_TRACE("hostName=%s", host_str.c_str());
-            OSL_TRACE("port=%i", int(nPort));
-            OSL_TRACE("userName=%s", user_str.c_str());
-            OSL_TRACE("password=%s", pass_str.c_str());
-            OSL_TRACE("schema=%s", schema_str.c_str());
-
             m_settings.cppConnection.reset(cppDriver->connect(connProps));
         } catch (const sql::SQLException &e) {
             mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
@@ -195,10 +179,9 @@ void OConnection::construct(const rtl::OUString& url, const Sequence< PropertyVa
     }
 
     m_settings.schema = aDbName;
-    OSL_TRACE("%s", rtl::OUStringToOString(m_settings.schema, getConnectionEncoding()).getStr());
 
     // Check if the server is 4.1 or above
-    if (this->getMysqlVersion() < 40100) {
+    if (getMysqlVersion() < 40100) {
         throw SQLException(
             "MariaDB LibreOffice Connector requires MySQL Server 4.1 or above",
             *this,
@@ -211,13 +194,12 @@ void OConnection::construct(const rtl::OUString& url, const Sequence< PropertyVa
     stmt->executeUpdate("SET NAMES utf8");
 }
 
-rtl::OUString OConnection::getImplementationName() throw (css::uno::RuntimeException, std::exception)
+rtl::OUString OConnection::getImplementationName()
 {
     return rtl::OUString("com.sun.star.sdbc.drivers.mysqlc.OConnection");
 }
 
 css::uno::Sequence<rtl::OUString> OConnection::getSupportedServiceNames()
-    throw (css::uno::RuntimeException, std::exception)
 {
     css::uno::Sequence<rtl::OUString> s(1);
     s[0] = "com.sun.star.sdbc.Connection";
@@ -225,15 +207,12 @@ css::uno::Sequence<rtl::OUString> OConnection::getSupportedServiceNames()
 }
 
 sal_Bool OConnection::supportsService(rtl::OUString const & ServiceName)
-    throw (css::uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 Reference< XStatement > SAL_CALL OConnection::createStatement()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::createStatement");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -251,9 +230,7 @@ Reference< XStatement > SAL_CALL OConnection::createStatement()
 }
 
 Reference< XPreparedStatement > SAL_CALL OConnection::prepareStatement(const rtl::OUString& _sSql)
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::prepareStatement");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
     const rtl::OUString sSqlStatement = transFormPreparedStatement( _sSql );
@@ -272,9 +249,7 @@ Reference< XPreparedStatement > SAL_CALL OConnection::prepareStatement(const rtl
 }
 
 Reference< XPreparedStatement > SAL_CALL OConnection::prepareCall(const rtl::OUString& /*_sSql*/ )
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::prepareCall");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -283,9 +258,7 @@ Reference< XPreparedStatement > SAL_CALL OConnection::prepareCall(const rtl::OUS
 }
 
 rtl::OUString SAL_CALL OConnection::nativeSQL(const rtl::OUString& _sSql)
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::nativeSQL");
     MutexGuard aGuard(m_aMutex);
 
     const rtl::OUString sSqlStatement = transFormPreparedStatement( _sSql );
@@ -300,9 +273,7 @@ rtl::OUString SAL_CALL OConnection::nativeSQL(const rtl::OUString& _sSql)
 }
 
 void SAL_CALL OConnection::setAutoCommit(sal_Bool autoCommit)
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::setAutoCommit");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
     try {
@@ -313,9 +284,7 @@ void SAL_CALL OConnection::setAutoCommit(sal_Bool autoCommit)
 }
 
 sal_Bool SAL_CALL OConnection::getAutoCommit()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::getAutoCommit");
     // you have to distinguish which if you are in autocommit mode or not
     // at normal case true should be fine here
 
@@ -332,9 +301,7 @@ sal_Bool SAL_CALL OConnection::getAutoCommit()
 }
 
 void SAL_CALL OConnection::commit()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::commit");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
     try {
@@ -345,9 +312,7 @@ void SAL_CALL OConnection::commit()
 }
 
 void SAL_CALL OConnection::rollback()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::rollback");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
     try {
@@ -358,9 +323,7 @@ void SAL_CALL OConnection::rollback()
 }
 
 sal_Bool SAL_CALL OConnection::isClosed()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::isClosed");
     MutexGuard aGuard(m_aMutex);
 
     // just simple -> we are close when we are disposed that means someone called dispose(); (XComponent)
@@ -368,9 +331,7 @@ sal_Bool SAL_CALL OConnection::isClosed()
 }
 
 Reference< XDatabaseMetaData > SAL_CALL OConnection::getMetaData()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::getMetaData");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -388,9 +349,7 @@ Reference< XDatabaseMetaData > SAL_CALL OConnection::getMetaData()
 }
 
 void SAL_CALL OConnection::setReadOnly(sal_Bool readOnly)
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::setReadOnly");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -398,9 +357,7 @@ void SAL_CALL OConnection::setReadOnly(sal_Bool readOnly)
 }
 
 sal_Bool SAL_CALL OConnection::isReadOnly()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::isReadOnly");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -409,9 +366,7 @@ sal_Bool SAL_CALL OConnection::isReadOnly()
 }
 
 void SAL_CALL OConnection::setCatalog(const rtl::OUString& catalog)
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::setCatalog");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -424,9 +379,7 @@ void SAL_CALL OConnection::setCatalog(const rtl::OUString& catalog)
 }
 
 rtl::OUString SAL_CALL OConnection::getCatalog()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::getCatalog");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -440,9 +393,7 @@ rtl::OUString SAL_CALL OConnection::getCatalog()
 }
 
 void SAL_CALL OConnection::setTransactionIsolation(sal_Int32 level)
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::setTransactionIsolation");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -475,9 +426,7 @@ void SAL_CALL OConnection::setTransactionIsolation(sal_Int32 level)
 }
 
 sal_Int32 SAL_CALL OConnection::getTransactionIsolation()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::getTransactionIsolation");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -497,9 +446,7 @@ sal_Int32 SAL_CALL OConnection::getTransactionIsolation()
 }
 
 Reference<XNameAccess> SAL_CALL OConnection::getTypeMap()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::getTypeMap");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -508,9 +455,7 @@ Reference<XNameAccess> SAL_CALL OConnection::getTypeMap()
 }
 
 void SAL_CALL OConnection::setTypeMap(const Reference<XNameAccess >& typeMap)
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::setTypeMap");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -519,9 +464,7 @@ void SAL_CALL OConnection::setTypeMap(const Reference<XNameAccess >& typeMap)
 
 // XCloseable
 void SAL_CALL OConnection::close()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::close");
     /*
       we need block, because the mutex is a local variable,
       which will guard the block
@@ -536,25 +479,20 @@ void SAL_CALL OConnection::close()
 
 // XWarningsSupplier
 Any SAL_CALL OConnection::getWarnings()
-    throw(SQLException, RuntimeException, std::exception)
 {
     Any x = Any();
-    OSL_TRACE("OConnection::getWarnings");
     // when you collected some warnings -> return it
     return x;
 }
 
 void SAL_CALL OConnection::clearWarnings()
-    throw(SQLException, RuntimeException, std::exception)
 {
-    OSL_TRACE("OConnection::clearWarnings");
     // you should clear your collected warnings here#
 }
 
 void OConnection::disposing()
 {
-    OSL_TRACE("OConnection::disposing");
-    // we noticed that we should be destroied in near future so we have to dispose our statements
+    // we noticed that we should be destroyed in near future so we have to dispose our statements
     MutexGuard aGuard(m_aMutex);
 
     for (OWeakRefArray::iterator i = m_aStatements.begin(); i != m_aStatements.end() ; ++i) {
@@ -565,46 +503,14 @@ void OConnection::disposing()
     }
     m_aStatements.clear();
 
-    m_bClosed   = true;
     m_xMetaData = WeakReference< XDatabaseMetaData >();
 
     dispose_ChildImpl();
     OConnection_BASE::disposing();
 }
 
-/* ToDo - upcast the connection to MySQL_Connection and use ::getSessionVariable() */
-
-rtl::OUString OConnection::getMysqlVariable(const char *varname)
-    throw(SQLException, RuntimeException)
-{
-    OSL_TRACE("OConnection::getMysqlVariable");
-    MutexGuard aGuard(m_aMutex);
-    checkDisposed(OConnection_BASE::rBHelper.bDisposed);
-
-    rtl::OUString ret;
-    rtl::OUStringBuffer aStatement;
-    aStatement.appendAscii( "SHOW SESSION VARIABLES LIKE '" );
-    aStatement.appendAscii( varname );
-    aStatement.append( '\'' );
-
-    try {
-        XStatement * stmt = new OStatement(this, m_settings.cppConnection->createStatement());
-        Reference< XResultSet > rs = stmt->executeQuery( aStatement.makeStringAndClear() );
-        if (rs.is() && rs->next()) {
-            Reference< XRow > xRow(rs, UNO_QUERY);
-            ret = xRow->getString(2);
-        }
-    } catch (const sql::SQLException & e) {
-        mysqlc_sdbc_driver::translateAndThrow(e, *this, getConnectionEncoding());
-    }
-
-    return ret;
-}
-
 sal_Int32 OConnection::getMysqlVersion()
-    throw(SQLException, RuntimeException)
 {
-    OSL_TRACE("OConnection::getMysqlVersion");
     MutexGuard aGuard(m_aMutex);
     checkDisposed(OConnection_BASE::rBHelper.bDisposed);
 
@@ -619,22 +525,6 @@ sal_Int32 OConnection::getMysqlVersion()
     return version;
 }
 
-// TODO: Not used
-//sal_Int32 OConnection::sdbcColumnType(rtl::OUString typeName)
-//{
-//  OSL_TRACE("OConnection::sdbcColumnType");
-//  int i = 0;
-//  while (mysqlc_types[i].typeName) {
-//      if (rtl::OUString::createFromAscii(mysqlc_types[i].typeName).equals(
-//          typeName.toAsciiUpperCase()))
-//      {
-//          return mysqlc_types[i].dataType;
-//      }
-//      i++;
-//  }
-//  return 0;
-//}
-
 rtl::OUString OConnection::transFormPreparedStatement(const rtl::OUString& _sSQL)
 {
     rtl::OUString sSqlStatement = _sSQL;
@@ -644,12 +534,12 @@ rtl::OUString OConnection::transFormPreparedStatement(const rtl::OUString& _sSQL
             Reference< XConnection> xCon = this;
             aArgs[0] <<= NamedValue(rtl::OUString("ActiveConnection"), makeAny(xCon));
 
-            m_xParameterSubstitution.set(m_rDriver.getFactory()->createInstanceWithArguments("org.openoffice.comp.helper.ParameterSubstitution",aArgs),UNO_QUERY);
+            m_xParameterSubstitution.set(m_xDriver->getFactory()->createInstanceWithArguments("org.openoffice.comp.helper.ParameterSubstitution",aArgs),UNO_QUERY);
         } catch(const Exception&) {}
     }
     if ( m_xParameterSubstitution.is() ) {
         try {
-            sSqlStatement = m_xParameterSubstitution->substituteVariables(sSqlStatement,sal_True);
+            sSqlStatement = m_xParameterSubstitution->substituteVariables(sSqlStatement,true);
         } catch(const Exception&) { }
     }
     return sSqlStatement;
