@@ -988,7 +988,7 @@ void OResultSet::setFastPropertyValue_NoBroadcast(sal_Int32 nHandle, const Any&
         case PROPERTY_ID_CURSORNAME:
         case PROPERTY_ID_RESULTSETCONCURRENCY:
         case PROPERTY_ID_RESULTSETTYPE:
-            throw Exception();
+            throw Exception("cannot set prop " + rtl::OUString::number(nHandle), nullptr);
         case PROPERTY_ID_FETCHDIRECTION:
             break;
         case PROPERTY_ID_FETCHSIZE:
@@ -1043,10 +1043,9 @@ css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL OResultSet::getProp
 
 void OResultSet::checkColumnIndex(sal_Int32 index)
 {
-    if ((index < 1 || index > (int) fieldCount)) {
+    if (index < 1 || index > (int) fieldCount) {
         /* static object for efficiency or thread safety is a problem ? */
-        rtl::OUString buf( "index out of range" );
-        throw SQLException(buf, *this, rtl::OUString(), 1, Any());
+        throw SQLException("index out of range", *this, rtl::OUString(), 1, Any());
     }
 }
 
