@@ -17,21 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/core/contexthandler.hxx"
+#include <oox/core/contexthandler.hxx>
 
-#include "oox/core/fragmenthandler.hxx"
+#include <oox/core/fragmenthandler.hxx>
 
 namespace oox {
 namespace core {
 
-// ============================================================================
-
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::xml::sax;
 
-
-// ============================================================================
-
 ContextHandler::ContextHandler( const ContextHandler& rParent ) :
     ContextHandler_BASE(),
     mxBaseData( rParent.mxBaseData )
@@ -89,41 +84,33 @@ void ContextHandler::implSetLocator( const Reference< XLocator >& rxLocator )
 
 // com.sun.star.xml.sax.XFastContextHandler interface -------------------------
 
-void ContextHandler::startFastElement( sal_Int32, const Reference< XFastAttributeList >& ) throw( SAXException, RuntimeException )
+void ContextHandler::startFastElement( sal_Int32, const Reference< XFastAttributeList >& )
 {
 }
 
-void ContextHandler::startUnknownElement( const OUString&, const OUString&, const Reference< XFastAttributeList >& ) throw( SAXException, RuntimeException )
+void ContextHandler::startUnknownElement( const OUString&, const OUString&, const Reference< XFastAttributeList >& )
 {
 }
 
-void ContextHandler::endFastElement( sal_Int32 ) throw( SAXException, RuntimeException )
+void ContextHandler::endFastElement( sal_Int32 )
 {
 }
 
-void ContextHandler::endUnknownElement( const OUString&, const OUString& ) throw( SAXException, RuntimeException )
+void ContextHandler::endUnknownElement( const OUString&, const OUString& )
 {
 }
 
-Reference< XFastContextHandler > ContextHandler::createFastChildContext( sal_Int32, const Reference< XFastAttributeList >& ) throw( SAXException, RuntimeException )
+Reference< XFastContextHandler > ContextHandler::createFastChildContext( sal_Int32, const Reference< XFastAttributeList >& )
 {
-    return 0;
+    return nullptr;
 }
 
-Reference< XFastContextHandler > ContextHandler::createUnknownChildContext( const OUString&, const OUString&, const Reference< XFastAttributeList >& ) throw( SAXException, RuntimeException )
+Reference< XFastContextHandler > ContextHandler::createUnknownChildContext( const OUString&, const OUString&, const Reference< XFastAttributeList >& )
 {
-    return 0;
+    return nullptr;
 }
 
-void ContextHandler::characters( const OUString& ) throw( SAXException, RuntimeException )
-{
-}
-
-void ContextHandler::ignorableWhitespace( const OUString& ) throw( SAXException, RuntimeException )
-{
-}
-
-void ContextHandler::processingInstruction( const OUString&, const OUString& ) throw( SAXException, RuntimeException )
+void ContextHandler::characters( const OUString& )
 {
 }
 
@@ -131,7 +118,7 @@ void ContextHandler::processingInstruction( const OUString&, const OUString& ) t
 
 ContextHandlerRef ContextHandler::createRecordContext( sal_Int32, SequenceInputStream& )
 {
-    return 0;
+    return nullptr;
 }
 
 void ContextHandler::startRecord( sal_Int32, SequenceInputStream& )
@@ -142,8 +129,6 @@ void ContextHandler::endRecord( sal_Int32 )
 {
 }
 
-// ============================================================================
-
 } // namespace core
 } // namespace oox
 
