@@ -19,10 +19,10 @@
 
 #include <sal/config.h>
 
-#include <boost/noncopyable.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/drawing/XShape.hpp>
 #include <com/sun/star/frame/XModel.hpp>
+#include <com/sun/star/io/XStream.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/task/XInteractionHandler.hpp>
 #include <com/sun/star/task/XStatusIndicator.hpp>
@@ -37,13 +37,13 @@
 #include <memory>
 #include <set>
 
-#include "oox/core/filterbase.hxx"
-#include "oox/helper/binaryinputstream.hxx"
-#include "oox/helper/binaryoutputstream.hxx"
-#include "oox/helper/graphichelper.hxx"
-#include "oox/helper/modelobjecthelper.hxx"
-#include "oox/ole/oleobjecthelper.hxx"
-#include "oox/ole/vbaproject.hxx"
+#include <oox/core/filterbase.hxx>
+#include <oox/helper/binaryinputstream.hxx>
+#include <oox/helper/binaryoutputstream.hxx>
+#include <oox/helper/graphichelper.hxx>
+#include <oox/helper/modelobjecthelper.hxx>
+#include <oox/ole/oleobjecthelper.hxx>
+#include <oox/ole/vbaproject.hxx>
 
 namespace oox {
 namespace core {
@@ -74,13 +74,15 @@ struct UrlPool
 struct StaticUrlPool : public ::rtl::Static< UrlPool, StaticUrlPool > {};
 
 /** This guard prevents recursive loading/saving of the same document. */
-class DocumentOpenedGuard: private boost::noncopyable
+class DocumentOpenedGuard
 {
 public:
     explicit            DocumentOpenedGuard( const OUString& rUrl );
                         ~DocumentOpenedGuard();
+                        DocumentOpenedGuard(const DocumentOpenedGuard&) = delete;
+    DocumentOpenedGuard& operator=(const DocumentOpenedGuard&) = delete;
 
-    inline bool         isValid() const { return mbValid; }
+    bool         isValid() const { return mbValid; }
 
 private:
     OUString            maUrl;
@@ -138,7 +140,6 @@ struct FilterBaseImpl
     VbaProjectRef       mxVbaProject;           /// VBA project manager.
 
     Reference< XComponentContext >      mxComponentContext;
-    Reference< XMultiComponentFactory > mxComponentFactory;
     Reference< XModel >                 mxModel;
     Reference< XMultiServiceFactory >   mxModelFactory;
     Reference< XFrame >                 mxTargetFrame;
@@ -150,23 +151,24 @@ struct FilterBaseImpl
 
     bool mbExportVBA;
 
-    explicit            FilterBaseImpl( const Reference< XComponentContext >& rxContext ) throw( RuntimeException );
+    /// @throws RuntimeException
+    explicit            FilterBaseImpl( const Reference< XComponentContext >& rxContext );
 
-    void                setDocumentModel( const Reference< XComponent >& rxComponent ) throw( IllegalArgumentException );
+    /// @throws IllegalArgumentException
+    void                setDocumentModel( const Reference< XComponent >& rxComponent );
 
     void                initializeFilter();
 };
 
-FilterBaseImpl::FilterBaseImpl( const Reference< XComponentContext >& rxContext ) throw( RuntimeException ) :
+FilterBaseImpl::FilterBaseImpl( const Reference< XComponentContext >& rxContext ) :
     meDirection( FILTERDIRECTION_UNKNOWN ),
     meVersion( ECMA_DIALECT ),
     mxComponentContext( rxContext, UNO_SET_THROW ),
-    mxComponentFactory( rxContext->getServiceManager(), UNO_SET_THROW ),
     mbExportVBA(false)
 {
 }
 
-void FilterBaseImpl::setDocumentModel( const Reference< XComponent >& rxComponent ) throw( IllegalArgumentException )
+void FilterBaseImpl::setDocumentModel( const Reference< XComponent >& rxComponent )
 {
     try
     {
@@ -191,7 +193,7 @@ void FilterBaseImpl::initializeFilter()
     }
 }
 
-FilterBase::FilterBase( const Reference< XComponentContext >& rxContext ) throw( RuntimeException ) :
+FilterBase::FilterBase( const Reference< XComponentContext >& rxContext ) :
     mxImpl( new FilterBaseImpl( rxContext ) )
 {
 }
@@ -377,7 +379,7 @@ VbaProject& FilterBase::getVbaProject() const
     return *mxImpl->mxVbaProject;
 }
 
-bool FilterBase::importBinaryData( StreamDataSequence& orDataSeq, const OUString& rStreamName )
+bool FilterBase::importBinaryData( StreamDataSequence & orDataSeq, const OUString& rStreamName )
 {
     OSL_ENSURE( !rStreamName.isEmpty(), "FilterBase::importBinaryData - empty stream name" );
     if( rStreamName.isEmpty() )
@@ -396,12 +398,12 @@ bool FilterBase::importBinaryData( StreamDataSequence& orDataSeq, const OUString
 
 // com.sun.star.lang.XServiceInfo interface
 
-sal_Bool SAL_CALL FilterBase::supportsService( const OUString& rServiceName ) throw( RuntimeException, std::exception )
+sal_Bool SAL_CALL FilterBase::supportsService( const OUString& rServiceName )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
-Sequence< OUString > SAL_CALL FilterBase::getSupportedServiceNames() throw( RuntimeException, std::exception )
+Sequence< OUString > SAL_CALL FilterBase::getSupportedServiceNames()
 {
     Sequence< OUString > aServiceNames( 2 );
     aServiceNames[ 0 ] = "com.sun.star.document.ImportFilter";
@@ -411,7 +413,7 @@ Sequence< OUString > SAL_CALL FilterBase::getSupportedServiceNames() throw( Runt
 
 // com.sun.star.lang.XInitialization interface
 
-void SAL_CALL FilterBase::initialize( const Sequence< Any >& rArgs ) throw( Exception, RuntimeException, std::exception )
+void SAL_CALL FilterBase::initialize( const Sequence< Any >& rArgs )
 {
     if( rArgs.getLength() >= 2 ) try
     {
@@ -448,7 +450,7 @@ void SAL_CALL FilterBase::initialize( const Sequence< Any >& rArgs ) throw( Exce
 
 // com.sun.star.document.XImporter interface
 
-void SAL_CALL FilterBase::setTargetDocument( const Reference< XComponent >& rxDocument ) throw( IllegalArgumentException, RuntimeException, std::exception )
+void SAL_CALL FilterBase::setTargetDocument( const Reference< XComponent >& rxDocument )
 {
     mxImpl->setDocumentModel( rxDocument );
     mxImpl->meDirection = FILTERDIRECTION_IMPORT;
@@ -456,7 +458,7 @@ void SAL_CALL FilterBase::setTargetDocument( const Reference< XComponent >& rxDo
 
 // com.sun.star.document.XExporter interface
 
-void SAL_CALL FilterBase::setSourceDocument( const Reference< XComponent >& rxDocument ) throw( IllegalArgumentException, RuntimeException, std::exception )
+void SAL_CALL FilterBase::setSourceDocument( const Reference< XComponent >& rxDocument )
 {
     mxImpl->setDocumentModel( rxDocument );
     mxImpl->meDirection = FILTERDIRECTION_EXPORT;
@@ -464,7 +466,7 @@ void SAL_CALL FilterBase::setSourceDocument( const Reference< XComponent >& rxDo
 
 // com.sun.star.document.XFilter interface
 
-sal_Bool SAL_CALL FilterBase::filter( const Sequence< PropertyValue >& rMediaDescSeq ) throw( RuntimeException, std::exception )
+sal_Bool SAL_CALL FilterBase::filter( const Sequence< PropertyValue >& rMediaDescSeq )
 {
     if( !mxImpl->mxModel.is() || !mxImpl->mxModelFactory.is() || (mxImpl->meDirection == FILTERDIRECTION_UNKNOWN) )
         throw RuntimeException();
@@ -499,7 +501,7 @@ sal_Bool SAL_CALL FilterBase::filter( const Sequence< PropertyValue >& rMediaDes
     return bRet;
 }
 
-void SAL_CALL FilterBase::cancel() throw( RuntimeException, std::exception )
+void SAL_CALL FilterBase::cancel()
 {
 }
 
