@@ -17,30 +17,31 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/drawingml/chart/objectformatter.hxx"
+#include <drawingml/chart/objectformatter.hxx>
 
+#include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/util/XNumberFormatsSupplier.hpp>
 #include <com/sun/star/util/XNumberFormatTypes.hpp>
 #include <osl/thread.h>
+#include <osl/diagnose.h>
 #include <rtl/strbuf.hxx>
-#include "oox/core/xmlfilterbase.hxx"
-#include "oox/drawingml/fillproperties.hxx"
-#include "oox/drawingml/lineproperties.hxx"
-#include "oox/drawingml/shapepropertymap.hxx"
-#include "oox/drawingml/textbody.hxx"
-#include "oox/drawingml/textparagraph.hxx"
-#include "oox/drawingml/theme.hxx"
-#include "oox/drawingml/chart/chartspacemodel.hxx"
-#include "oox/helper/modelobjecthelper.hxx"
+#include <oox/core/xmlfilterbase.hxx>
+#include <drawingml/fillproperties.hxx>
+#include <drawingml/lineproperties.hxx>
+#include <oox/drawingml/shapepropertymap.hxx>
+#include <drawingml/textbody.hxx>
+#include <drawingml/textparagraph.hxx>
+#include <oox/drawingml/theme.hxx>
+#include <drawingml/chart/chartspacemodel.hxx>
+#include <oox/helper/modelobjecthelper.hxx>
+#include <oox/helper/graphichelper.hxx>
+#include <oox/token/properties.hxx>
 
 namespace oox {
 namespace drawingml {
 namespace chart {
 
-
-
 using namespace ::com::sun::star::chart2;
-using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::graphic;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::uno;
@@ -48,8 +49,6 @@ using namespace ::com::sun::star::util;
 
 using ::oox::core::XmlFilterBase;
 
-
-
 namespace {
 
 struct AutoFormatPatternEntry
@@ -116,8 +115,6 @@ static const AutoFormatPatternEntry spAutoFormatPattern4[] =
 #undef AUTOFORMAT_PATTERN_COLORMOD
 #undef AUTOFORMAT_PATTERN_END
 
-
-
 struct AutoFormatEntry
 {
     sal_Int32           mnFirstStyleIdx;    /// First chart style index.
@@ -132,10 +129,10 @@ struct AutoFormatEntry
 };
 
 #define AUTOFORMAT_COLOR( first, last, themed_style, color_token ) \
-    { first, last, themed_style, color_token, XML_TOKEN_INVALID, 0, 100, 0, false }
+    { first, last, themed_style, color_token, XML_TOKEN_INVALID, 0, 100, nullptr, false }
 
 #define AUTOFORMAT_COLORMOD( first, last, themed_style, color_token, mod_token, mod_value ) \
-    { first, last, themed_style, color_token, mod_token, mod_value, 100, 0, false }
+    { first, last, themed_style, color_token, mod_token, mod_value, 100, nullptr, false }
 
 #define AUTOFORMAT_ACCENTSMOD( first, themed_style, mod_token, mod_value ) \
     AUTOFORMAT_COLORMOD( first,     first,     themed_style, XML_accent1, mod_token, mod_value ), \
@@ -149,7 +146,7 @@ struct AutoFormatEntry
     { first, last, themed_style, XML_TOKEN_INVALID, XML_TOKEN_INVALID, 0, line_width, pattern, false }
 
 #define AUTOFORMAT_FADED( first, last, themed_style, color_token, line_width ) \
-    { first, last, themed_style, color_token, XML_TOKEN_INVALID, 0, line_width, 0, true }
+    { first, last, themed_style, color_token, XML_TOKEN_INVALID, 0, line_width, nullptr, true }
 
 #define AUTOFORMAT_FADEDACCENTS( first, themed_style, line_width ) \
     AUTOFORMAT_FADED( first,     first,     themed_style, XML_accent1, line_width ), \
@@ -171,6 +168,14 @@ static const AutoFormatEntry spNoFormats[] =
     AUTOFORMAT_END()
 };
 
+static const AutoFormatEntry spChartSpaceFill[] =
+{
+    AUTOFORMAT_COLOR( 1, 32, THEMED_STYLE_SUBTLE, XML_bg1 ),
+    AUTOFORMAT_COLOR( 33, 40, THEMED_STYLE_SUBTLE, XML_lt1 ),
+    AUTOFORMAT_COLOR( 41, 48, THEMED_STYLE_SUBTLE, XML_dk1 ),
+    AUTOFORMAT_END()
+};
+
 static const AutoFormatEntry spDataTableLines[] =
 {
     AUTOFORMAT_COLORMOD(  1, 32, THEMED_STYLE_SUBTLE, XML_tx1, XML_tint, 75000 ),
@@ -316,17 +321,6 @@ static const AutoFormatEntry spFilledSeries3dFills[] =
     AUTOFORMAT_END()
 };
 
-static const AutoFormatEntry spFilledSeriesEffects[] =
-{
-    // 1...8: no effect, same as Chart2
-    AUTOFORMAT_COLOR(  9, 16, THEMED_STYLE_SUBTLE,   XML_dk1 ),
-    AUTOFORMAT_COLOR( 17, 24, THEMED_STYLE_MODERATE, XML_dk1 ),
-    AUTOFORMAT_COLOR( 25, 32, THEMED_STYLE_INTENSE,  XML_dk1 ),
-    // 33...40: no effect, same as Chart2
-    AUTOFORMAT_COLOR( 41, 48, THEMED_STYLE_INTENSE,  XML_dk1 ),
-    AUTOFORMAT_END()
-};
-
 static const AutoFormatEntry spUpDownBarLines[] =
 {
     AUTOFORMAT_COLOR(       1, 16, THEMED_STYLE_SUBTLE, XML_tx1 ),
@@ -374,24 +368,13 @@ static const AutoFormatEntry spDownBarFills[] =
     AUTOFORMAT_ACCENTSMOD( 27,     THEMED_STYLE_INTENSE,          XML_shade, 25000 ),
     AUTOFORMAT_COLORMOD(   33, 33, THEMED_STYLE_SUBTLE,  XML_dk1, XML_tint,  85000 ),
     AUTOFORMAT_COLORMOD(   34, 34, THEMED_STYLE_SUBTLE,  XML_dk1, XML_tint,  95000 ),
-    AUTOFORMAT_ACCENTSMOD( 27,     THEMED_STYLE_SUBTLE,           XML_shade, 25000 ),
+    AUTOFORMAT_ACCENTSMOD( 35,     THEMED_STYLE_SUBTLE,           XML_shade, 25000 ),
     AUTOFORMAT_COLORMOD(   41, 41, THEMED_STYLE_INTENSE, XML_dk1, XML_tint,  85000 ),
     AUTOFORMAT_COLOR(      42, 42, THEMED_STYLE_INTENSE, XML_dk1 ),
     AUTOFORMAT_ACCENTSMOD( 43,     THEMED_STYLE_INTENSE,          XML_shade, 25000 ),
     AUTOFORMAT_END()
 };
 
-static const AutoFormatEntry spUpDownBarEffects[] =
-{
-    // 1...8: no effect, same as Chart2
-    AUTOFORMAT_COLOR(  9, 16, THEMED_STYLE_SUBTLE,   XML_dk1 ),
-    AUTOFORMAT_COLOR( 17, 24, THEMED_STYLE_MODERATE, XML_dk1 ),
-    AUTOFORMAT_COLOR( 25, 32, THEMED_STYLE_INTENSE,  XML_dk1 ),
-    // 33...40: no effect, same as Chart2
-    AUTOFORMAT_COLOR( 41, 48, THEMED_STYLE_INTENSE,  XML_dk1 ),
-    AUTOFORMAT_END()
-};
-
 #undef AUTOFORMAT_COLOR
 #undef AUTOFORMAT_COLORMOD
 #undef AUTOFORMAT_ACCENTSMOD
@@ -406,11 +389,9 @@ const AutoFormatEntry* lclGetAutoFormatEntry( const AutoFormatEntry* pEntries, s
     for( ; pEntries && (pEntries->mnFirstStyleIdx >= 0); ++pEntries )
         if( (pEntries->mnFirstStyleIdx <= nStyle) && (nStyle <= pEntries->mnLastStyleIdx) )
             return pEntries;
-    return 0;
+    return nullptr;
 }
 
-
-
 struct AutoTextEntry
 {
     sal_Int32           mnFirstStyleIdx;    /// First chart style index.
@@ -457,35 +438,30 @@ const AutoTextEntry* lclGetAutoTextEntry( const AutoTextEntry* pEntries, sal_Int
     for( ; pEntries && (pEntries->mnFirstStyleIdx >= 0); ++pEntries )
         if( (pEntries->mnFirstStyleIdx <= nStyle) && (nStyle <= pEntries->mnLastStyleIdx) )
             return pEntries;
-    return 0;
+    return nullptr;
 }
 
-// These PropIds arrays will be indexed into using a ShapePropertyId enum (include/oox/drawingml/shapepropertymap.hxx)
+// These PropIds arrays will be indexed into using a ShapeProperty enum
 
-/** Property identifiers for common chart objects, to be used in ShapePropertyInfo. */
-static const sal_Int32 spnCommonPropIds[] =
+static const ShapePropertyIds spnCommonPropIds =
 {
     PROP_LineStyle, PROP_LineWidth, PROP_LineColor, PROP_LineTransparence, PROP_LineDashName,
     PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID,
     PROP_FillStyle, PROP_FillColor, PROP_FillTransparence, PROP_INVALID, PROP_FillGradientName,
     PROP_FillBitmapName, PROP_FillBitmapMode, PROP_FillBitmapSizeX, PROP_FillBitmapSizeY,
-    PROP_FillBitmapPositionOffsetX, PROP_FillBitmapPositionOffsetY, PROP_FillBitmapRectanglePoint,
-    PROP_END_LIST
+    PROP_FillBitmapPositionOffsetX, PROP_FillBitmapPositionOffsetY, PROP_FillBitmapRectanglePoint
 };
 
-/** Property identifiers for linear data series, to be used in ShapePropertyInfo. */
-static const sal_Int32 spnLinearPropIds[] =
+static const ShapePropertyIds spnLinearPropIds =
 {
     PROP_LineStyle, PROP_LineWidth, PROP_Color, PROP_Transparency, PROP_LineDashName,
     PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID,
     PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID,
     PROP_INVALID, PROP_INVALID, PROP_INVALID, PROP_INVALID,
-    PROP_INVALID, PROP_INVALID, PROP_INVALID,
-    PROP_END_LIST
+    PROP_INVALID, PROP_INVALID, PROP_INVALID
 };
 
-/** Property identifiers for filled data series, to be used in ShapePropertyInfo. */
-static const sal_Int32 spnFilledPropIds[] =
+static const ShapePropertyIds spnFilledPropIds =
 {
     PROP_BorderStyle,
     PROP_BorderWidth,
@@ -502,7 +478,7 @@ static const sal_Int32 spnFilledPropIds[] =
     PROP_FillStyle,
     PROP_Color,
     PROP_Transparency,
-    PROP_INVALID,
+    PROP_FillTransparenceGradientName,
     PROP_GradientName,
     PROP_FillBitmapName,
     PROP_FillBitmapMode,
@@ -511,7 +487,7 @@ static const sal_Int32 spnFilledPropIds[] =
     PROP_FillBitmapPositionOffsetX,
     PROP_FillBitmapPositionOffsetY,
     PROP_FillBitmapRectanglePoint,
-    PROP_END_LIST
+    PROP_FillHatch
 };
 
 /** Property info for common chart objects, to be used in ShapePropertyMap. */
@@ -521,62 +497,65 @@ static const ShapePropertyInfo saLinearPropInfo( spnLinearPropIds, false, true,
 /** Property info for filled data series, to be used in ShapePropertyMap. */
 static const ShapePropertyInfo saFilledPropInfo( spnFilledPropIds, false, true, true, true );
 
-
-
 /** Contains information about formatting of a specific chart object type. */
 struct ObjectTypeFormatEntry
 {
     ObjectType          meObjType;          /// Object type for automatic format.
-    const ShapePropertyInfo* mpPropInfo;    /// Property info for the ShapePropertyMap class.
+    const ShapePropertyInfo& mrPropInfo;    /// Property info for the ShapePropertyMap class.
     const AutoFormatEntry* mpAutoLines;     /// Automatic line formatting for all chart styles.
     const AutoFormatEntry* mpAutoFills;     /// Automatic fill formatting for all chart styles.
-    const AutoFormatEntry* mpAutoEffects;   /// Automatic effect formatting for all chart styles.
     const AutoTextEntry* mpAutoTexts;       /// Automatic text attributes for all chart styles.
     bool                mbIsFrame;          /// True = object is a frame, false = object is a line.
+    ObjectTypeFormatEntry(ObjectType eObjType, const ShapePropertyInfo& rPropInfo,
+                                 const AutoFormatEntry* pAutoLines,
+                                 const AutoFormatEntry* pAutoFills,
+                                 const AutoTextEntry* pAutoTexts,
+                                 bool bIsFrame)
+        :meObjType(eObjType), mrPropInfo(rPropInfo), mpAutoLines(pAutoLines)
+        ,mpAutoFills(pAutoFills), mpAutoTexts(pAutoTexts), mbIsFrame(bIsFrame)
+    {} // prevent creation of implicit default ctor which fails in MSVC
 };
 
-#define TYPEFORMAT_FRAME( obj_type, prop_type, auto_texts, auto_lines, auto_fills, auto_effects ) \
-    { obj_type, prop_type, auto_lines, auto_fills, auto_effects, auto_texts, true }
+#define TYPEFORMAT_FRAME( obj_type, prop_type, auto_texts, auto_lines, auto_fills ) \
+    { obj_type, prop_type, auto_lines, auto_fills, auto_texts, true }
 
 #define TYPEFORMAT_LINE( obj_type, prop_type, auto_texts, auto_lines ) \
-    { obj_type, prop_type, auto_lines, 0, 0, auto_texts, false }
+    { obj_type, prop_type, auto_lines, nullptr,  auto_texts, false }
 
 static const ObjectTypeFormatEntry spObjTypeFormatEntries[] =
 {
-    //                object type                property info      auto text          auto line            auto fill              auto effect
-    TYPEFORMAT_FRAME( OBJECTTYPE_CHARTSPACE,     &saCommonPropInfo, 0,                 spNoFormats,         spNoFormats,           0 /* eq to Ch2 */ ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_CHARTTITLE,     &saCommonPropInfo, spChartTitleTexts, 0 /* eq to Ch2 */,   0 /* eq to Ch2 */,     0 /* eq to Ch2 */ ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_LEGEND,         &saCommonPropInfo, spOtherTexts,      spNoFormats,         spNoFormats,           0 /* eq to Ch2 */ ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_PLOTAREA2D,     &saCommonPropInfo, 0,                 0 /* eq to Ch2 */,   spPlotArea2dFills,     0 /* eq to Ch2 */ ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_PLOTAREA3D,     &saCommonPropInfo, 0,                 0 /* eq to Ch2 */,   0 /* eq to Ch2 */,     0 /* eq to Ch2 */ ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_WALL,           &saCommonPropInfo, 0,                 spWallFloorLines,    spWallFloorFills,      0 /* eq to Ch2 */ ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_FLOOR,          &saCommonPropInfo, 0,                 spWallFloorLines,    spWallFloorFills,      0 /* eq to Ch2 */ ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_AXIS,           &saCommonPropInfo, spOtherTexts,      spAxisLines ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_AXISTITLE,      &saCommonPropInfo, spAxisTitleTexts,  0 /* eq to Ch2 */,   0 /* eq to Ch2 */,     0 /* eq to Ch2 */ ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_AXISUNIT,       &saCommonPropInfo, spAxisTitleTexts,  0 /* eq in Ch2 */,   0 /* eq in Ch2 */,     0 /* eq in Ch2 */ ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_MAJORGRIDLINE,  &saCommonPropInfo, 0,                 spMajorGridLines ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_MINORGRIDLINE,  &saCommonPropInfo, 0,                 spMinorGridLines ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_LINEARSERIES2D, &saLinearPropInfo, 0,                 spLinearSeriesLines ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_FILLEDSERIES2D, &saFilledPropInfo, 0,                 spFilledSeriesLines, spFilledSeries2dFills, spFilledSeriesEffects ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_FILLEDSERIES3D, &saFilledPropInfo, 0,                 spFilledSeriesLines, spFilledSeries3dFills, spFilledSeriesEffects ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_DATALABEL,      &saCommonPropInfo, spOtherTexts,      0 /* eq to Ch2 */,   0 /* eq to Ch2 */,     0 /* eq to Ch2 */ ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_TRENDLINE,      &saCommonPropInfo, 0,                 spOtherLines ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_TRENDLINELABEL, &saCommonPropInfo, spOtherTexts,      0 /* eq to Ch2 */,   0 /* eq to Ch2 */,     0 /* eq to Ch2 */ ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_ERRORBAR,       &saCommonPropInfo, 0,                 spOtherLines ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_SERLINE,        &saCommonPropInfo, 0,                 spOtherLines ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_LEADERLINE,     &saCommonPropInfo, 0,                 spOtherLines ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_DROPLINE,       &saCommonPropInfo, 0,                 spOtherLines ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_HILOLINE,       &saLinearPropInfo, 0,                 spOtherLines ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_UPBAR,          &saCommonPropInfo, 0,                 spUpDownBarLines,    spUpBarFills,          spUpDownBarEffects ),
-    TYPEFORMAT_FRAME( OBJECTTYPE_DOWNBAR,        &saCommonPropInfo, 0,                 spUpDownBarLines,    spDownBarFills,        spUpDownBarEffects ),
-    TYPEFORMAT_LINE(  OBJECTTYPE_DATATABLE,      &saCommonPropInfo, spOtherTexts,      spDataTableLines )
+    //                object type                property info      auto text          auto line            auto fill
+    TYPEFORMAT_FRAME( OBJECTTYPE_CHARTSPACE,     saCommonPropInfo, nullptr,                 spNoFormats,         spChartSpaceFill ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_CHARTTITLE,     saCommonPropInfo, spChartTitleTexts, nullptr /* eq to Ch2 */,   nullptr /* eq to Ch2 */),
+    TYPEFORMAT_FRAME( OBJECTTYPE_LEGEND,         saCommonPropInfo, spOtherTexts,      spNoFormats,         spNoFormats ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_PLOTAREA2D,     saCommonPropInfo, nullptr,                 nullptr /* eq to Ch2 */,   spPlotArea2dFills ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_PLOTAREA3D,     saCommonPropInfo, nullptr,                 nullptr /* eq to Ch2 */,   nullptr /* eq to Ch2 */ ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_WALL,           saCommonPropInfo, nullptr,                 spWallFloorLines,    spWallFloorFills ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_FLOOR,          saCommonPropInfo, nullptr,                 spWallFloorLines,    spWallFloorFills ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_AXIS,           saCommonPropInfo, spOtherTexts,      spAxisLines ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_AXISTITLE,      saCommonPropInfo, spAxisTitleTexts,  nullptr /* eq to Ch2 */,   nullptr /* eq to Ch2 */ ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_AXISUNIT,       saCommonPropInfo, spAxisTitleTexts,  nullptr /* eq in Ch2 */,   nullptr /* eq in Ch2 */ ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_MAJORGRIDLINE,  saCommonPropInfo, nullptr,                 spMajorGridLines ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_MINORGRIDLINE,  saCommonPropInfo, nullptr,                 spMinorGridLines ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_LINEARSERIES2D, saLinearPropInfo, nullptr,                 spLinearSeriesLines ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_FILLEDSERIES2D, saFilledPropInfo, nullptr,                 spFilledSeriesLines, spFilledSeries2dFills ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_FILLEDSERIES3D, saFilledPropInfo, nullptr,                 spFilledSeriesLines, spFilledSeries3dFills ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_DATALABEL,      saCommonPropInfo, spOtherTexts,      nullptr /* eq to Ch2 */,   nullptr /* eq to Ch2 */ ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_TRENDLINE,      saCommonPropInfo, nullptr,                 spOtherLines ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_TRENDLINELABEL, saCommonPropInfo, spOtherTexts,      nullptr /* eq to Ch2 */,   nullptr /* eq to Ch2 */ ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_ERRORBAR,       saCommonPropInfo, nullptr,                 spOtherLines ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_SERLINE,        saCommonPropInfo, nullptr,                 spOtherLines ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_LEADERLINE,     saCommonPropInfo, nullptr,                 spOtherLines ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_DROPLINE,       saCommonPropInfo, nullptr,                 spOtherLines ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_HILOLINE,       saLinearPropInfo, nullptr,                 spOtherLines ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_UPBAR,          saCommonPropInfo, nullptr,                 spUpDownBarLines,    spUpBarFills ),
+    TYPEFORMAT_FRAME( OBJECTTYPE_DOWNBAR,        saCommonPropInfo, nullptr,                 spUpDownBarLines,    spDownBarFills ),
+    TYPEFORMAT_LINE(  OBJECTTYPE_DATATABLE,      saCommonPropInfo, spOtherTexts,      spDataTableLines )
 };
 
 #undef TYPEFORMAT_FRAME
 #undef TYPEFORMAT_LINE
 
-
-
 void lclConvertPictureOptions( FillProperties& orFillProps, const PictureOptionsModel& rPicOptions )
 {
     bool bStacked = (rPicOptions.mnPictureFormat == XML_stack) || (rPicOptions.mnPictureFormat == XML_stackScale);
@@ -585,12 +564,8 @@ void lclConvertPictureOptions( FillProperties& orFillProps, const PictureOptions
 
 } // namespace
 
-
-
 struct ObjectFormatterData;
 
-
-
 class DetailFormatterBase
 {
 public:
@@ -617,8 +592,6 @@ protected:
     ColorPatternVec     maColorPattern;     /// Different cycling colors for data series.
 };
 
-
-
 class LineFormatter : public DetailFormatterBase
 {
 public:
@@ -636,14 +609,13 @@ private:
     LinePropertiesPtr   mxAutoLine;         /// Automatic line properties.
 };
 
-
-
 class FillFormatter : public DetailFormatterBase
 {
 public:
     explicit            FillFormatter(
                             ObjectFormatterData& rData,
-                            const AutoFormatEntry* pAutoFormatEntry );
+                            const AutoFormatEntry* pAutoFormatEntry,
+                            const ObjectType eObjType );
 
     /** Converts area formatting to the passed property set. */
     void                convertFormatting(
@@ -656,24 +628,6 @@ private:
     FillPropertiesPtr   mxAutoFill;         /// Automatic fill properties.
 };
 
-
-
-class EffectFormatter : public DetailFormatterBase
-{
-public:
-    explicit            EffectFormatter(
-                            ObjectFormatterData& rData,
-                            const AutoFormatEntry* pAutoFormatEntry );
-
-    /** Converts effect formatting to the passed property set. */
-    void                convertFormatting(
-                            ShapePropertyMap& rPropMap,
-                            const ModelRef< Shape >& rxShapeProp,
-                            sal_Int32 nSeriesIdx ) const;
-};
-
-
-
 class TextFormatter : public DetailFormatterBase
 {
 public:
@@ -695,8 +649,6 @@ private:
     TextCharacterPropertiesPtr mxAutoText;  /// Automatic text properties.
 };
 
-
-
 /** Formatter for a specific object type. */
 class ObjectTypeFormatter
 {
@@ -704,7 +656,8 @@ public:
     explicit            ObjectTypeFormatter(
                             ObjectFormatterData& rData,
                             const ObjectTypeFormatEntry& rEntry,
-                            const ChartSpaceModel& rChartSpace );
+                            const ChartSpaceModel& rChartSpace,
+                            const ObjectType eObjType );
 
     /** Sets frame formatting properties to the passed property set. */
     void                convertFrameFormatting(
@@ -737,14 +690,11 @@ public:
 private:
     LineFormatter       maLineFormatter;    /// Converter for line formatting.
     FillFormatter       maFillFormatter;    /// Converter for fill formatting.
-    EffectFormatter     maEffectFormatter;  /// Converter for effect formatting.
     TextFormatter       maTextFormatter;    /// Converter for text formatting.
     ModelObjectHelper&  mrModelObjHelper;   /// Helper for named drawing formatting.
     const ObjectTypeFormatEntry& mrEntry;   /// Additional settings.
 };
 
-
-
 struct ObjectFormatterData
 {
     typedef RefMap< ObjectType, ObjectTypeFormatter > ObjectTypeFormatterMap;
@@ -766,8 +716,6 @@ struct ObjectFormatterData
     ObjectTypeFormatter* getTypeFormatter( ObjectType eObjType );
 };
 
-
-
 DetailFormatterBase::DetailFormatterBase( ObjectFormatterData& rData, const AutoFormatEntry* pAutoFormatEntry ) :
     mrData( rData ),
     mnPhClr( -1 )
@@ -858,8 +806,6 @@ sal_Int32 DetailFormatterBase::getSchemeColor( sal_Int32 nColorToken, sal_Int32
     return aColor.getColor( mrData.mrFilter.getGraphicHelper() );
 }
 
-
-
 LineFormatter::LineFormatter( ObjectFormatterData& rData, const AutoFormatEntry* pAutoFormatEntry ) :
     DetailFormatterBase( rData, pAutoFormatEntry )
 {
@@ -886,18 +832,22 @@ void LineFormatter::convertFormatting( ShapePropertyMap& rPropMap, const ModelRe
     aLineProps.pushToPropMap( rPropMap, mrData.mrFilter.getGraphicHelper(), getPhColor( nSeriesIdx ) );
 }
 
-
-
-FillFormatter::FillFormatter( ObjectFormatterData& rData, const AutoFormatEntry* pAutoFormatEntry ) :
+FillFormatter::FillFormatter( ObjectFormatterData& rData, const AutoFormatEntry* pAutoFormatEntry, const ObjectType eObjType ) :
     DetailFormatterBase( rData, pAutoFormatEntry )
 {
     if( pAutoFormatEntry )
     {
         mxAutoFill.reset( new FillProperties );
-        mxAutoFill->moFillType = XML_noFill;
+        if( eObjType != OBJECTTYPE_CHARTSPACE )
+            mxAutoFill->moFillType = XML_noFill;
         if( const Theme* pTheme = mrData.mrFilter.getCurrentTheme() )
             if( const FillProperties* pFillProps = pTheme->getFillStyle( pAutoFormatEntry->mnThemedIdx ) )
                 *mxAutoFill = *pFillProps;
+
+        if (eObjType == OBJECTTYPE_CHARTSPACE)
+        {
+            mxAutoFill->moFillType = rData.mrFilter.getGraphicHelper().getDefaultChartAreaFillStyle();
+        }
     }
 }
 
@@ -913,25 +863,12 @@ void FillFormatter::convertFormatting( ShapePropertyMap& rPropMap, const ModelRe
     aFillProps.pushToPropMap( rPropMap, mrData.mrFilter.getGraphicHelper(), 0, getPhColor( nSeriesIdx ) );
 }
 
-
-
-EffectFormatter::EffectFormatter( ObjectFormatterData& rData, const AutoFormatEntry* pAutoFormatEntry ) :
-    DetailFormatterBase( rData, pAutoFormatEntry )
-{
-}
-//TODO :
-void EffectFormatter::convertFormatting( ShapePropertyMap& /*rPropMap*/, const ModelRef< Shape >& /*rxShapeProp*/, sal_Int32 /*nSeriesIdx*/ ) const
-{
-}
-
-
-
 namespace {
 
 const TextCharacterProperties* lclGetTextProperties( const ModelRef< TextBody >& rxTextProp )
 {
     return (rxTextProp.is() && !rxTextProp->getParagraphs().empty()) ?
-        &rxTextProp->getParagraphs().front()->getProperties().getTextCharacterProperties() : 0;
+        &rxTextProp->getParagraphs().front()->getProperties().getTextCharacterProperties() : nullptr;
 }
 
 } // namespace
@@ -946,8 +883,10 @@ TextFormatter::TextFormatter( ObjectFormatterData& rData, const AutoTextEntry* p
             if( const TextCharacterProperties* pTextProps = pTheme->getFontStyle( pAutoTextEntry->mnThemedFont ) )
                 *mxAutoText = *pTextProps;
         sal_Int32 nTextColor = getPhColor( -1 );
-        if( nTextColor >= 0 )
-            mxAutoText->maCharColor.setSrgbClr( nTextColor );
+        if( nTextColor >= 0 ) {
+            mxAutoText->maFillProperties.maFillColor.setSrgbClr( nTextColor );
+            mxAutoText->maFillProperties.moFillType.set(XML_solidFill);
+        }
         mxAutoText->moHeight = pAutoTextEntry->mnDefFontSize;
         mxAutoText->moBold = pAutoTextEntry->mbBold;
 
@@ -975,12 +914,9 @@ void TextFormatter::convertFormatting( PropertySet& rPropSet, const ModelRef< Te
     convertFormatting( rPropSet, lclGetTextProperties( rxTextProp ) );
 }
 
-
-
-ObjectTypeFormatter::ObjectTypeFormatter( ObjectFormatterData& rData, const ObjectTypeFormatEntry& rEntry, const ChartSpaceModel& rChartSpace ) :
+ObjectTypeFormatter::ObjectTypeFormatter( ObjectFormatterData& rData, const ObjectTypeFormatEntry& rEntry, const ChartSpaceModel& rChartSpace, const ObjectType eObjType ) :
     maLineFormatter(   rData, lclGetAutoFormatEntry( rEntry.mpAutoLines,   rChartSpace.mnStyle ) ),
-    maFillFormatter(   rData, lclGetAutoFormatEntry( rEntry.mpAutoFills,   rChartSpace.mnStyle ) ),
-    maEffectFormatter( rData, lclGetAutoFormatEntry( rEntry.mpAutoEffects, rChartSpace.mnStyle ) ),
+    maFillFormatter(   rData, lclGetAutoFormatEntry( rEntry.mpAutoFills,   rChartSpace.mnStyle ), eObjType ),
     maTextFormatter(   rData, lclGetAutoTextEntry(   rEntry.mpAutoTexts,   rChartSpace.mnStyle ), rChartSpace.mxTextProp ),
     mrModelObjHelper( rData.maModelObjHelper ),
     mrEntry( rEntry )
@@ -989,11 +925,10 @@ ObjectTypeFormatter::ObjectTypeFormatter( ObjectFormatterData& rData, const Obje
 
 void ObjectTypeFormatter::convertFrameFormatting( PropertySet& rPropSet, const ModelRef< Shape >& rxShapeProp, const PictureOptionsModel* pPicOptions, sal_Int32 nSeriesIdx )
 {
-    ShapePropertyMap aPropMap( mrModelObjHelper, *mrEntry.mpPropInfo );
+    ShapePropertyMap aPropMap( mrModelObjHelper, mrEntry.mrPropInfo );
     maLineFormatter.convertFormatting( aPropMap, rxShapeProp, nSeriesIdx );
     if( mrEntry.mbIsFrame )
         maFillFormatter.convertFormatting( aPropMap, rxShapeProp, pPicOptions, nSeriesIdx );
-    maEffectFormatter.convertFormatting( aPropMap, rxShapeProp, nSeriesIdx );
     rPropSet.setProperties( aPropMap );
 }
 
@@ -1004,7 +939,7 @@ void ObjectTypeFormatter::convertTextFormatting( PropertySet& rPropSet, const Mo
 
 void ObjectTypeFormatter::convertFormatting( PropertySet& rPropSet, const ModelRef< Shape >& rxShapeProp, const ModelRef< TextBody >& rxTextProp )
 {
-    convertFrameFormatting( rPropSet, rxShapeProp, 0, -1 );
+    convertFrameFormatting( rPropSet, rxShapeProp, nullptr, -1 );
     convertTextFormatting( rPropSet, rxTextProp );
 }
 
@@ -1015,24 +950,20 @@ void ObjectTypeFormatter::convertTextFormatting( PropertySet& rPropSet, const Te
 
 void ObjectTypeFormatter::convertAutomaticFill( PropertySet& rPropSet, sal_Int32 nSeriesIdx )
 {
-    ShapePropertyMap aPropMap( mrModelObjHelper, *mrEntry.mpPropInfo );
+    ShapePropertyMap aPropMap( mrModelObjHelper, mrEntry.mrPropInfo );
     ModelRef< Shape > xShapeProp;
-    maFillFormatter.convertFormatting( aPropMap, xShapeProp, 0, nSeriesIdx );
-    maEffectFormatter.convertFormatting( aPropMap, xShapeProp, nSeriesIdx );
+    maFillFormatter.convertFormatting( aPropMap, xShapeProp, nullptr, nSeriesIdx );
     rPropSet.setProperties( aPropMap );
 }
 
-
-
 ObjectFormatterData::ObjectFormatterData( const XmlFilterBase& rFilter, const Reference< XChartDocument >& rxChartDoc, const ChartSpaceModel& rChartSpace ) :
     mrFilter( rFilter ),
     maModelObjHelper( Reference< XMultiServiceFactory >( rxChartDoc, UNO_QUERY ) ),
     maEnUsLocale( "en", "US", OUString() ),
     mnMaxSeriesIdx( -1 )
 {
-    const ObjectTypeFormatEntry* pEntryEnd = STATIC_ARRAY_END( spObjTypeFormatEntries );
-    for( const ObjectTypeFormatEntry* pEntry = spObjTypeFormatEntries; pEntry != pEntryEnd; ++pEntry )
-        maTypeFormatters[ pEntry->meObjType ].reset( new ObjectTypeFormatter( *this, *pEntry, rChartSpace ) );
+    for(auto const &rEntry : spObjTypeFormatEntries)
+        maTypeFormatters[ rEntry.meObjType ].reset( new ObjectTypeFormatter( *this, rEntry, rChartSpace, rEntry.meObjType ) );
 
     try
     {
@@ -1052,8 +983,6 @@ ObjectTypeFormatter* ObjectFormatterData::getTypeFormatter( ObjectType eObjType
     return maTypeFormatters.get( eObjType ).get();
 }
 
-
-
 ObjectFormatter::ObjectFormatter( const XmlFilterBase& rFilter, const Reference< XChartDocument >& rxChartDoc, const ChartSpaceModel& rChartSpace ) :
     mxData( new ObjectFormatterData( rFilter, rxChartDoc, rChartSpace ) )
 {
@@ -1076,7 +1005,7 @@ sal_Int32 ObjectFormatter::getMaxSeriesIndex() const
 void ObjectFormatter::convertFrameFormatting( PropertySet& rPropSet, const ModelRef< Shape >& rxShapeProp, ObjectType eObjType, sal_Int32 nSeriesIdx )
 {
     if( ObjectTypeFormatter* pFormat = mxData->getTypeFormatter( eObjType ) )
-        pFormat->convertFrameFormatting( rPropSet, rxShapeProp, 0, nSeriesIdx );
+        pFormat->convertFrameFormatting( rPropSet, rxShapeProp, nullptr, nSeriesIdx );
 }
 
 void ObjectFormatter::convertFrameFormatting( PropertySet& rPropSet, const ModelRef< Shape >& rxShapeProp, const PictureOptionsModel& rPicOptions, ObjectType eObjType, sal_Int32 nSeriesIdx )
@@ -1103,7 +1032,7 @@ void ObjectFormatter::convertTextFormatting( PropertySet& rPropSet, const TextCh
         pFormat->convertTextFormatting( rPropSet, rTextProps );
 }
 
-void ObjectFormatter::convertTextRotation( PropertySet& rPropSet, const ModelRef< TextBody >& rxTextProp, bool bSupportsStacked )
+void ObjectFormatter::convertTextRotation( PropertySet& rPropSet, const ModelRef< TextBody >& rxTextProp, bool bSupportsStacked, sal_Int32 nDefaultRotation )
 {
     if( rxTextProp.is() )
     {
@@ -1117,9 +1046,9 @@ void ObjectFormatter::convertTextRotation( PropertySet& rPropSet, const ModelRef
 
         /*  Chart2 expects rotation angle as double value in range of [0,360).
             OOXML counts clockwise, Chart2 counts counterclockwise. */
-        double fAngle = static_cast< double >( bStacked ? 0 : rxTextProp->getTextProperties().moRotation.get( 0 ) );
+        double fAngle = static_cast< double >( bStacked ? 0 : rxTextProp->getTextProperties().moRotation.get( nDefaultRotation ) );
         // MS Office UI allows values only in range of [-90,90].
-        if ( fAngle <= -5400000.0 || fAngle >= 5400000.0 )
+        if ( fAngle < -5400000.0 || fAngle > 5400000.0 )
         {
             fAngle = 0.0;
         }
@@ -1128,19 +1057,39 @@ void ObjectFormatter::convertTextRotation( PropertySet& rPropSet, const ModelRef
     }
 }
 
-void ObjectFormatter::convertNumberFormat( PropertySet& rPropSet, const NumberFormat& rNumberFormat, bool bPercentFormat )
+void ObjectFormatter::convertTextWrap( PropertySet& rPropSet, const ModelRef< TextBody >& rxTextProp )
+{
+    if( rxTextProp.is() )
+    {
+        PropertyMap& aPropMap = rxTextProp->getTextProperties().maPropertyMap;
+        if( aPropMap.hasProperty(PROP_TextWordWrap) )
+        {
+            Any aValue = aPropMap.getProperty( PROP_TextWordWrap );
+            if( aValue.hasValue() )
+            {
+                bool bValue = false;
+                aValue >>= bValue;
+                rPropSet.setProperty( PROP_TextWordWrap, bValue );
+            }
+        }
+    }
+}
+
+void ObjectFormatter::convertNumberFormat( PropertySet& rPropSet, const NumberFormat& rNumberFormat, bool bAxis, bool bShowPercent )
 {
     if( mxData->mxNumFmts.is() )
     {
-        sal_Int32 nPropId = bPercentFormat ? PROP_PercentageNumberFormat : PROP_NumberFormat;
+        const bool bGeneral = rNumberFormat.maFormatCode.equalsIgnoreAsciiCase("general");
+        const bool bPercent = !bAxis && bShowPercent && !rNumberFormat.mbSourceLinked;
+        sal_Int32 nPropId = bPercent ? PROP_PercentageNumberFormat : PROP_NumberFormat;
+        OUString sFormatCode(rNumberFormat.maFormatCode);
+        if (bPercent && bGeneral)
+            sFormatCode = "0%";
         try
         {
-            bool bGeneral = rNumberFormat.maFormatCode.equalsIgnoreAsciiCase("general");
-            sal_Int32 nIndex = bGeneral && !bPercentFormat ?
+            sal_Int32 nIndex = bGeneral && !bPercent ?
                 mxData->mxNumTypes->getStandardIndex( mxData->maFromLocale ) :
-                mxData->mxNumFmts->addNewConverted(
-                        bGeneral ? OUString("0%") : rNumberFormat.maFormatCode,
-                        mxData->maEnUsLocale, mxData->maFromLocale );
+                mxData->mxNumFmts->addNewConverted( sFormatCode, mxData->maEnUsLocale, mxData->maFromLocale );
             if( nIndex >= 0 )
                 rPropSet.setProperty( nPropId, nIndex );
         }
@@ -1150,9 +1099,11 @@ void ObjectFormatter::convertNumberFormat( PropertySet& rPropSet, const NumberFo
                 append( OUStringToOString( rNumberFormat.maFormatCode, osl_getThreadTextEncoding() ) ).append( '\'' ).getStr() );
         }
 
-        // Format code is ignored if "LinkNumberFormatToSource" is set to "true" :-/
-        // See AxisHelper::getExplicitNumberFormatKeyForAxis()
-        rPropSet.setProperty(PROP_LinkNumberFormatToSource, makeAny(rNumberFormat.maFormatCode.isEmpty()));
+        // Setting "LinkNumberFormatToSource" does not really work, at least not for axis :-/
+        if (!bAxis)
+            rPropSet.setProperty(PROP_LinkNumberFormatToSource, makeAny(rNumberFormat.mbSourceLinked));
+        else
+            rPropSet.setProperty(PROP_LinkNumberFormatToSource, makeAny(rNumberFormat.maFormatCode.isEmpty()));
     }
 }
 
@@ -1167,8 +1118,6 @@ bool ObjectFormatter::isAutomaticFill( const ModelRef< Shape >& rxShapeProp )
     return !rxShapeProp || !rxShapeProp->getFillProperties().moFillType.has();
 }
 
-
-
 } // namespace chart
 } // namespace drawingml
 } // namespace oox
