@@ -10,11 +10,15 @@
 #include <config_folders.h>
 #include <rtl/bootstrap.hxx>
 #include <tools/stream.hxx>
-#include <comphelper/sequenceasvector.hxx>
+#include <comphelper/sequence.hxx>
 
-#include "drawingml/customshapeproperties.hxx"
-#include "oox/token/tokenmap.hxx"
+#include <drawingml/customshapeproperties.hxx>
+#include <oox/token/properties.hxx>
+#include <oox/token/tokenmap.hxx>
 #include <com/sun/star/awt/Rectangle.hpp>
+#include <com/sun/star/beans/PropertyValues.hpp>
+#include <com/sun/star/drawing/EnhancedCustomShapeTextFrame.hpp>
+#include <com/sun/star/drawing/EnhancedCustomShapeAdjustmentValue.hpp>
 
 using namespace ::com::sun::star;
 
@@ -22,24 +26,24 @@ namespace
 {
 
 // Parses a string like: Value = (any) { (long) 19098 }, State = (com.sun.star.beans.PropertyState) DIRECT_VALUE, Name = "adj"
-void lcl_parseAdjustmentValue(comphelper::SequenceAsVector<drawing::EnhancedCustomShapeAdjustmentValue>& rAdjustmentValues, const OString& rValue)
+void lcl_parseAdjustmentValue(std::vector<drawing::EnhancedCustomShapeAdjustmentValue>& rAdjustmentValues, const OString& rValue)
 {
     sal_Int32 nIndex = 0;
     drawing::EnhancedCustomShapeAdjustmentValue aAdjustmentValue;
     do
     {
         OString aToken = rValue.getToken(0, ',', nIndex).trim();
-        static const OString aNamePrefix("Name = \"");
-        static const OString aValuePrefix("Value = (any) { (long) ");
+        static const char aNamePrefix[] = "Name = \"";
+        static const char aValuePrefix[] = "Value = (any) { (long) ";
         if (aToken.startsWith(aNamePrefix))
         {
-            OString aName = aToken.copy(aNamePrefix.getLength(), aToken.getLength() - aNamePrefix.getLength() - strlen("\""));
+            OString aName = aToken.copy(strlen(aNamePrefix), aToken.getLength() - strlen(aNamePrefix) - strlen("\""));
             aAdjustmentValue.Name = OUString::fromUtf8(aName);
         }
         else if (aToken.startsWith(aValuePrefix))
         {
-            OString aValue = aToken.copy(aValuePrefix.getLength(), aToken.getLength() - aValuePrefix.getLength() - strlen(" }"));
-            aAdjustmentValue.Value = uno::makeAny(aValue.toInt32());
+            OString aValue = aToken.copy(strlen(aValuePrefix), aToken.getLength() - strlen(aValuePrefix) - strlen(" }"));
+            aAdjustmentValue.Value <<= aValue.toInt32();
         }
         else if (!aToken.startsWith("State = "))
             SAL_WARN("oox", "lcl_parseAdjustmentValue: unexpected prefix: " << aToken);
@@ -49,7 +53,7 @@ void lcl_parseAdjustmentValue(comphelper::SequenceAsVector<drawing::EnhancedCust
 }
 
 // Parses a string like: { Value = (any) { (long) 19098 }, State = (com.sun.star.beans.PropertyState) DIRECT_VALUE, Name = "adj" }, { Value = ..., State = ..., Name = ... }
-void lcl_parseAdjustmentValues(comphelper::SequenceAsVector<drawing::EnhancedCustomShapeAdjustmentValue>& rAdjustmentValues, const OString& rValue)
+void lcl_parseAdjustmentValues(std::vector<drawing::EnhancedCustomShapeAdjustmentValue>& rAdjustmentValues, const OString& rValue)
 {
     sal_Int32 nLevel = 0;
     sal_Int32 nStart = 0;
@@ -76,28 +80,28 @@ drawing::EnhancedCustomShapeParameterPair lcl_parseEnhancedCustomShapeParameterP
 {
     drawing::EnhancedCustomShapeParameterPair aPair;
     OString aToken = rValue;
-    // We expect the followings here: First.Value, First.Type, Second.Value, Second.Type
-    static const OString aExpectedFVPrefix = "First = (com.sun.star.drawing.EnhancedCustomShapeParameter) { Value = (any) { (long) ";
+    // We expect the following here: First.Value, First.Type, Second.Value, Second.Type
+    static const char aExpectedFVPrefix[] = "First = (com.sun.star.drawing.EnhancedCustomShapeParameter) { Value = (any) { (long) ";
     assert(aToken.startsWith(aExpectedFVPrefix));
-    sal_Int32 nIndex = aExpectedFVPrefix.getLength();
-    aPair.First.Value = uno::makeAny(static_cast<sal_uInt32>(aToken.getToken(0, '}', nIndex).toInt32()));
+    sal_Int32 nIndex = strlen(aExpectedFVPrefix);
+    aPair.First.Value <<= static_cast<sal_uInt32>(aToken.getToken(0, '}', nIndex).toInt32());
 
-    static const OString aExpectedFTPrefix = ", Type = (short) ";
+    static const char aExpectedFTPrefix[] = ", Type = (short) ";
     aToken = aToken.copy(nIndex);
     assert(aToken.startsWith(aExpectedFTPrefix));
-    nIndex = aExpectedFTPrefix.getLength();
+    nIndex = strlen(aExpectedFTPrefix);
     aPair.First.Type = static_cast<sal_uInt16>(aToken.getToken(0, '}', nIndex).toInt32());
 
-    static const OString aExpectedSVPrefix = ", Second = (com.sun.star.drawing.EnhancedCustomShapeParameter) { Value = (any) { (long) ";
+    static const char aExpectedSVPrefix[] = ", Second = (com.sun.star.drawing.EnhancedCustomShapeParameter) { Value = (any) { (long) ";
     aToken = aToken.copy(nIndex);
     assert(aToken.startsWith(aExpectedSVPrefix));
-    nIndex = aExpectedSVPrefix.getLength();
-    aPair.Second.Value = uno::makeAny(static_cast<sal_uInt32>(aToken.getToken(0, '}', nIndex).toInt32()));
+    nIndex = strlen(aExpectedSVPrefix);
+    aPair.Second.Value <<= static_cast<sal_uInt32>(aToken.getToken(0, '}', nIndex).toInt32());
 
-    static const OString aExpectedSTPrefix = ", Type = (short) ";
+    static const char aExpectedSTPrefix[] = ", Type = (short) ";
     aToken = aToken.copy(nIndex);
     assert(aToken.startsWith(aExpectedSTPrefix));
-    nIndex = aExpectedSTPrefix.getLength();
+    nIndex = strlen(aExpectedSTPrefix);
     aPair.Second.Type = static_cast<sal_uInt16>(aToken.getToken(0, '}', nIndex).toInt32());
     return aPair;
 }
@@ -106,16 +110,16 @@ drawing::EnhancedCustomShapeSegment lcl_parseEnhancedCustomShapeSegment(const OS
 {
     drawing::EnhancedCustomShapeSegment aSegment;
     OString aToken = rValue;
-    // We expect the followings here: Command, Count
-    static const OString aExpectedCommandPrefix = "Command = (short) ";
+    // We expect the following here: Command, Count
+    static const char aExpectedCommandPrefix[] = "Command = (short) ";
     assert(aToken.startsWith(aExpectedCommandPrefix));
-    sal_Int32 nIndex = aExpectedCommandPrefix.getLength();
+    sal_Int32 nIndex = strlen(aExpectedCommandPrefix);
     aSegment.Command = static_cast<sal_Int16>(aToken.getToken(0, ',', nIndex).toInt32());
 
-    static const OString aExpectedCountPrefix = " Count = (short) ";
+    static const char aExpectedCountPrefix[] = " Count = (short) ";
     aToken = aToken.copy(nIndex);
     assert(aToken.startsWith(aExpectedCountPrefix));
-    nIndex = aExpectedCountPrefix.getLength();
+    nIndex = strlen(aExpectedCountPrefix);
     aSegment.Count = static_cast<sal_Int16>(aToken.getToken(0, '}', nIndex).toInt32());
     return aSegment;
 }
@@ -124,29 +128,29 @@ awt::Rectangle lcl_parseRectangle(const OString& rValue)
 {
     awt::Rectangle aRectangle;
     OString aToken = rValue;
-    // We expect the followings here: X, Y, Width, Height
-    static const OString aExpectedXPrefix = "X = (long) ";
+    // We expect the following here: X, Y, Width, Height
+    static const char aExpectedXPrefix[] = "X = (long) ";
     assert(aToken.startsWith(aExpectedXPrefix));
-    sal_Int32 nIndex = aExpectedXPrefix.getLength();
-    aRectangle.X = static_cast<sal_Int32>(aToken.getToken(0, ',', nIndex).toInt32());
+    sal_Int32 nIndex = strlen(aExpectedXPrefix);
+    aRectangle.X = aToken.getToken(0, ',', nIndex).toInt32();
 
-    static const OString aExpectedYPrefix = " Y = (long) ";
+    static const char aExpectedYPrefix[] = " Y = (long) ";
     aToken = aToken.copy(nIndex);
     assert(aToken.startsWith(aExpectedYPrefix));
-    nIndex = aExpectedYPrefix.getLength();
-    aRectangle.Y = static_cast<sal_Int32>(aToken.getToken(0, ',', nIndex).toInt32());
+    nIndex = strlen(aExpectedYPrefix);
+    aRectangle.Y = aToken.getToken(0, ',', nIndex).toInt32();
 
-    static const OString aExpectedWidthPrefix = " Width = (long) ";
+    static const char aExpectedWidthPrefix[] = " Width = (long) ";
     aToken = aToken.copy(nIndex);
     assert(aToken.startsWith(aExpectedWidthPrefix));
-    nIndex = aExpectedWidthPrefix.getLength();
-    aRectangle.Width = static_cast<sal_Int32>(aToken.getToken(0, ',', nIndex).toInt32());
+    nIndex = strlen(aExpectedWidthPrefix);
+    aRectangle.Width = aToken.getToken(0, ',', nIndex).toInt32();
 
-    static const OString aExpectedHeightPrefix = " Height = (long) ";
+    static const char aExpectedHeightPrefix[] = " Height = (long) ";
     aToken = aToken.copy(nIndex);
     assert(aToken.startsWith(aExpectedHeightPrefix));
-    nIndex = aExpectedHeightPrefix.getLength();
-    aRectangle.Width = static_cast<sal_Int32>(aToken.copy(nIndex).toInt32());
+    nIndex = strlen(aExpectedHeightPrefix);
+    aRectangle.Height = aToken.copy(nIndex).toInt32();
 
     return aRectangle;
 }
@@ -155,17 +159,17 @@ awt::Size lcl_parseSize(const OString& rValue)
 {
     awt::Size aSize;
     OString aToken = rValue;
-    // We expect the followings here: Width, Height
-    static const OString aExpectedWidthPrefix = "Width = (long) ";
+    // We expect the following here: Width, Height
+    static const char aExpectedWidthPrefix[] = "Width = (long) ";
     assert(aToken.startsWith(aExpectedWidthPrefix));
-    sal_Int32 nIndex = aExpectedWidthPrefix.getLength();
-    aSize.Width = static_cast<sal_Int32>(aToken.getToken(0, ',', nIndex).toInt32());
+    sal_Int32 nIndex = strlen(aExpectedWidthPrefix);
+    aSize.Width = aToken.getToken(0, ',', nIndex).toInt32();
 
-    static const OString aExpectedHeightPrefix = " Height = (long) ";
+    static const char aExpectedHeightPrefix[] = " Height = (long) ";
     aToken = aToken.copy(nIndex);
     assert(aToken.startsWith(aExpectedHeightPrefix));
-    nIndex = aExpectedHeightPrefix.getLength();
-    aSize.Height = static_cast<sal_Int32>(aToken.copy(nIndex).toInt32());
+    nIndex = strlen(aExpectedHeightPrefix);
+    aSize.Height = aToken.copy(nIndex).toInt32();
 
     return aSize;
 }
@@ -193,10 +197,10 @@ drawing::EnhancedCustomShapeTextFrame lcl_parseEnhancedCustomShapeTextFrame(cons
         else if (rValue[i] == ',' && !bIgnore)
         {
             OString aToken = rValue.copy(nStart, i - nStart);
-            static const OString aExpectedPrefix("TopLeft = (com.sun.star.drawing.EnhancedCustomShapeParameterPair) { ");
+            static const char aExpectedPrefix[] = "TopLeft = (com.sun.star.drawing.EnhancedCustomShapeParameterPair) { ";
             if (aToken.startsWith(aExpectedPrefix))
             {
-                aToken = aToken.copy(aExpectedPrefix.getLength(), aToken.getLength() - aExpectedPrefix.getLength() - strlen(" }"));
+                aToken = aToken.copy(strlen(aExpectedPrefix), aToken.getLength() - strlen(aExpectedPrefix) - strlen(" }"));
                 aTextFrame.TopLeft = lcl_parseEnhancedCustomShapeParameterPair(aToken);
             }
             else
@@ -205,11 +209,11 @@ drawing::EnhancedCustomShapeTextFrame lcl_parseEnhancedCustomShapeTextFrame(cons
         }
     }
 
-    OString aToken = rValue.copy(nStart, rValue.getLength() - nStart);
-    static const OString aExpectedPrefix("BottomRight = (com.sun.star.drawing.EnhancedCustomShapeParameterPair) { ");
+    OString aToken = rValue.copy(nStart);
+    static const char aExpectedPrefix[] = "BottomRight = (com.sun.star.drawing.EnhancedCustomShapeParameterPair) { ";
     if (aToken.startsWith(aExpectedPrefix))
     {
-        aToken = aToken.copy(aExpectedPrefix.getLength(), aToken.getLength() - aExpectedPrefix.getLength() - strlen(" }"));
+        aToken = aToken.copy(strlen(aExpectedPrefix), aToken.getLength() - strlen(aExpectedPrefix) - strlen(" }"));
         aTextFrame.BottomRight = lcl_parseEnhancedCustomShapeParameterPair(aToken);
     }
     else
@@ -220,7 +224,7 @@ drawing::EnhancedCustomShapeTextFrame lcl_parseEnhancedCustomShapeTextFrame(cons
 
 // Parses a string like: Name = "Position", Handle = (long) 0, Value = (any) { ... }, State = (com.sun.star.beans.PropertyState) DIRECT_VALUE
 // where "{ ... }" may contain "," as well.
-void lcl_parseHandlePosition(comphelper::SequenceAsVector<beans::PropertyValue>& rHandle, const OString& rValue)
+void lcl_parseHandlePosition(std::vector<beans::PropertyValue>& rHandle, const OString& rValue)
 {
     sal_Int32 nLevel = 0;
     bool bIgnore = false;
@@ -242,14 +246,14 @@ void lcl_parseHandlePosition(comphelper::SequenceAsVector<beans::PropertyValue>&
         else if (rValue[i] == ',' && !bIgnore)
         {
             OString aToken = rValue.copy(nStart, i - nStart);
-            static const OString aExpectedPrefix("Value = (any) { (com.sun.star.drawing.EnhancedCustomShapeParameterPair) { ");
+            static const char aExpectedPrefix[] = "Value = (any) { (com.sun.star.drawing.EnhancedCustomShapeParameterPair) { ";
             if (aToken.startsWith(aExpectedPrefix))
             {
-                aToken = aToken.copy(aExpectedPrefix.getLength(), aToken.getLength() - aExpectedPrefix.getLength() - strlen(" } }"));
+                aToken = aToken.copy(strlen(aExpectedPrefix), aToken.getLength() - strlen(aExpectedPrefix) - strlen(" } }"));
 
                 beans::PropertyValue aPropertyValue;
                 aPropertyValue.Name = "Position";
-                aPropertyValue.Value = uno::makeAny(lcl_parseEnhancedCustomShapeParameterPair(aToken));
+                aPropertyValue.Value <<= lcl_parseEnhancedCustomShapeParameterPair(aToken);
                 rHandle.push_back(aPropertyValue);
             }
             else if (!aToken.startsWith("Name =") && !aToken.startsWith("Handle ="))
@@ -261,7 +265,7 @@ void lcl_parseHandlePosition(comphelper::SequenceAsVector<beans::PropertyValue>&
 
 // Parses a string like: Name = "RangeYMaximum", Handle = (long) 0, Value = (any) { ... }, State = (com.sun.star.beans.PropertyState) DIRECT_VALUE
 // where "{ ... }" may contain "," as well.
-void lcl_parseHandleRange(comphelper::SequenceAsVector<beans::PropertyValue>& rHandle, const OString& rValue, const OUString& rName)
+void lcl_parseHandleRange(std::vector<beans::PropertyValue>& rHandle, const OString& rValue, const OUString& rName)
 {
     sal_Int32 nLevel = 0;
     bool bIgnore = false;
@@ -283,26 +287,26 @@ void lcl_parseHandleRange(comphelper::SequenceAsVector<beans::PropertyValue>& rH
         else if (rValue[i] == ',' && !bIgnore)
         {
             OString aToken = rValue.copy(nStart, i - nStart);
-            static const OString aExpectedPrefix("Value = (any) { (com.sun.star.drawing.EnhancedCustomShapeParameter) { ");
+            static const char aExpectedPrefix[] = "Value = (any) { (com.sun.star.drawing.EnhancedCustomShapeParameter) { ";
             if (aToken.startsWith(aExpectedPrefix))
             {
                 drawing::EnhancedCustomShapeParameter aParameter;
-                aToken = aToken.copy(aExpectedPrefix.getLength(), aToken.getLength() - aExpectedPrefix.getLength() - strlen(" } }"));
-                // We expect the followings here: Value and Type
-                static const OString aExpectedVPrefix = "Value = (any) { (long) ";
+                aToken = aToken.copy(strlen(aExpectedPrefix), aToken.getLength() - strlen(aExpectedPrefix) - strlen(" } }"));
+                // We expect the following here: Value and Type
+                static const char aExpectedVPrefix[] = "Value = (any) { (long) ";
                 assert(aToken.startsWith(aExpectedVPrefix));
-                sal_Int32 nIndex = aExpectedVPrefix.getLength();
-                aParameter.Value = uno::makeAny(aToken.getToken(0, '}', nIndex).toInt32());
+                sal_Int32 nIndex = strlen(aExpectedVPrefix);
+                aParameter.Value <<= aToken.getToken(0, '}', nIndex).toInt32();
 
-                static const OString aExpectedTPrefix = ", Type = (short) ";
+                static const char aExpectedTPrefix[] = ", Type = (short) ";
                 aToken = aToken.copy(nIndex);
                 assert(aToken.startsWith(aExpectedTPrefix));
-                nIndex = aExpectedTPrefix.getLength();
+                nIndex = strlen(aExpectedTPrefix);
                 aParameter.Type = static_cast<sal_Int16>(aToken.getToken(0, '}', nIndex).toInt32());
 
                 beans::PropertyValue aPropertyValue;
                 aPropertyValue.Name = rName;
-                aPropertyValue.Value = uno::makeAny(aParameter);
+                aPropertyValue.Value <<= aParameter;
                 rHandle.push_back(aPropertyValue);
 
             }
@@ -314,17 +318,19 @@ void lcl_parseHandleRange(comphelper::SequenceAsVector<beans::PropertyValue>& rH
 }
 
 // Parses a string like: Name = "RefY", Handle = (long) 0, Value = (any) { (long) 0 }, State = (com.sun.star.beans.PropertyState) DIRECT_VALUE
-void lcl_parseHandleRef(comphelper::SequenceAsVector<beans::PropertyValue>& rHandle, const OString& rValue, const OUString& rName)
+void lcl_parseHandleRef(std::vector<beans::PropertyValue>& rHandle, const OString& rValue, const OUString& rName)
 {
-    static const OString aExpectedXPrefix("Name = \"RefX\", Handle = (long) 0, Value = (any) { (long) ");
-    static const OString aExpectedYPrefix("Name = \"RefY\", Handle = (long) 0, Value = (any) { (long) ");
-    if (rValue.startsWith(aExpectedXPrefix) || rValue.startsWith(aExpectedYPrefix))
+    static const char aPrefix[] = "\", Handle = (long) 0, Value = (any) { (long) ";
+    const sal_Int32 nCheck= SAL_N_ELEMENTS(aPrefix) - 1;
+    const sal_Int32 nStart= SAL_N_ELEMENTS("Name = \"") - 1 + rName.getLength();
+
+    if (rValue.copy(nStart, nCheck).equalsL(aPrefix, nCheck))
     {
-        sal_Int32 nIndex = aExpectedXPrefix.getLength();
+        sal_Int32 nIndex = nStart + nCheck;
         beans::PropertyValue aPropertyValue;
         aPropertyValue.Name = rName;
         // We only expect a Value here
-        aPropertyValue.Value = uno::makeAny(rValue.getToken(0, '}', nIndex).toInt32());
+        aPropertyValue.Value <<= rValue.getToken(0, '}', nIndex).toInt32();
         rHandle.push_back(aPropertyValue);
     }
     else
@@ -333,7 +339,7 @@ void lcl_parseHandleRef(comphelper::SequenceAsVector<beans::PropertyValue>& rHan
 
 uno::Sequence<beans::PropertyValue> lcl_parseHandle(const OString& rValue)
 {
-    comphelper::SequenceAsVector<beans::PropertyValue> aRet;
+    std::vector<beans::PropertyValue> aRet;
     sal_Int32 nLevel = 0;
     sal_Int32 nStart = 0;
     for (sal_Int32 i = 0; i < rValue.getLength(); ++i)
@@ -368,15 +374,19 @@ uno::Sequence<beans::PropertyValue> lcl_parseHandle(const OString& rValue)
                     lcl_parseHandleRef(aRet, aToken, "RefX");
                 else if (aToken.startsWith("Name = \"RefY\""))
                     lcl_parseHandleRef(aRet, aToken, "RefY");
+                else if (aToken.startsWith("Name = \"RefR\""))
+                    lcl_parseHandleRef(aRet, aToken, "RefR");
+                else if (aToken.startsWith("Name = \"RefAngle\""))
+                    lcl_parseHandleRef(aRet, aToken, "RefAngle");
                 else
                     SAL_WARN("oox", "lcl_parseHandle: unexpected token: " << aToken);
             }
         }
     }
-    return aRet.getAsConstList();
+    return comphelper::containerToSequence(aRet);
 }
 
-void lcl_parseHandles(comphelper::SequenceAsVector< uno::Sequence<beans::PropertyValue> >& rHandles, const OString& rValue)
+void lcl_parseHandles(std::vector< uno::Sequence<beans::PropertyValue> >& rHandles, const OString& rValue)
 {
     sal_Int32 nLevel = 0;
     sal_Int32 nStart = 0;
@@ -400,7 +410,7 @@ void lcl_parseHandles(comphelper::SequenceAsVector< uno::Sequence<beans::Propert
     }
 }
 
-void lcl_parseEquations(comphelper::SequenceAsVector<OUString>& rEquations, const OString& rValue)
+void lcl_parseEquations(std::vector<OUString>& rEquations, const OString& rValue)
 {
     bool bInString = false;
     sal_Int32 nStart = 0;
@@ -419,9 +429,9 @@ void lcl_parseEquations(comphelper::SequenceAsVector<OUString>& rEquations, cons
     }
 }
 
-void lcl_parsePathCoordinateValues(comphelper::SequenceAsVector<beans::PropertyValue>& rPath, const OString& rValue)
+void lcl_parsePathCoordinateValues(std::vector<beans::PropertyValue>& rPath, const OString& rValue)
 {
-    comphelper::SequenceAsVector<drawing::EnhancedCustomShapeParameterPair> aPairs;
+    std::vector<drawing::EnhancedCustomShapeParameterPair> aPairs;
     sal_Int32 nLevel = 0;
     sal_Int32 nStart = 0;
     for (sal_Int32 i = 0; i < rValue.getLength(); ++i)
@@ -442,13 +452,13 @@ void lcl_parsePathCoordinateValues(comphelper::SequenceAsVector<beans::PropertyV
 
     beans::PropertyValue aPropertyValue;
     aPropertyValue.Name = "Coordinates";
-    aPropertyValue.Value = uno::makeAny(aPairs.getAsConstList());
+    aPropertyValue.Value <<= comphelper::containerToSequence(aPairs);
     rPath.push_back(aPropertyValue);
 }
 
 // Parses a string like: Name = "Coordinates", Handle = (long) 0, Value = (any) { ... }, State = (com.sun.star.beans.PropertyState) DIRECT_VALUE
 // where "{ ... }" may contain "," as well.
-void lcl_parsePathCoordinates(comphelper::SequenceAsVector<beans::PropertyValue>& rPath, const OString& rValue)
+void lcl_parsePathCoordinates(std::vector<beans::PropertyValue>& rPath, const OString& rValue)
 {
     sal_Int32 nLevel = 0;
     bool bIgnore = false;
@@ -470,10 +480,10 @@ void lcl_parsePathCoordinates(comphelper::SequenceAsVector<beans::PropertyValue>
         else if (rValue[i] == ',' && !bIgnore)
         {
             OString aToken = rValue.copy(nStart, i - nStart);
-            static const OString aExpectedPrefix("Value = (any) { ([]com.sun.star.drawing.EnhancedCustomShapeParameterPair) { ");
+            static const char aExpectedPrefix[] = "Value = (any) { ([]com.sun.star.drawing.EnhancedCustomShapeParameterPair) { ";
             if (aToken.startsWith(aExpectedPrefix))
             {
-                aToken = aToken.copy(aExpectedPrefix.getLength(), aToken.getLength() - aExpectedPrefix.getLength() - strlen(" } }"));
+                aToken = aToken.copy(strlen(aExpectedPrefix), aToken.getLength() - strlen(aExpectedPrefix) - strlen(" } }"));
                 lcl_parsePathCoordinateValues(rPath, aToken);
             }
             else if (!aToken.startsWith("Name =") && !aToken.startsWith("Handle ="))
@@ -483,9 +493,9 @@ void lcl_parsePathCoordinates(comphelper::SequenceAsVector<beans::PropertyValue>
     }
 }
 
-void lcl_parsePathSegmentValues(comphelper::SequenceAsVector<beans::PropertyValue>& rPath, const OString& rValue)
+void lcl_parsePathSegmentValues(std::vector<beans::PropertyValue>& rPath, const OString& rValue)
 {
-    comphelper::SequenceAsVector<drawing::EnhancedCustomShapeSegment> aSegments;
+    std::vector<drawing::EnhancedCustomShapeSegment> aSegments;
     sal_Int32 nLevel = 0;
     sal_Int32 nStart = 0;
     for (sal_Int32 i = 0; i < rValue.getLength(); ++i)
@@ -506,13 +516,13 @@ void lcl_parsePathSegmentValues(comphelper::SequenceAsVector<beans::PropertyValu
 
     beans::PropertyValue aPropertyValue;
     aPropertyValue.Name = "Segments";
-    aPropertyValue.Value = uno::makeAny(aSegments.getAsConstList());
+    aPropertyValue.Value <<= comphelper::containerToSequence(aSegments);
     rPath.push_back(aPropertyValue);
 }
 
 // Parses a string like: Name = "Segments", Handle = (long) 0, Value = (any) { ... }, State = (com.sun.star.beans.PropertyState) DIRECT_VALUE
 // where "{ ... }" may contain "," as well.
-void lcl_parsePathSegments(comphelper::SequenceAsVector<beans::PropertyValue>& rPath, const OString& rValue)
+void lcl_parsePathSegments(std::vector<beans::PropertyValue>& rPath, const OString& rValue)
 {
     sal_Int32 nLevel = 0;
     bool bIgnore = false;
@@ -534,10 +544,10 @@ void lcl_parsePathSegments(comphelper::SequenceAsVector<beans::PropertyValue>& r
         else if (rValue[i] == ',' && !bIgnore)
         {
             OString aToken = rValue.copy(nStart, i - nStart);
-            static const OString aExpectedPrefix("Value = (any) { ([]com.sun.star.drawing.EnhancedCustomShapeSegment) { ");
+            static const char aExpectedPrefix[] = "Value = (any) { ([]com.sun.star.drawing.EnhancedCustomShapeSegment) { ";
             if (aToken.startsWith(aExpectedPrefix))
             {
-                aToken = aToken.copy(aExpectedPrefix.getLength(), aToken.getLength() - aExpectedPrefix.getLength() - strlen(" } }"));
+                aToken = aToken.copy(strlen(aExpectedPrefix), aToken.getLength() - strlen(aExpectedPrefix) - strlen(" } }"));
                 lcl_parsePathSegmentValues(rPath, aToken);
             }
             else if (!aToken.startsWith("Name =") && !aToken.startsWith("Handle ="))
@@ -547,9 +557,9 @@ void lcl_parsePathSegments(comphelper::SequenceAsVector<beans::PropertyValue>& r
     }
 }
 
-void lcl_parsePathTextFrameValues(comphelper::SequenceAsVector<beans::PropertyValue>& rPath, const OString& rValue)
+void lcl_parsePathTextFrameValues(std::vector<beans::PropertyValue>& rPath, const OString& rValue)
 {
-    comphelper::SequenceAsVector<drawing::EnhancedCustomShapeTextFrame> aTextFrames;
+    std::vector<drawing::EnhancedCustomShapeTextFrame> aTextFrames;
     sal_Int32 nLevel = 0;
     sal_Int32 nStart = 0;
     for (sal_Int32 i = 0; i < rValue.getLength(); ++i)
@@ -570,13 +580,13 @@ void lcl_parsePathTextFrameValues(comphelper::SequenceAsVector<beans::PropertyVa
 
     beans::PropertyValue aPropertyValue;
     aPropertyValue.Name = "TextFrames";
-    aPropertyValue.Value = uno::makeAny(aTextFrames.getAsConstList());
+    aPropertyValue.Value <<= comphelper::containerToSequence(aTextFrames);
     rPath.push_back(aPropertyValue);
 }
 
 // Parses a string like: Name = "TextFrames", Handle = (long) 0, Value = (any) { ... }, State = (com.sun.star.beans.PropertyState) DIRECT_VALUE
 // where "{ ... }" may contain "," as well.
-void lcl_parsePathTextFrames(comphelper::SequenceAsVector<beans::PropertyValue>& rPath, const OString& rValue)
+void lcl_parsePathTextFrames(std::vector<beans::PropertyValue>& rPath, const OString& rValue)
 {
     sal_Int32 nLevel = 0;
     bool bIgnore = false;
@@ -598,10 +608,10 @@ void lcl_parsePathTextFrames(comphelper::SequenceAsVector<beans::PropertyValue>&
         else if (rValue[i] == ',' && !bIgnore)
         {
             OString aToken = rValue.copy(nStart, i - nStart);
-            static const OString aExpectedPrefix("Value = (any) { ([]com.sun.star.drawing.EnhancedCustomShapeTextFrame) { ");
+            static const char aExpectedPrefix[] = "Value = (any) { ([]com.sun.star.drawing.EnhancedCustomShapeTextFrame) { ";
             if (aToken.startsWith(aExpectedPrefix))
             {
-                aToken = aToken.copy(aExpectedPrefix.getLength(), aToken.getLength() - aExpectedPrefix.getLength() - strlen(" } }"));
+                aToken = aToken.copy(strlen(aExpectedPrefix), aToken.getLength() - strlen(aExpectedPrefix) - strlen(" } }"));
                 lcl_parsePathTextFrameValues(rPath, aToken);
             }
             else if (!aToken.startsWith("Name =") && !aToken.startsWith("Handle ="))
@@ -611,9 +621,9 @@ void lcl_parsePathTextFrames(comphelper::SequenceAsVector<beans::PropertyValue>&
     }
 }
 
-void lcl_parsePathSubViewSizeValues(comphelper::SequenceAsVector<beans::PropertyValue>& rPath, const OString& rValue)
+void lcl_parsePathSubViewSizeValues(std::vector<beans::PropertyValue>& rPath, const OString& rValue)
 {
-    comphelper::SequenceAsVector<awt::Size> aSizes;
+    std::vector<awt::Size> aSizes;
     sal_Int32 nLevel = 0;
     sal_Int32 nStart = 0;
     for (sal_Int32 i = 0; i < rValue.getLength(); ++i)
@@ -634,11 +644,11 @@ void lcl_parsePathSubViewSizeValues(comphelper::SequenceAsVector<beans::Property
 
     beans::PropertyValue aPropertyValue;
     aPropertyValue.Name = "SubViewSize";
-    aPropertyValue.Value = uno::makeAny(aSizes.getAsConstList());
+    aPropertyValue.Value <<= comphelper::containerToSequence(aSizes);
     rPath.push_back(aPropertyValue);
 }
 
-void lcl_parsePathSubViewSize(comphelper::SequenceAsVector<beans::PropertyValue>& rPath, const OString& rValue)
+void lcl_parsePathSubViewSize(std::vector<beans::PropertyValue>& rPath, const OString& rValue)
 {
     sal_Int32 nLevel = 0;
     bool bIgnore = false;
@@ -660,10 +670,10 @@ void lcl_parsePathSubViewSize(comphelper::SequenceAsVector<beans::PropertyValue>
         else if (rValue[i] == ',' && !bIgnore)
         {
             OString aToken = rValue.copy(nStart, i - nStart);
-            static const OString aExpectedPrefix("Value = (any) { ([]com.sun.star.awt.Size) { ");
+            static const char aExpectedPrefix[] = "Value = (any) { ([]com.sun.star.awt.Size) { ";
             if (aToken.startsWith(aExpectedPrefix))
             {
-                aToken = aToken.copy(aExpectedPrefix.getLength(), aToken.getLength() - aExpectedPrefix.getLength() - strlen(" } }"));
+                aToken = aToken.copy(strlen(aExpectedPrefix), aToken.getLength() - strlen(aExpectedPrefix) - strlen(" } }"));
                 lcl_parsePathSubViewSizeValues(rPath, aToken);
             }
             else if (!aToken.startsWith("Name =") && !aToken.startsWith("Handle ="))
@@ -673,7 +683,7 @@ void lcl_parsePathSubViewSize(comphelper::SequenceAsVector<beans::PropertyValue>
     }
 }
 
-void lcl_parsePath(comphelper::SequenceAsVector<beans::PropertyValue>& rPath, const OString& rValue)
+void lcl_parsePath(std::vector<beans::PropertyValue>& rPath, const OString& rValue)
 {
     sal_Int32 nLevel = 0;
     sal_Int32 nStart = 0;
@@ -717,7 +727,7 @@ void CustomShapeProperties::initializePresetDataMap()
 {
     OUString aPath("$BRAND_BASE_DIR/" LIBO_SHARE_FOLDER "/filter/oox-drawingml-cs-presets");
     rtl::Bootstrap::expandMacros(aPath);
-    SvFileStream aStream(aPath, STREAM_READ);
+    SvFileStream aStream(aPath, StreamMode::READ);
     if (aStream.GetError() != ERRCODE_NONE)
         SAL_WARN("oox", "failed to open oox-drawingml-cs-presets");
     OString aLine;
@@ -727,14 +737,14 @@ void CustomShapeProperties::initializePresetDataMap()
     bool bFirst = true;
     while (bNotDone)
     {
-        static const OString aCommentPrefix("/* ");
+        static const char aCommentPrefix[] = "/* ";
         if (aLine.startsWith(aCommentPrefix))
         {
             if (bFirst)
                 bFirst = false;
             else
-                maPresetDataMap[StaticTokenMap::get().getTokenFromUnicode(aName)] = aPropertyMap;
-            aName = OUString::fromUtf8(aLine.copy(aCommentPrefix.getLength(), aLine.getLength() - aCommentPrefix.getLength() - strlen(" */")));
+                maPresetDataMap[TokenMap::getTokenFromUnicode(aName)] = aPropertyMap;
+            aName = OUString::fromUtf8(aLine.copy(strlen(aCommentPrefix), aLine.getLength() - strlen(aCommentPrefix) - strlen(" */")));
         }
         else
         {
@@ -743,13 +753,13 @@ void CustomShapeProperties::initializePresetDataMap()
                 aStream.ReadLine(aLine);
                 if (aLine != "([]com.sun.star.drawing.EnhancedCustomShapeAdjustmentValue) {}")
                 {
-                    comphelper::SequenceAsVector<drawing::EnhancedCustomShapeAdjustmentValue> aAdjustmentValues;
+                    std::vector<drawing::EnhancedCustomShapeAdjustmentValue> aAdjustmentValues;
                     OString aExpectedPrefix("([]com.sun.star.drawing.EnhancedCustomShapeAdjustmentValue) { ");
                     assert(aLine.startsWith(aExpectedPrefix));
 
                     OString aValue = aLine.copy(aExpectedPrefix.getLength(), aLine.getLength() - aExpectedPrefix.getLength() - strlen(" }"));
                     lcl_parseAdjustmentValues(aAdjustmentValues, aValue);
-                    aPropertyMap.setProperty(PROP_AdjustmentValues, aAdjustmentValues.getAsConstList());
+                    aPropertyMap.setProperty(PROP_AdjustmentValues, comphelper::containerToSequence(aAdjustmentValues));
                 }
                 else
                     aPropertyMap.setProperty(PROP_AdjustmentValues, uno::Sequence<OUString>(0));
@@ -759,13 +769,13 @@ void CustomShapeProperties::initializePresetDataMap()
                 aStream.ReadLine(aLine);
                 if (aLine != "([]string) {}")
                 {
-                    comphelper::SequenceAsVector<OUString> aEquations;
+                    std::vector<OUString> aEquations;
                     OString aExpectedPrefix("([]string) { ");
                     assert(aLine.startsWith(aExpectedPrefix));
 
                     OString aValue = aLine.copy(aExpectedPrefix.getLength(), aLine.getLength() - aExpectedPrefix.getLength() - strlen(" }"));
                     lcl_parseEquations(aEquations, aValue);
-                    aPropertyMap.setProperty(PROP_Equations, aEquations.getAsConstList());
+                    aPropertyMap.setProperty(PROP_Equations, comphelper::containerToSequence(aEquations));
                 }
                 else
                     aPropertyMap.setProperty(PROP_Equations, uno::Sequence<OUString>(0));
@@ -775,13 +785,13 @@ void CustomShapeProperties::initializePresetDataMap()
                 aStream.ReadLine(aLine);
                 if (aLine != "([][]com.sun.star.beans.PropertyValue) {}")
                 {
-                    comphelper::SequenceAsVector< uno::Sequence<beans::PropertyValue> > aHandles;
+                    std::vector< uno::Sequence<beans::PropertyValue> > aHandles;
                     OString aExpectedPrefix("([][]com.sun.star.beans.PropertyValue) { ");
                     assert(aLine.startsWith(aExpectedPrefix));
 
                     OString aValue = aLine.copy(aExpectedPrefix.getLength(), aLine.getLength() - aExpectedPrefix.getLength() - strlen(" }"));
                     lcl_parseHandles(aHandles, aValue);
-                    aPropertyMap.setProperty(PROP_Handles, aHandles.getAsConstList());
+                    aPropertyMap.setProperty(PROP_Handles, comphelper::containerToSequence(aHandles));
                 }
                 else
                     aPropertyMap.setProperty(PROP_Handles, uno::Sequence<OUString>(0));
@@ -812,10 +822,10 @@ void CustomShapeProperties::initializePresetDataMap()
                 OString aExpectedPrefix("([]com.sun.star.beans.PropertyValue) { ");
                 assert(aLine.startsWith(aExpectedPrefix));
 
-                comphelper::SequenceAsVector<beans::PropertyValue> aPathValue;
+                std::vector<beans::PropertyValue> aPathValue;
                 OString aValue = aLine.copy(aExpectedPrefix.getLength(), aLine.getLength() - aExpectedPrefix.getLength() - strlen(" }"));
                 lcl_parsePath(aPathValue, aValue);
-                aPropertyMap.setProperty(PROP_Path, aPathValue.getAsConstList());
+                aPropertyMap.setProperty(PROP_Path, comphelper::containerToSequence(aPathValue));
             }
             else if (aLine == "Type")
             {
@@ -837,7 +847,7 @@ void CustomShapeProperties::initializePresetDataMap()
         }
         bNotDone = aStream.ReadLine(aLine);
     }
-    maPresetDataMap[StaticTokenMap::get().getTokenFromUnicode(aName)] = aPropertyMap;
+    maPresetDataMap[TokenMap::getTokenFromUnicode(aName)] = aPropertyMap;
 }
 
 }
