@@ -17,29 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/drawingml/embeddedwavaudiofile.hxx"
-#include "oox/helper/attributelist.hxx"
-
-using namespace ::oox::core;
-using namespace ::com::sun::star::uno;
-using namespace ::com::sun::star::xml::sax;
-
+#include <drawingml/embeddedwavaudiofile.hxx>
+#include <oox/helper/attributelist.hxx>
+#include <oox/token/namespaces.hxx>
+#include <oox/token/tokens.hxx>
 
 namespace oox { namespace drawingml {
 
-
     // CT_EmbeddedWAVAudioFile
-    void getEmbeddedWAVAudioFile( const Relations& rRelations,
-            const Reference< XFastAttributeList >& xAttribs, EmbeddedWAVAudioFile & aAudio )
-    {
-        AttributeList attribs(xAttribs);
-
-        OUString sId = xAttribs->getOptionalValue( R_TOKEN( embed ) );
-        aAudio.msEmbed = rRelations.getFragmentPathFromRelId( sId );
-        aAudio.mbBuiltIn = attribs.getBool( XML_builtIn, false );
-        aAudio.msName = xAttribs->getOptionalValue( XML_name );
-    }
-
+OUString getEmbeddedWAVAudioFile( const core::Relations& rRelations, const AttributeList& rAttribs )
+{
+    if (rAttribs.getBool( XML_builtIn, false ))
+        return rAttribs.getString( XML_name ).get();
+    else
+        return rRelations.getFragmentPathFromRelId( rAttribs.getString( R_TOKEN(embed) ).get() );
+}
 
 } }
 
