@@ -17,31 +17,27 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/drawingml/lineproperties.hxx"
+#include <drawingml/lineproperties.hxx>
 #include <vector>
 #include <rtl/ustrbuf.hxx>
 #include <osl/diagnose.h>
 #include <com/sun/star/beans/NamedValue.hpp>
-#include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/drawing/FlagSequence.hpp>
 #include <com/sun/star/drawing/LineDash.hpp>
 #include <com/sun/star/drawing/LineJoint.hpp>
 #include <com/sun/star/drawing/LineStyle.hpp>
 #include <com/sun/star/drawing/PointSequence.hpp>
 #include <com/sun/star/drawing/PolyPolygonBezierCoords.hpp>
-#include "oox/drawingml/drawingmltypes.hxx"
-#include "oox/drawingml/shapepropertymap.hxx"
-#include "oox/helper/containerhelper.hxx"
-#include "oox/helper/graphichelper.hxx"
-#include "oox/token/tokens.hxx"
+#include <oox/drawingml/drawingmltypes.hxx>
+#include <oox/drawingml/shapepropertymap.hxx>
+#include <oox/helper/containerhelper.hxx>
+#include <oox/helper/graphichelper.hxx>
+#include <oox/token/tokens.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::drawing;
 
-using ::com::sun::star::uno::Any;
-using ::com::sun::star::uno::Reference;
-using ::com::sun::star::container::XNameContainer;
 
 namespace oox {
 namespace drawingml {
@@ -209,31 +205,36 @@ void lclPushMarkerProperties( ShapePropertyMap& rPropMap,
 
     if( !aBuffer.isEmpty() )
     {
+        bool bIsArrow = nArrowType == XML_arrow;
         sal_Int32 nLength = lclGetArrowSize( rArrowProps.moArrowLength.get( XML_med ) );
         sal_Int32 nWidth  = lclGetArrowSize( rArrowProps.moArrowWidth.get( XML_med ) );
 
         sal_Int32 nNameIndex = nWidth * 3 + nLength + 1;
         aBuffer.append( ' ' ).append( nNameIndex );
+        if (bIsArrow)
+        {
+            // Arrow marker form depends also on line width
+            aBuffer.append(' ').append(nLineWidth);
+        }
         OUString aMarkerName = aBuffer.makeStringAndClear();
 
-        bool bIsArrow = nArrowType == XML_arrow;
         double fArrowLength = 1.0;
         switch( nLength )
         {
-            case OOX_ARROWSIZE_SMALL:   fArrowLength = (bIsArrow ? 3.5 : 2.0); break;
-            case OOX_ARROWSIZE_MEDIUM:  fArrowLength = (bIsArrow ? 4.5 : 3.0); break;
-            case OOX_ARROWSIZE_LARGE:   fArrowLength = (bIsArrow ? 6.0 : 5.0); break;
+            case OOX_ARROWSIZE_SMALL:   fArrowLength = (bIsArrow ? 2.5 : 2.0); break;
+            case OOX_ARROWSIZE_MEDIUM:  fArrowLength = (bIsArrow ? 3.5 : 3.0); break;
+            case OOX_ARROWSIZE_LARGE:   fArrowLength = (bIsArrow ? 5.5 : 5.0); break;
         }
         double fArrowWidth = 1.0;
         switch( nWidth )
         {
-            case OOX_ARROWSIZE_SMALL:   fArrowWidth = (bIsArrow ? 3.5 : 2.0);  break;
-            case OOX_ARROWSIZE_MEDIUM:  fArrowWidth = (bIsArrow ? 4.5 : 3.0);  break;
-            case OOX_ARROWSIZE_LARGE:   fArrowWidth = (bIsArrow ? 6.0 : 5.0);  break;
+            case OOX_ARROWSIZE_SMALL:   fArrowWidth = (bIsArrow ? 2.5 : 2.0);  break;
+            case OOX_ARROWSIZE_MEDIUM:  fArrowWidth = (bIsArrow ? 3.5 : 3.0);  break;
+            case OOX_ARROWSIZE_LARGE:   fArrowWidth = (bIsArrow ? 5.5 : 5.0);  break;
         }
         // set arrow width relative to line width
         sal_Int32 nBaseLineWidth = ::std::max< sal_Int32 >( nLineWidth, 70 );
-        nMarkerWidth = static_cast< sal_Int32 >( fArrowWidth * nBaseLineWidth );
+        nMarkerWidth = static_cast<sal_Int32>( fArrowWidth * nBaseLineWidth );
 
         /*  Test if the marker already exists in the marker table, do not
             create it again in this case. If markers are inserted explicitly
@@ -241,8 +242,12 @@ void lclPushMarkerProperties( ShapePropertyMap& rPropMap,
             TODO: this can be optimized by using a map. */
         if( !rPropMap.hasNamedLineMarkerInTable( aMarkerName ) )
         {
-// pass X and Y as percentage to OOX_ARROW_POINT
-#define OOX_ARROW_POINT( x, y ) awt::Point( static_cast< sal_Int32 >( fArrowWidth * x ), static_cast< sal_Int32 >( fArrowLength * y ) )
+            // pass X and Y as percentage to OOX_ARROW_POINT
+            auto OOX_ARROW_POINT = [fArrowLength, fArrowWidth]( double x, double y ) { return awt::Point( static_cast< sal_Int32 >( fArrowWidth * x ), static_cast< sal_Int32 >( fArrowLength * y ) ); };
+            // tdf#100491 Arrow line marker, unlike other markers, depends on line width.
+            // So calculate width of half line (more convenient during drawing) taking into account
+            // further conversions/scaling done in OOX_ARROW_POINT and scaling to nMarkerWidth.
+            const double fArrowLineHalfWidth = ::std::max< double >( 100.0 * 0.5 * nLineWidth / nMarkerWidth, 1 );
 
             ::std::vector< awt::Point > aPoints;
             OSL_ASSERT((rArrowProps.moArrowType.get() & sal_Int32(0xFFFF0000))==0);
@@ -255,13 +260,16 @@ void lclPushMarkerProperties( ShapePropertyMap& rPropMap,
                     aPoints.push_back( OOX_ARROW_POINT(  50,   0 ) );
                 break;
                 case XML_arrow:
-                    aPoints.push_back( OOX_ARROW_POINT(  50,   0 ) );
-                    aPoints.push_back( OOX_ARROW_POINT( 100,  91 ) );
-                    aPoints.push_back( OOX_ARROW_POINT(  85, 100 ) );
-                    aPoints.push_back( OOX_ARROW_POINT(  50,  36 ) );
-                    aPoints.push_back( OOX_ARROW_POINT(  15, 100 ) );
-                    aPoints.push_back( OOX_ARROW_POINT(   0,  91 ) );
-                    aPoints.push_back( OOX_ARROW_POINT(  50,   0 ) );
+                    aPoints.push_back( OOX_ARROW_POINT( 50, 0 ) );
+                    aPoints.push_back( OOX_ARROW_POINT( 100, 100 - fArrowLineHalfWidth * 1.5) );
+                    aPoints.push_back( OOX_ARROW_POINT( 100 - fArrowLineHalfWidth * 1.5, 100 ) );
+                    aPoints.push_back( OOX_ARROW_POINT( 50.0 + fArrowLineHalfWidth, 5.5 * fArrowLineHalfWidth) );
+                    aPoints.push_back( OOX_ARROW_POINT( 50.0 + fArrowLineHalfWidth, 100 ) );
+                    aPoints.push_back( OOX_ARROW_POINT( 50.0 - fArrowLineHalfWidth, 100 ) );
+                    aPoints.push_back( OOX_ARROW_POINT( 50.0 - fArrowLineHalfWidth, 5.5 * fArrowLineHalfWidth) );
+                    aPoints.push_back( OOX_ARROW_POINT( fArrowLineHalfWidth * 1.5, 100 ) );
+                    aPoints.push_back( OOX_ARROW_POINT( 0, 100 - fArrowLineHalfWidth * 1.5) );
+                    aPoints.push_back( OOX_ARROW_POINT( 50, 0 ) );
                 break;
                 case XML_stealth:
                     aPoints.push_back( OOX_ARROW_POINT(  50,   0 ) );
@@ -293,7 +301,6 @@ void lclPushMarkerProperties( ShapePropertyMap& rPropMap,
                     aPoints.push_back( OOX_ARROW_POINT(  50,   0 ) );
                 break;
             }
-#undef OOX_ARROW_POINT
 
             OSL_ENSURE( !aPoints.empty(), "lclPushMarkerProperties - missing arrow coordinates" );
             if( !aPoints.empty() )
@@ -324,15 +331,15 @@ void lclPushMarkerProperties( ShapePropertyMap& rPropMap,
     {
         if( bLineEnd )
         {
-            rPropMap.setProperty( SHAPEPROP_LineEnd, aNamedMarker );
-            rPropMap.setProperty( SHAPEPROP_LineEndWidth, nMarkerWidth );
-            rPropMap.setProperty( SHAPEPROP_LineEndCenter, bMarkerCenter );
+            rPropMap.setProperty( ShapeProperty::LineEnd, aNamedMarker );
+            rPropMap.setProperty( ShapeProperty::LineEndWidth, nMarkerWidth );
+            rPropMap.setProperty( ShapeProperty::LineEndCenter, bMarkerCenter );
         }
         else
         {
-            rPropMap.setProperty( SHAPEPROP_LineStart, aNamedMarker );
-            rPropMap.setProperty( SHAPEPROP_LineStartWidth, nMarkerWidth );
-            rPropMap.setProperty( SHAPEPROP_LineStartCenter, bMarkerCenter );
+            rPropMap.setProperty( ShapeProperty::LineStart, aNamedMarker );
+            rPropMap.setProperty( ShapeProperty::LineStartWidth, nMarkerWidth );
+            rPropMap.setProperty( ShapeProperty::LineStartCenter, bMarkerCenter );
         }
     }
 }
@@ -390,27 +397,27 @@ void LineProperties::pushToPropMap( ShapePropertyMap& rPropMap,
             aLineDash.DashLen *= nBaseLineWidth;
             aLineDash.Distance *= nBaseLineWidth;
 
-            if( rPropMap.setProperty( SHAPEPROP_LineDash, aLineDash ) )
+            if( rPropMap.setProperty( ShapeProperty::LineDash, aLineDash ) )
                 eLineStyle = drawing::LineStyle_DASH;
         }
 
         // set final line style property
-        rPropMap.setProperty( SHAPEPROP_LineStyle, eLineStyle );
+        rPropMap.setProperty( ShapeProperty::LineStyle, eLineStyle );
 
         // line joint type
         if( moLineJoint.has() )
-            rPropMap.setProperty( SHAPEPROP_LineJoint, lclGetLineJoint( moLineJoint.get() ) );
+            rPropMap.setProperty( ShapeProperty::LineJoint, lclGetLineJoint( moLineJoint.get() ) );
 
         // line width in 1/100mm
-        rPropMap.setProperty( SHAPEPROP_LineWidth, nLineWidth );
+        rPropMap.setProperty( ShapeProperty::LineWidth, nLineWidth );
 
         // line color and transparence
         Color aLineColor = maLineFill.getBestSolidColor();
         if( aLineColor.isUsed() )
         {
-            rPropMap.setProperty( SHAPEPROP_LineColor, aLineColor.getColor( rGraphicHelper, nPhClr ) );
+            rPropMap.setProperty( ShapeProperty::LineColor, aLineColor.getColor( rGraphicHelper, nPhClr ) );
             if( aLineColor.hasTransparency() )
-                rPropMap.setProperty( SHAPEPROP_LineTransparency, aLineColor.getTransparency() );
+                rPropMap.setProperty( ShapeProperty::LineTransparency, aLineColor.getTransparency() );
         }
 
         // line markers
