@@ -17,9 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/ole/axbinaryreader.hxx"
+#include <oox/ole/axbinaryreader.hxx>
 
-#include "oox/ole/olehelper.hxx"
+#include <oox/ole/axfontdata.hxx>
+#include <oox/ole/olehelper.hxx>
 
 #include <osl/diagnose.h>
 
@@ -167,7 +168,7 @@ bool AxBinaryPropertyReader::FontProperty::readProperty( AxAlignedInputStream& r
 
 bool AxBinaryPropertyReader::PictureProperty::readProperty( AxAlignedInputStream& rInStrm )
 {
-    return OleHelper::importStdPic( mrPicData, rInStrm, true );
+    return OleHelper::importStdPic( mrPicData, rInStrm );
 }
 
 AxBinaryPropertyReader::AxBinaryPropertyReader( BinaryInputStream& rInStrm, bool b64BitPropFlags ) :
