@@ -17,6 +17,7 @@
 
 #include <tools/stream.hxx>
 
+#include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/script/XLibraryContainer.hpp>
 #include <com/sun/star/script/vba/XVBAModuleInfo.hpp>
 #include <com/sun/star/script/vba/XVBACompatibility.hpp>
@@ -25,8 +26,8 @@
 #include <ooo/vba/excel/XWorkbook.hpp>
 
 #include <oox/helper/binaryoutputstream.hxx>
-#include "oox/helper/propertyset.hxx"
-#include "oox/token/properties.hxx"
+#include <oox/helper/propertyset.hxx>
+#include <oox/token/properties.hxx>
 
 #include <sot/storage.hxx>
 
@@ -73,7 +74,7 @@ void exportUTF16String(SvStream& rStrm, const OUString& rString)
     }
 }
 
-bool isWorkbook(css::uno::Reference<css::uno::XInterface> xInterface)
+bool isWorkbook(const css::uno::Reference<css::uno::XInterface>& xInterface)
 {
     css::uno::Reference<ooo::vba::excel::XWorkbook> xWorkbook(xInterface, css::uno::UNO_QUERY);
     return xWorkbook.is();
@@ -87,7 +88,7 @@ OUString createHexStringFromDigit(sal_uInt8 nDigit)
     return aString.toAsciiUpperCase();
 }
 
-OUString createGuidStringFromInt(sal_uInt8 nGuid[16])
+OUString createGuidStringFromInt(sal_uInt8 const nGuid[16])
 {
     OUStringBuffer aBuffer;
     aBuffer.append('{');
@@ -111,7 +112,7 @@ OUString generateGUIDString()
 
 }
 
-VBACompressionChunk::VBACompressionChunk(SvStream& rCompressedStream, const sal_uInt8* pData, sal_Size nChunkSize)
+VBACompressionChunk::VBACompressionChunk(SvStream& rCompressedStream, const sal_uInt8* pData, std::size_t nChunkSize)
     : mrCompressedStream(rCompressedStream)
     , mpUncompressedData(pData)
     , mpCompressedChunkStream(nullptr)
@@ -176,7 +177,7 @@ void VBACompressionChunk::write()
         sal_uInt16 nHeader = handleHeader(true);
         setUInt16(pCompressedChunkStream, 0, nHeader);
         // copy the compressed stream to our output stream
-        mrCompressedStream.Write(pCompressedChunkStream, mnCompressedCurrent);
+        mrCompressedStream.WriteBytes(pCompressedChunkStream, mnCompressedCurrent);
     }
 }
 
@@ -355,8 +356,8 @@ void VBACompressionChunk::writeRawChunk()
 {
     // we need to use up to 4096 bytes of the original stream
     // and fill the rest with padding
-    mrCompressedStream.Write(mpUncompressedData, mnChunkSize);
-    sal_Size nPadding = 4096 - mnChunkSize;
+    mrCompressedStream.WriteBytes(mpUncompressedData, mnChunkSize);
+    std::size_t nPadding = 4096 - mnChunkSize;
     for (size_t i = 0; i < nPadding; ++i)
     {
         mrCompressedStream.WriteUInt8(0);
@@ -377,11 +378,11 @@ void VBACompression::write()
     mrCompressedStream.WriteUInt8(0x01); // signature byte of a compressed container
     bool bStreamNotEnded = true;
     const sal_uInt8* pData = static_cast<const sal_uInt8*>(mrUncompressedStream.GetData());
-    sal_Size nSize = mrUncompressedStream.GetEndOfData();
-    sal_Size nRemainingSize = nSize;
+    std::size_t nSize = mrUncompressedStream.GetEndOfData();
+    std::size_t nRemainingSize = nSize;
     while(bStreamNotEnded)
     {
-        sal_Size nChunkSize = nRemainingSize > 4096 ? 4096 : nRemainingSize;
+        std::size_t nChunkSize = nRemainingSize > 4096 ? 4096 : nRemainingSize;
         VBACompressionChunk aChunk(mrCompressedStream, &pData[nSize - nRemainingSize], nChunkSize);
         aChunk.write();
 
@@ -394,26 +395,22 @@ void VBACompression::write()
 // section 2.4.3
 #if VBA_ENCRYPTION
 
-VBAEncryption::VBAEncryption(const sal_uInt8* pData, const sal_uInt16 length, SvStream& rEncryptedData, sal_uInt8* pSeed, sal_uInt8 nProjKey)
+VBAEncryption::VBAEncryption(const sal_uInt8* pData, const sal_uInt16 length, SvStream& rEncryptedData, sal_uInt8 nProjKey)
     :mpData(pData)
     ,mnLength(length)
     ,mrEncryptedData(rEncryptedData)
     ,mnUnencryptedByte1(0)
     ,mnEncryptedByte1(0)
     ,mnEncryptedByte2(0)
-    ,mnVersion(2)
     ,mnProjKey(nProjKey)
     ,mnIgnoredLength(0)
-    ,mnSeed(pSeed ? *pSeed : 0x00)
+    ,mnSeed(0x00)
     ,mnVersionEnc(0)
 {
-    if (!pSeed)
-    {
-        std::random_device rd;
-        std::mt19937 gen(rd());
-        std::uniform_int_distribution<> dis(0, 255);
-        mnSeed = dis(gen);
-    }
+    std::random_device rd;
+    std::mt19937 gen(rd());
+    std::uniform_int_distribution<> dis(0, 255);
+    mnSeed = dis(gen);
 }
 
 void VBAEncryption::writeSeed()
@@ -423,6 +420,7 @@ void VBAEncryption::writeSeed()
 
 void VBAEncryption::writeVersionEnc()
 {
+    static const sal_uInt8 mnVersion = 2; // the encrypted version
     mnVersionEnc = mnSeed ^ mnVersion;
     exportString(mrEncryptedData, createHexStringFromDigit(mnVersionEnc));
 }
@@ -508,7 +506,7 @@ void VBAEncryption::write()
 
 #endif
 
-VbaExport::VbaExport(css::uno::Reference<css::frame::XModel> xModel):
+VbaExport::VbaExport(css::uno::Reference<css::frame::XModel> const & xModel):
     mxModel(xModel)
 {
 }
@@ -762,7 +760,7 @@ void writePROJECTMODULE(SvStream& rStrm, const OUString& name, const sal_uInt16
 }
 
 // section 2.3.4.2.3
-void writePROJECTMODULES(SvStream& rStrm, css::uno::Reference<css::container::XNameContainer> xNameContainer, const std::vector<sal_Int32>& rLibrayMap)
+void writePROJECTMODULES(SvStream& rStrm, const css::uno::Reference<css::container::XNameContainer>& xNameContainer, const std::vector<sal_Int32>& rLibrayMap)
 {
     css::uno::Sequence<OUString> aElementNames = xNameContainer->getElementNames();
     sal_Int32 n = aElementNames.getLength();
@@ -785,7 +783,7 @@ void writePROJECTMODULES(SvStream& rStrm, css::uno::Reference<css::container::XN
 }
 
 // section 2.3.4.2
-void exportDirStream(SvStream& rStrm, css::uno::Reference<css::container::XNameContainer> xNameContainer, const std::vector<sal_Int32>& rLibraryMap, const OUString& projectName)
+void exportDirStream(SvStream& rStrm, const css::uno::Reference<css::container::XNameContainer>& xNameContainer, const std::vector<sal_Int32>& rLibraryMap, const OUString& projectName)
 {
     SvMemoryStream aDirStream(4096, 4096);
 
@@ -799,7 +797,7 @@ void exportDirStream(SvStream& rStrm, css::uno::Reference<css::container::XNameC
 
 #if VBA_EXPORT_DEBUG
     const OUString aDirFileName("/tmp/vba_dir_out.bin");
-    SvFileStream aDirStreamDebug(aDirFileName, STREAM_READWRITE);
+    SvFileStream aDirStreamDebug(aDirFileName, StreamMode::READWRITE);
 
     aDirStreamDebug.WriteStream(aDirStream);
     aDirStream.Seek(0);
@@ -814,7 +812,7 @@ void exportDirStream(SvStream& rStrm, css::uno::Reference<css::container::XNameC
 }
 
 // section 2.3.4.3 Module Stream
-void exportModuleStream(SvStream& rStrm, const OUString& rSourceCode, const OUString& aElementName, css::script::ModuleInfo& rInfo)
+void exportModuleStream(SvStream& rStrm, const OUString& rSourceCode, const OUString& aElementName, css::script::ModuleInfo const & rInfo)
 {
     SvMemoryStream aModuleStream(4096, 4096);
 
@@ -844,7 +842,7 @@ void exportModuleStream(SvStream& rStrm, const OUString& rSourceCode, const OUSt
 
 #if VBA_EXPORT_DEBUG
     OUString aModuleFileName("/tmp/vba_" + aElementName + "_out.bin");
-    SvFileStream aModuleStreamDebug(aModuleFileName, STREAM_READWRITE);
+    SvFileStream aModuleStreamDebug(aModuleFileName, StreamMode::READWRITE);
     aModuleStreamDebug.WriteStream(aModuleStream);
     aModuleStream.Seek(0);
 #endif
@@ -867,7 +865,7 @@ void exportVBAProjectStream(SvStream& rStrm)
 }
 
 // section 2.3.1 PROJECT Stream
-void exportPROJECTStream(SvStream& rStrm, css::uno::Reference<css::container::XNameContainer> xNameContainer,
+void exportPROJECTStream(SvStream& rStrm, const css::uno::Reference<css::container::XNameContainer>& xNameContainer,
         const OUString& projectName, const std::vector<sal_Int32>& rLibraryMap)
 {
     css::uno::Sequence<OUString> aElementNames = xNameContainer->getElementNames();
@@ -914,7 +912,7 @@ void exportPROJECTStream(SvStream& rStrm, css::uno::Reference<css::container::XN
     aProtectedStream.WriteUInt32(0x00000000);
     const sal_uInt8* pData = static_cast<const sal_uInt8*>(aProtectedStream.GetData());
     sal_uInt8 nProjKey = VBAEncryption::calculateProjKey(aProjectID);
-    VBAEncryption aProtectionState(pData, 4, rStrm, nullptr, nProjKey);
+    VBAEncryption aProtectionState(pData, 4, rStrm, nProjKey);
     aProtectionState.write();
     exportString(rStrm, "\"\r\n");
 #else
@@ -927,7 +925,7 @@ void exportPROJECTStream(SvStream& rStrm, css::uno::Reference<css::container::XN
     aProtectedStream.Seek(0);
     aProtectedStream.WriteUInt8(0x00);
     pData = static_cast<const sal_uInt8*>(aProtectedStream.GetData());
-    VBAEncryption aProjectPassword(pData, 1, rStrm, nullptr, nProjKey);
+    VBAEncryption aProjectPassword(pData, 1, rStrm, nProjKey);
     aProjectPassword.write();
     exportString(rStrm, "\"\r\n");
 #else
@@ -940,7 +938,7 @@ void exportPROJECTStream(SvStream& rStrm, css::uno::Reference<css::container::XN
     aProtectedStream.Seek(0);
     aProtectedStream.WriteUInt8(0xFF);
     pData = static_cast<const sal_uInt8*>(aProtectedStream.GetData());
-    VBAEncryption aVisibilityState(pData, 1, rStrm, nullptr, nProjKey);
+    VBAEncryption aVisibilityState(pData, 1, rStrm, nProjKey);
     aVisibilityState.write();
     exportString(rStrm, "\"\r\n\r\n");
 #else
@@ -992,7 +990,7 @@ void exportPROJECTwmStream(SvStream& rStrm, const css::uno::Sequence<OUString>&
     rStrm.WriteUInt16(0x0000); // terminator
 }
 
-void getCorrectExportOrder(css::uno::Reference<css::container::XNameContainer> xNameContainer, std::vector<sal_Int32>& rLibraryMap)
+void getCorrectExportOrder(const css::uno::Reference<css::container::XNameContainer>& xNameContainer, std::vector<sal_Int32>& rLibraryMap)
 {
     css::uno::Sequence<OUString> aElementNames = xNameContainer->getElementNames();
     sal_Int32 n = aElementNames.getLength();
@@ -1046,7 +1044,7 @@ void getCorrectExportOrder(css::uno::Reference<css::container::XNameContainer> x
     || VBA_USE_ORIGINAL_DIR_STREAM
 void addFileStreamToSotStream(const OUString& rPath, SotStorageStream* pStream)
 {
-    SvFileStream aFileStream(rPath, STREAM_READWRITE);
+    SvFileStream aFileStream(rPath, StreamMode::READWRITE);
     pStream->WriteStream(aFileStream);
 }
 #endif
@@ -1065,12 +1063,12 @@ void VbaExport::exportVBA(SotStorage* pRootStorage)
     getCorrectExportOrder(xNameContainer, aLibraryMap);
 
     // start here with the VBA export
-    SotStorage* pVBAStream = pRootStorage->OpenSotStorage("VBA", STREAM_READWRITE);
-    SotStorageStream* pDirStream = pVBAStream->OpenSotStream("dir", STREAM_READWRITE);
+    tools::SvRef<SotStorage> xVBAStream = pRootStorage->OpenSotStorage("VBA", StreamMode::READWRITE);
+    SotStorageStream* pDirStream = xVBAStream->OpenSotStream("dir", StreamMode::READWRITE);
 
-    SotStorageStream* pVBAProjectStream = pVBAStream->OpenSotStream("_VBA_PROJECT", STREAM_READWRITE);
-    SotStorageStream* pPROJECTStream = pRootStorage->OpenSotStream("PROJECT", STREAM_READWRITE);
-    SotStorageStream* pPROJECTwmStream = pRootStorage->OpenSotStream("PROJECTwm", STREAM_READWRITE);
+    SotStorageStream* pVBAProjectStream = xVBAStream->OpenSotStream("_VBA_PROJECT", StreamMode::READWRITE);
+    SotStorageStream* pPROJECTStream = pRootStorage->OpenSotStream("PROJECT", StreamMode::READWRITE);
+    SotStorageStream* pPROJECTwmStream = pRootStorage->OpenSotStream("PROJECTwm", StreamMode::READWRITE);
 
 #if VBA_USE_ORIGINAL_WM_STREAM
     OUString aProjectwmPath = "/home/moggi/Documents/testfiles/vba/PROJECTwm";
@@ -1106,11 +1104,11 @@ void VbaExport::exportVBA(SotStorage* pRootStorage)
     OUString aSheet2Path = "/home/moggi/Documents/testfiles/vba/VBA/Sheet2";
     OUString aSheet3Path = "/home/moggi/Documents/testfiles/vba/VBA/Sheet3";
     OUString aWorkbookPath = "/home/moggi/Documents/testfiles/vba/VBA/ThisWorkbook";
-    SotStorageStream* pModule1Stream = pVBAStream->OpenSotStream("Module1", STREAM_READWRITE);
-    SotStorageStream* pSheet1Stream = pVBAStream->OpenSotStream("Sheet1", STREAM_READWRITE);
-    SotStorageStream* pSheet2Stream = pVBAStream->OpenSotStream("Sheet2", STREAM_READWRITE);
-    SotStorageStream* pSheet3Stream = pVBAStream->OpenSotStream("Sheet3", STREAM_READWRITE);
-    SotStorageStream* pWorkbookStream = pVBAStream->OpenSotStream("ThisWorkbook", STREAM_READWRITE);
+    SotStorageStream* pModule1Stream = xVBAStream->OpenSotStream("Module1", StreamMode::READWRITE);
+    SotStorageStream* pSheet1Stream = xVBAStream->OpenSotStream("Sheet1", StreamMode::READWRITE);
+    SotStorageStream* pSheet2Stream = xVBAStream->OpenSotStream("Sheet2", StreamMode::READWRITE);
+    SotStorageStream* pSheet3Stream = xVBAStream->OpenSotStream("Sheet3", StreamMode::READWRITE);
+    SotStorageStream* pWorkbookStream = xVBAStream->OpenSotStream("ThisWorkbook", StreamMode::READWRITE);
     addFileStreamToSotStream(aModule1Path, pModule1Stream);
     addFileStreamToSotStream(aSheet1Path, pSheet1Stream);
     addFileStreamToSotStream(aSheet2Path, pSheet2Stream);
@@ -1128,7 +1126,7 @@ void VbaExport::exportVBA(SotStorage* pRootStorage)
     for (sal_Int32 i = 0; i < n; ++i)
     {
         const OUString& rModuleName = aElementNames[aLibraryMap[i]];
-        SotStorageStream* pModuleStream = pVBAStream->OpenSotStream(rModuleName, STREAM_READWRITE);
+        SotStorageStream* pModuleStream = xVBAStream->OpenSotStream(rModuleName, StreamMode::READWRITE);
         css::uno::Any aCode = xNameContainer->getByName(rModuleName);
         css::script::ModuleInfo aModuleInfo = xModuleInfo->getModuleInfo(rModuleName);
         OUString aSourceCode;
@@ -1142,7 +1140,7 @@ void VbaExport::exportVBA(SotStorage* pRootStorage)
     pVBAProjectStream->Commit();
 
     pDirStream->Commit();
-    pVBAStream->Commit();
+    xVBAStream->Commit();
     pPROJECTStream->Commit();
     pPROJECTwmStream->Commit();
     pRootStorage->Commit();
