@@ -17,18 +17,24 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/ppt/dgmlayout.hxx"
-#include "oox/drawingml/theme.hxx"
-#include "oox/drawingml/themefragmenthandler.hxx"
-#include "oox/drawingml/diagram/diagram.hxx"
-#include "oox/dump/pptxdumper.hxx"
+#include <basegfx/matrix/b2dhommatrix.hxx>
+#include <oox/ppt/dgmlayout.hxx>
+#include <oox/drawingml/theme.hxx>
+#include <oox/drawingml/themefragmenthandler.hxx>
+#include <drawingml/diagram/diagram.hxx>
+#include <oox/dump/pptxdumper.hxx>
 
+#include <com/sun/star/awt/Rectangle.hpp>
+#include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/drawing/XShape.hpp>
 #include <com/sun/star/drawing/XMasterPageTarget.hpp>
+#include <com/sun/star/uno/XComponentContext.hpp>
 #include <com/sun/star/xml/dom/XDocument.hpp>
 #include <com/sun/star/xml/sax/XFastSAXSerializable.hpp>
 #include <com/sun/star/container/XChild.hpp>
 
+#include <services.hxx>
+
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::xml::sax;
@@ -37,21 +43,21 @@ using namespace ::oox::drawingml;
 
 namespace oox { namespace ppt {
 
-OUString SAL_CALL QuickDiagrammingLayout_getImplementationName() throw()
+OUString SAL_CALL QuickDiagrammingLayout_getImplementationName()
 {
     return OUString( "com.sun.star.comp.Impress.oox.QuickDiagrammingLayout" );
 }
 
-uno::Sequence< OUString > SAL_CALL QuickDiagrammingLayout_getSupportedServiceNames() throw()
+uno::Sequence< OUString > SAL_CALL QuickDiagrammingLayout_getSupportedServiceNames()
 {
     const OUString aServiceName = "com.sun.star.comp.ooxpptx.dgm.layout";
     const Sequence< OUString > aSeq( &aServiceName, 1 );
     return aSeq;
 }
 
-uno::Reference< uno::XInterface > SAL_CALL QuickDiagrammingLayout_createInstance( const Reference< XComponentContext >& rxContext ) throw( Exception )
+uno::Reference< uno::XInterface > SAL_CALL QuickDiagrammingLayout_createInstance( const Reference< XComponentContext >& rxContext )
 {
-    return (cppu::OWeakObject*)new QuickDiagrammingLayout( rxContext );
+    return static_cast<cppu::OWeakObject*>(new QuickDiagrammingLayout( rxContext ));
 }
 
 QuickDiagrammingLayout::QuickDiagrammingLayout( const Reference< XComponentContext >& rxContext )
@@ -59,7 +65,7 @@ QuickDiagrammingLayout::QuickDiagrammingLayout( const Reference< XComponentConte
     mpThemePtr(new drawingml::Theme())
 {}
 
-bool QuickDiagrammingLayout::importDocument() throw()
+bool QuickDiagrammingLayout::importDocument()
 {
     Reference<drawing::XShape>  xParentShape(getParentShape(),
                                              UNO_QUERY_THROW);
@@ -117,19 +123,11 @@ bool QuickDiagrammingLayout::importDocument() throw()
     // don't add pShape itself, but only its children
     pShape->setXShape(getParentShape());
 
-    const awt::Size& rSize=xParentShape->getSize();
-    const awt::Point& rPoint=xParentShape->getPosition();
-    const long nScaleFactor=360;
-    const awt::Rectangle aRect(nScaleFactor*rPoint.X,
-                               nScaleFactor*rPoint.Y,
-                               nScaleFactor*rSize.Width,
-                               nScaleFactor*rSize.Height);
     basegfx::B2DHomMatrix aMatrix;
     pShape->addChildren( *this,
                          mpThemePtr.get(),
                          xParentShapes,
-                         aMatrix,
-                         &aRect );
+                         aMatrix );
 
     return true;
 }
@@ -144,15 +142,6 @@ const ::oox::drawingml::Theme* QuickDiagrammingLayout::getCurrentTheme() const
     return mpThemePtr.get();
 }
 
-sal_Int32 QuickDiagrammingLayout::getSchemeClr( sal_Int32 nColorSchemeToken ) const
-{
-    sal_Int32 nColor = 0;
-    if( mpThemePtr )
-        mpThemePtr->getClrScheme().getColor( nColorSchemeToken,
-                                             nColor );
-    return nColor;
-}
-
 const oox::drawingml::table::TableStyleListPtr QuickDiagrammingLayout::getTableStyles()
 {
     return oox::drawingml::table::TableStyleListPtr();
@@ -160,22 +149,22 @@ const oox::drawingml::table::TableStyleListPtr QuickDiagrammingLayout::getTableS
 
 ::oox::vml::Drawing* QuickDiagrammingLayout::getVmlDrawing()
 {
-    return 0;
+    return nullptr;
 }
 
 ::oox::drawingml::chart::ChartConverter* QuickDiagrammingLayout::getChartConverter()
 {
-    return 0;
+    return nullptr;
 }
 
-OUString QuickDiagrammingLayout::implGetImplementationName() const
+OUString QuickDiagrammingLayout::getImplementationName()
 {
     return QuickDiagrammingLayout_getImplementationName();
 }
 
 ::oox::ole::VbaProject* QuickDiagrammingLayout::implCreateVbaProject() const
 {
-    return 0;
+    return nullptr;
 }
 
 }}
