@@ -19,7 +19,9 @@
 
 #include "ocompinstream.hxx"
 #include <com/sun/star/embed/StorageFormats.hpp>
+#include <com/sun/star/io/IOException.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
+#include <cppuhelper/queryinterface.hxx>
 #include <osl/diagnose.h>
 
 #include "owriteablestream.hxx"
@@ -28,61 +30,57 @@
 using namespace ::com::sun::star;
 
 OInputCompStream::OInputCompStream( OWriteStream_Impl& aImpl,
-                                    uno::Reference < io::XInputStream > xStream,
+                                    uno::Reference < io::XInputStream > const & xStream,
                                     const uno::Sequence< beans::PropertyValue >& aProps,
                                     sal_Int32 nStorageType )
 : m_pImpl( &aImpl )
-, m_rMutexRef( m_pImpl->m_rMutexRef )
+, m_xMutex( m_pImpl->m_xMutex )
 , m_xStream( xStream )
-, m_pInterfaceContainer( NULL )
+, m_pInterfaceContainer( nullptr )
 , m_aProperties( aProps )
-, m_bDisposed( sal_False )
+, m_bDisposed( false )
 , m_nStorageType( nStorageType )
 {
-    OSL_ENSURE( m_pImpl->m_rMutexRef.Is(), "No mutex is provided!\n" );
-    if ( !m_pImpl->m_rMutexRef.Is() )
+    OSL_ENSURE( m_pImpl->m_xMutex.is(), "No mutex is provided!" );
+    if ( !m_pImpl->m_xMutex.is() )
         throw uno::RuntimeException(); // just a disaster
 
-    OSL_ENSURE( xStream.is(), "No stream is provided!\n" );
+    assert(m_xStream.is());
 }
 
-OInputCompStream::OInputCompStream( uno::Reference < io::XInputStream > xStream,
+OInputCompStream::OInputCompStream( uno::Reference < io::XInputStream > const & xStream,
                                     const uno::Sequence< beans::PropertyValue >& aProps,
                                     sal_Int32 nStorageType )
-: m_pImpl( NULL )
-, m_rMutexRef( new SotMutexHolder )
+: m_pImpl( nullptr )
+, m_xMutex( new comphelper::RefCountedMutex )
 , m_xStream( xStream )
-, m_pInterfaceContainer( NULL )
+, m_pInterfaceContainer( nullptr )
 , m_aProperties( aProps )
-, m_bDisposed( sal_False )
+, m_bDisposed( false )
 , m_nStorageType( nStorageType )
 {
-    OSL_ENSURE( xStream.is(), "No stream is provided!\n" );
+    assert(m_xStream.is());
 }
 
 OInputCompStream::~OInputCompStream()
 {
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
+
+    if ( !m_bDisposed )
     {
-        ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
-
-        if ( !m_bDisposed )
-        {
-            m_refCount++;
-            dispose();
-        }
-
-        if ( m_pInterfaceContainer )
-            delete m_pInterfaceContainer;
+        m_refCount++;
+        dispose();
     }
+
+    delete m_pInterfaceContainer;
 }
 
 uno::Any SAL_CALL OInputCompStream::queryInterface( const uno::Type& rType )
-        throw( uno::RuntimeException )
 {
     uno::Any aReturn;
 
     // common interfaces
-    aReturn <<= ::cppu::queryInterface
+    aReturn = ::cppu::queryInterface
                 (   rType
                     ,   static_cast<io::XInputStream*> ( this )
                     ,   static_cast<io::XStream*> ( this )
@@ -90,16 +88,16 @@ uno::Any SAL_CALL OInputCompStream::queryInterface( const uno::Type& rType )
                     ,   static_cast<beans::XPropertySet*> ( this )
                     ,   static_cast<embed::XExtendedStorageStream*> ( this ) );
 
-    if ( aReturn.hasValue() == sal_True )
+    if ( aReturn.hasValue() )
         return aReturn ;
 
     if ( m_nStorageType == embed::StorageFormats::OFOPXML )
     {
-        aReturn <<= ::cppu::queryInterface
+        aReturn = ::cppu::queryInterface
                     (   rType
                         ,   static_cast<embed::XRelationshipAccess*> ( this ) );
 
-        if ( aReturn.hasValue() == sal_True )
+        if ( aReturn.hasValue() )
             return aReturn ;
     }
 
@@ -107,126 +105,79 @@ uno::Any SAL_CALL OInputCompStream::queryInterface( const uno::Type& rType )
 }
 
 sal_Int32 SAL_CALL OInputCompStream::readBytes( uno::Sequence< sal_Int8 >& aData, sal_Int32 nBytesToRead )
-        throw ( io::NotConnectedException,
-                io::BufferSizeExceededException,
-                io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
-    if ( !m_xStream.is() )
-    {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "No stream!" );
-        throw uno::RuntimeException();
-    }
-
     return m_xStream->readBytes( aData, nBytesToRead );
 }
 
 sal_Int32 SAL_CALL OInputCompStream::readSomeBytes( uno::Sequence< sal_Int8 >& aData, sal_Int32 nMaxBytesToRead )
-        throw ( io::NotConnectedException,
-                io::BufferSizeExceededException,
-                io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
-    if ( !m_xStream.is() )
-    {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "No stream!" );
-        throw uno::RuntimeException();
-    }
-
     return m_xStream->readSomeBytes( aData, nMaxBytesToRead );
 
 }
 
 void SAL_CALL OInputCompStream::skipBytes( sal_Int32 nBytesToSkip )
-        throw ( io::NotConnectedException,
-                io::BufferSizeExceededException,
-                io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
-    if ( !m_xStream.is() )
-    {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "No stream!" );
-        throw uno::RuntimeException();
-    }
-
     m_xStream->skipBytes( nBytesToSkip );
 
 }
 
 sal_Int32 SAL_CALL OInputCompStream::available(  )
-        throw ( io::NotConnectedException,
-                io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
-    if ( !m_xStream.is() )
-    {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "No stream!" );
-        throw uno::RuntimeException();
-    }
-
     return m_xStream->available();
 
 }
 
 void SAL_CALL OInputCompStream::closeInput(  )
-        throw ( io::NotConnectedException,
-                io::IOException,
-                uno::RuntimeException )
 {
     dispose();
 }
 
 uno::Reference< io::XInputStream > SAL_CALL OInputCompStream::getInputStream()
-        throw ( uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
-    if ( !m_xStream.is() )
-        return uno::Reference< io::XInputStream >();
-
     return uno::Reference< io::XInputStream >( static_cast< io::XInputStream* >( this ), uno::UNO_QUERY );
 }
 
 uno::Reference< io::XOutputStream > SAL_CALL OInputCompStream::getOutputStream()
-        throw ( uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -236,10 +187,10 @@ uno::Reference< io::XOutputStream > SAL_CALL OInputCompStream::getOutputStream()
 void OInputCompStream::InternalDispose()
 {
     // can be called only by OWriteStream_Impl
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -257,17 +208,16 @@ void OInputCompStream::InternalDispose()
     catch( uno::Exception& )
     {}
 
-    m_pImpl = NULL;
-    m_bDisposed = sal_True;
+    m_pImpl = nullptr;
+    m_bDisposed = true;
 }
 
 void SAL_CALL OInputCompStream::dispose(  )
-        throw ( uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -282,35 +232,33 @@ void SAL_CALL OInputCompStream::dispose(  )
     if ( m_pImpl )
     {
         m_pImpl->InputStreamDisposed( this );
-        m_pImpl = NULL;
+        m_pImpl = nullptr;
     }
 
-    m_bDisposed = sal_True;
+    m_bDisposed = true;
 }
 
 void SAL_CALL OInputCompStream::addEventListener( const uno::Reference< lang::XEventListener >& xListener )
-        throw ( uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
     if ( !m_pInterfaceContainer )
-        m_pInterfaceContainer = new ::cppu::OInterfaceContainerHelper( m_rMutexRef->GetMutex() );
+        m_pInterfaceContainer = new ::comphelper::OInterfaceContainerHelper2( m_xMutex->GetMutex() );
 
     m_pInterfaceContainer->addInterface( xListener );
 }
 
 void SAL_CALL OInputCompStream::removeEventListener( const uno::Reference< lang::XEventListener >& xListener )
-        throw ( uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -319,14 +267,12 @@ void SAL_CALL OInputCompStream::removeEventListener( const uno::Reference< lang:
 }
 
 sal_Bool SAL_CALL OInputCompStream::hasByID(  const OUString& sID )
-        throw ( io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -336,24 +282,21 @@ sal_Bool SAL_CALL OInputCompStream::hasByID(  const OUString& sID )
     try
     {
         getRelationshipByID( sID );
-        return sal_True;
+        return true;
     }
     catch( container::NoSuchElementException& )
     {}
 
-    return sal_False;
+    return false;
 }
 
 OUString SAL_CALL OInputCompStream::getTargetByID(  const OUString& sID  )
-        throw ( container::NoSuchElementException,
-                io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -369,15 +312,12 @@ OUString SAL_CALL OInputCompStream::getTargetByID(  const OUString& sID  )
 }
 
 OUString SAL_CALL OInputCompStream::getTypeByID(  const OUString& sID  )
-        throw ( container::NoSuchElementException,
-                io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -393,15 +333,12 @@ OUString SAL_CALL OInputCompStream::getTypeByID(  const OUString& sID  )
 }
 
 uno::Sequence< beans::StringPair > SAL_CALL OInputCompStream::getRelationshipByID(  const OUString& sID  )
-        throw ( container::NoSuchElementException,
-                io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -414,7 +351,7 @@ uno::Sequence< beans::StringPair > SAL_CALL OInputCompStream::getRelationshipByI
         for ( sal_Int32 nInd2 = 0; nInd2 < aSeq[nInd1].getLength(); nInd2++ )
             if ( aSeq[nInd1][nInd2].First == "Id" )
             {
-                if ( aSeq[nInd1][nInd2].Second.equals( sID ) )
+                if ( aSeq[nInd1][nInd2].Second == sID )
                     return aSeq[nInd1];
                 break;
             }
@@ -423,14 +360,12 @@ uno::Sequence< beans::StringPair > SAL_CALL OInputCompStream::getRelationshipByI
 }
 
 uno::Sequence< uno::Sequence< beans::StringPair > > SAL_CALL OInputCompStream::getRelationshipsByType(  const OUString& sType  )
-        throw ( io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -446,7 +381,7 @@ uno::Sequence< uno::Sequence< beans::StringPair > > SAL_CALL OInputCompStream::g
         for ( sal_Int32 nInd2 = 0; nInd2 < aSeq[nInd1].getLength(); nInd2++ )
             if ( aSeq[nInd1][nInd2].First == "Type" )
             {
-                if ( aSeq[nInd1][nInd2].Second.equals( sType ) )
+                if ( aSeq[nInd1][nInd2].Second == sType )
                 {
                     aResult.realloc( nEntriesNum );
                     aResult[nEntriesNum-1] = aSeq[nInd1];
@@ -458,13 +393,12 @@ uno::Sequence< uno::Sequence< beans::StringPair > > SAL_CALL OInputCompStream::g
 }
 
 uno::Sequence< uno::Sequence< beans::StringPair > > SAL_CALL OInputCompStream::getAllRelationships()
-        throw (io::IOException, uno::RuntimeException)
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -485,16 +419,13 @@ uno::Sequence< uno::Sequence< beans::StringPair > > SAL_CALL OInputCompStream::g
     throw io::IOException(); // the relations info could not be read
 }
 
-void SAL_CALL OInputCompStream::insertRelationshipByID(  const OUString& /*sID*/, const uno::Sequence< beans::StringPair >& /*aEntry*/, ::sal_Bool /*bReplace*/  )
-        throw ( container::ElementExistException,
-                io::IOException,
-                uno::RuntimeException )
+void SAL_CALL OInputCompStream::insertRelationshipByID(  const OUString& /*sID*/, const uno::Sequence< beans::StringPair >& /*aEntry*/, sal_Bool /*bReplace*/  )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -505,15 +436,12 @@ void SAL_CALL OInputCompStream::insertRelationshipByID(  const OUString& /*sID*/
 }
 
 void SAL_CALL OInputCompStream::removeRelationshipByID(  const OUString& /*sID*/  )
-        throw ( container::NoSuchElementException,
-                io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -523,16 +451,13 @@ void SAL_CALL OInputCompStream::removeRelationshipByID(  const OUString& /*sID*/
     throw io::IOException(); // TODO: Access denied
 }
 
-void SAL_CALL OInputCompStream::insertRelationships(  const uno::Sequence< uno::Sequence< beans::StringPair > >& /*aEntries*/, ::sal_Bool /*bReplace*/  )
-        throw ( container::ElementExistException,
-                io::IOException,
-                uno::RuntimeException )
+void SAL_CALL OInputCompStream::insertRelationships(  const uno::Sequence< uno::Sequence< beans::StringPair > >& /*aEntries*/, sal_Bool /*bReplace*/  )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -543,14 +468,12 @@ void SAL_CALL OInputCompStream::insertRelationships(  const uno::Sequence< uno::
 }
 
 void SAL_CALL OInputCompStream::clearRelationships()
-        throw ( io::IOException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -561,13 +484,12 @@ void SAL_CALL OInputCompStream::clearRelationships()
 }
 
 uno::Reference< beans::XPropertySetInfo > SAL_CALL OInputCompStream::getPropertySetInfo()
-        throw ( uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -576,24 +498,19 @@ uno::Reference< beans::XPropertySetInfo > SAL_CALL OInputCompStream::getProperty
 }
 
 void SAL_CALL OInputCompStream::setPropertyValue( const OUString& aPropertyName, const uno::Any& /*aValue*/ )
-        throw ( beans::UnknownPropertyException,
-                beans::PropertyVetoException,
-                lang::IllegalArgumentException,
-                lang::WrappedTargetException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
     // all the provided properties are accessible
     for ( sal_Int32 aInd = 0; aInd < m_aProperties.getLength(); aInd++ )
     {
-        if ( m_aProperties[aInd].Name.equals( aPropertyName ) )
+        if ( m_aProperties[aInd].Name == aPropertyName )
         {
             throw beans::PropertyVetoException(); // TODO
         }
@@ -603,15 +520,12 @@ void SAL_CALL OInputCompStream::setPropertyValue( const OUString& aPropertyName,
 }
 
 uno::Any SAL_CALL OInputCompStream::getPropertyValue( const OUString& aProp )
-        throw ( beans::UnknownPropertyException,
-                lang::WrappedTargetException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -627,7 +541,7 @@ uno::Any SAL_CALL OInputCompStream::getPropertyValue( const OUString& aProp )
     // all the provided properties are accessible
     for ( sal_Int32 aInd = 0; aInd < m_aProperties.getLength(); aInd++ )
     {
-        if ( m_aProperties[aInd].Name.equals( aPropertyName ) )
+        if ( m_aProperties[aInd].Name == aPropertyName )
         {
             return m_aProperties[aInd].Value;
         }
@@ -639,15 +553,12 @@ uno::Any SAL_CALL OInputCompStream::getPropertyValue( const OUString& aProp )
 void SAL_CALL OInputCompStream::addPropertyChangeListener(
     const OUString& /*aPropertyName*/,
     const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/ )
-        throw ( beans::UnknownPropertyException,
-                lang::WrappedTargetException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -657,15 +568,12 @@ void SAL_CALL OInputCompStream::addPropertyChangeListener(
 void SAL_CALL OInputCompStream::removePropertyChangeListener(
     const OUString& /*aPropertyName*/,
     const uno::Reference< beans::XPropertyChangeListener >& /*aListener*/ )
-        throw ( beans::UnknownPropertyException,
-                lang::WrappedTargetException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -675,15 +583,12 @@ void SAL_CALL OInputCompStream::removePropertyChangeListener(
 void SAL_CALL OInputCompStream::addVetoableChangeListener(
     const OUString& /*PropertyName*/,
     const uno::Reference< beans::XVetoableChangeListener >& /*aListener*/ )
-        throw ( beans::UnknownPropertyException,
-                lang::WrappedTargetException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
@@ -693,15 +598,12 @@ void SAL_CALL OInputCompStream::addVetoableChangeListener(
 void SAL_CALL OInputCompStream::removeVetoableChangeListener(
     const OUString& /*PropertyName*/,
     const uno::Reference< beans::XVetoableChangeListener >& /*aListener*/ )
-        throw ( beans::UnknownPropertyException,
-                lang::WrappedTargetException,
-                uno::RuntimeException )
 {
-    ::osl::MutexGuard aGuard( m_rMutexRef->GetMutex() );
+    ::osl::MutexGuard aGuard( m_xMutex->GetMutex() );
 
     if ( m_bDisposed )
     {
-        ::package::StaticAddLog( OSL_LOG_PREFIX "Disposed!" );
+        SAL_INFO("package.xstor", "Disposed!");
         throw lang::DisposedException();
     }
 
