@@ -18,12 +18,13 @@
  */
 
 #include <ZipPackageEntry.hxx>
+#include <com/sun/star/lang/NoSupportException.hpp>
 #include <com/sun/star/packages/zip/ZipConstants.hpp>
 #include <osl/diagnose.h>
 
 #include <ZipPackageFolder.hxx>
 #include <ZipPackageStream.hxx>
-#include <ContentInfo.hxx>
+#include "ContentInfo.hxx"
 
 #include <comphelper/storagehelper.hxx>
 
@@ -51,17 +52,15 @@ ZipPackageEntry::ZipPackageEntry()
 ZipPackageEntry::~ZipPackageEntry()
 {
     // When the entry is destroyed it must be already disconnected from the parent
-    OSL_ENSURE( !mpParent, "The parent must be disconnected already! Memory corruption is possible!\n" );
+    OSL_ENSURE( !mpParent, "The parent must be disconnected already! Memory corruption is possible!" );
 }
 
 // XChild
 OUString SAL_CALL ZipPackageEntry::getName(  )
-    throw(RuntimeException, std::exception)
 {
     return msName;
 }
 void SAL_CALL ZipPackageEntry::setName( const OUString& aName )
-    throw(RuntimeException, std::exception)
 {
     if ( mpParent && !msName.isEmpty() && mpParent->hasByName ( msName ) )
         mpParent->removeByName ( msName );
@@ -77,7 +76,6 @@ void SAL_CALL ZipPackageEntry::setName( const OUString& aName )
         mpParent->doInsertByName ( this, false );
 }
 uno::Reference< XInterface > SAL_CALL ZipPackageEntry::getParent(  )
-        throw(RuntimeException, std::exception)
 {
     // return uno::Reference< XInterface >( xParent, UNO_QUERY );
     return uno::Reference< XInterface >( static_cast< ::cppu::OWeakObject* >( mpParent ), UNO_QUERY );
@@ -92,7 +90,6 @@ void ZipPackageEntry::doSetParent ( ZipPackageFolder * pNewParent )
 }
 
 void SAL_CALL ZipPackageEntry::setParent( const uno::Reference< XInterface >& xNewParent )
-        throw(NoSupportException, RuntimeException, std::exception)
 {
     sal_Int64 nTest(0);
     uno::Reference < XUnoTunnel > xTunnel ( xNewParent, UNO_QUERY );
@@ -110,24 +107,19 @@ void SAL_CALL ZipPackageEntry::setParent( const uno::Reference< XInterface >& xN
 }
     //XPropertySet
 uno::Reference< beans::XPropertySetInfo > SAL_CALL ZipPackageEntry::getPropertySetInfo(  )
-        throw(RuntimeException, std::exception)
 {
     return uno::Reference < beans::XPropertySetInfo > ();
 }
 void SAL_CALL ZipPackageEntry::addPropertyChangeListener( const OUString& /*aPropertyName*/, const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/ )
-        throw(beans::UnknownPropertyException, WrappedTargetException, RuntimeException, std::exception)
 {
 }
 void SAL_CALL ZipPackageEntry::removePropertyChangeListener( const OUString& /*aPropertyName*/, const uno::Reference< beans::XPropertyChangeListener >& /*aListener*/ )
-        throw(beans::UnknownPropertyException, WrappedTargetException, RuntimeException, std::exception)
 {
 }
 void SAL_CALL ZipPackageEntry::addVetoableChangeListener( const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener >& /*aListener*/ )
-        throw(beans::UnknownPropertyException, WrappedTargetException, RuntimeException, std::exception)
 {
 }
 void SAL_CALL ZipPackageEntry::removeVetoableChangeListener( const OUString& /*PropertyName*/, const uno::Reference< beans::XVetoableChangeListener >& /*aListener*/ )
-        throw(beans::UnknownPropertyException, WrappedTargetException, RuntimeException, std::exception)
 {
 }
 
