@@ -32,10 +32,11 @@ import com.sun.star.awt.XUserInputInterception;
 import com.sun.star.awt.XWindow;
 import com.sun.star.frame.XModel;
 import com.sun.star.lang.EventObject;
-import com.sun.star.lang.XMultiServiceFactory;
 import com.sun.star.uno.UnoRuntime;
+
 import java.awt.Robot;
 import java.awt.event.InputEvent;
+
 import lib.MultiMethodTest;
 import util.AccessibilityTools;
 
@@ -53,7 +54,7 @@ import util.AccessibilityTools;
 *  <li> <code>'XUserInputInterception.XModel'</code> (of type <code>XModel</code>):
 *   used as model where a mouse click or a key press could be done </li>
 * </ul> <p>
-* Test is <b> NOT </b> multithread compilant. <p>
+* Test is <b> NOT </b> multithread compliant. <p>
 * @see com.sun.star.awt.XUserInputInterception
 */
 public class _XUserInputInterception extends MultiMethodTest {
@@ -91,9 +92,10 @@ public class _XUserInputInterception extends MultiMethodTest {
     /** indicates if the mouseReleased event was called*/
     private boolean m_keyReleased2 = false;
 
-    /** get the object rlation XUserInputInterception.XModel from the
+    /** get the object relation XUserInputInterception.XModel from the
      * test environment
      */
+    @Override
     protected void before() {
         log.print("try to get object relation 'XUserInputInterception.XModel': ");
         m_XModel = (XModel)tEnv.getObjRelation("XUserInputInterception.XModel");
@@ -148,7 +150,7 @@ public class _XUserInputInterception extends MultiMethodTest {
 
         et.run();
 
-        util.utils.shortWait(tParam.getInt(util.PropertyName.SHORT_WAIT) * 2);
+        waitForEventIdle();
         log.println("key listener thread should be finished.");
 
 
@@ -171,7 +173,7 @@ public class _XUserInputInterception extends MultiMethodTest {
     }
 
     /**
-     * This test adds two different mouse klick listener to the object. <p>
+     * This test adds two different mouse click listener to the object. <p>
      *
      * Has <b> OK </b> if no exception is thrown.
      */
@@ -191,12 +193,12 @@ public class _XUserInputInterception extends MultiMethodTest {
 
     /**
      *  The test requires <CODE>addMouseClickHandler()</CODE> which adds two key listener.
-     * Then one of them will be removed. In a second thread a mouse klick event is released
+     * Then one of them will be removed. In a second thread a mouse click event is released
      * by the <CODE>robot</CODE> class.<p>
      * Has <b> OK </b> status if only one of the listener are triggered. <p>
      * The following method tests are to be completed successfully before :
      * <ul>
-     *  <li> <code> addMouseKlickHandler() </code> : adds two key listener </li>
+     *  <li> <code> addMouseClickHandler() </code> : adds two key listener </li>
      * </ul>
      */
     public void _removeMouseClickHandler() {
@@ -211,7 +213,7 @@ public class _XUserInputInterception extends MultiMethodTest {
 
         et.run();
 
-        util.utils.shortWait(tParam.getInt(util.PropertyName.SHORT_WAIT) * 2);
+        waitForEventIdle();
         log.println("mouse listener thread should be finished.");
 
         boolean bOK = m_mousePressed1 & m_mouseReleased1 &
@@ -236,6 +238,7 @@ public class _XUserInputInterception extends MultiMethodTest {
     /**
     * Forces environment recreation.
     */
+    @Override
     protected void after() {
         disposeEnvironment();
     }
@@ -394,21 +397,17 @@ public class _XUserInputInterception extends MultiMethodTest {
      * press a key with the <CODE>Robot</CODE> class
      * @see java.awt.Robot
      */
-    private class EventTrigger extends Thread{
+    private class EventTrigger implements Runnable {
 
-        /**
-         * represents a <CODE>AccessibilityTools</CODE>
-         */
-        private final AccessibilityTools at = new AccessibilityTools();
         /**
          * represents an <CODE>EventType</CODE>
          * @see EventTest.EventTriggerType
          */
-        private int eventType = 0;
+        private final int eventType;
         /**
          * represents a <CODE>XModel</CODE> of a document
          */
-        private XModel xModel = null;
+        private final XModel xModel;
 
         /**
          * Creates an instacne of this class. The parameter <CODE>eType</CODE> represents
@@ -452,10 +451,10 @@ public class _XUserInputInterception extends MultiMethodTest {
             }
         }
         /**
-         * This method cklicks into the middel of a document. It uses Accessibility
+         * This method clicks into the middle of a document. It uses Accessibility
          * to get the document and query for its position and its range to calculate
          * the middle. This values was used for <CODE>Robot</CODE> Class. This
-         * Robot class is able to move the mouse and to cklick a mouse button
+         * Robot class is able to move the mouse and to click a mouse button
          * @see java.awt.Robot
         */
         private void clickIntoDoc(){
@@ -464,7 +463,6 @@ public class _XUserInputInterception extends MultiMethodTest {
                 util.DesktopTools.bringWindowToFront(xModel);
 
                 XWindow xWindow = AccessibilityTools.getCurrentWindow(
-                                          (XMultiServiceFactory) tParam.getMSF(),
                                           xModel);
 
                 XAccessible xRoot = AccessibilityTools.getAccessibleObject(xWindow);
@@ -484,7 +482,7 @@ public class _XUserInputInterception extends MultiMethodTest {
                     Robot rob = new Robot();
                     int x = point.X + (rect.Width / 2);
                     int y = point.Y + (rect.Height / 2);
-                    log.println("try to klick into the middle of the document");
+                    log.println("try to click into the middle of the document");
                     rob.mouseMove(x, y);
                     rob.mousePress(InputEvent.BUTTON1_MASK);
                     rob.mouseRelease(InputEvent.BUTTON1_MASK);
@@ -520,11 +518,11 @@ public class _XUserInputInterception extends MultiMethodTest {
     */
     private interface EventTriggerType{
 
-        /** klick the mouse into the scroll bar*/
-        final public static int MOUSE_KLICK_INTO_DOC = 1;
+        /** click the mouse into the scroll bar*/
+        int MOUSE_KLICK_INTO_DOC = 1;
 
         /** write some text into a spread sheet*/
-        final public static int KEY_TEXT_INTO_DOC = 2;
+        int KEY_TEXT_INTO_DOC = 2;
     }
 }
 
