@@ -27,18 +27,15 @@
 #if defined(UNX)
 #include <unistd.h>
 #endif
-#ifdef __MINGW32__
-#include <unistd.h>
-#endif
 
-#include <reflread.hxx>
+#include "reflread.hxx"
 
-#include <reflwrit.hxx>
+#include "reflwrit.hxx"
 
-#include "registry/reader.hxx"
-#include "registry/refltype.hxx"
-#include "registry/types.hxx"
-#include "registry/version.h"
+#include <registry/reader.hxx>
+#include <registry/refltype.hxx>
+#include <registry/types.hxx>
+#include <registry/version.h>
 
 #include "reflcnst.hxx"
 #include "keyimpl.hxx"
@@ -424,20 +421,14 @@ void dumpType(typereg::Reader const & reader, OString const & indent) {
 
 }
 
-
-//  ORegistry()
-
 ORegistry::ORegistry()
     : m_refCount(1)
     , m_readOnly(false)
     , m_isOpen(false)
-    , ROOT( "/" )
+    , ROOT("/")
 {
 }
 
-
-//  ~ORegistry()
-
 ORegistry::~ORegistry()
 {
     ORegKey* pRootKey = m_openKeyTable[ROOT];
@@ -448,35 +439,31 @@ ORegistry::~ORegistry()
         m_file.close();
 }
 
-
-
-//  initRegistry
-
 RegError ORegistry::initRegistry(const OUString& regName, RegAccessMode accessMode, bool bCreate)
 {
     RegError eRet = RegError::INVALID_REGISTRY;
     OStoreFile      rRegFile;
-    storeAccessMode sAccessMode = store_AccessReadWrite;
+    storeAccessMode sAccessMode = storeAccessMode::ReadWrite;
     storeError      errCode;
 
     if (bCreate)
     {
-        sAccessMode = store_AccessCreate;
+        sAccessMode = storeAccessMode::Create;
     }
     else if (accessMode & RegAccessMode::READONLY)
     {
-        sAccessMode = store_AccessReadOnly;
+        sAccessMode = storeAccessMode::ReadOnly;
         m_readOnly = true;
     }
 
     if (regName.isEmpty() &&
-        store_AccessCreate == sAccessMode)
+        storeAccessMode::Create == sAccessMode)
     {
         errCode = rRegFile.createInMemory();
     }
     else
     {
-        errCode = rRegFile.create(regName, sAccessMode, REG_PAGESIZE);
+        errCode = rRegFile.create(regName, sAccessMode);
     }
 
     if (errCode)
@@ -499,7 +486,7 @@ RegError ORegistry::initRegistry(const OUString& regName, RegAccessMode accessMo
         OStoreDirectory rStoreDir;
         storeError _err = rStoreDir.create(rRegFile, OUString(), OUString(), sAccessMode);
 
-        if ( _err == store_E_None )
+        if (_err == store_E_None)
         {
             m_file = rRegFile;
             m_name = regName;
@@ -515,10 +502,6 @@ RegError ORegistry::initRegistry(const OUString& regName, RegAccessMode accessMo
     return eRet;
 }
 
-
-
-//  closeRegistry
-
 RegError ORegistry::closeRegistry()
 {
     REG_GUARD(m_mutex);
@@ -535,10 +518,6 @@ RegError ORegistry::closeRegistry()
     }
 }
 
-
-
-//  destroyRegistry
-
 RegError ORegistry::destroyRegistry(const OUString& regName)
 {
     REG_GUARD(m_mutex);
@@ -552,10 +531,10 @@ RegError ORegistry::destroyRegistry(const OUString& regName)
             pReg.reset();
 
             OUString systemName;
-            if ( FileBase::getSystemPathFromFileURL(regName, systemName) != FileBase::E_None )
+            if (FileBase::getSystemPathFromFileURL(regName, systemName) != FileBase::E_None)
                 systemName = regName;
 
-            OString name( OUStringToOString(systemName, osl_getThreadTextEncoding()) );
+            OString name(OUStringToOString(systemName, osl_getThreadTextEncoding()));
             if (unlink(name.getStr()) != 0)
             {
                 return RegError::DESTROY_REGISTRY_FAILED;
@@ -580,10 +559,10 @@ RegError ORegistry::destroyRegistry(const OUString& regName)
             if (!m_name.isEmpty())
             {
                 OUString systemName;
-                if ( FileBase::getSystemPathFromFileURL(m_name, systemName) != FileBase::E_None )
+                if (FileBase::getSystemPathFromFileURL(m_name, systemName) != FileBase::E_None)
                     systemName = m_name;
 
-                OString name( OUStringToOString(systemName, osl_getThreadTextEncoding()) );
+                OString name(OUStringToOString(systemName, osl_getThreadTextEncoding()));
                 if (unlink(name.getStr()) != 0)
                 {
                     return RegError::DESTROY_REGISTRY_FAILED;
@@ -598,9 +577,6 @@ RegError ORegistry::destroyRegistry(const OUString& regName)
     return RegError::NO_ERROR;
 }
 
-
-//  acquireKey
-
 RegError ORegistry::acquireKey (RegKeyHandle hKey)
 {
     ORegKey* pKey = static_cast< ORegKey* >(hKey);
@@ -613,9 +589,6 @@ RegError ORegistry::acquireKey (RegKeyHandle hKey)
     return RegError::NO_ERROR;
 }
 
-
-//  releaseKey
-
 RegError ORegistry::releaseKey (RegKeyHandle hKey)
 {
     ORegKey* pKey = static_cast< ORegKey* >(hKey);
@@ -631,9 +604,6 @@ RegError ORegistry::releaseKey (RegKeyHandle hKey)
     return RegError::NO_ERROR;
 }
 
-
-//  createKey
-
 RegError ORegistry::createKey(RegKeyHandle hKey, const OUString& keyName,
                               RegKeyHandle* phNewKey)
 {
@@ -641,7 +611,7 @@ RegError ORegistry::createKey(RegKeyHandle hKey, const OUString& keyName,
 
     *phNewKey = nullptr;
 
-    if ( keyName.isEmpty() )
+    if (keyName.isEmpty())
         return RegError::INVALID_KEYNAME;
 
     REG_GUARD(m_mutex);
@@ -670,10 +640,10 @@ RegError ORegistry::createKey(RegKeyHandle hKey, const OUString& keyName,
     sal_Int32 nIndex = 0;
     do
     {
-        token = sFullKeyName.getToken( 0, '/', nIndex );
+        token = sFullKeyName.getToken(0, '/', nIndex);
         if (!token.isEmpty())
         {
-            if (rStoreDir.create(pKey->getStoreFile(), sFullPath.getStr(), token, store_AccessCreate))
+            if (rStoreDir.create(pKey->getStoreFile(), sFullPath.getStr(), token, storeAccessMode::Create))
             {
                 return RegError::CREATE_KEY_FAILED;
             }
@@ -681,7 +651,7 @@ RegError ORegistry::createKey(RegKeyHandle hKey, const OUString& keyName,
             sFullPath.append(token);
             sFullPath.append('/');
         }
-    } while( nIndex != -1 );
+    } while(nIndex != -1);
 
 
     pKey = new ORegKey(sFullKeyName, this);
@@ -691,10 +661,6 @@ RegError ORegistry::createKey(RegKeyHandle hKey, const OUString& keyName,
     return RegError::NO_ERROR;
 }
 
-
-
-//  openKey
-
 RegError ORegistry::openKey(RegKeyHandle hKey, const OUString& keyName,
                             RegKeyHandle* phOpenKey)
 {
@@ -702,7 +668,7 @@ RegError ORegistry::openKey(RegKeyHandle hKey, const OUString& keyName,
 
     *phOpenKey = nullptr;
 
-    if ( keyName.isEmpty() )
+    if (keyName.isEmpty())
     {
         return RegError::INVALID_KEYNAME;
     }
@@ -720,7 +686,7 @@ RegError ORegistry::openKey(RegKeyHandle hKey, const OUString& keyName,
         sal_Int32 n = path.lastIndexOf('/') + 1;
         switch (OStoreDirectory().create(
                     pKey->getStoreFile(), path.copy(0, n), path.copy(n),
-                    isReadOnly() ? store_AccessReadOnly : store_AccessReadWrite))
+                    isReadOnly() ? storeAccessMode::ReadOnly : storeAccessMode::ReadWrite))
         {
         case store_E_NotExists:
             return RegError::KEY_NOT_EXISTS;
@@ -740,10 +706,6 @@ RegError ORegistry::openKey(RegKeyHandle hKey, const OUString& keyName,
     return RegError::NO_ERROR;
 }
 
-
-
-//  closeKey
-
 RegError ORegistry::closeKey(RegKeyHandle hKey)
 {
     ORegKey* pKey = static_cast< ORegKey* >(hKey);
@@ -751,7 +713,7 @@ RegError ORegistry::closeKey(RegKeyHandle hKey)
     REG_GUARD(m_mutex);
 
     OUString const aKeyName (pKey->getName());
-    if (!(m_openKeyTable.count(aKeyName) > 0))
+    if (m_openKeyTable.count(aKeyName) <= 0)
         return RegError::KEY_NOT_OPEN;
 
     if (pKey->isModified())
@@ -765,7 +727,6 @@ RegError ORegistry::closeKey(RegKeyHandle hKey)
         else
         {
             // closing modified RootKey, flush registry file.
-            OSL_TRACE("registry::ORegistry::closeKey(): flushing modified RootKey");
             (void) m_file.flush();
         }
         pKey->setModified(false);
@@ -775,13 +736,10 @@ RegError ORegistry::closeKey(RegKeyHandle hKey)
     return releaseKey(pKey);
 }
 
-
-//  deleteKey
-
 RegError ORegistry::deleteKey(RegKeyHandle hKey, const OUString& keyName)
 {
     ORegKey* pKey = static_cast< ORegKey* >(hKey);
-    if ( keyName.isEmpty() )
+    if (keyName.isEmpty())
         return RegError::INVALID_KEYNAME;
 
     REG_GUARD(m_mutex);
@@ -797,7 +755,7 @@ RegError ORegistry::eraseKey(ORegKey* pKey, const OUString& keyName)
 {
     RegError _ret = RegError::NO_ERROR;
 
-    if ( keyName.isEmpty() )
+    if (keyName.isEmpty())
     {
         return RegError::INVALID_KEYNAME;
     }
@@ -807,7 +765,7 @@ RegError ORegistry::eraseKey(ORegKey* pKey, const OUString& keyName)
     OUString     sRelativKey;
     sal_Int32    lastIndex = keyName.lastIndexOf('/');
 
-    if ( lastIndex >= 0 )
+    if (lastIndex >= 0)
     {
         sRelativKey += keyName.copy(lastIndex + 1);
 
@@ -845,7 +803,7 @@ RegError ORegistry::eraseKey(ORegKey* pKey, const OUString& keyName)
     tmpName += ROOT;
 
     OStoreFile sFile(pKey->getStoreFile());
-    if ( sFile.isValid() && sFile.remove(sFullPath, tmpName) )
+    if (sFile.isValid() && sFile.remove(sFullPath, tmpName))
     {
         return RegError::DELETE_KEY_FAILED;
     }
@@ -857,9 +815,6 @@ RegError ORegistry::eraseKey(ORegKey* pKey, const OUString& keyName)
     return pKey->closeKey(pOldKey);
 }
 
-
-//  deleteSubKeysAndValues
-
 RegError ORegistry::deleteSubkeysAndValues(ORegKey* pKey)
 {
     OStoreDirectory::iterator   iter;
@@ -867,7 +822,7 @@ RegError ORegistry::deleteSubkeysAndValues(ORegKey* pKey)
     OStoreDirectory             rStoreDir(pKey->getStoreDir());
     storeError                  _err = rStoreDir.first(iter);
 
-    while ( _err == store_E_None )
+    while (_err == store_E_None)
     {
         OUString const keyName = iter.m_pszName;
 
@@ -884,7 +839,7 @@ RegError ORegistry::deleteSubkeysAndValues(ORegKey* pKey)
             if (sFullPath.getLength() > 1)
                 sFullPath += ROOT;
 
-            if ( ((OStoreFile&)pKey->getStoreFile()).remove(sFullPath, keyName) )
+            if (const_cast<OStoreFile&>(pKey->getStoreFile()).remove(sFullPath, keyName))
             {
                 return RegError::DELETE_VALUE_FAILED;
             }
@@ -897,10 +852,6 @@ RegError ORegistry::deleteSubkeysAndValues(ORegKey* pKey)
     return RegError::NO_ERROR;
 }
 
-
-
-//  loadKey
-
 RegError ORegistry::loadKey(RegKeyHandle hKey, const OUString& regFileName,
                             bool bWarnings, bool bReport)
 {
@@ -918,11 +869,11 @@ RegError ORegistry::loadKey(RegKeyHandle hKey, const OUString& regFileName,
     OStoreDirectory             rStoreDir(pRootKey->getStoreDir());
     storeError                  _err = rStoreDir.first(iter);
 
-    while ( _err == store_E_None )
+    while (_err == store_E_None)
     {
         OUString const keyName = iter.m_pszName;
 
-        if ( iter.m_nAttrib & STORE_ATTRIB_ISDIR )
+        if (iter.m_nAttrib & STORE_ATTRIB_ISDIR)
         {
             _ret = loadAndSaveKeys(pKey, pRootKey, keyName, 0, bWarnings, bReport);
         }
@@ -944,60 +895,8 @@ RegError ORegistry::loadKey(RegKeyHandle hKey, const OUString& regFileName,
     return _ret;
 }
 
-
-
-//  saveKey
-
-RegError ORegistry::saveKey(RegKeyHandle hKey, const OUString& regFileName,
-                            bool bWarnings, bool bReport)
-{
-    ORegKey* pKey = static_cast< ORegKey* >(hKey);
-
-    std::unique_ptr< ORegistry > pReg (new ORegistry());
-    RegError _ret = pReg->initRegistry(regFileName, RegAccessMode::READWRITE, true/*bCreate*/);
-    if (_ret != RegError::NO_ERROR)
-        return _ret;
-    ORegKey* pRootKey = pReg->getRootKey();
-
-    REG_GUARD(m_mutex);
-
-    OStoreDirectory::iterator   iter;
-    OStoreDirectory             rStoreDir(pKey->getStoreDir());
-    storeError                  _err = rStoreDir.first(iter);
-
-    while ( _err == store_E_None )
-    {
-        OUString const keyName = iter.m_pszName;
-
-        if ( iter.m_nAttrib & STORE_ATTRIB_ISDIR )
-        {
-            _ret = loadAndSaveKeys(pRootKey, pKey, keyName,
-                                   pKey->getName().getLength(),
-                                   bWarnings, bReport);
-        }
-        else
-        {
-            _ret = loadAndSaveValue(pRootKey, pKey, keyName,
-                                    pKey->getName().getLength(),
-                                    bWarnings, bReport);
-        }
-
-        if (_ret != RegError::NO_ERROR)
-            break;
-
-        _err = rStoreDir.next(iter);
-    }
-
-    (void) pReg->releaseKey(pRootKey);
-    return _ret;
-}
-
-
-
-//  loadAndSaveValue()
-
 RegError ORegistry::loadAndSaveValue(ORegKey* pTargetKey,
-                                     ORegKey* pSourceKey,
+                                     ORegKey const * pSourceKey,
                                      const OUString& valueName,
                                      sal_uInt32 nCut,
                                      bool bWarnings,
@@ -1008,13 +907,13 @@ RegError ORegistry::loadAndSaveValue(ORegKey* pTargetKey,
     RegValueType    valueType;
     sal_uInt32      valueSize;
     sal_uInt32      nSize;
-    storeAccessMode sourceAccess = store_AccessReadWrite;
+    storeAccessMode sourceAccess = storeAccessMode::ReadWrite;
     OUString        sTargetPath(pTargetKey->getName());
     OUString        sSourcePath(pSourceKey->getName());
 
     if (pSourceKey->isReadOnly())
     {
-        sourceAccess = store_AccessReadOnly;
+        sourceAccess = storeAccessMode::ReadOnly;
     }
 
     if (nCut)
@@ -1074,7 +973,7 @@ RegError ORegistry::loadAndSaveValue(ORegKey* pTargetKey,
 
     OStoreFile  rTargetFile(pTargetKey->getStoreFile());
 
-    if (!rValue.create(rTargetFile, sTargetPath, valueName, store_AccessReadWrite))
+    if (!rValue.create(rTargetFile, sTargetPath, valueName, storeAccessMode::ReadWrite))
     {
         if (valueType == RegValueType::BINARY)
         {
@@ -1097,8 +996,7 @@ RegError ORegistry::loadAndSaveValue(ORegKey* pTargetKey,
         }
     }
 
-    // write
-    if (rValue.create(rTargetFile, sTargetPath, valueName, store_AccessCreate))
+    if (rValue.create(rTargetFile, sTargetPath, valueName, storeAccessMode::Create))
     {
         rtl_freeMemory(pBuffer);
         return RegError::INVALID_VALUE;
@@ -1120,17 +1018,13 @@ RegError ORegistry::loadAndSaveValue(ORegKey* pTargetKey,
     return _ret;
 }
 
-
-
-//  checkblop()
-
 RegError ORegistry::checkBlop(OStoreStream& rValue,
                               const OUString& sTargetPath,
                               sal_uInt32 srcValueSize,
-                              sal_uInt8* pSrcBuffer,
+                              sal_uInt8 const * pSrcBuffer,
                               bool bReport)
 {
-    RegistryTypeReader reader(pSrcBuffer, srcValueSize, false);
+    RegistryTypeReader reader(pSrcBuffer, srcValueSize);
 
     if (reader.getTypeClass() == RT_TYPE_INVALID)
     {
@@ -1141,7 +1035,7 @@ RegError ORegistry::checkBlop(OStoreStream& rValue,
     RegValueType    valueType;
     sal_uInt32      valueSize;
     sal_uInt32      rwBytes;
-    OString         targetPath( OUStringToOString(sTargetPath, RTL_TEXTENCODING_UTF8) );
+    OString         targetPath(OUStringToOString(sTargetPath, RTL_TEXTENCODING_UTF8));
 
     if (!rValue.readAt(0, pBuffer, VALUE_HEADERSIZE, rwBytes) &&
         (rwBytes == VALUE_HEADERSIZE))
@@ -1157,7 +1051,7 @@ RegError ORegistry::checkBlop(OStoreStream& rValue,
             if (!rValue.readAt(VALUE_HEADEROFFSET, pBuffer, valueSize, rwBytes) &&
                 (rwBytes == valueSize))
             {
-                RegistryTypeReader reader2(pBuffer, valueSize, false);
+                RegistryTypeReader reader2(pBuffer, valueSize);
 
                 if ((reader.getTypeClass() != reader2.getTypeClass())
                     || reader2.getTypeClass() == RT_TYPE_INVALID)
@@ -1229,18 +1123,17 @@ RegError ORegistry::checkBlop(OStoreStream& rValue,
     }
 }
 
-static sal_uInt32 checkTypeReaders(RegistryTypeReader& reader1,
-                                   RegistryTypeReader& reader2,
+static sal_uInt32 checkTypeReaders(RegistryTypeReader const & reader1,
+                                   RegistryTypeReader const & reader2,
                                    std::set< OUString >& nameSet)
 {
     sal_uInt32 count=0;
-    sal_uInt16 i;
-    for (i=0 ; i < reader1.getFieldCount(); i++)
+    for (sal_uInt32 i=0 ; i < reader1.getFieldCount(); i++)
     {
         nameSet.insert(reader1.getFieldName(i));
         count++;
     }
-    for (i=0 ; i < reader2.getFieldCount(); i++)
+    for (sal_uInt32 i=0 ; i < reader2.getFieldCount(); i++)
     {
         if (nameSet.find(reader2.getFieldName(i)) == nameSet.end())
         {
@@ -1251,12 +1144,9 @@ static sal_uInt32 checkTypeReaders(RegistryTypeReader& reader1,
     return count;
 }
 
-
-//  mergeModuleValue()
-
 RegError ORegistry::mergeModuleValue(OStoreStream& rTargetValue,
-                                     RegistryTypeReader& reader,
-                                     RegistryTypeReader& reader2)
+                                     RegistryTypeReader const & reader,
+                                     RegistryTypeReader const & reader2)
 {
     std::set< OUString > nameSet;
     sal_uInt32 count = checkTypeReaders(reader, reader2, nameSet);
@@ -1268,9 +1158,7 @@ RegError ORegistry::mergeModuleValue(OStoreStream& rTargetValue,
         RegistryTypeWriter writer(reader.getTypeClass(),
                                   reader.getTypeName(),
                                   reader.getSuperTypeName(),
-                                  (sal_uInt16)count,
-                                  0,
-                                  0);
+                                  (sal_uInt16)count);
 
         for (sal_uInt32 i=0 ; i < reader.getFieldCount(); i++)
         {
@@ -1326,9 +1214,6 @@ RegError ORegistry::mergeModuleValue(OStoreStream& rTargetValue,
     return RegError::NO_ERROR;
 }
 
-
-//  loadAndSaveKeys()
-
 RegError ORegistry::loadAndSaveKeys(ORegKey* pTargetKey,
                                     ORegKey* pSourceKey,
                                     const OUString& keyName,
@@ -1350,7 +1235,7 @@ RegError ORegistry::loadAndSaveKeys(ORegKey* pTargetKey,
     sFullKeyName += keyName;
 
     OStoreDirectory rStoreDir;
-    if (rStoreDir.create(pTargetKey->getStoreFile(), sFullPath, keyName, store_AccessCreate))
+    if (rStoreDir.create(pTargetKey->getStoreFile(), sFullPath, keyName, storeAccessMode::Create))
     {
         return RegError::CREATE_KEY_FAILED;
     }
@@ -1369,7 +1254,7 @@ RegError ORegistry::loadAndSaveKeys(ORegKey* pTargetKey,
     OStoreDirectory             rTmpStoreDir(pTmpKey->getStoreDir());
     storeError                  _err = rTmpStoreDir.first(iter);
 
-    while ( _err == store_E_None)
+    while (_err == store_E_None)
     {
         OUString const sName = iter.m_pszName;
 
@@ -1395,20 +1280,12 @@ RegError ORegistry::loadAndSaveKeys(ORegKey* pTargetKey,
     return _ret;
 }
 
-
-
-//  getRootKey()
-
 ORegKey* ORegistry::getRootKey()
 {
     m_openKeyTable[ROOT]->acquire();
     return m_openKeyTable[ROOT];
 }
 
-
-
-//  dumpRegistry()
-
 RegError ORegistry::dumpRegistry(RegKeyHandle hKey) const
 {
     ORegKey                     *pKey = static_cast<ORegKey*>(hKey);
@@ -1418,11 +1295,11 @@ RegError ORegistry::dumpRegistry(RegKeyHandle hKey) const
     OStoreDirectory             rStoreDir(pKey->getStoreDir());
     storeError                  _err = rStoreDir.first(iter);
 
-    OString regName( OUStringToOString( getName(), osl_getThreadTextEncoding() ) );
-    OString keyName( OUStringToOString( pKey->getName(), RTL_TEXTENCODING_UTF8 ) );
+    OString regName(OUStringToOString(getName(), osl_getThreadTextEncoding()));
+    OString keyName(OUStringToOString(pKey->getName(), RTL_TEXTENCODING_UTF8));
     fprintf(stdout, "Registry \"%s\":\n\n%s\n", regName.getStr(), keyName.getStr());
 
-    while ( _err == store_E_None )
+    while (_err == store_E_None)
     {
         sName = iter.m_pszName;
 
@@ -1445,9 +1322,6 @@ RegError ORegistry::dumpRegistry(RegKeyHandle hKey) const
     return RegError::NO_ERROR;
 }
 
-
-//  dumpValue()
-
 RegError ORegistry::dumpValue(const OUString& sPath, const OUString& sName, sal_Int16 nSpc) const
 {
     OStoreStream    rValue;
@@ -1456,11 +1330,11 @@ RegError ORegistry::dumpValue(const OUString& sPath, const OUString& sName, sal_
     RegValueType    valueType;
     OUString        sFullPath(sPath);
     OString         sIndent;
-    storeAccessMode accessMode = store_AccessReadWrite;
+    storeAccessMode accessMode = storeAccessMode::ReadWrite;
 
     if (isReadOnly())
     {
-        accessMode = store_AccessReadOnly;
+        accessMode = storeAccessMode::ReadOnly;
     }
 
     for (int i= 0; i < nSpc; i++) sIndent += " ";
@@ -1544,12 +1418,11 @@ RegError ORegistry::dumpValue(const OUString& sPath, const OUString& sName, sal_
                     sal::static_int_cast< unsigned long >(valueSize));
                 fprintf(stdout, "%s       Data = ", indent);
 
-                sal_Unicode* value = new sal_Unicode[size];
-                readString(pBuffer, value, size);
+                std::unique_ptr<sal_Unicode[]> value(new sal_Unicode[size]);
+                readString(pBuffer, value.get(), size);
 
-                OString uStr = OUStringToOString(value, RTL_TEXTENCODING_UTF8);
+                OString uStr = OUStringToOString(value.get(), RTL_TEXTENCODING_UTF8);
                 fprintf(stdout, "L\"%s\"\n", uStr.getStr());
-                delete[] value;
             }
             break;
         case RegValueType::BINARY:
@@ -1560,8 +1433,7 @@ RegError ORegistry::dumpValue(const OUString& sPath, const OUString& sName, sal_
                     sal::static_int_cast< unsigned long >(valueSize));
                 fprintf(stdout, "%s       Data = ", indent);
                 dumpType(
-                    typereg::Reader(
-                        pBuffer, valueSize, false, TYPEREG_VERSION_1),
+                    typereg::Reader(pBuffer, valueSize),
                     sIndent + "              ");
             }
             break;
@@ -1593,7 +1465,7 @@ RegError ORegistry::dumpValue(const OUString& sPath, const OUString& sName, sal_
                         stdout, "%lu = %ld\n",
                         sal::static_int_cast< unsigned long >(i),
                         sal::static_int_cast< long >(longValue));
-                    offset += 4; // 4 Bytes fuer sal_Int32
+                    offset += 4; // 4 Bytes for sal_Int32
                 }
             }
             break;
@@ -1618,7 +1490,7 @@ RegError ORegistry::dumpValue(const OUString& sPath, const OUString& sName, sal_
                 {
                     readUINT32(pBuffer+offset, sLen);
 
-                    offset += 4; // 4 Bytes (sal_uInt32) fuer die Groesse des strings in Bytes
+                    offset += 4; // 4 bytes (sal_uInt32) for the string size
 
                     sal_Char *pValue = static_cast<sal_Char*>(rtl_allocateMemory(sLen));
                     readUtf8(pBuffer+offset, pValue, sLen);
@@ -1656,7 +1528,7 @@ RegError ORegistry::dumpValue(const OUString& sPath, const OUString& sName, sal_
                 {
                     readUINT32(pBuffer+offset, sLen);
 
-                    offset += 4; // 4 Bytes (sal_uInt32) fuer die Groesse des strings in Bytes
+                    offset += 4; // 4 bytes (sal_uInt32) for the string size
 
                     sal_Unicode *pValue = static_cast<sal_Unicode*>(rtl_allocateMemory((sLen / 2) * sizeof(sal_Unicode)));
                     readString(pBuffer+offset, pValue, sLen);
@@ -1684,20 +1556,17 @@ RegError ORegistry::dumpValue(const OUString& sPath, const OUString& sName, sal_
     return RegError::NO_ERROR;
 }
 
-
-//  dumpKey()
-
 RegError ORegistry::dumpKey(const OUString& sPath, const OUString& sName, sal_Int16 nSpace) const
 {
     OStoreDirectory     rStoreDir;
     OUString            sFullPath(sPath);
     OString             sIndent;
-    storeAccessMode     accessMode = store_AccessReadWrite;
+    storeAccessMode     accessMode = storeAccessMode::ReadWrite;
     RegError            _ret = RegError::NO_ERROR;
 
     if (isReadOnly())
     {
-        accessMode = store_AccessReadOnly;
+        accessMode = storeAccessMode::ReadOnly;
     }
 
     for (int i= 0; i < nSpace; i++) sIndent += " ";
@@ -1722,11 +1591,11 @@ RegError ORegistry::dumpKey(const OUString& sPath, const OUString& sName, sal_In
 
     _err = rStoreDir.first(iter);
 
-    while ( _err == store_E_None)
+    while (_err == store_E_None)
     {
         sSubName = iter.m_pszName;
 
-        if ( iter.m_nAttrib & STORE_ATTRIB_ISDIR )
+        if (iter.m_nAttrib & STORE_ATTRIB_ISDIR)
         {
             _ret = dumpKey(sSubPath, sSubName, nSpace+2);
         } else
