@@ -17,16 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "CondFormat.hxx"
-#include "CondFormat.hrc"
+#include <CondFormat.hxx>
 
-#include "uistrings.hrc"
-#include "RptResId.hrc"
-#include "rptui_slotid.hrc"
-#include "ModuleHelper.hxx"
-#include "helpids.hrc"
-#include "UITools.hxx"
-#include "ReportController.hxx"
+#include <strings.hxx>
+#include <strings.hrc>
+#include <rptui_slotid.hrc>
+#include <core_resource.hxx>
+#include <helpids.h>
+#include <UITools.hxx>
+#include <ReportController.hxx>
 #include "Condition.hxx"
 
 #include <com/sun/star/beans/XPropertySet.hpp>
@@ -43,7 +42,7 @@
 #include <comphelper/property.hxx>
 
 #include <algorithm>
-#include "UndoActions.hxx"
+#include <UndoActions.hxx>
 
 
 namespace rptui
@@ -69,7 +68,7 @@ namespace rptui
         vcl::Window& m_rWindow;
 
     public:
-        UpdateLocker( vcl::Window& _rWindow )
+        explicit UpdateLocker( vcl::Window& _rWindow )
             :m_rWindow( _rWindow )
         {
             _rWindow.SetUpdateMode( false );
@@ -130,7 +129,22 @@ namespace rptui
 
     ConditionalFormattingDialog::~ConditionalFormattingDialog()
     {
+        disposeOnce();
+    }
+
+    void ConditionalFormattingDialog::dispose()
+    {
+
+        for (auto i = m_aConditions.begin(); i != m_aConditions.end(); ++i)
+        {
+            i->disposeAndClear();
+        }
+
         m_aConditions.clear();
+        m_pConditionPlayground.clear();
+        m_pScrollWindow.clear();
+        m_pCondScroll.clear();
+        ModalDialog::dispose();
     }
 
     void ConditionalFormattingDialog::impl_updateConditionIndicies()
@@ -182,8 +196,7 @@ namespace rptui
             Reference< XFormatCondition > xCond = m_xCopy->createFormatCondition();
             ::comphelper::copyProperties(m_xCopy.get(),xCond.get());
             m_xCopy->insertByIndex( _nNewCondIndex, makeAny( xCond ) );
-
-            ConditionPtr pCon( new Condition( m_pConditionPlayground, *this, m_rController ) );
+            VclPtrInstance<Condition> pCon( m_pConditionPlayground, *this, m_rController );
             pCon->setCondition( xCond );
             pCon->reorderWithinParent(_nNewCondIndex);
             m_aConditions.insert( m_aConditions.begin() + _nNewCondIndex, pCon );
@@ -264,14 +277,14 @@ namespace rptui
 
         // do this in two steps, so we don't become inconsistent if any of the UNO actions fails
         Any aMovedCondition;
-        ConditionPtr pMovedCondition;
+        Condition *pMovedCondition;
         try
         {
             aMovedCondition = m_xCopy->getByIndex( (sal_Int32)nOldConditionIndex );
             m_xCopy->removeByIndex( (sal_Int32)nOldConditionIndex );
 
             Conditions::iterator aRemovePos( m_aConditions.begin() + nOldConditionIndex );
-            pMovedCondition = *aRemovePos;
+            pMovedCondition = aRemovePos->get();
             m_aConditions.erase( aRemovePos );
         }
         catch( const Exception& )
@@ -300,7 +313,7 @@ namespace rptui
         impl_ensureConditionVisible( nNewConditionIndex );
     }
 
-    IMPL_LINK( ConditionalFormattingDialog, OnScroll, ScrollBar*, /*_pNotInterestedIn*/ )
+    IMPL_LINK( ConditionalFormattingDialog, OnScroll, ScrollBar*, /*_pNotInterestedIn*/, void )
     {
         size_t nFirstCondIndex( impl_getFirstVisibleConditionIndex() );
         size_t nFocusCondIndex = impl_getFocusedConditionIndex( nFirstCondIndex );
@@ -311,8 +324,6 @@ namespace rptui
             impl_focusCondition( nFirstCondIndex );
         else if ( nFocusCondIndex >= nFirstCondIndex + MAX_CONDITIONS )
             impl_focusCondition( nFirstCondIndex + MAX_CONDITIONS - 1 );
-
-        return 0;
     }
 
     void ConditionalFormattingDialog::impl_layoutConditions()
@@ -330,7 +341,7 @@ namespace rptui
         impl_layoutConditions();
 
         // scrollbar visibility
-        if ( !impl_needScrollBar() )
+        if ( m_aConditions.size() <= MAX_CONDITIONS )
             // normalize the position, so it can, in all situations, be used as top index
             m_pCondScroll->SetThumbPos( 0 );
     }
@@ -342,7 +353,7 @@ namespace rptui
             sal_Int32 nCount = m_xCopy->getCount();
             for ( sal_Int32 i = 0; i < nCount ; ++i )
             {
-                ConditionPtr pCon( new Condition( m_pConditionPlayground, *this, m_rController ) );
+                VclPtrInstance<Condition> pCon( m_pConditionPlayground, *this, m_rController );
                 Reference< XFormatCondition > xCond( m_xCopy->getByIndex(i), UNO_QUERY );
                 pCon->reorderWithinParent(i);
                 pCon->setCondition( xCond );
@@ -358,7 +369,7 @@ namespace rptui
         impl_conditionCountChanged();
     }
 
-    void ConditionalFormattingDialog::applyCommand( size_t _nCondIndex, sal_uInt16 _nCommandId, const ::Color _aColor )
+    void ConditionalFormattingDialog::applyCommand(size_t _nCondIndex, sal_uInt16 _nCommandId, const ::Color& rColor)
     {
         OSL_PRECOND( _nCommandId, "ConditionalFormattingDialog::applyCommand: illegal command id!" );
         try
@@ -374,7 +385,7 @@ namespace rptui
             aArgs[1].Value <<= VCLUnoHelper::GetInterface(this);
 
             aArgs[2].Name = PROPERTY_FONTCOLOR;
-            aArgs[2].Value <<= (sal_uInt32)_aColor.GetColor();
+            aArgs[2].Value <<= (sal_uInt32)rColor.GetColor();
 
             // we use this way to create undo actions
             m_rController.executeUnChecked(_nCommandId,aArgs);
@@ -423,11 +434,11 @@ namespace rptui
         short nRet = ModalDialog::Execute();
         if ( nRet == RET_OK )
         {
-            const OUString sUndoAction( ModuleRes( RID_STR_UNDO_CONDITIONAL_FORMATTING ) );
+            const OUString sUndoAction( RptResId( RID_STR_UNDO_CONDITIONAL_FORMATTING ) );
             const UndoContext aUndoContext( m_rController.getUndoManager(), sUndoAction );
             try
             {
-                sal_Int32 j(0), i(0);;
+                sal_Int32 j(0), i(0);
                 for (   Conditions::const_iterator cond = m_aConditions.begin();
                         cond != m_aConditions.end();
                         ++cond, ++i
@@ -472,49 +483,54 @@ namespace rptui
     {
         switch ( _rNEvt.GetType() )
         {
-        case EVENT_KEYINPUT:
-        {
-            const KeyEvent* pKeyEvent( _rNEvt.GetKeyEvent() );
-            const vcl::KeyCode& rKeyCode = pKeyEvent->GetKeyCode();
-            if ( rKeyCode.IsMod1() && rKeyCode.IsMod2() )
+            case MouseNotifyEvent::KEYINPUT:
             {
-                if ( rKeyCode.GetCode() == 0x0508 )
+                const KeyEvent* pKeyEvent( _rNEvt.GetKeyEvent() );
+                const vcl::KeyCode& rKeyCode = pKeyEvent->GetKeyCode();
+                if ( rKeyCode.IsMod1() && rKeyCode.IsMod2() )
                 {
-                    impl_deleteCondition_nothrow( impl_getFocusedConditionIndex( 0 ) );
-                    return true;
+                    if ( rKeyCode.GetCode() == 0x0508 )
+                    {
+                        impl_deleteCondition_nothrow( impl_getFocusedConditionIndex( 0 ) );
+                        return true;
+                    }
+                    if ( rKeyCode.GetCode() == 0x0507 ) // +
+                    {
+                        impl_addCondition_nothrow( impl_getFocusedConditionIndex( impl_getConditionCount() - 1 ) + 1 );
+                        return true;
+                    }
                 }
-                if ( rKeyCode.GetCode() == 0x0507 ) // +
-                {
-                    impl_addCondition_nothrow( impl_getFocusedConditionIndex( impl_getConditionCount() - 1 ) + 1 );
-                    return true;
-                }
-            }
-        }
-        break;
-        case EVENT_GETFOCUS:
-        {
-            if ( m_bDeletingCondition )
                 break;
-
-            const vcl::Window* pGetFocusWindow( _rNEvt.GetWindow() );
-
-            // determine whether the new focus window is part of an (currently invisible) condition
-            const vcl::Window* pConditionCandidate = pGetFocusWindow->GetParent();
-            const vcl::Window* pPlaygroundCandidate = pConditionCandidate ? pConditionCandidate->GetParent() : NULL;
-            while   (   ( pPlaygroundCandidate )
-                    &&  ( pPlaygroundCandidate != this )
-                    &&  ( pPlaygroundCandidate != m_pConditionPlayground )
-                    )
-            {
-                pConditionCandidate = pConditionCandidate->GetParent();
-                pPlaygroundCandidate = pConditionCandidate ? pConditionCandidate->GetParent() : NULL;
             }
-            if (pConditionCandidate && pPlaygroundCandidate == m_pConditionPlayground)
+            case MouseNotifyEvent::GETFOCUS:
             {
-                impl_ensureConditionVisible( dynamic_cast< const Condition& >( *pConditionCandidate ).getConditionIndex() );
+                if (m_bDeletingCondition)
+                    break;
+
+                if (!m_pConditionPlayground) //e.g. during dispose
+                    break;
+
+                const vcl::Window* pGetFocusWindow( _rNEvt.GetWindow() );
+
+                // determine whether the new focus window is part of an (currently invisible) condition
+                const vcl::Window* pConditionCandidate = pGetFocusWindow->GetParent();
+                const vcl::Window* pPlaygroundCandidate = pConditionCandidate ? pConditionCandidate->GetParent() : nullptr;
+                while   (     pPlaygroundCandidate
+                        &&  ( pPlaygroundCandidate != this )
+                        &&  ( pPlaygroundCandidate != m_pConditionPlayground )
+                        )
+                {
+                    pConditionCandidate = pConditionCandidate->GetParent();
+                    pPlaygroundCandidate = pConditionCandidate ? pConditionCandidate->GetParent() : nullptr;
+                }
+                if (pConditionCandidate && pPlaygroundCandidate == m_pConditionPlayground)
+                {
+                    impl_ensureConditionVisible( dynamic_cast< const Condition& >( *pConditionCandidate ).getConditionIndex() );
+                }
+                break;
             }
-        }
-        break;
+            default:
+                break;
         }
 
         return ModalDialog::PreNotify( _rNEvt );
