@@ -16,12 +16,13 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
-#include "propbrw.hxx"
-#include "RptObject.hxx"
-#include "ReportController.hxx"
+#include <memory>
+#include <propbrw.hxx>
+#include <RptObject.hxx>
+#include <ReportController.hxx>
 #include <cppuhelper/component_context.hxx>
-#include <RptResId.hrc>
-#include "rptui_slotid.hrc"
+#include <strings.hrc>
+#include <rptui_slotid.hrc>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
 #include <com/sun/star/awt/XLayoutConstrains.hpp>
@@ -46,12 +47,13 @@
 #include <comphelper/types.hxx>
 #include <comphelper/sequence.hxx>
 #include <comphelper/processfactory.hxx>
-#include "SectionView.hxx"
-#include "ReportSection.hxx"
-#include "uistrings.hrc"
-#include "DesignView.hxx"
-#include "ViewsWindow.hxx"
-#include "UITools.hxx"
+#include <core_resource.hxx>
+#include <SectionView.hxx>
+#include <ReportSection.hxx>
+#include <strings.hxx>
+#include <DesignView.hxx>
+#include <ViewsWindow.hxx>
+#include <UITools.hxx>
 #include <unotools/confignode.hxx>
 
 namespace rptui
@@ -68,10 +70,9 @@ using namespace container;
 using namespace ::comphelper;
 
 
-
 namespace
 {
-    static bool lcl_shouldEnableHelpSection( const Reference< XComponentContext >& _rxContext )
+    bool lcl_shouldEnableHelpSection( const Reference< XComponentContext >& _rxContext )
     {
         ::utl::OConfigurationTreeRoot aConfiguration(
             ::utl::OConfigurationTreeRoot::createWithComponentContext(
@@ -87,9 +88,6 @@ namespace
 // PropBrw
 
 
-
-
-
 PropBrw::PropBrw(const Reference< XComponentContext >& _xORB, vcl::Window* pParent, ODesignView*  _pDesignView)
           :DockingWindow(pParent,WinBits(WB_STDMODELESS|WB_SIZEABLE|WB_3DLOOK|WB_ROLLABLE))
           ,m_xORB(_xORB)
@@ -121,12 +119,12 @@ PropBrw::PropBrw(const Reference< XComponentContext >& _xORB, vcl::Window* pPare
         {
             ::cppu::ContextEntry_Init aHandlerContextInfo[] =
             {
-                ::cppu::ContextEntry_Init( OUString( "ContextDocument" ), makeAny( m_pDesignView->getController().getModel() )),
-                ::cppu::ContextEntry_Init( OUString( "DialogParentWindow" ), makeAny( VCLUnoHelper::GetInterface ( this ) )),
-                ::cppu::ContextEntry_Init( OUString( "ActiveConnection" ), makeAny( m_pDesignView->getController().getConnection() ) ),
+                ::cppu::ContextEntry_Init( "ContextDocument", makeAny( m_pDesignView->getController().getModel() )),
+                ::cppu::ContextEntry_Init( "DialogParentWindow", makeAny( VCLUnoHelper::GetInterface ( this ) )),
+                ::cppu::ContextEntry_Init( "ActiveConnection", makeAny( m_pDesignView->getController().getConnection() ) ),
             };
             m_xInspectorContext.set(
-                ::cppu::createComponentContext( aHandlerContextInfo, sizeof( aHandlerContextInfo ) / sizeof( aHandlerContextInfo[0] ),
+                ::cppu::createComponentContext( aHandlerContextInfo, SAL_N_ELEMENTS( aHandlerContextInfo ),
                 m_xORB ) );
             // create a property browser controller
             bool bEnableHelpSection = lcl_shouldEnableHelpSection( m_xORB );
@@ -174,13 +172,12 @@ PropBrw::PropBrw(const Reference< XComponentContext >& _xORB, vcl::Window* pPare
         m_xBrowserComponentWindow->setPosSize(0, 0, aPropWinSize.Width(), aPropWinSize.Height(),
             awt::PosSize::WIDTH | awt::PosSize::HEIGHT | awt::PosSize::X | awt::PosSize::Y);
         Resize();
-        m_xBrowserComponentWindow->setVisible(sal_True);
+        m_xBrowserComponentWindow->setVisible(true);
     }
     ::rptui::notifySystemWindow(pParent,this,::comphelper::mem_fun(&TaskPaneList::AddWindow));
 }
 
 
-
 PropBrw::~PropBrw()
 {
     disposeOnce();
@@ -199,8 +196,8 @@ void PropBrw::dispose()
             const OUString pProps[] = { OUString( "ContextDocument" )
                                             ,  OUString( "DialogParentWindow" )
                                             , OUString( "ActiveConnection" )};
-            for (size_t i = 0; i < sizeof(pProps)/sizeof(pProps[0]); ++i)
-                xName->removeByName(pProps[i]);
+            for (const auto & i : pProps)
+                xName->removeByName(i);
         }
     }
     catch(Exception&)
@@ -263,7 +260,7 @@ bool PropBrw::Close()
         try
         {
             Reference< XController > xController( m_xMeAsFrame->getController() );
-            if ( xController.is() && !xController->suspend( sal_True ) )
+            if ( xController.is() && !xController->suspend( true ) )
                 return false;
         }
         catch( const Exception& )
@@ -282,7 +279,6 @@ bool PropBrw::Close()
 }
 
 
-
 uno::Sequence< Reference<uno::XInterface> > PropBrw::CreateCompPropSet(const SdrMarkList& _rMarkList)
 {
     const size_t nMarkCount = _rMarkList.GetMarkCount();
@@ -331,75 +327,75 @@ void PropBrw::implSetNewObject( const uno::Sequence< Reference<uno::XInterface>
 }
 
 
-
 OUString PropBrw::GetHeadlineName( const uno::Sequence< Reference<uno::XInterface> >& _aObjects )
 {
     OUString aName;
     if ( !_aObjects.getLength() )
     {
-        aName = ModuleRes(RID_STR_BRWTITLE_NO_PROPERTIES);
+        aName = RptResId(RID_STR_BRWTITLE_NO_PROPERTIES);
     }
     else if ( _aObjects.getLength() == 1 )    // single selection
     {
-        aName = ModuleRes(RID_STR_BRWTITLE_PROPERTIES);
+        aName = RptResId(RID_STR_BRWTITLE_PROPERTIES);
 
         uno::Reference< container::XNameContainer > xNameCont(_aObjects[0],uno::UNO_QUERY);
         Reference< lang::XServiceInfo > xServiceInfo( xNameCont->getByName("ReportComponent"), UNO_QUERY );
         if ( xServiceInfo.is() )
         {
-            sal_uInt16 nResId = 0;
+            const char* pResId = nullptr;
             if ( xServiceInfo->supportsService( SERVICE_FIXEDTEXT ) )
             {
-                nResId = RID_STR_PROPTITLE_FIXEDTEXT;
+                pResId = RID_STR_PROPTITLE_FIXEDTEXT;
             }
             else if ( xServiceInfo->supportsService( SERVICE_IMAGECONTROL ) )
             {
-                nResId = RID_STR_PROPTITLE_IMAGECONTROL;
+                pResId = RID_STR_PROPTITLE_IMAGECONTROL;
             }
             else if ( xServiceInfo->supportsService( SERVICE_FORMATTEDFIELD ) )
             {
-                nResId = RID_STR_PROPTITLE_FORMATTED;
+                pResId = RID_STR_PROPTITLE_FORMATTED;
             }
             else if ( xServiceInfo->supportsService( SERVICE_SHAPE ) )
             {
-                nResId = RID_STR_PROPTITLE_SHAPE;
+                pResId = RID_STR_PROPTITLE_SHAPE;
             }
             else if ( xServiceInfo->supportsService( SERVICE_REPORTDEFINITION ) )
             {
-                nResId = RID_STR_PROPTITLE_REPORT;
+                pResId = RID_STR_PROPTITLE_REPORT;
             }
             else if ( xServiceInfo->supportsService( SERVICE_SECTION ) )
             {
-                nResId = RID_STR_PROPTITLE_SECTION;
+                pResId = RID_STR_PROPTITLE_SECTION;
             }
             else if ( xServiceInfo->supportsService( SERVICE_FUNCTION ) )
             {
-                nResId = RID_STR_PROPTITLE_FUNCTION;
+                pResId = RID_STR_PROPTITLE_FUNCTION;
             }
             else if ( xServiceInfo->supportsService( SERVICE_GROUP ) )
             {
-                nResId = RID_STR_PROPTITLE_GROUP;
+                pResId = RID_STR_PROPTITLE_GROUP;
             }
             else if ( xServiceInfo->supportsService( SERVICE_FIXEDLINE ) )
             {
-                nResId = RID_STR_PROPTITLE_FIXEDLINE;
+                pResId = RID_STR_PROPTITLE_FIXEDLINE;
             }
             else
             {
                 OSL_FAIL("Unknown service name!");
-                nResId = RID_STR_CLASS_FORMATTEDFIELD;
+                aName += RID_STR_CLASS_FORMATTEDFIELD;
+                return aName;
             }
 
-            if (nResId)
+            if (pResId)
             {
-                aName += ModuleRes(nResId);
+                aName += RptResId(pResId);
             }
         }
     }
     else    // multiselection
     {
-        aName = ModuleRes(RID_STR_BRWTITLE_PROPERTIES);
-        aName += ModuleRes(RID_STR_BRWTITLE_MULTISELECT);
+        aName = RptResId(RID_STR_BRWTITLE_PROPERTIES);
+        aName += RptResId(RID_STR_BRWTITLE_MULTISELECT);
     }
 
     return aName;
@@ -566,7 +562,7 @@ void PropBrw::Update( const uno::Reference< uno::XInterface>& _xReportComponent)
     }
 }
 
-IMPL_LINK_NOARG_TYPED( PropBrw, OnAsyncGetFocus, void*, void )
+IMPL_LINK_NOARG( PropBrw, OnAsyncGetFocus, void*, void )
 {
     if (m_xBrowserComponentWindow.is())
         m_xBrowserComponentWindow->setFocus();
