@@ -20,14 +20,13 @@
 #include "file_path_helper.hxx"
 #include "uunxapi.hxx"
 
-#include <boost/noncopyable.hpp>
 #include <osl/diagnose.h>
 #include <rtl/ustring.hxx>
 #include <sal/log.hxx>
 
-const sal_Unicode FPH_CHAR_PATH_SEPARATOR = (sal_Unicode)'/';
-const sal_Unicode FPH_CHAR_DOT            = (sal_Unicode)'.';
-const sal_Unicode FPH_CHAR_COLON          = (sal_Unicode)':';
+const sal_Unicode FPH_CHAR_PATH_SEPARATOR = '/';
+const sal_Unicode FPH_CHAR_DOT            = '.';
+const sal_Unicode FPH_CHAR_COLON          = ':';
 
 inline const rtl::OUString FPH_PATH_SEPARATOR()
 { return rtl::OUString(FPH_CHAR_PATH_SEPARATOR); }
@@ -41,14 +40,14 @@ inline const rtl::OUString FPH_PARENT_DIR_ENTRY()
 void SAL_CALL osl_systemPathRemoveSeparator(rtl_uString* pustrPath)
 {
     OSL_PRECOND(nullptr != pustrPath, "osl_systemPathRemoveSeparator: Invalid parameter");
-    if (nullptr != pustrPath)
+    if (pustrPath != nullptr)
     {
         // maybe there are more than one separator at end
         // so we run in a loop
-        while ((pustrPath->length > 1) && (FPH_CHAR_PATH_SEPARATOR == pustrPath->buffer[pustrPath->length - 1]))
+        while ((pustrPath->length > 1) && (pustrPath->buffer[pustrPath->length - 1] == FPH_CHAR_PATH_SEPARATOR))
         {
             pustrPath->length--;
-            pustrPath->buffer[pustrPath->length] = (sal_Unicode)'\0';
+            pustrPath->buffer[pustrPath->length] = '\0';
         }
 
         SAL_WARN_IF( !((0 == pustrPath->length) || (1 == pustrPath->length) ||
@@ -61,7 +60,7 @@ void SAL_CALL osl_systemPathRemoveSeparator(rtl_uString* pustrPath)
 void SAL_CALL osl_systemPathEnsureSeparator(rtl_uString** ppustrPath)
 {
     OSL_PRECOND((nullptr != ppustrPath) && (nullptr != *ppustrPath), "osl_systemPathEnsureSeparator: Invalid parameter");
-    if ((nullptr != ppustrPath) && (nullptr != *ppustrPath))
+    if ((ppustrPath != nullptr) && (*ppustrPath != nullptr))
     {
         rtl::OUString path(*ppustrPath);
         sal_Int32    lp = path.getLength();
@@ -82,7 +81,7 @@ void SAL_CALL osl_systemPathEnsureSeparator(rtl_uString** ppustrPath)
 bool SAL_CALL osl_systemPathIsRelativePath(const rtl_uString* pustrPath)
 {
     OSL_PRECOND(nullptr != pustrPath, "osl_systemPathIsRelativePath: Invalid parameter");
-    return ((nullptr == pustrPath) || (0 == pustrPath->length) || (pustrPath->buffer[0] != FPH_CHAR_PATH_SEPARATOR));
+    return ((pustrPath == nullptr) || (pustrPath->length == 0) || (pustrPath->buffer[0] != FPH_CHAR_PATH_SEPARATOR));
 }
 
 void SAL_CALL osl_systemPathMakeAbsolutePath(
@@ -106,7 +105,7 @@ void SAL_CALL osl_systemPathGetFileNameOrLastDirectoryPart(
     const rtl_uString*     pustrPath,
     rtl_uString**       ppustrFileNameOrLastDirPart)
 {
-    OSL_PRECOND(pustrPath && ppustrFileNameOrLastDirPart, \
+    OSL_PRECOND(pustrPath && ppustrFileNameOrLastDirPart,
                 "osl_systemPathGetFileNameOrLastDirectoryPart: Invalid parameter");
 
     rtl::OUString path(const_cast<rtl_uString*>(pustrPath));
@@ -115,11 +114,11 @@ void SAL_CALL osl_systemPathGetFileNameOrLastDirectoryPart(
 
     rtl::OUString last_part;
 
-    if (path.getLength() > 1 || (1 == path.getLength() && *path.getStr() != FPH_CHAR_PATH_SEPARATOR))
+    if (path.getLength() > 1 || (path.getLength() == 1 && path[0] != FPH_CHAR_PATH_SEPARATOR))
     {
         sal_Int32 idx_ps = path.lastIndexOf(FPH_CHAR_PATH_SEPARATOR);
         idx_ps++; // always right to increment by one even if idx_ps == -1!
-        last_part = rtl::OUString(path.getStr() + idx_ps);
+        last_part = path.copy(idx_ps);
     }
     rtl_uString_assign(ppustrFileNameOrLastDirPart, last_part.pData);
 }
@@ -128,7 +127,7 @@ bool SAL_CALL osl_systemPathIsHiddenFileOrDirectoryEntry(
     const rtl_uString* pustrPath)
 {
     OSL_PRECOND(nullptr != pustrPath, "osl_systemPathIsHiddenFileOrDirectoryEntry: Invalid parameter");
-    if ((nullptr == pustrPath) || (0 == pustrPath->length))
+    if ((pustrPath == nullptr) || (pustrPath->length == 0))
         return false;
 
     rtl::OUString fdp;
@@ -152,12 +151,9 @@ bool SAL_CALL osl_systemPathIsLocalOrParentDirectoryEntry(
             dirent == FPH_PARENT_DIR_ENTRY());
 }
 
-/***********************************************
- Simple iterator for a path list separated by
- the specified character
- **********************************************/
-
-class path_list_iterator: private boost::noncopyable
+/** Simple iterator for a path list separated by the specified character
+*/
+class path_list_iterator
 {
 public:
 
@@ -173,6 +169,9 @@ public:
         reset();
     }
 
+    path_list_iterator(const path_list_iterator&) = delete;
+    path_list_iterator& operator=(const path_list_iterator&) = delete;
+
     void reset()
     {
         m_path_segment_begin = m_path_segment_end = m_path_list.getStr();
