@@ -19,7 +19,7 @@
 
 #include <config_features.h>
 
-#include "sal/config.h"
+#include <sal/config.h>
 
 #if defined MACOSX
 #include <cassert>
@@ -28,17 +28,16 @@
 #include <sys/stat.h>
 #endif
 
-#include "osl/process.h"
-#include "sal/main.h"
-#include "sal/types.h"
+#include <osl/process.h>
+#include <sal/main.h>
+#include <sal/types.h>
 
-#include <saltime.hxx>
+#include "saltime.hxx"
+#include <salusesyslog.hxx>
 
 #if HAVE_SYSLOG_H
 #include <string.h>
 #include <syslog.h>
-// from sal/osl/all/log.cxx:
-extern bool sal_use_syslog;
 #endif
 
 extern "C" {
@@ -65,7 +64,7 @@ void sal_detail_initialize(int argc, char ** argv) {
         openMax = 1024;
     }
     assert(openMax >= 0 && openMax <= std::numeric_limits< int >::max());
-    for (int fd = 3; fd < openMax; ++fd) {
+    for (int fd = 3; fd < int(openMax); ++fd) {
         struct stat s;
         if (fstat(fd, &s) != -1 && S_ISREG(s.st_mode))
             close(fd);
