@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#define UNICODE
 #include "system.h"
 #include <string.h>
 #ifdef _MSC_VER
@@ -29,38 +28,121 @@
 #endif
 
 #include <cassert>
+#include <memory>
 
-#include <osl/diagnose.h>
-#include <osl/security.h>
 #include <osl/nlsupport.h>
-#include <osl/mutex.h>
-#include <osl/thread.h>
-#include <sal/log.hxx>
+#include <o3tl/char16_t2wchar_t.hxx>
 
-#include "procimpl.h"
-#include "sockimpl.h"
-#include "file_url.h"
+#include "filetime.hxx"
+#include "nlsupport.hxx"
+#include "procimpl.hxx"
+#include "file_url.hxx"
 #include "path_helper.hxx"
-#include <rtl/ustrbuf.h>
 #include <rtl/alloc.h>
 
-/***************************************************************************
- * Process.
- ***************************************************************************/
-
 oslProcessError SAL_CALL osl_terminateProcess(oslProcess Process)
 {
-    if (Process == NULL)
+    if (Process == nullptr)
         return osl_Process_E_Unknown;
 
-    if (TerminateProcess(((oslProcessImpl*)Process)->m_hProcess, 0))
+    HANDLE hProcess = static_cast<oslProcessImpl*>(Process)->m_hProcess;
+    DWORD dwPID = GetProcessId(hProcess);
+
+    // cannot be System Process (0x00000000)
+    if (dwPID == 0x0)
+        return osl_Process_E_InvalidError;
+
+    // Test to see if we can create a thread in a process... adapted from:
+    // * https://support.microsoft.com/en-us/help/178893/how-to-terminate-an-application-cleanly-in-win32
+    // * http://www.drdobbs.com/a-safer-alternative-to-terminateprocess/184416547
+
+    // TODO: we really should firstly check to see if we have access to create threads and only
+    // duplicate the handle with elevated access if we don't have access... this can be done, but
+    // it's not exactly easy - an example can be found here:
+    // http://windowsitpro.com/site-files/windowsitpro.com/files/archive/windowsitpro.com/content/content/15989/listing_01.txt
+
+    HANDLE hDupProcess = nullptr;
+
+
+    // we need to make sure we can create a thread in the remote process, if the handle was created
+    // in something that doesn't give us appropriate levels of access then we will need to give it the
+    // desired level of access - if the process handle was grabbed from OpenProcess it's quite possible
+    // that the handle doesn't have the appropriate level of access...
+
+    // see https://msdn.microsoft.com/en-au/library/windows/desktop/ms684880(v=vs.85).aspx
+    DWORD const dwAccessFlags = (PROCESS_CREATE_THREAD | PROCESS_QUERY_INFORMATION | PROCESS_VM_OPERATION
+                                    | PROCESS_VM_WRITE | PROCESS_VM_READ);
+
+    BOOL bHaveDuplHdl = DuplicateHandle(GetCurrentProcess(),    // handle to process that has handle
+                                    hProcess,                   // handle to be duplicated
+                                    GetCurrentProcess(),        // process that will get the dup handle
+                                    &hDupProcess,               // store duplicate process handle here
+                                    dwAccessFlags,              // desired access
+                                    FALSE,                      // handle can't be inherited
+                                    0);                         // zero means no additional action needed
+
+    if (bHaveDuplHdl)
+        hProcess = hDupProcess;     // so we were able to duplicate the handle, all good...
+    else
+        SAL_WARN("sal.osl", "Could not duplicate process handle, let's hope for the best...");
+
+    DWORD dwProcessStatus = 0;
+    HANDLE hRemoteThread = nullptr;
+
+    if (GetExitCodeProcess(hProcess, &dwProcessStatus) && (dwProcessStatus == STILL_ACTIVE))
+    {
+        // We need to get the address of the Win32 procedure ExitProcess, can't call it
+        // directly because we'll be calling the thunk and that will probably lead to an
+        // access violation. Once we have the address, then we need to create a new
+        // thread in the process (which we might need to run in the address space of
+        // another process) and then call on ExitProcess to try to cleanly terminate that
+        // process
+
+        DWORD dwTID = 0;    // dummy variable as we don't need to track the thread ID
+
+        // Note: we want to call on ExitProcess() and not TerminateProcess() - this is
+        // because with ExitProcess() Windows notifies all attached dlls that the process
+        // is detaching from the dll, but TerminateProcess() terminates all threads
+        // immediately, doesn't call any termination handlers and doesn't notify any dlls
+        // that it is detaching from them
+
+        HINSTANCE hKernel = GetModuleHandleW(L"kernel32.dll");
+        FARPROC pfnExitProc = GetProcAddress(hKernel, "ExitProcess");
+        hRemoteThread = CreateRemoteThread(
+                            hProcess,           /* process handle */
+                            nullptr,               /* default security descriptor */
+                            0,                  /* initial size of stack in bytes is default
+                                                   size for executable */
+                            reinterpret_cast<LPTHREAD_START_ROUTINE>(pfnExitProc), /* Win32 ExitProcess() */
+                            reinterpret_cast<PVOID>(UINT(0)), /* ExitProcess(UINT uExitCode) argument */
+                            0,                  /* value of 0 tells thread to run immediately
+                                                   after creation */
+                            &dwTID);            /* new remote thread's identifier */
+
+    }
+
+    bool bHasExited = false;
+
+    if (hRemoteThread)
+    {
+        WaitForSingleObject(hProcess, INFINITE); // wait for process to terminate, never stop waiting...
+        CloseHandle(hRemoteThread);              // close the thread handle to allow the process to exit
+        bHasExited = true;
+    }
+
+    // need to close this duplicated process handle...
+    if (bHaveDuplHdl)
+        CloseHandle(hProcess);
+
+    if (bHasExited)
         return osl_Process_E_None;
 
-    return osl_Process_E_Unknown;
+    // fallback - given that we wait for an infinite time on WaitForSingleObject, this should
+    // never occur... unless CreateRemoteThread failed
+    SAL_WARN("sal.osl", "TerminateProcess(hProcess, 0) called - we should never get here!");
+    return (TerminateProcess(hProcess, 0) == FALSE) ? osl_Process_E_Unknown : osl_Process_E_None;
 }
 
-/***************************************************************************/
-
 oslProcess SAL_CALL osl_getProcess(oslProcessIdentifier Ident)
 {
     oslProcessImpl* pProcImpl;
@@ -69,45 +151,41 @@ oslProcess SAL_CALL osl_getProcess(oslProcessIdentifier Ident)
 
     if (hProcess)
     {
-        pProcImpl = reinterpret_cast< oslProcessImpl*>( rtl_allocateMemory(sizeof(oslProcessImpl)) );
+        pProcImpl = static_cast< oslProcessImpl*>( rtl_allocateMemory(sizeof(oslProcessImpl)) );
         pProcImpl->m_hProcess  = hProcess;
         pProcImpl->m_IdProcess = Ident;
     }
     else
-        pProcImpl = NULL;
+        pProcImpl = nullptr;
 
     return pProcImpl;
 }
 
-/***************************************************************************/
-
 void SAL_CALL osl_freeProcessHandle(oslProcess Process)
 {
-    if (Process != NULL)
+    if (Process != nullptr)
     {
-        CloseHandle(((oslProcessImpl*)Process)->m_hProcess);
+        CloseHandle(static_cast<oslProcessImpl*>(Process)->m_hProcess);
 
-        rtl_freeMemory((oslProcessImpl*)Process);
+        rtl_freeMemory(Process);
     }
 }
 
-/***************************************************************************/
-
 oslProcessError SAL_CALL osl_getProcessInfo(oslProcess Process, oslProcessData Fields,
                                    oslProcessInfo* pInfo)
 {
     HANDLE hProcess;
     DWORD  IdProcess;
 
-    if (Process == NULL)
+    if (Process == nullptr)
     {
         hProcess  = GetCurrentProcess();
         IdProcess = GetCurrentProcessId();
     }
     else
     {
-        hProcess  = ((oslProcessImpl*)Process)->m_hProcess;
-        IdProcess = ((oslProcessImpl*)Process)->m_IdProcess;
+        hProcess  = static_cast<oslProcessImpl*>(Process)->m_hProcess;
+        IdProcess = static_cast<oslProcessImpl*>(Process)->m_IdProcess;
     }
 
     if (! pInfo || (pInfo->Size != sizeof(oslProcessInfo)))
@@ -129,7 +207,7 @@ oslProcessError SAL_CALL osl_getProcessInfo(oslProcess Process, oslProcessData F
 
     if (Fields & osl_Process_HEAPUSAGE)
     {
-        void*   lpAddress=0;
+        void*   lpAddress=nullptr;
         MEMORY_BASIC_INFORMATION Info;
 
         pInfo->HeapUsage = 0;
@@ -142,9 +220,9 @@ oslProcessError SAL_CALL osl_getProcessInfo(oslProcess Process, oslProcessData F
             if ((Info.State == MEM_COMMIT) && (Info.Type == MEM_PRIVATE))
                 pInfo->HeapUsage += Info.RegionSize;
 
-            lpAddress = (LPBYTE)lpAddress + Info.RegionSize;
+            lpAddress = static_cast<LPBYTE>(lpAddress) + Info.RegionSize;
         }
-        while (lpAddress < (void *)0x80000000); // 2GB address space
+        while (reinterpret_cast<uintptr_t>(lpAddress) <= (uintptr_t)0x7FFFFFFF); // 2GB address space
 
         pInfo->Fields |= osl_Process_HEAPUSAGE;
     }
@@ -158,11 +236,11 @@ oslProcessError SAL_CALL osl_getProcessInfo(oslProcess Process, oslProcessData F
         {
             __int64 Value;
 
-            Value = *((__int64 *)&UserTime);
+            Value = osl::detail::getFiletime(UserTime);
             pInfo->UserTime.Seconds   = (unsigned long) (Value / 10000000L);
             pInfo->UserTime.Nanosec   = (unsigned long)((Value % 10000000L) * 100);
 
-            Value = *((__int64 *)&KernelTime);
+            Value = osl::detail::getFiletime(KernelTime);
             pInfo->SystemTime.Seconds = (unsigned long) (Value / 10000000L);
             pInfo->SystemTime.Nanosec = (unsigned long)((Value % 10000000L) * 100);
 
@@ -173,28 +251,24 @@ oslProcessError SAL_CALL osl_getProcessInfo(oslProcess Process, oslProcessData F
     return (pInfo->Fields == Fields) ? osl_Process_E_None : osl_Process_E_Unknown;
 }
 
-/***************************************************************************/
-
 oslProcessError SAL_CALL osl_joinProcess(oslProcess Process)
 {
-    return osl_joinProcessWithTimeout(Process, NULL);
+    return osl_joinProcessWithTimeout(Process, nullptr);
 }
 
-/***************************************************************************/
-
 oslProcessError SAL_CALL osl_joinProcessWithTimeout(oslProcess Process, const TimeValue* pTimeout)
 {
     DWORD           timeout   = INFINITE;
     oslProcessError osl_error = osl_Process_E_None;
     DWORD           ret;
 
-    if (NULL == Process)
+    if (nullptr == Process)
         return osl_Process_E_Unknown;
 
     if (pTimeout)
         timeout = pTimeout->Seconds * 1000 + pTimeout->Nanosec / 1000000L;
 
-    ret = WaitForSingleObject(((oslProcessImpl*)Process)->m_hProcess, timeout);
+    ret = WaitForSingleObject(static_cast<oslProcessImpl*>(Process)->m_hProcess, timeout);
 
     if (WAIT_FAILED == ret)
         osl_error = osl_Process_E_Unknown;
@@ -213,10 +287,10 @@ oslProcessError bootstrap_getExecutableFile(rtl_uString ** ppFileURL)
     ::osl::LongPathBuffer< sal_Unicode > aBuffer( MAX_LONG_PATH );
     DWORD buflen = 0;
 
-    if ((buflen = GetModuleFileNameW (0, ::osl::mingw_reinterpret_cast<LPWSTR>(aBuffer), aBuffer.getBufSizeInSymbols())) > 0)
+    if ((buflen = GetModuleFileNameW (nullptr, o3tl::toW(aBuffer), aBuffer.getBufSizeInSymbols())) > 0)
     {
-        rtl_uString * pAbsPath = 0;
-        rtl_uString_newFromStr_WithLength (&(pAbsPath), aBuffer, buflen);
+        rtl_uString * pAbsPath = nullptr;
+        rtl_uString_newFromStr_WithLength (&pAbsPath, aBuffer, buflen);
         if (pAbsPath)
         {
             /* Convert from path to url. */
@@ -234,10 +308,6 @@ oslProcessError bootstrap_getExecutableFile(rtl_uString ** ppFileURL)
 
 }
 
-/***************************************************************************
- * Command Line Arguments.
- ***************************************************************************/
-
 struct CommandArgs_Impl
 {
     sal_uInt32     m_nCount;
@@ -247,7 +317,7 @@ struct CommandArgs_Impl
 static struct CommandArgs_Impl g_command_args =
 {
     0,
-    0
+    nullptr
 };
 
 #ifdef _MSC_VER
@@ -257,8 +327,8 @@ static struct CommandArgs_Impl g_command_args =
 static rtl_uString ** osl_createCommandArgs_Impl (int argc, char **)
 {
     rtl_uString ** ppArgs =
-        (rtl_uString**)rtl_allocateZeroMemory (argc * sizeof(rtl_uString*));
-    if (ppArgs != 0)
+        static_cast<rtl_uString**>(rtl_allocateZeroMemory (argc * sizeof(rtl_uString*)));
+    if (ppArgs != nullptr)
     {
         int i;
         int nArgs;
@@ -267,29 +337,29 @@ static rtl_uString ** osl_createCommandArgs_Impl (int argc, char **)
         for (i = 0; i < nArgs; i++)
         {
             /* Convert to unicode */
-            rtl_uString_newFromStr( &(ppArgs[i]), reinterpret_cast<const sal_Unicode*>(wargv[i]) );
+            rtl_uString_newFromStr( &(ppArgs[i]), o3tl::toU(wargv[i]) );
         }
-        if (ppArgs[0] != 0)
+        if (ppArgs[0] != nullptr)
         {
             /* Ensure absolute path */
             ::osl::LongPathBuffer< sal_Unicode > aBuffer( MAX_LONG_PATH );
             DWORD dwResult = 0;
 
-            dwResult = SearchPath (
-                0, reinterpret_cast<LPCWSTR>(ppArgs[0]->buffer), L".exe", aBuffer.getBufSizeInSymbols(), ::osl::mingw_reinterpret_cast<LPWSTR>(aBuffer), 0);
+            dwResult = SearchPathW (
+                nullptr, o3tl::toW(ppArgs[0]->buffer), L".exe", aBuffer.getBufSizeInSymbols(), o3tl::toW(aBuffer), nullptr);
             if ((0 < dwResult) && (dwResult < aBuffer.getBufSizeInSymbols()))
             {
-                /* Replace argv[0] with it's absolute path */
+                /* Replace argv[0] with its absolute path */
                 rtl_uString_newFromStr_WithLength(
                     &(ppArgs[0]), aBuffer, dwResult);
             }
         }
-        if (ppArgs[0] != 0)
+        if (ppArgs[0] != nullptr)
         {
             /* Convert to FileURL, see @ osl_getExecutableFile() */
-            rtl_uString * pResult = 0;
+            rtl_uString * pResult = nullptr;
             osl_getFileURLFromSystemPath (ppArgs[0], &pResult);
-            if (pResult != 0)
+            if (pResult != nullptr)
             {
                 rtl_uString_assign (&(ppArgs[0]), pResult);
                 rtl_uString_release (pResult);
@@ -303,8 +373,6 @@ static rtl_uString ** osl_createCommandArgs_Impl (int argc, char **)
 #pragma warning( pop )
 #endif
 
-/***************************************************************************/
-
 oslProcessError SAL_CALL osl_getExecutableFile( rtl_uString **ppustrFile )
 {
     osl_acquireMutex (*osl_getGlobalMutex());
@@ -320,8 +388,6 @@ oslProcessError SAL_CALL osl_getExecutableFile( rtl_uString **ppustrFile )
     return osl_Process_E_None;
 }
 
-/***************************************************************************/
-
 sal_uInt32 SAL_CALL osl_getCommandArgCount()
 {
     sal_uInt32 result = 0;
@@ -340,8 +406,6 @@ sal_uInt32 SAL_CALL osl_getCommandArgCount()
     return result;
 }
 
-/***************************************************************************/
-
 oslProcessError SAL_CALL osl_getCommandArg( sal_uInt32 nArg, rtl_uString **strCommandArg)
 {
     oslProcessError result = osl_Process_E_NotFound;
@@ -359,8 +423,6 @@ oslProcessError SAL_CALL osl_getCommandArg( sal_uInt32 nArg, rtl_uString **strCo
     return result;
 }
 
-/***************************************************************************/
-
 void SAL_CALL osl_setCommandArgs (int argc, char ** argv)
 {
     assert(argc > 0);
@@ -369,7 +431,7 @@ void SAL_CALL osl_setCommandArgs (int argc, char ** argv)
     if (g_command_args.m_nCount == 0)
     {
         rtl_uString** ppArgs = osl_createCommandArgs_Impl (argc, argv);
-        if (ppArgs != 0)
+        if (ppArgs != nullptr)
         {
             g_command_args.m_nCount = argc;
             g_command_args.m_ppArgs = ppArgs;
@@ -378,18 +440,15 @@ void SAL_CALL osl_setCommandArgs (int argc, char ** argv)
     osl_releaseMutex (*osl_getGlobalMutex());
 }
 
-/***************************************************************************
- * Environment
- ***************************************************************************/
 #define ENV_BUFFER_SIZE (32*1024-1)
 
 oslProcessError SAL_CALL osl_getEnvironment(rtl_uString *ustrVar, rtl_uString **ustrValue)
 {
     WCHAR buff[ENV_BUFFER_SIZE];
 
-    if (GetEnvironmentVariableW(reinterpret_cast<LPCWSTR>(ustrVar->buffer), buff, ENV_BUFFER_SIZE) > 0)
+    if (GetEnvironmentVariableW(o3tl::toW(ustrVar->buffer), buff, ENV_BUFFER_SIZE) > 0)
     {
-        rtl_uString_newFromStr(ustrValue, reinterpret_cast<const sal_Unicode*>(buff));
+        rtl_uString_newFromStr(ustrValue, o3tl::toU(buff));
         return osl_Process_E_None;
     }
     return osl_Process_E_Unknown;
@@ -398,16 +457,16 @@ oslProcessError SAL_CALL osl_getEnvironment(rtl_uString *ustrVar, rtl_uString **
 oslProcessError SAL_CALL osl_setEnvironment(rtl_uString *ustrVar, rtl_uString *ustrValue)
 {
     // set Windows environment variable
-    LPCWSTR lpName = reinterpret_cast<LPCWSTR>(ustrVar->buffer);
-    LPCWSTR lpValue = reinterpret_cast<LPCWSTR>(ustrValue->buffer);
+    LPCWSTR lpName = o3tl::toW(ustrVar->buffer);
+    LPCWSTR lpValue = o3tl::toW(ustrValue->buffer);
     if (SetEnvironmentVariableW(lpName, lpValue))
     {
-        wchar_t *buffer = new wchar_t[wcslen(lpName) + 1 + wcslen(lpValue) + 1];
-        wcscpy(buffer, lpName);
-        wcscat(buffer, L"=");
-        wcscat(buffer, lpValue);
-        _wputenv(buffer);
-        delete[] buffer;
+        auto buffer = std::unique_ptr<wchar_t[]>(
+            new wchar_t[wcslen(lpName) + 1 + wcslen(lpValue) + 1]);
+        wcscpy(buffer.get(), lpName);
+        wcscat(buffer.get(), L"=");
+        wcscat(buffer.get(), lpValue);
+        _wputenv(buffer.get());
         return osl_Process_E_None;
     }
     return osl_Process_E_Unknown;
@@ -417,38 +476,32 @@ oslProcessError SAL_CALL osl_clearEnvironment(rtl_uString *ustrVar)
 {
     // delete the variable from the current process environment
     // by setting SetEnvironmentVariable's second parameter to NULL
-    LPCWSTR lpName = reinterpret_cast<LPCWSTR>(ustrVar->buffer);
-    if (SetEnvironmentVariableW(lpName, NULL))
+    LPCWSTR lpName = o3tl::toW(ustrVar->buffer);
+    if (SetEnvironmentVariableW(lpName, nullptr))
     {
-        wchar_t *buffer = new wchar_t[wcslen(lpName) + 1 + 1];
-        wcscpy(buffer, lpName);
-        wcscat(buffer, L"=");
-        _wputenv(buffer);
-        delete[] buffer;
+        auto buffer = std::unique_ptr<wchar_t[]>(
+            new wchar_t[wcslen(lpName) + 1 + 1]);
+        wcscpy(buffer.get(), lpName);
+        wcscat(buffer.get(), L"=");
+        _wputenv(buffer.get());
         return osl_Process_E_None;
     }
     return osl_Process_E_Unknown;
 }
 
-/***************************************************************************
- * Current Working Directory.
- ***************************************************************************/
-
-extern "C" oslMutex g_CurrentDirectoryMutex;
-
 oslProcessError SAL_CALL osl_getProcessWorkingDir( rtl_uString **pustrWorkingDir )
 {
     ::osl::LongPathBuffer< sal_Unicode > aBuffer( MAX_LONG_PATH );
     DWORD   dwLen = 0;
 
     osl_acquireMutex( g_CurrentDirectoryMutex );
-    dwLen = GetCurrentDirectory( aBuffer.getBufSizeInSymbols(), ::osl::mingw_reinterpret_cast<LPWSTR>(aBuffer) );
+    dwLen = GetCurrentDirectoryW( aBuffer.getBufSizeInSymbols(), o3tl::toW(aBuffer) );
     osl_releaseMutex( g_CurrentDirectoryMutex );
 
     if ( dwLen && dwLen < aBuffer.getBufSizeInSymbols() )
     {
         oslFileError    eError;
-        rtl_uString     *ustrTemp = NULL;;
+        rtl_uString     *ustrTemp = nullptr;
 
         rtl_uString_newFromStr_WithLength( &ustrTemp, aBuffer, dwLen );
         eError = osl_getFileURLFromSystemPath( ustrTemp, pustrWorkingDir );
@@ -464,23 +517,15 @@ oslProcessError SAL_CALL osl_getProcessWorkingDir( rtl_uString **pustrWorkingDir
         return osl_Process_E_Unknown;
 }
 
-/***************************************************************************
- * Process Locale.
- ***************************************************************************/
-
-extern "C" void _imp_getProcessLocale( rtl_Locale ** ppLocale );
-
-static rtl_Locale * g_theProcessLocale = NULL;
-
-/***************************************************************************/
+static rtl_Locale * g_theProcessLocale = nullptr;
 
 oslProcessError SAL_CALL osl_getProcessLocale( rtl_Locale ** ppLocale )
 {
     osl_acquireMutex( *osl_getGlobalMutex() );
 
     /* determine the users default locale */
-    if( NULL == g_theProcessLocale )
-        _imp_getProcessLocale( &g_theProcessLocale );
+    if( nullptr == g_theProcessLocale )
+        imp_getProcessLocale( &g_theProcessLocale );
 
     /* or return the cached value */
     *ppLocale = g_theProcessLocale;
@@ -489,8 +534,6 @@ oslProcessError SAL_CALL osl_getProcessLocale( rtl_Locale ** ppLocale )
     return osl_Process_E_None;
 }
 
-/***************************************************************************/
-
 oslProcessError SAL_CALL osl_setProcessLocale( rtl_Locale * pLocale )
 {
     osl_acquireMutex( *osl_getGlobalMutex() );
