@@ -17,10 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#ifndef _RTL_STRING_CONST_H_
-#define _RTL_STRING_CONST_H_
-
-#include <rtl_String_Utils.hxx>
+#ifndef INCLUDED_SAL_QA_OSTRINGBUFFER_RTL_STRING_CONST_H
+#define INCLUDED_SAL_QA_OSTRINGBUFFER_RTL_STRING_CONST_H
 
 #include <limits.h>
 #include <sal/types.h>
@@ -37,61 +35,61 @@ static const rtl_TextEncoding kEncodingRTLTextUSASCII = RTL_TEXTENCODING_ASCII_U
 static const sal_uInt32 kConvertFlagsOUStringToOString = OUSTRING_TO_OSTRING_CVTFLAGS;
 static const sal_uInt32 kConvertFlagsOStringToOUString = OSTRING_TO_OUSTRING_CVTFLAGS;
 
-static const sal_Char *kTestStr1  = "Sun Microsystems";
-static const sal_Char *kTestStr2  = "Sun Microsystems Java Technology";
-static const sal_Char *kTestStr7  = "Sun ";
-static const sal_Char *kTestStr8  = "Microsystems";
-static const sal_Char *kTestStr14 = "   Sun Microsystems";
-static const sal_Char *kTestStr17 = "   Sun Microsystems   ";
-static const sal_Char *kTestStr23  = " Java Technology";
-static const sal_Char *kTestStr25 = "";
-static const sal_Char *kTestStr27 = "s";
-static const sal_Char *kTestStr28 = "\50\3\5\7\11\13\15\17sun";
-static const sal_Char *kTestStr29 = "\50\3\5\7\11\13\15\17sun\21\23\25\27\31\33\50";
-static const sal_Char *kTestStr31 = "sun Microsystems";
-static const sal_Char *kTestStr36 = "Microsystems Java Technology";
-static const sal_Char *kTestStr37 = "Sun  Java Technology";
-static const sal_Char *kTestStr38 = "\21\23\25\27\31\33\50";
-static const sal_Char *kTestStr39 = "\50\3\5\7\11\13\15\17sun   Sun Microsystems   ";
-static const sal_Char *kTestStr40 = "\50\3\5\7\11\13\15\17sunsun Microsystems";
-static const sal_Char *kTestStr45  = "Sun true";
-static const sal_Char *kTestStr46  = "Sun false";
-static const sal_Char *kTestStr47  = "true";
-static const sal_Char *kTestStr48  = "false";
-static const sal_Char *kTestStr49 = "\50\3\5\7\11\13\15\17suntrue";
-static const sal_Char *kTestStr50 = "\50\3\5\7\11\13\15\17sunfalse";
-static const sal_Char *kTestStr51  = "Sun M";
+static const sal_Char * const kTestStr1  = "Sun Microsystems";
+static const sal_Char * const kTestStr2  = "Sun Microsystems Java Technology";
+static const sal_Char * const kTestStr7  = "Sun ";
+static const sal_Char * const kTestStr8  = "Microsystems";
+static const sal_Char * const kTestStr14 = "   Sun Microsystems";
+static const sal_Char * const kTestStr17 = "   Sun Microsystems   ";
+static const sal_Char * const kTestStr23  = " Java Technology";
+static const sal_Char * const kTestStr25 = "";
+static const sal_Char * const kTestStr27 = "s";
+static const sal_Char * const kTestStr28 = "\50\3\5\7\11\13\15\17sun";
+static const sal_Char * const kTestStr29 = "\50\3\5\7\11\13\15\17sun\21\23\25\27\31\33\50";
+static const sal_Char * const kTestStr31 = "sun Microsystems";
+static const sal_Char * const kTestStr36 = "Microsystems Java Technology";
+static const sal_Char * const kTestStr37 = "Sun  Java Technology";
+static const sal_Char * const kTestStr38 = "\21\23\25\27\31\33\50";
+static const sal_Char * const kTestStr39 = "\50\3\5\7\11\13\15\17sun   Sun Microsystems   ";
+static const sal_Char * const kTestStr40 = "\50\3\5\7\11\13\15\17sunsun Microsystems";
+static const sal_Char * const kTestStr45  = "Sun true";
+static const sal_Char * const kTestStr46  = "Sun false";
+static const sal_Char * const kTestStr47  = "true";
+static const sal_Char * const kTestStr48  = "false";
+static const sal_Char * const kTestStr49 = "\50\3\5\7\11\13\15\17suntrue";
+static const sal_Char * const kTestStr50 = "\50\3\5\7\11\13\15\17sunfalse";
+static const sal_Char * const kTestStr51  = "Sun M";
 //static const sal_Char *kTestStr52  = "Sun \077777";
 //static const sal_Char *kTestStr53  = "Sun \100000";
 //static const sal_Char *kTestStr54  = "\77777";
 //static const sal_Char *kTestStr55  = "\100000";
-static const sal_Char *kTestStr56 = "\50\3\5\7\11\13\15\17suns";
+static const sal_Char * const kTestStr56 = "\50\3\5\7\11\13\15\17suns";
 //static const sal_Char *kTestStr57 = "\50\3\5\7\11\13\15\17sun\77777";
 //static const sal_Char *kTestStr58 = "\50\3\5\7\11\13\15\17sun\10000";
-static const sal_Char *kTestStr59  = "Sun 11";
-static const sal_Char *kTestStr60  = "11";
-static const sal_Char *kTestStr61  = "\50\3\5\7\11\13\15\17sun11";
-static const sal_Char *kTestStr62  = "Sun 0";
-static const sal_Char *kTestStr63  = "Sun -11";
-static const sal_Char *kTestStr64  = "Sun 2147483647";
-static const sal_Char *kTestStr65  = "Sun -2147483648";
-static const sal_Char *kTestStr66  = "0";
-static const sal_Char *kTestStr67  = "-11";
-static const sal_Char *kTestStr68  = "2147483647";
-static const sal_Char *kTestStr69  = "-2147483648";
-static const sal_Char *kTestStr70  = "\50\3\5\7\11\13\15\17sun0";
-static const sal_Char *kTestStr71  = "\50\3\5\7\11\13\15\17sun-11";
-static const sal_Char *kTestStr72  = "\50\3\5\7\11\13\15\17sun2147483647";
-static const sal_Char *kTestStr73  = "\50\3\5\7\11\13\15\17sun-2147483648";
-static const sal_Char *kTestStr116  = "Sun 9223372036854775807";
-static const sal_Char *kTestStr117  = "Sun -9223372036854775808";
-static const sal_Char *kTestStr118  = "9223372036854775807";
-static const sal_Char *kTestStr119  = "-9223372036854775808";
-static const sal_Char *kTestStr120  = "\50\3\5\7\11\13\15\17sun9223372036854775807";
-static const sal_Char *kTestStr121  = "\50\3\5\7\11\13\15\17sun-9223372036854775808";
-static const sal_Char *kTestStr143  = "Sun \377";
-static const sal_Char *kTestStr144  = "\377";
-static const sal_Char *kTestStr145 = "\50\3\5\7\11\13\15\17sun\377";
+static const sal_Char * const kTestStr59  = "Sun 11";
+static const sal_Char * const kTestStr60  = "11";
+static const sal_Char * const kTestStr61  = "\50\3\5\7\11\13\15\17sun11";
+static const sal_Char * const kTestStr62  = "Sun 0";
+static const sal_Char * const kTestStr63  = "Sun -11";
+static const sal_Char * const kTestStr64  = "Sun 2147483647";
+static const sal_Char * const kTestStr65  = "Sun -2147483648";
+static const sal_Char * const kTestStr66  = "0";
+static const sal_Char * const kTestStr67  = "-11";
+static const sal_Char * const kTestStr68  = "2147483647";
+static const sal_Char * const kTestStr69  = "-2147483648";
+static const sal_Char * const kTestStr70  = "\50\3\5\7\11\13\15\17sun0";
+static const sal_Char * const kTestStr71  = "\50\3\5\7\11\13\15\17sun-11";
+static const sal_Char * const kTestStr72  = "\50\3\5\7\11\13\15\17sun2147483647";
+static const sal_Char * const kTestStr73  = "\50\3\5\7\11\13\15\17sun-2147483648";
+static const sal_Char * const kTestStr116  = "Sun 9223372036854775807";
+static const sal_Char * const kTestStr117  = "Sun -9223372036854775808";
+static const sal_Char * const kTestStr118  = "9223372036854775807";
+static const sal_Char * const kTestStr119  = "-9223372036854775808";
+static const sal_Char * const kTestStr120  = "\50\3\5\7\11\13\15\17sun9223372036854775807";
+static const sal_Char * const kTestStr121  = "\50\3\5\7\11\13\15\17sun-9223372036854775808";
+static const sal_Char * const kTestStr143  = "Sun \377";
+static const sal_Char * const kTestStr144  = "\377";
+static const sal_Char * const kTestStr145 = "\50\3\5\7\11\13\15\17sun\377";
 
 static const sal_Int32 kTestStr1Len  = 16;
 static const sal_Int32 kTestStr2Len  = 32;
@@ -294,8 +292,6 @@ static const sal_Int32 kSInt32Max = INT_MAX;
 static const sal_Int64 kUInt32Max = UINT_MAX;
 static const sal_Int64 kSInt64Max = SAL_CONST_INT64(9223372036854775807);
 
-//------------------------------------------------------------------------
-
 static const sal_Int32 kInt32MaxNumsCount = 5;
 
 static const sal_Int32 kInt32MaxNums[kInt32MaxNumsCount] =
@@ -319,26 +315,18 @@ static const sal_Int32 kBinaryNumsCount = 16;
 
 static const sal_Int32 kBinaryMaxNumsCount = 7;
 
-//------------------------------------------------------------------------
-
 static const sal_Int32 kOctolNumsCount = 16;
 
 static const sal_Int32 kOctolMaxNumsCount = 7;
 
-//------------------------------------------------------------------------
-
 static const sal_Int32 kDecimalNumsCount = 16;
 
 static const sal_Int32 kDecimalMaxNumsCount = 7;
 
-//------------------------------------------------------------------------
-
 static const sal_Int32 kHexDecimalNumsCount = 16;
 
 static const sal_Int32 kHexDecimalMaxNumsCount = 7;
 
-//------------------------------------------------------------------------
-
 static const sal_Int32 kBase36NumsCount = 36;
 
 static const sal_Int32 kBase36MaxNumsCount = 7;
@@ -352,7 +340,7 @@ static const double   expValDouble[nDoubleCount]=
             1.7e-309,6.5822e-16,1.7e+307,2.2e30,3.1,3.1,-3.1,
             0.0,0.0,0.0,1.00e+308
     };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nFloatCount=22;
 static const float  expValFloat[nFloatCount] =
         {
@@ -362,7 +350,7 @@ static const float  expValFloat[nFloatCount] =
             1.00e38f,6.241e-37f,6.241e37f,3.1f,3.1f,-3.1f,
             3.1f,0.0f,0.0f,0.0f
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nCharCount=15;
 static const sal_Unicode  expValChar[nCharCount] =
         {
@@ -371,7 +359,7 @@ static const sal_Unicode  expValChar[nCharCount] =
             64,10,39,34,
             0,0,83
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nDefaultCount=6;
 static const sal_Unicode input1Default[nDefaultCount] =
         {
@@ -385,7 +373,7 @@ static const sal_Int32  expValDefault[nDefaultCount] =
         {
             4,9,-1,-1,3,-1
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nNormalCount=10;
 static const sal_Unicode input1Normal[nNormalCount] =
         {
@@ -399,7 +387,7 @@ static const sal_Int32  expValNormal[nNormalCount] =
         {
             4,-1,-1,9,15,-1,-1,-1,-1,-1
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nlastDefaultCount=5;
 static const sal_Unicode input1lastDefault[nlastDefaultCount] =
         {
@@ -413,7 +401,7 @@ static const sal_Int32  expVallastDefault[nlastDefaultCount] =
         {
             4,15,-1,21,-1
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nlastNormalCount=8;
 static const sal_Unicode input1lastNormal[nlastNormalCount] =
         {
@@ -427,7 +415,7 @@ static const sal_Int32  expVallastNormal[nlastNormalCount] =
         {
             4,-1,4,15,-1,-1,-1,-1
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nStrDefaultCount=6;
 static const sal_Int32 input2StrDefault[nStrDefaultCount] =
         {
@@ -437,7 +425,7 @@ static const sal_Int32 expValStrDefault[nStrDefaultCount] =
         {
             0,4,-1,-1,-1,3
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nStrNormalCount=9;
 static const sal_Int32 input2StrNormal[nStrNormalCount] =
         {
@@ -447,7 +435,7 @@ static const sal_Int32 expValStrNormal[nStrNormalCount] =
         {
             0,-1,4,-1,-1,-1,-1,-1,3
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nStrLastDefaultCount=6;
 static const sal_Int32 input2StrLastDefault[nStrLastDefaultCount] =
         {
@@ -457,7 +445,7 @@ static const sal_Int32  expValStrLastDefault[nStrLastDefaultCount] =
         {
             0,4,-1,-1,-1,3
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 nStrLastNormalCount=12;
 static const sal_Int32 input2StrLastNormal[nStrLastNormalCount] =
         {
@@ -467,14 +455,14 @@ static const sal_Int32  expValStrLastNormal[nStrLastNormalCount] =
         {
             0,-1,0,4,-1,-1,-1,-1,-1,3,15,11
         };
-//------------------------------------------------------------------------
+
 static const sal_Int32 kNonSInt32Max = INT_MIN;
 static const sal_Int32 kNonSInt16Max = SHRT_MIN;
-//------------------------------------------------------------------------
+
 #ifdef __cplusplus
 }
 #endif
 
-#endif /* _RTL_STRING_CONST_H_ */
+#endif // INCLUDED_SAL_QA_OSTRINGBUFFER_RTL_STRING_CONST_H
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
