@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -119,11 +120,11 @@ public:
         //     "osl_joinProcess returned with failure",
         //     osl_Process_E_None == osl_error
         // );
-    oslProcessInfo* pInfo = new oslProcessInfo;
+    std::unique_ptr<oslProcessInfo> pInfo( new oslProcessInfo );
     //please pay attention to initial the Size to sizeof(oslProcessInfo), or else
     //you will get unknown error when call osl_getProcessInfo
     pInfo->Size = sizeof(oslProcessInfo);
-    osl_error = osl_getProcessInfo( hProcess, osl_Process_EXITCODE, pInfo );
+    osl_error = osl_getProcessInfo( hProcess, osl_Process_EXITCODE, pInfo.get() );
     CPPUNIT_ASSERT_EQUAL_MESSAGE
         (
             "osl_getProcessInfo returned with failure",
@@ -132,7 +133,6 @@ public:
 
     printf("the exit code is %" SAL_PRIuUINT32 ".\n", pInfo->Code );
     CPPUNIT_ASSERT_EQUAL_MESSAGE("rtl_getAppCommandArg or rtl_getAppCommandArgCount error.", static_cast<oslProcessExitCode>(2), pInfo->Code);
-    delete pInfo;
     }
 
     CPPUNIT_TEST_SUITE(getAppCommandArg);
@@ -144,7 +144,7 @@ public:
 /************************************************************************
  * For diagnostics( from sal/test/testuuid.cxx )
  ************************************************************************/
-void printUuid( sal_uInt8 *pNode )
+void printUuid( const sal_uInt8 *pNode )
 {
     printf("# UUID is: ");
     for( sal_Int32 i1 = 0 ; i1 < 4 ; i1++ )
@@ -168,7 +168,7 @@ void printUuid( sal_uInt8 *pNode )
 /**************************************************************************
  *  output UUID to a string
  **************************************************************************/
-void printUuidtoBuffer( sal_uInt8 *pNode, sal_Char * pBuffer )
+void printUuidtoBuffer( const sal_uInt8 *pNode, sal_Char * pBuffer )
 {
     sal_Int8 nPtr = 0;
     for( sal_Int32 i1 = 0 ; i1 < 16 ; i1++ )
@@ -258,8 +258,4 @@ public:
 CPPUNIT_TEST_SUITE_NAMED_REGISTRATION(rtl_Process::getAppCommandArg, "rtl_Process");
 CPPUNIT_TEST_SUITE_NAMED_REGISTRATION(rtl_Process::getGlobalProcessId, "rtl_Process");
 
-// this macro creates an empty function, which will called by the RegisterAllFunctions()
-// to let the user the possibility to also register some functions by hand.
-CPPUNIT_PLUGIN_IMPLEMENT();
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
