@@ -17,25 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#ifndef _RTL_PROCESS_CONST_H_
-#define _RTL_PROCESS_CONST_H_
+#ifndef INCLUDED_SAL_QA_RTL_PROCESS_RTL_PROCESS_CONST_H
+#define INCLUDED_SAL_QA_RTL_PROCESS_RTL_PROCESS_CONST_H
 
-//------------------------------------------------------------------------
 #include <rtl/ustring.hxx>
 
-using namespace ::rtl;
-
 #ifdef __cplusplus
 extern "C"
 {
 #endif
-//------------------------------------------------------------------------
-::rtl::OUString suParam0(RTL_CONSTASCII_USTRINGPARAM("-join"));
-::rtl::OUString suParam1(RTL_CONSTASCII_USTRINGPARAM("-with"));
-::rtl::OUString suParam2(RTL_CONSTASCII_USTRINGPARAM("-child"));
-::rtl::OUString suParam3(RTL_CONSTASCII_USTRINGPARAM("-process"));
 
-//------------------------------------------------------------------------
+::rtl::OUString suParam0("-join");
+::rtl::OUString suParam1("-with");
+::rtl::OUString suParam2("-child");
+::rtl::OUString suParam3("-process");
+
 #ifdef __cplusplus
 }
 #endif
