@@ -18,7 +18,7 @@
  */
 
 #include "alloc_impl.hxx"
-#include "rtl/alloc.h"
+#include <rtl/alloc.h>
 #include <sal/log.hxx>
 #include <sal/macros.h>
 
@@ -26,32 +26,18 @@
 #include <string.h>
 #include <stdio.h>
 
-#include "internal/rtllifecycle.h"
-#include <internal/oslmemory.h>
+#include <rtllifecycle.h>
+#include <oslmemory.h>
 
-AllocMode alloc_mode = AMode_UNSET;
+AllocMode alloc_mode = AllocMode::UNSET;
 
 #if !defined(FORCE_SYSALLOC)
 static void determine_alloc_mode()
 {
-    assert(alloc_mode == AMode_UNSET);
-    alloc_mode = (getenv("G_SLICE") == nullptr ? AMode_CUSTOM : AMode_SYSTEM);
+    assert(alloc_mode == AllocMode::UNSET);
+    alloc_mode = AllocMode::SYSTEM;
 }
 
-/* ================================================================= *
- *
- * custom allocator includes.
- *
- * ================================================================= */
-
-#include "sal/macros.h"
-
-/* ================================================================= *
- *
- * custom allocator internals.
- *
- * ================================================================= */
-
 static const sal_Size g_alloc_sizes[] =
 {
     /* powers of 2**(1/4) */
@@ -86,14 +72,7 @@ static rtl_cache_type * g_alloc_table[RTL_MEMORY_CACHED_LIMIT >> RTL_MEMALIGN_SH
 
 static rtl_arena_type * gp_alloc_arena = nullptr;
 
-/* ================================================================= *
- *
- * custom allocator implementation.
- *
- * ================================================================= */
-
-void *
-SAL_CALL rtl_allocateMemory_CUSTOM (sal_Size n) SAL_THROW_EXTERN_C()
+void * SAL_CALL rtl_allocateMemory_CUSTOM(sal_Size n) SAL_THROW_EXTERN_C()
 {
     void * p = nullptr;
     if (n > 0)
@@ -114,12 +93,12 @@ try_alloc:
         else
             addr = static_cast<char*>(rtl_arena_alloc (gp_alloc_arena, &size));
 
-        if (addr != nullptr)
+        if (addr)
         {
             reinterpret_cast<sal_Size*>(addr)[0] = size;
             p = addr + RTL_MEMALIGN;
         }
-        else if (gp_alloc_arena == nullptr)
+        else if (!gp_alloc_arena)
         {
             ensureMemorySingleton();
             if (gp_alloc_arena)
@@ -132,11 +111,9 @@ try_alloc:
     return p;
 }
 
-/* ================================================================= */
-
 void SAL_CALL rtl_freeMemory_CUSTOM (void * p) SAL_THROW_EXTERN_C()
 {
-    if (p != nullptr)
+    if (p)
     {
         char *   addr = static_cast<char*>(p) - RTL_MEMALIGN;
         sal_Size size = reinterpret_cast<sal_Size*>(addr)[0];
@@ -148,19 +125,17 @@ void SAL_CALL rtl_freeMemory_CUSTOM (void * p) SAL_THROW_EXTERN_C()
     }
 }
 
-/* ================================================================= */
-
 void * SAL_CALL rtl_reallocateMemory_CUSTOM (void * p, sal_Size n) SAL_THROW_EXTERN_C()
 {
     if (n > 0)
     {
-        if (p != nullptr)
+        if (p)
         {
             void *   p_old = p;
             sal_Size n_old = reinterpret_cast<sal_Size*>( static_cast<char*>(p) - RTL_MEMALIGN  )[0] - RTL_MEMALIGN;
 
             p = rtl_allocateMemory (n);
-            if (p != nullptr)
+            if (p)
             {
                 memcpy (p, p_old, (n < n_old) ? n : n_old);
                 rtl_freeMemory (p_old);
@@ -171,27 +146,22 @@ void * SAL_CALL rtl_reallocateMemory_CUSTOM (void * p, sal_Size n) SAL_THROW_EXT
             p = rtl_allocateMemory (n);
         }
     }
-    else if (p != nullptr)
+    else if (p)
     {
-        rtl_freeMemory (p), p = nullptr;
+        rtl_freeMemory (p);
+        p = nullptr;
     }
     return p;
 }
 
 #endif
 
-/* ================================================================= *
- *
- * custom allocator initialization / finalization.
- *
- * ================================================================= */
-
 void rtl_memory_init()
 {
 #if !defined(FORCE_SYSALLOC)
     {
         /* global memory arena */
-        assert(gp_alloc_arena == nullptr);
+        assert(!gp_alloc_arena);
 
         gp_alloc_arena = rtl_arena_create (
             "rtl_alloc_arena",
@@ -202,7 +172,7 @@ void rtl_memory_init()
             rtl_arena_free,
             0         /* flags */
         );
-        assert(gp_alloc_arena != nullptr);
+        assert(gp_alloc_arena);
     }
     {
         sal_Size size;
@@ -226,23 +196,21 @@ void rtl_memory_init()
         }
     }
 #endif
-    // SAL_INFO("sal.rtl", "rtl_memory_init completed");
 }
 
-/* ================================================================= */
-
 void rtl_memory_fini()
 {
 #if !defined(FORCE_SYSALLOC)
     int i, n;
 
     /* clear g_alloc_table */
+    // cppcheck-suppress sizeofwithsilentarraypointer
     memset (g_alloc_table, 0, sizeof(g_alloc_table));
 
     /* cleanup g_alloc_caches */
     for (i = 0, n = RTL_MEMORY_CACHED_SIZES; i < n; i++)
     {
-        if (g_alloc_caches[i] != nullptr)
+        if (g_alloc_caches[i])
         {
             rtl_cache_destroy (g_alloc_caches[i]);
             g_alloc_caches[i] = nullptr;
@@ -250,43 +218,30 @@ void rtl_memory_fini()
     }
 
     /* cleanup gp_alloc_arena */
-    if (gp_alloc_arena != nullptr)
+    if (gp_alloc_arena)
     {
         rtl_arena_destroy (gp_alloc_arena);
         gp_alloc_arena = nullptr;
     }
 #endif
-    // SAL_INFO("sal.rtl", "rtl_memory_fini completed");
 }
 
-/* ================================================================= *
- *
- * system allocator implementation.
- *
- * ================================================================= */
-
-void * SAL_CALL rtl_allocateMemory_SYSTEM (sal_Size n)
+void * SAL_CALL rtl_allocateMemory_SYSTEM(sal_Size n)
 {
     return malloc (n);
 }
 
-/* ================================================================= */
-
-void SAL_CALL rtl_freeMemory_SYSTEM (void * p)
+void SAL_CALL rtl_freeMemory_SYSTEM(void * p)
 {
     free (p);
 }
 
-/* ================================================================= */
-
-void * SAL_CALL rtl_reallocateMemory_SYSTEM (void * p, sal_Size n)
+void * SAL_CALL rtl_reallocateMemory_SYSTEM(void * p, sal_Size n)
 {
     return realloc (p, n);
 }
 
-/* ================================================================= */
-
-void* SAL_CALL rtl_allocateMemory (sal_Size n) SAL_THROW_EXTERN_C()
+void* SAL_CALL rtl_allocateMemory(sal_Size n) SAL_THROW_EXTERN_C()
 {
     SAL_WARN_IF(
         n >= SAL_MAX_INT32, "sal.rtl",
@@ -294,11 +249,11 @@ void* SAL_CALL rtl_allocateMemory (sal_Size n) SAL_THROW_EXTERN_C()
 #if !defined(FORCE_SYSALLOC)
     while (true)
     {
-        if (alloc_mode == AMode_CUSTOM)
+        if (alloc_mode == AllocMode::CUSTOM)
         {
             return rtl_allocateMemory_CUSTOM(n);
         }
-        if (alloc_mode == AMode_SYSTEM)
+        if (alloc_mode == AllocMode::SYSTEM)
         {
             return rtl_allocateMemory_SYSTEM(n);
         }
@@ -309,7 +264,7 @@ void* SAL_CALL rtl_allocateMemory (sal_Size n) SAL_THROW_EXTERN_C()
 #endif
 }
 
-void* SAL_CALL rtl_reallocateMemory (void * p, sal_Size n) SAL_THROW_EXTERN_C()
+void* SAL_CALL rtl_reallocateMemory(void * p, sal_Size n) SAL_THROW_EXTERN_C()
 {
     SAL_WARN_IF(
         n >= SAL_MAX_INT32, "sal.rtl",
@@ -317,11 +272,11 @@ void* SAL_CALL rtl_reallocateMemory (void * p, sal_Size n) SAL_THROW_EXTERN_C()
 #if !defined(FORCE_SYSALLOC)
     while (true)
     {
-        if (alloc_mode == AMode_CUSTOM)
+        if (alloc_mode == AllocMode::CUSTOM)
         {
             return rtl_reallocateMemory_CUSTOM(p,n);
         }
-        if (alloc_mode == AMode_SYSTEM)
+        if (alloc_mode == AllocMode::SYSTEM)
         {
             return rtl_reallocateMemory_SYSTEM(p,n);
         }
@@ -332,17 +287,17 @@ void* SAL_CALL rtl_reallocateMemory (void * p, sal_Size n) SAL_THROW_EXTERN_C()
 #endif
 }
 
-void SAL_CALL rtl_freeMemory (void * p) SAL_THROW_EXTERN_C()
+void SAL_CALL rtl_freeMemory(void * p) SAL_THROW_EXTERN_C()
 {
 #if !defined(FORCE_SYSALLOC)
     while (true)
     {
-        if (alloc_mode == AMode_CUSTOM)
+        if (alloc_mode == AllocMode::CUSTOM)
         {
             rtl_freeMemory_CUSTOM(p);
             return;
         }
-        if (alloc_mode == AMode_SYSTEM)
+        if (alloc_mode == AllocMode::SYSTEM)
         {
             rtl_freeMemory_SYSTEM(p);
             return;
@@ -354,41 +309,31 @@ void SAL_CALL rtl_freeMemory (void * p) SAL_THROW_EXTERN_C()
 #endif
 }
 
-/* ================================================================= *
- *
- * rtl_(allocate|free)ZeroMemory() implementation.
- *
- * ================================================================= */
-
-void * SAL_CALL rtl_allocateZeroMemory (sal_Size n) SAL_THROW_EXTERN_C()
+void * SAL_CALL rtl_allocateZeroMemory(sal_Size n) SAL_THROW_EXTERN_C()
 {
     void * p = rtl_allocateMemory (n);
-    if (p != nullptr)
+    if (p)
         memset (p, 0, n);
     return p;
 }
 
-/* ================================================================= */
-
-void SAL_CALL rtl_freeZeroMemory (void * p, sal_Size n) SAL_THROW_EXTERN_C()
+void SAL_CALL rtl_freeZeroMemory(void * p, sal_Size n) SAL_THROW_EXTERN_C()
 {
-    if (p != nullptr)
+    if (p)
     {
         rtl_secureZeroMemory (p, n);
         rtl_freeMemory (p);
     }
 }
 
-void* SAL_CALL rtl_allocateAlignedMemory (sal_Size Alignment, sal_Size Bytes) SAL_THROW_EXTERN_C()
+void* SAL_CALL rtl_allocateAlignedMemory(sal_Size Alignment, sal_Size Bytes) SAL_THROW_EXTERN_C()
 {
     return osl_aligned_alloc(Alignment, Bytes);
 }
 
-void SAL_CALL rtl_freeAlignedMemory (void* Ptr) SAL_THROW_EXTERN_C()
+void SAL_CALL rtl_freeAlignedMemory(void* Ptr) SAL_THROW_EXTERN_C()
 {
     osl_aligned_free(Ptr);
 }
 
-/* ================================================================= */
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
