@@ -17,12 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
-#include "rtl/textcvt.h"
-#include "sal/types.h"
+#include <rtl/textcvt.h>
+#include <sal/types.h>
 
-#include "context.hxx"
 #include "converter.hxx"
 #include "convertiso2022cn.hxx"
 #include "tenchelp.hxx"
@@ -137,7 +136,7 @@ sal_Size ImplConvertIso2022CnToUnicode(void const * pData,
     for (; nConverted < nSrcBytes; ++nConverted)
     {
         bool bUndefined = true;
-        sal_uInt32 nChar = *(sal_uChar const *) pSrcBuf++;
+        sal_uInt32 nChar = *reinterpret_cast<unsigned char const *>(pSrcBuf++);
         sal_uInt32 nPlane;
         switch (eState)
         {
@@ -374,17 +373,17 @@ sal_Size ImplConvertIso2022CnToUnicode(void const * pData,
 
     no_output:
         --pSrcBuf;
-        nInfo |= RTL_TEXTTOUNICODE_INFO_DESTBUFFERTOSMALL;
+        nInfo |= RTL_TEXTTOUNICODE_INFO_DESTBUFFERTOOSMALL;
         break;
     }
 
     if (eState > IMPL_ISO_2022_CN_TO_UNICODE_STATE_SO
         && (nInfo & (RTL_TEXTTOUNICODE_INFO_ERROR
-                         | RTL_TEXTTOUNICODE_INFO_DESTBUFFERTOSMALL))
+                         | RTL_TEXTTOUNICODE_INFO_DESTBUFFERTOOSMALL))
                == 0)
     {
         if ((nFlags & RTL_TEXTTOUNICODE_FLAGS_FLUSH) == 0)
-            nInfo |= RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL;
+            nInfo |= RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL;
         else
             switch (sal::detail::textenc::handleBadInputTextToUnicodeConversion(
                         false, true, 0, nFlags, &pDestBufPtr, pDestBufEnd,
@@ -397,7 +396,7 @@ sal_Size ImplConvertIso2022CnToUnicode(void const * pData,
                 break;
 
             case sal::detail::textenc::BAD_INPUT_NO_OUTPUT:
-                nInfo |= RTL_TEXTTOUNICODE_INFO_DESTBUFFERTOSMALL;
+                nInfo |= RTL_TEXTTOUNICODE_INFO_DESTBUFFERTOOSMALL;
                 break;
             }
     }
@@ -417,7 +416,7 @@ sal_Size ImplConvertIso2022CnToUnicode(void const * pData,
     return pDestBufPtr - pDestBuf;
 }
 
-void * ImplCreateUnicodeToIso2022CnContext(void)
+void * ImplCreateUnicodeToIso2022CnContext()
 {
     ImplUnicodeToIso2022CnContext * pContext =
         new ImplUnicodeToIso2022CnContext;
