@@ -17,9 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 #include <salhelper/timer.hxx>
-
-#include <osl/diagnose.h>
 #include <salhelper/simplereferenceobject.hxx>
+
 #include <osl/thread.hxx>
 #include <osl/conditn.hxx>
 #include <osl/mutex.hxx>
@@ -29,20 +28,16 @@ using namespace salhelper;
 
 class salhelper::TimerManager : public osl::Thread
 {
-
 public:
-
-
     TimerManager();
 
-
-    virtual ~TimerManager();
+    virtual ~TimerManager() override;
 
     /// register timer
-    bool SAL_CALL registerTimer(salhelper::Timer* pTimer);
+    void SAL_CALL registerTimer(salhelper::Timer* pTimer);
 
     /// unregister timer
-    bool SAL_CALL unregisterTimer(salhelper::Timer* pTimer);
+    void SAL_CALL unregisterTimer(salhelper::Timer const * pTimer);
 
     /// lookup timer
     bool SAL_CALL lookupTimer(const salhelper::Timer* pTimer);
@@ -50,56 +45,49 @@ public:
     /// retrieves the "Singleton" TimerManager Instance
     static TimerManager* SAL_CALL getTimerManager();
 
-
 protected:
-
     /// worker-function of thread
     virtual void SAL_CALL run() override;
 
-    // Checking and triggering of a timer event
+    /// Checking and triggering of a timer event
     void SAL_CALL checkForTimeout();
 
-    // cleanup Method
+    /// cleanup Method
     virtual void SAL_CALL onTerminated() override;
 
-    // sorted-queue data
+    /// sorted-queue data
     salhelper::Timer*       m_pHead;
-    // List Protection
+    /// List Protection
     osl::Mutex                  m_Lock;
-    // Signal the insertion of a timer
+    /// Signal the insertion of a timer
     osl::Condition              m_notEmpty;
 
-    // "Singleton Pattern"
+    /// "Singleton Pattern"
     static salhelper::TimerManager* m_pManager;
 
 };
 
-
-
-// Timer class
-
-
 Timer::Timer()
-    : m_aTimeOut( 0 ),
-      m_aExpired( 0 ),
-      m_aRepeatDelta( 0 ),
-      m_pNext( nullptr )
+    : m_aTimeOut(0),
+      m_aExpired(0),
+      m_aRepeatDelta(0),
+      m_pNext(nullptr)
 {
 }
 
-Timer::Timer( const TTimeValue& rTime )
-    : m_aTimeOut( rTime ),
-      m_aExpired( 0 ),
-      m_aRepeatDelta( 0 ),
-      m_pNext( nullptr )
+Timer::Timer(const TTimeValue& rTime)
+    : m_aTimeOut(rTime),
+      m_aExpired(0),
+      m_aRepeatDelta(0),
+      m_pNext(nullptr)
 {
 }
 
-Timer::Timer( const TTimeValue& rTime, const TTimeValue& Repeat )
-    : m_aTimeOut( rTime ),
-      m_aExpired( 0 ),
-      m_aRepeatDelta( Repeat ),
-      m_pNext( nullptr )
+Timer::Timer(const TTimeValue& rTime, const TTimeValue& Repeat)
+    : m_aTimeOut(rTime),
+      m_aExpired(0),
+      m_aRepeatDelta(Repeat),
+      m_pNext(nullptr)
 {
 }
 
@@ -110,19 +98,15 @@ Timer::~Timer()
 
 void Timer::start()
 {
-    if (! isTicking())
+    if (!isTicking())
     {
-        if (! m_aTimeOut.isEmpty())
+        if (!m_aTimeOut.isEmpty())
             setRemainingTime(m_aTimeOut);
 
         TimerManager *pManager = TimerManager::getTimerManager();
 
-        OSL_ASSERT(pManager);
-
-        if ( pManager != nullptr )
-        {
+        if (pManager)
             pManager->registerTimer(this);
-        }
     }
 }
 
@@ -130,25 +114,18 @@ void Timer::stop()
 {
     TimerManager *pManager = TimerManager::getTimerManager();
 
-    OSL_ASSERT(pManager);
-
-    if ( pManager != nullptr )
-    {
+    if (pManager)
         pManager->unregisterTimer(this);
-    }
 }
 
 sal_Bool Timer::isTicking() const
 {
     TimerManager *pManager = TimerManager::getTimerManager();
 
-    OSL_ASSERT(pManager);
-
     if (pManager)
         return pManager->lookupTimer(this);
     else
-        return sal_False;
-
+        return false;
 }
 
 sal_Bool Timer::isExpired() const
@@ -162,22 +139,16 @@ sal_Bool Timer::isExpired() const
 
 sal_Bool Timer::expiresBefore(const Timer* pTimer) const
 {
-    OSL_ASSERT(pTimer);
-
-    if ( pTimer != nullptr )
-    {
+    if (pTimer)
         return m_aExpired < pTimer->m_aExpired;
-    }
     else
-    {
-        return sal_False;
-    }
+        return false;
 }
 
 void Timer::setAbsoluteTime(const TTimeValue& Time)
 {
-    m_aTimeOut     = 0;
-    m_aExpired     = Time;
+    m_aTimeOut = 0;
+    m_aExpired = Time;
     m_aRepeatDelta = 0;
 
     m_aExpired.normalize();
@@ -222,7 +193,7 @@ TTimeValue Timer::getRemainingTime() const
         if (secs > 0)
         {
             secs  -= 1;
-            nsecs += 1000000000L;
+            nsecs += 1000000000;
         }
         else
             return TTimeValue(0, 0);
@@ -231,11 +202,6 @@ TTimeValue Timer::getRemainingTime() const
     return TTimeValue(secs, nsecs);
 }
 
-
-
-
-// Timer manager
-
 namespace
 {
     // Synchronize access to TimerManager
@@ -244,16 +210,24 @@ namespace
 
 TimerManager* salhelper::TimerManager::m_pManager = nullptr;
 
+/** The timer manager cleanup has been removed (no thread is killed anymore),
+    so the thread leaks.
+
+    This will result in a GPF in case the salhelper-library gets unloaded before
+    process termination.
+
+    @TODO : rewrite this file, so that the timerManager thread gets destroyed,
+            when there are no timers anymore !
+**/
+
 TimerManager::TimerManager()
 {
     osl::MutexGuard Guard(theTimerManagerMutex::get());
 
-    OSL_ASSERT(m_pManager == nullptr);
+    assert(m_pManager == nullptr);
 
     m_pManager = this;
-
     m_pHead= nullptr;
-
     m_notEmpty.reset();
 
     // start thread
@@ -264,13 +238,13 @@ TimerManager::~TimerManager()
 {
     osl::MutexGuard Guard(theTimerManagerMutex::get());
 
-    if ( m_pManager == this )
+    if (m_pManager == this)
         m_pManager = nullptr;
 }
 
 void TimerManager::onTerminated()
 {
-    delete this; // mfe: AAARRRGGGHHH!!!
+    delete this; // FIXME
 }
 
 TimerManager* TimerManager::getTimerManager()
@@ -283,14 +257,10 @@ TimerManager* TimerManager::getTimerManager()
     return m_pManager;
 }
 
-bool TimerManager::registerTimer(Timer* pTimer)
+void TimerManager::registerTimer(Timer* pTimer)
 {
-    OSL_ASSERT(pTimer);
-
-    if ( pTimer == nullptr )
-    {
-        return false;
-    }
+    if (!pTimer)
+        return;
 
     osl::MutexGuard Guard(m_Lock);
 
@@ -320,18 +290,12 @@ bool TimerManager::registerTimer(Timer* pTimer)
         // signal it to TimerManager Thread
         m_notEmpty.set();
     }
-
-    return true;
 }
 
-bool TimerManager::unregisterTimer(Timer* pTimer)
+void TimerManager::unregisterTimer(Timer const * pTimer)
 {
-    OSL_ASSERT(pTimer);
-
-    if ( pTimer == nullptr )
-    {
-        return false;
-    }
+    if (!pTimer)
+        return;
 
     // lock access
     osl::MutexGuard Guard(m_Lock);
@@ -344,22 +308,16 @@ bool TimerManager::unregisterTimer(Timer* pTimer)
         {
             // remove timer from list
             *ppIter = (*ppIter)->m_pNext;
-            return true;
+            return;
         }
         ppIter= &((*ppIter)->m_pNext);
     }
-
-    return false;
 }
 
 bool TimerManager::lookupTimer(const Timer* pTimer)
 {
-    OSL_ASSERT(pTimer);
-
-    if ( pTimer == nullptr )
-    {
+    if (!pTimer)
         return false;
-    }
 
     // lock access
     osl::MutexGuard Guard(m_Lock);
@@ -368,9 +326,7 @@ bool TimerManager::lookupTimer(const Timer* pTimer)
     for (Timer* pIter = m_pHead; pIter != nullptr; pIter= pIter->m_pNext)
     {
         if (pIter == pTimer)
-        {
             return true;
-        }
     }
 
     return false;
@@ -378,10 +334,9 @@ bool TimerManager::lookupTimer(const Timer* pTimer)
 
 void TimerManager::checkForTimeout()
 {
-
     m_Lock.acquire();
 
-    if ( m_pHead == nullptr )
+    if (!m_pHead)
     {
         m_Lock.release();
         return;
@@ -401,7 +356,7 @@ void TimerManager::checkForTimeout()
         pTimer->onShot();
 
         // restart timer if specified
-        if ( ! pTimer->m_aRepeatDelta.isEmpty() )
+        if (!pTimer->m_aRepeatDelta.isEmpty())
         {
             TTimeValue Now;
 
@@ -420,9 +375,6 @@ void TimerManager::checkForTimeout()
     {
         m_Lock.release();
     }
-
-
-    return;
 }
 
 void TimerManager::run()
@@ -433,9 +385,8 @@ void TimerManager::run()
 
     while (schedule())
     {
-        TTimeValue      delay;
-        TTimeValue*     pDelay=nullptr;
-
+        TTimeValue delay;
+        TTimeValue* pDelay=nullptr;
 
         m_Lock.acquire();
 
@@ -462,18 +413,4 @@ void TimerManager::run()
 
 }
 
-
-
-
-// Timer manager cleanup
-
-
-// jbu:
-// The timer manager cleanup has been removed (no thread is killed anymore).
-// So the thread leaks.
-// This will result in a GPF in case the salhelper-library gets unloaded before
-// process termination.
-// -> TODO : rewrite this file, so that the timerManager thread gets destroyed,
-//           when there are no timers anymore !
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
