@@ -136,10 +136,9 @@ private:
 };
 
 
-
 /*----------------------------------------
 *
-*   Attributlist implementation
+*   Attributelist implementation
 *
 *----------------------------------------*/
 struct AttributeListImpl_impl;
@@ -176,9 +175,9 @@ struct TagAttribute
                   const OUString &sType ,
                   const OUString &sValue )
     {
-        this->sName     = sName;
-        this->sType     = sType;
-        this->sValue    = sValue;
+        sName     = sName;
+        sType     = sType;
+        sValue    = sValue;
     }
 
     OUString sName;
@@ -197,7 +196,6 @@ struct AttributeListImpl_impl
 };
 
 
-
 sal_Int16 AttributeListImpl::getLength() throw  (RuntimeException)
 {
     return m_pImpl->vecAttribute.size();
@@ -265,14 +263,12 @@ OUString AttributeListImpl::getValueByName(const OUString& sName) throw  (Runtim
 }
 
 
-
 AttributeListImpl::AttributeListImpl()
 {
     m_pImpl = new AttributeListImpl_impl;
 }
 
 
-
 AttributeListImpl::~AttributeListImpl()
 {
     delete m_pImpl;
@@ -293,15 +289,6 @@ void AttributeListImpl::clear()
 }
 
 
-
-
-
-
-
-
-
-
-
 /**
 * for external binding
 *
@@ -331,7 +318,6 @@ Sequence<OUString> OSaxWriterTest_getSupportedServiceNames( ) throw  ()
 }
 
 
-
 void OSaxWriterTest::testInvariant( const OUString& TestName,
                                     const Reference < XInterface >& TestObject )
     throw  (    IllegalArgumentException, RuntimeException)
@@ -406,7 +392,6 @@ sal_Int32 OSaxWriterTest::test(
 }
 
 
-
 sal_Bool OSaxWriterTest::testPassed()                   throw  (RuntimeException)
 {
     return m_seqErrors.getLength() == 0;
@@ -452,13 +437,12 @@ void OSaxWriterTest::writeParagraph(
 }
 
 
-
 void OSaxWriterTest::testSimple( const Reference< XExtendedDocumentHandler > &r )
 {
     OUString testParagraph = OUString(
-        "Dies ist ein bloeder Test um zu uberpruefen, ob der SAXWriter "
-        "wohl Zeilenumbrueche halbwegs richtig macht oder ob er die Zeile "
-        "bis zum bitteren Ende schreibt." );
+        "This is a stupid test to check whether the SAXWriter possibly makes "
+        "line breaks halfway correctly or whether it writes the line to the "
+        "bitter end." );
 
     OFileWriter *pw = new OFileWriter("output.xml");
     AttributeListImpl *pList = new AttributeListImpl;
@@ -491,7 +475,7 @@ void OSaxWriterTest::testSimple( const Reference< XExtendedDocumentHandler > &r
     r->startElement( OUString( "hi") , rList );
     r->ignorableWhitespace( OUString() );
 
-    // the enpassant must be converted & -> &amp;
+    // the ampersand must be converted & -> &amp;
     r->characters( OUString( "&#252;") );
 
     // Test added for mib. Tests if errors during conversions occurs
@@ -516,7 +500,7 @@ void OSaxWriterTest::testSimple( const Reference< XExtendedDocumentHandler > &r
 
 
     r->ignorableWhitespace( OUString() );
-    r->comment( OUString( "Dies ist ein Kommentar !") );
+    r->comment( OUString( "This is a comment !") );
     r->ignorableWhitespace( OUString() );
 
     r->startElement( OUString( "emptytagtest")  , rList );
@@ -629,9 +613,9 @@ void OSaxWriterTest::testPerformance(const  Reference< XExtendedDocumentHandler
 
     OUString testParagraph =
         OUString(
-            "Dies ist ein bloeder Test um zu uberpruefen, ob der SAXWriter "
-            "wohl Zeilenumbrueche halbwegs richtig macht oder ob er die Zeile "
-            "bis zum bitteren Ende schreibt." );
+            "This is a stupid test to check whether the SAXWriter possibly makes "
+            "line breaks halfway correctly or whether it writes the line to the "
+            "bitter end." );
 
 
     Reference< XAttributeList > rList( (XAttributeList *) pList , UNO_QUERY );
