@@ -22,7 +22,7 @@ namespace sc_apitest {
 
 #define NUMBER_OF_TESTS 4
 
-class ScAnnontationsObj : public CalcUnoApiTest, apitest::XSheetAnnotations
+class ScAnnontationsObj : public CalcUnoApiTest, public apitest::XSheetAnnotations
 {
 public:
     ScAnnontationsObj();
@@ -83,6 +83,7 @@ uno::Reference< uno::XInterface > ScAnnontationsObj::init()
 void ScAnnontationsObj::setUp()
 {
     nTest++;
+    CPPUNIT_ASSERT(nTest <= NUMBER_OF_TESTS);
     CalcUnoApiTest::setUp();
 }
 
