@@ -20,13 +20,13 @@
 #include <sfx2/objsh.hxx>
 #include <svl/listener.hxx>
 
-#include "document.hxx"
-#include "brdcst.hxx"
-#include "bcaslot.hxx"
-#include "scerrors.hxx"
-#include "docoptio.hxx"
-#include "refupdat.hxx"
-#include "table.hxx"
+#include <document.hxx>
+#include <brdcst.hxx>
+#include <bcaslot.hxx>
+#include <scerrors.hxx>
+#include <docoptio.hxx>
+#include <refupdat.hxx>
+#include <table.hxx>
 #include <bulkdatahint.hxx>
 
 #if DEBUG_AREA_BROADCASTER
@@ -34,6 +34,8 @@
 #include <grouparealistener.hxx>
 #endif
 
+#include <o3tl/make_unique.hxx>
+
 // Number of slots per dimension
 // must be integer divisors of MAXCOLCOUNT respectively MAXROWCOUNT
 #define BCA_SLOTS_COL ((MAXCOLCOUNT_DEFINE) / 16)
@@ -62,32 +64,6 @@
 #error BCA_SLOTS_DEFINE DOOMed!
 #endif
 
-// STATIC DATA -----------------------------------------------------------
-
-namespace sc {
-
-bool AreaListener::SortByArea::operator ()( const AreaListener& rLeft, const AreaListener& rRight ) const
-{
-    if (rLeft.maArea.aStart.Tab() != rRight.maArea.aStart.Tab())
-        return rLeft.maArea.aStart.Tab() < rRight.maArea.aStart.Tab();
-
-    if (rLeft.maArea.aStart.Col() != rRight.maArea.aStart.Col())
-        return rLeft.maArea.aStart.Col() < rRight.maArea.aStart.Col();
-
-    if (rLeft.maArea.aStart.Row() != rRight.maArea.aStart.Row())
-        return rLeft.maArea.aStart.Row() < rRight.maArea.aStart.Row();
-
-    if (rLeft.maArea.aEnd.Tab() != rRight.maArea.aEnd.Tab())
-        return rLeft.maArea.aEnd.Tab() < rRight.maArea.aEnd.Tab();
-
-    if (rLeft.maArea.aEnd.Col() != rRight.maArea.aEnd.Col())
-        return rLeft.maArea.aEnd.Col() < rRight.maArea.aEnd.Col();
-
-    return rLeft.maArea.aEnd.Row() < rRight.maArea.aEnd.Row();
-}
-
-}
-
 struct ScSlotData
 {
     SCROW  nStartRow;   // first row of this segment
@@ -118,7 +94,7 @@ static SCSIZE initSlotDistribution( ScSlotDistribution & rSD, SCSIZE & rBSR )
     // Must be sorted by row1,row2!
     while (nRow2 <= MAXROWCOUNT)
     {
-        rSD.push_back( ScSlotData( nRow1, nRow2, nSlice, nSlots));
+        rSD.emplace_back( nRow1, nRow2, nSlice, nSlots);
         nSlots += (nRow2 - nRow1) / nSlice;
         nRow1 = nRow2;
         nRow2 *= 2;
@@ -134,7 +110,7 @@ static SCSIZE nBcaSlots = initSlotDistribution( aSlotDistribution, nBcaSlotsRow)
 #endif
 
 ScBroadcastArea::ScBroadcastArea( const ScRange& rRange ) :
-    pUpdateChainNext(NULL),
+    pUpdateChainNext(nullptr),
     aRange(rRange),
     nRefCount(0),
     mbInUpdateChain(false),
@@ -159,33 +135,32 @@ ScBroadcastAreaSlot::~ScBroadcastAreaSlot()
         // deleted.
         ScBroadcastArea* pArea = (*aIter).mpArea;
         // Erase all so no hash will be accessed upon destruction of the
-        // boost::unordered_map.
+        // unordered_map.
         aBroadcastAreaTbl.erase( aIter++);
         if (!pArea->DecRef())
             delete pArea;
     }
 }
 
-bool ScBroadcastAreaSlot::CheckHardRecalcStateCondition() const
+ScDocument::HardRecalcState ScBroadcastAreaSlot::CheckHardRecalcStateCondition() const
 {
-    if ( pDoc->GetHardRecalcState() )
-        return true;
-    if (aBroadcastAreaTbl.size() >= aBroadcastAreaTbl.max_size())
-    {   // this is more hypothetical now, check existed for old SV_PTRARR_SORT
-        if ( !pDoc->GetHardRecalcState() )
-        {
+    ScDocument::HardRecalcState eState = pDoc->GetHardRecalcState();
+    if (eState == ScDocument::HardRecalcState::OFF)
+    {
+        if (aBroadcastAreaTbl.size() >= aBroadcastAreaTbl.max_size())
+        {   // this is more hypothetical now, check existed for old SV_PTRARR_SORT
             SfxObjectShell* pShell = pDoc->GetDocumentShell();
             OSL_ENSURE( pShell, "Missing DocShell :-/" );
 
             if ( pShell )
-                pShell->SetError( SCWARN_CORE_HARD_RECALC, OUString( OSL_LOG_PREFIX ) );
+                pShell->SetError(SCWARN_CORE_HARD_RECALC);
 
             pDoc->SetAutoCalc( false );
-            pDoc->SetHardRecalcState( true );
+            eState = ScDocument::HardRecalcState::ETERNAL;
+            pDoc->SetHardRecalcState( eState );
         }
-        return true;
     }
-    return false;
+    return eState;
 }
 
 bool ScBroadcastAreaSlot::StartListeningArea(
@@ -193,7 +168,7 @@ bool ScBroadcastAreaSlot::StartListeningArea(
 {
     bool bNewArea = false;
     OSL_ENSURE(pListener, "StartListeningArea: pListener Null");
-    if (CheckHardRecalcStateCondition())
+    if (CheckHardRecalcStateCondition() == ScDocument::HardRecalcState::ETERNAL)
         return false;
     if ( !rpArea )
     {
@@ -217,7 +192,7 @@ bool ScBroadcastAreaSlot::StartListeningArea(
             {
                 OSL_FAIL("StartListeningArea: area not found and not inserted in slot?!?");
                 delete rpArea;
-                rpArea = 0;
+                rpArea = nullptr;
             }
         }
         if (rpArea)
@@ -234,7 +209,7 @@ bool ScBroadcastAreaSlot::StartListeningArea(
 void ScBroadcastAreaSlot::InsertListeningArea( ScBroadcastArea* pArea )
 {
     OSL_ENSURE( pArea, "InsertListeningArea: pArea NULL");
-    if (CheckHardRecalcStateCondition())
+    if (CheckHardRecalcStateCondition() == ScDocument::HardRecalcState::ETERNAL)
         return;
     if (aBroadcastAreaTbl.insert( pArea).second)
         pArea->IncRef();
@@ -248,7 +223,7 @@ void ScBroadcastAreaSlot::EndListeningArea(
     OSL_ENSURE(pListener, "EndListeningArea: pListener Null");
     if ( !rpArea )
     {
-        ScBroadcastAreas::const_iterator aIter( FindBroadcastArea( rRange, bGroupListening));
+        ScBroadcastAreas::iterator aIter( FindBroadcastArea( rRange, bGroupListening));
         if (aIter == aBroadcastAreaTbl.end() || isMarkedErased( aIter))
             return;
         rpArea = (*aIter).mpArea;
@@ -256,7 +231,7 @@ void ScBroadcastAreaSlot::EndListeningArea(
         if ( !rpArea->GetBroadcaster().HasListeners() )
         {   // if nobody is listening we can dispose it
             if (rpArea->GetRef() == 1)
-                rpArea = NULL;      // will be deleted by erase
+                rpArea = nullptr;      // will be deleted by erase
             EraseArea( aIter);
         }
     }
@@ -264,19 +239,19 @@ void ScBroadcastAreaSlot::EndListeningArea(
     {
         if (rpArea && !rpArea->GetBroadcaster().HasListeners())
         {
-            ScBroadcastAreas::const_iterator aIter( FindBroadcastArea( rRange, bGroupListening));
+            ScBroadcastAreas::iterator aIter( FindBroadcastArea( rRange, bGroupListening));
             if (aIter == aBroadcastAreaTbl.end() || isMarkedErased( aIter))
                 return;
             OSL_ENSURE( (*aIter).mpArea == rpArea, "EndListeningArea: area pointer mismatch");
             if (rpArea->GetRef() == 1)
-                rpArea = NULL;      // will be deleted by erase
+                rpArea = nullptr;      // will be deleted by erase
             EraseArea( aIter);
         }
     }
 }
 
-ScBroadcastAreas::const_iterator ScBroadcastAreaSlot::FindBroadcastArea(
-        const ScRange& rRange, bool bGroupListening ) const
+ScBroadcastAreas::iterator ScBroadcastAreaSlot::FindBroadcastArea(
+        const ScRange& rRange, bool bGroupListening )
 {
     aTmpSeekBroadcastArea.UpdateRange( rRange);
     aTmpSeekBroadcastArea.SetGroupListening(bGroupListening);
@@ -285,7 +260,7 @@ ScBroadcastAreas::const_iterator ScBroadcastAreaSlot::FindBroadcastArea(
 
 namespace {
 
-void broadcastRangeByCell( SvtBroadcaster& rBC, const ScRange& rRange, sal_uLong nHint )
+void broadcastRangeByCell( SvtBroadcaster& rBC, const ScRange& rRange, SfxHintId nHint )
 {
     ScHint aHint(nHint, ScAddress());
     ScAddress& rPos = aHint.GetAddress();
@@ -306,7 +281,7 @@ void broadcastRangeByCell( SvtBroadcaster& rBC, const ScRange& rRange, sal_uLong
 
 }
 
-bool ScBroadcastAreaSlot::AreaBroadcast( const ScRange& rRange, sal_uLong nHint )
+bool ScBroadcastAreaSlot::AreaBroadcast( const ScRange& rRange, SfxHintId nHint )
 {
     if (aBroadcastAreaTbl.empty())
         return false;
@@ -412,57 +387,6 @@ bool ScBroadcastAreaSlot::AreaBroadcast( const ScHint& rHint)
     return bIsBroadcasted;
 }
 
-bool ScBroadcastAreaSlot::AreaBroadcastInRange( const ScRange& rRange,
-        const ScHint& rHint)
-{
-    if (aBroadcastAreaTbl.empty())
-        return false;
-    bool bInBroadcast = mbInBroadcastIteration;
-    mbInBroadcastIteration = true;
-    bool bIsBroadcasted = false;
-
-    mbHasErasedArea = false;
-
-    for (ScBroadcastAreas::const_iterator aIter( aBroadcastAreaTbl.begin()),
-            aIterEnd( aBroadcastAreaTbl.end()); aIter != aIterEnd; ++aIter )
-    {
-        if (mbHasErasedArea && isMarkedErased( aIter))
-            continue;
-
-        ScBroadcastArea* pArea = (*aIter).mpArea;
-        const ScRange& rAreaRange = pArea->GetRange();
-        if (rAreaRange.Intersects( rRange ))
-        {
-            if (pArea->IsGroupListening())
-            {
-                if (pBASM->IsInBulkBroadcast())
-                {
-                    pBASM->InsertBulkGroupArea(pArea, rRange);
-                }
-                else
-                {
-                    pArea->GetBroadcaster().Broadcast( rHint);
-                    bIsBroadcasted = true;
-                }
-            }
-            else if (!pBASM->IsInBulkBroadcast() || pBASM->InsertBulkArea( pArea))
-            {
-                pArea->GetBroadcaster().Broadcast( rHint);
-                bIsBroadcasted = true;
-            }
-        }
-    }
-
-    mbInBroadcastIteration = bInBroadcast;
-
-    // A Notify() during broadcast may call EndListeningArea() and thus dispose
-    // an area if it was the last listener, which would invalidate an iterator
-    // pointing to it, hence the real erase is done afterwards.
-    FinallyEraseAreas();
-
-    return bIsBroadcasted;
-}
-
 void ScBroadcastAreaSlot::DelBroadcastAreasInRange( const ScRange& rRange )
 {
     if (aBroadcastAreaTbl.empty())
@@ -488,7 +412,7 @@ void ScBroadcastAreaSlot::DelBroadcastAreasInRange( const ScRange& rRange )
 }
 
 void ScBroadcastAreaSlot::UpdateRemove( UpdateRefMode eUpdateRefMode,
-        const ScRange& rRange, SCsCOL nDx, SCsROW nDy, SCsTAB nDz )
+        const ScRange& rRange, SCCOL nDx, SCROW nDy, SCTAB nDz )
 {
     if (aBroadcastAreaTbl.empty())
         return;
@@ -582,7 +506,11 @@ void ScBroadcastAreaSlot::EraseArea( ScBroadcastAreas::iterator& rIter )
         ScBroadcastArea* pArea = (*rIter).mpArea;
         aBroadcastAreaTbl.erase( rIter);
         if (!pArea->DecRef())
+        {
+            if (pBASM->IsInBulkBroadcast())
+                pBASM->RemoveBulkGroupArea(pArea);
             delete pArea;
+        }
     }
 }
 
@@ -600,15 +528,15 @@ void ScBroadcastAreaSlot::GetAllListeners(
         const ScRange& rAreaRange = pArea->GetRange();
         switch (eGroup)
         {
-            case sc::ListenerSingle:
+            case sc::ListenerGroupType::Single:
                 if (pArea->IsGroupListening())
                     continue;
             break;
-            case sc::ListenerGroup:
+            case sc::ListenerGroupType::Group:
                 if (!pArea->IsGroupListening())
                     continue;
             break;
-            case sc::ListenerBoth:
+            case sc::ListenerGroupType::Both:
             default:
                 ;
         }
@@ -669,7 +597,7 @@ void ScBroadcastAreaSlot::Dump() const
         const SvtBroadcaster::ListenersType& rListeners = rBC.GetAllListeners();
         size_t n = rListeners.size();
 
-        cout << "  * range: " << rtl::OUStringToOString(pArea->GetRange().Format(SCA_VALID|SCA_TAB_3D, pDoc), RTL_TEXTENCODING_UTF8).getStr()
+        cout << "  * range: " << rtl::OUStringToOString(pArea->GetRange().Format(ScRefFlags::VALID|ScRefFlags::TAB_3D, pDoc), RTL_TEXTENCODING_UTF8).getStr()
             << ", group: " << pArea->IsGroupListening()
             << ", listener count: " << n << endl;
 
@@ -679,7 +607,7 @@ void ScBroadcastAreaSlot::Dump() const
             if (pFC)
             {
                 cout << "    * listener: formula cell: "
-                     << rtl::OUStringToOString(pFC->aPos.Format(SCA_VALID|SCA_TAB_3D, pDoc), RTL_TEXTENCODING_UTF8).getStr()
+                     << rtl::OUStringToOString(pFC->aPos.Format(ScRefFlags::VALID|ScRefFlags::TAB_3D, pDoc), RTL_TEXTENCODING_UTF8).getStr()
                      << endl;
                 continue;
             }
@@ -688,7 +616,7 @@ void ScBroadcastAreaSlot::Dump() const
             if (pFGListener)
             {
                 cout << "    * listener: formula group: (pos: "
-                     << rtl::OUStringToOString(pFGListener->getTopCellPos().Format(SCA_VALID | SCA_TAB_3D, pDoc), RTL_TEXTENCODING_UTF8).getStr()
+                     << rtl::OUStringToOString(pFGListener->getTopCellPos().Format(ScRefFlags::VALID | ScRefFlags::TAB_3D, pDoc), RTL_TEXTENCODING_UTF8).getStr()
                      << ", length: " << pFGListener->getGroupLength()
                      << ")" << endl;
                 continue;
@@ -709,26 +637,22 @@ void ScBroadcastAreaSlot::FinallyEraseAreas()
 
 ScBroadcastAreaSlotMachine::TableSlots::TableSlots()
 {
-    ppSlots = new ScBroadcastAreaSlot* [ nBcaSlots ];
-    memset( ppSlots, 0 , sizeof( ScBroadcastAreaSlot* ) * nBcaSlots );
+    ppSlots.reset( new ScBroadcastAreaSlot* [ nBcaSlots ] );
+    memset( ppSlots.get(), 0 , sizeof( ScBroadcastAreaSlot* ) * nBcaSlots );
 }
 
 ScBroadcastAreaSlotMachine::TableSlots::~TableSlots()
 {
-    for ( ScBroadcastAreaSlot** pp = ppSlots + nBcaSlots; --pp >= ppSlots; /* nothing */ )
-    {
-        if (*pp)
-            delete *pp;
-    }
-    delete [] ppSlots;
+    for ( ScBroadcastAreaSlot** pp = ppSlots.get() + nBcaSlots; --pp >= ppSlots.get(); /* nothing */ )
+        delete *pp;
 }
 
 ScBroadcastAreaSlotMachine::ScBroadcastAreaSlotMachine(
         ScDocument* pDocument ) :
-    pBCAlways( NULL ),
+    pBCAlways( nullptr ),
     pDoc( pDocument ),
-    pUpdateChain( NULL ),
-    pEOUpdateChain( NULL ),
+    pUpdateChain( nullptr ),
+    pEOUpdateChain( nullptr ),
     nInBulkBroadcast( 0 )
 {
 }
@@ -743,11 +667,11 @@ ScBroadcastAreaSlotMachine::~ScBroadcastAreaSlotMachine()
     delete pBCAlways;
     // Areas to-be-erased still present is a serious error in handling, but at
     // this stage there's nothing we can do anymore.
-    SAL_WARN_IF( !maAreasToBeErased.empty(), "sc", "ScBroadcastAreaSlotMachine::dtor: maAreasToBeErased not empty");
+    SAL_WARN_IF( !maAreasToBeErased.empty(), "sc.core", "ScBroadcastAreaSlotMachine::dtor: maAreasToBeErased not empty");
 }
 
 inline SCSIZE ScBroadcastAreaSlotMachine::ComputeSlotOffset(
-        const ScAddress& rAddress ) const
+        const ScAddress& rAddress )
 {
     SCROW nRow = rAddress.Row();
     SCCOL nCol = rAddress.Col();
@@ -756,13 +680,13 @@ inline SCSIZE ScBroadcastAreaSlotMachine::ComputeSlotOffset(
         OSL_FAIL( "Row/Col invalid, using first slot!" );
         return 0;
     }
-    for (size_t i=0; i < aSlotDistribution.size(); ++i)
+    for (ScSlotData & i : aSlotDistribution)
     {
-        if (nRow < aSlotDistribution[i].nStopRow)
+        if (nRow < i.nStopRow)
         {
-            const ScSlotData& rSD = aSlotDistribution[i];
+            const ScSlotData& rSD = i;
             return rSD.nCumulated +
-                (static_cast<SCSIZE>(nRow - rSD.nStartRow)) / rSD.nSlice +
+                static_cast<SCSIZE>(nRow - rSD.nStartRow) / rSD.nSlice +
                 static_cast<SCSIZE>(nCol) / BCA_SLOT_COLS * nBcaSlotsRow;
         }
     }
@@ -771,7 +695,7 @@ inline SCSIZE ScBroadcastAreaSlotMachine::ComputeSlotOffset(
 }
 
 void ScBroadcastAreaSlotMachine::ComputeAreaPoints( const ScRange& rRange,
-        SCSIZE& rStart, SCSIZE& rEnd, SCSIZE& rRowBreak ) const
+        SCSIZE& rStart, SCSIZE& rEnd, SCSIZE& rRowBreak )
 {
     rStart = ComputeSlotOffset( rRange.aStart );
     rEnd = ComputeSlotOffset( rRange.aEnd );
@@ -781,7 +705,7 @@ void ScBroadcastAreaSlotMachine::ComputeAreaPoints( const ScRange& rRange,
 }
 
 inline void ComputeNextSlot( SCSIZE & nOff, SCSIZE & nBreak, ScBroadcastAreaSlot** & pp,
-        SCSIZE & nStart, ScBroadcastAreaSlot** const & ppSlots, SCSIZE const & nRowBreak )
+        SCSIZE & nStart, ScBroadcastAreaSlot** const & ppSlots, SCSIZE nRowBreak )
 {
     if ( nOff < nBreak )
     {
@@ -808,21 +732,24 @@ void ScBroadcastAreaSlotMachine::StartListeningArea(
     }
     else
     {
+        // A new area needs to be inserted to the corresponding slots, for 3D
+        // ranges for all sheets, do not slice into per sheet areas or the
+        // !bDone will break too early (i.e. after the first sheet) if
+        // subsequent listeners are to be added.
+        ScBroadcastArea* pArea = nullptr;
         bool bDone = false;
         for (SCTAB nTab = rRange.aStart.Tab();
                 !bDone && nTab <= rRange.aEnd.Tab(); ++nTab)
         {
             TableSlotsMap::iterator iTab( aTableSlotsMap.find( nTab));
             if (iTab == aTableSlotsMap.end())
-                iTab = aTableSlotsMap.insert( TableSlotsMap::value_type(
-                            nTab, new TableSlots)).first;
+                iTab = aTableSlotsMap.emplace(nTab, new TableSlots).first;
             ScBroadcastAreaSlot** ppSlots = (*iTab).second->getSlots();
             SCSIZE nStart, nEnd, nRowBreak;
             ComputeAreaPoints( rRange, nStart, nEnd, nRowBreak );
             SCSIZE nOff = nStart;
             SCSIZE nBreak = nOff + nRowBreak;
             ScBroadcastAreaSlot** pp = ppSlots + nOff;
-            ScBroadcastArea* pArea = NULL;
             while ( !bDone && nOff <= nEnd )
             {
                 if ( !*pp )
@@ -855,7 +782,7 @@ void ScBroadcastAreaSlotMachine::EndListeningArea(
             if (!pBCAlways->HasListeners())
             {
                 delete pBCAlways;
-                pBCAlways = NULL;
+                pBCAlways = nullptr;
             }
         }
     }
@@ -871,7 +798,7 @@ void ScBroadcastAreaSlotMachine::EndListeningArea(
             SCSIZE nOff = nStart;
             SCSIZE nBreak = nOff + nRowBreak;
             ScBroadcastAreaSlot** pp = ppSlots + nOff;
-            ScBroadcastArea* pArea = NULL;
+            ScBroadcastArea* pArea = nullptr;
             if (nOff == 0 && nEnd == nBcaSlots-1)
             {
                 // Slightly optimized for 0,0,MAXCOL,MAXROW calls as they
@@ -896,7 +823,7 @@ void ScBroadcastAreaSlotMachine::EndListeningArea(
     }
 }
 
-bool ScBroadcastAreaSlotMachine::AreaBroadcast( const ScRange& rRange, sal_uLong nHint )
+bool ScBroadcastAreaSlotMachine::AreaBroadcast( const ScRange& rRange, SfxHintId nHint )
 {
     bool bBroadcasted = false;
     SCTAB nEndTab = rRange.aEnd.Tab();
@@ -946,30 +873,6 @@ bool ScBroadcastAreaSlotMachine::AreaBroadcast( const ScHint& rHint ) const
     }
 }
 
-bool ScBroadcastAreaSlotMachine::AreaBroadcastInRange( const ScRange& rRange,
-        const ScHint& rHint ) const
-{
-    bool bBroadcasted = false;
-    SCTAB nEndTab = rRange.aEnd.Tab();
-    for (TableSlotsMap::const_iterator iTab( aTableSlotsMap.lower_bound( rRange.aStart.Tab()));
-            iTab != aTableSlotsMap.end() && (*iTab).first <= nEndTab; ++iTab)
-    {
-        ScBroadcastAreaSlot** ppSlots = (*iTab).second->getSlots();
-        SCSIZE nStart, nEnd, nRowBreak;
-        ComputeAreaPoints( rRange, nStart, nEnd, nRowBreak );
-        SCSIZE nOff = nStart;
-        SCSIZE nBreak = nOff + nRowBreak;
-        ScBroadcastAreaSlot** pp = ppSlots + nOff;
-        while ( nOff <= nEnd )
-        {
-            if ( *pp )
-                bBroadcasted |= (*pp)->AreaBroadcastInRange( rRange, rHint );
-            ComputeNextSlot( nOff, nBreak, pp, nStart, ppSlots, nRowBreak);
-        }
-    }
-    return bBroadcasted;
-}
-
 void ScBroadcastAreaSlotMachine::DelBroadcastAreasInRange(
         const ScRange& rRange )
 {
@@ -1009,7 +912,7 @@ void ScBroadcastAreaSlotMachine::DelBroadcastAreasInRange(
 // for all affected: remove, chain, update range, insert, and maybe delete
 void ScBroadcastAreaSlotMachine::UpdateBroadcastAreas(
         UpdateRefMode eUpdateRefMode,
-        const ScRange& rRange, SCsCOL nDx, SCsROW nDy, SCsTAB nDz )
+        const ScRange& rRange, SCCOL nDx, SCROW nDy, SCTAB nDz )
 {
     // remove affected and put in chain
     SCTAB nEndTab = rRange.aEnd.Tab();
@@ -1144,7 +1047,8 @@ void ScBroadcastAreaSlotMachine::UpdateBroadcastAreas(
         {
             aRange = ScRange( theCol1,theRow1,theTab1, theCol2,theRow2,theTab2 );
             pArea->UpdateRange( aRange );
-            pArea->GetBroadcaster().Broadcast( ScAreaChangedHint( aRange ) );   // for DDE
+            // For DDE and ScLookupCache
+            pArea->GetBroadcaster().Broadcast( ScAreaChangedHint( aRange ) );
         }
 
         // insert to slots
@@ -1152,8 +1056,7 @@ void ScBroadcastAreaSlotMachine::UpdateBroadcastAreas(
         {
             TableSlotsMap::iterator iTab( aTableSlotsMap.find( nTab));
             if (iTab == aTableSlotsMap.end())
-                iTab = aTableSlotsMap.insert( TableSlotsMap::value_type(
-                            nTab, new TableSlots)).first;
+                iTab = aTableSlotsMap.emplace(nTab, new TableSlots).first;
             ScBroadcastAreaSlot** ppSlots = (*iTab).second->getSlots();
             SCSIZE nStart, nEnd, nRowBreak;
             ComputeAreaPoints( aRange, nStart, nEnd, nRowBreak );
@@ -1170,7 +1073,7 @@ void ScBroadcastAreaSlotMachine::UpdateBroadcastAreas(
         }
 
         // unchain
-        pArea->SetUpdateChainNext( NULL );
+        pArea->SetUpdateChainNext( nullptr );
         pArea->SetInUpdateChain( false );
 
         // Delete if not inserted to any slot. RemoveBulkArea(pArea) was
@@ -1178,7 +1081,7 @@ void ScBroadcastAreaSlotMachine::UpdateBroadcastAreas(
         if (!pArea->GetRef())
             delete pArea;
     }
-    pEOUpdateChain = NULL;
+    pEOUpdateChain = nullptr;
 }
 
 void ScBroadcastAreaSlotMachine::EnterBulkBroadcast()
@@ -1186,14 +1089,19 @@ void ScBroadcastAreaSlotMachine::EnterBulkBroadcast()
     ++nInBulkBroadcast;
 }
 
-void ScBroadcastAreaSlotMachine::LeaveBulkBroadcast()
+void ScBroadcastAreaSlotMachine::LeaveBulkBroadcast( SfxHintId nHintId )
 {
     if (nInBulkBroadcast > 0)
     {
         if (--nInBulkBroadcast == 0)
         {
             ScBroadcastAreasBulk().swap( aBulkBroadcastAreas);
-            BulkBroadcastGroupAreas();
+            bool bBroadcasted = BulkBroadcastGroupAreas( nHintId );
+            // Trigger the "final" tracking.
+            if (pDoc->IsTrackFormulasPending())
+                pDoc->FinalTrackFormulas( nHintId );
+            else if (bBroadcasted)
+                pDoc->TrackFormulas( nHintId );
         }
     }
 }
@@ -1205,41 +1113,51 @@ bool ScBroadcastAreaSlotMachine::InsertBulkArea( const ScBroadcastArea* pArea )
 
 void ScBroadcastAreaSlotMachine::InsertBulkGroupArea( ScBroadcastArea* pArea, const ScRange& rRange )
 {
-    BulkGroupAreasType::iterator it = maBulkGroupAreas.lower_bound(pArea);
-    if (it == maBulkGroupAreas.end() || maBulkGroupAreas.key_comp()(pArea, it->first))
+    BulkGroupAreasType::iterator it = m_BulkGroupAreas.lower_bound(pArea);
+    if (it == m_BulkGroupAreas.end() || m_BulkGroupAreas.key_comp()(pArea, it->first))
     {
         // Insert a new one.
-        it = maBulkGroupAreas.insert(it, pArea, new sc::ColumnSpanSet(false));
+        it = m_BulkGroupAreas.insert(it, std::make_pair(pArea, o3tl::make_unique<sc::ColumnSpanSet>(false)));
     }
 
-    sc::ColumnSpanSet* pSet = it->second;
+    sc::ColumnSpanSet *const pSet = it->second.get();
     assert(pSet);
     pSet->set(rRange, true);
 }
 
-void ScBroadcastAreaSlotMachine::BulkBroadcastGroupAreas()
+bool ScBroadcastAreaSlotMachine::BulkBroadcastGroupAreas( SfxHintId nHintId )
 {
-    if (maBulkGroupAreas.empty())
-        return;
+    if (m_BulkGroupAreas.empty())
+        return false;
 
-    sc::BulkDataHint aHint(*pDoc, NULL);
+    sc::BulkDataHint aHint( *pDoc, nHintId);
 
     bool bBroadcasted = false;
-    BulkGroupAreasType::iterator it = maBulkGroupAreas.begin(), itEnd = maBulkGroupAreas.end();
+    BulkGroupAreasType::iterator it = m_BulkGroupAreas.begin(), itEnd = m_BulkGroupAreas.end();
     for (; it != itEnd; ++it)
     {
         ScBroadcastArea* pArea = it->first;
-        const sc::ColumnSpanSet* pSpans = it->second;
         assert(pArea);
-        assert(pSpans);
-        aHint.setSpans(pSpans);
-        pArea->GetBroadcaster().Broadcast(aHint);
-        bBroadcasted = true;
+        SvtBroadcaster& rBC = pArea->GetBroadcaster();
+        if (!rBC.HasListeners())
+        {
+            /* FIXME: find the cause where the last listener is removed and
+             * this area is still listed here. */
+            SAL_WARN("sc.core","ScBroadcastAreaSlotMachine::BulkBroadcastGroupAreas - pArea has no listeners and should had been removed already");
+        }
+        else
+        {
+            const sc::ColumnSpanSet *const pSpans = it->second.get();
+            assert(pSpans);
+            aHint.setSpans(pSpans);
+            rBC.Broadcast(aHint);
+            bBroadcasted = true;
+        }
     }
 
-    maBulkGroupAreas.clear();
-    if (bBroadcasted)
-        pDoc->TrackFormulas();
+    m_BulkGroupAreas.clear();
+
+    return bBroadcasted;
 }
 
 size_t ScBroadcastAreaSlotMachine::RemoveBulkArea( const ScBroadcastArea* pArea )
@@ -1247,15 +1165,20 @@ size_t ScBroadcastAreaSlotMachine::RemoveBulkArea( const ScBroadcastArea* pArea
     return aBulkBroadcastAreas.erase( pArea );
 }
 
+void ScBroadcastAreaSlotMachine::RemoveBulkGroupArea( ScBroadcastArea* pArea )
+{
+    m_BulkGroupAreas.erase(pArea);
+}
+
 void ScBroadcastAreaSlotMachine::PushAreaToBeErased( ScBroadcastAreaSlot* pSlot,
         ScBroadcastAreas::iterator& rIter )
 {
-    maAreasToBeErased.push_back( ::std::make_pair( pSlot, rIter));
+    maAreasToBeErased.emplace_back( pSlot, rIter);
 }
 
 void ScBroadcastAreaSlotMachine::FinallyEraseAreas( ScBroadcastAreaSlot* pSlot )
 {
-    SAL_WARN_IF( pSlot->IsInBroadcastIteration(), "sc",
+    SAL_WARN_IF( pSlot->IsInBroadcastIteration(), "sc.core",
             "ScBroadcastAreaSlotMachine::FinallyEraseAreas: during iteration? NO!");
     if (pSlot->IsInBroadcastIteration())
         return;
