@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <sfx2/objsh.hxx>
 #include <svl/itemset.hxx>
 #include <svl/zforlist.hxx>
@@ -27,20 +27,22 @@
 
 #include <com/sun/star/sheet/ConditionOperator2.hpp>
 
-#include "conditio.hxx"
-#include "formulacell.hxx"
-#include "document.hxx"
-#include "hints.hxx"
-#include "compiler.hxx"
-#include "rechead.hxx"
-#include "rangelst.hxx"
-#include "stlpool.hxx"
-#include "rangenam.hxx"
-#include "colorscale.hxx"
-#include "cellvalue.hxx"
-#include "editutil.hxx"
-#include "tokenarray.hxx"
-#include "refupdatecontext.hxx"
+#include <attrib.hxx>
+#include <conditio.hxx>
+#include <formulacell.hxx>
+#include <document.hxx>
+#include <hints.hxx>
+#include <compiler.hxx>
+#include <rechead.hxx>
+#include <rangelst.hxx>
+#include <stlpool.hxx>
+#include <rangenam.hxx>
+#include <rangeutl.hxx>
+#include <colorscale.hxx>
+#include <cellvalue.hxx>
+#include <editutil.hxx>
+#include <tokenarray.hxx>
+#include <refupdatecontext.hxx>
 #include <formula/errorcodes.hxx>
 #include <svl/sharedstring.hxx>
 #include <svl/sharedstringpool.hxx>
@@ -79,13 +81,13 @@ void ScFormatEntry::endRendering()
 {
 }
 
-static bool lcl_HasRelRef( ScDocument* pDoc, ScTokenArray* pFormula, sal_uInt16 nRecursion = 0 )
+static bool lcl_HasRelRef( ScDocument* pDoc, const ScTokenArray* pFormula, sal_uInt16 nRecursion = 0 )
 {
     if (pFormula)
     {
-        pFormula->Reset();
+        FormulaTokenArrayPlainIterator aIter( *pFormula );
         FormulaToken* t;
-        for( t = pFormula->Next(); t; t = pFormula->Next() )
+        for( t = aIter.Next(); t; t = aIter.Next() )
         {
             switch( t->GetType() )
             {
@@ -144,7 +146,7 @@ static bool lcl_HasRelRef( ScDocument* pDoc, ScTokenArray* pFormula, sal_uInt16
 
 namespace {
 
-void start_listen_to(ScFormulaListener& rListener, ScTokenArray* pTokens, const ScRangeList& rRangeList)
+void start_listen_to(ScFormulaListener& rListener, const ScTokenArray* pTokens, const ScRangeList& rRangeList)
 {
     size_t n = rRangeList.size();
     for (size_t i = 0; i < n; ++i)
@@ -310,7 +312,7 @@ ScConditionEntry::ScConditionEntry( ScConditionMode eOper,
         if ( pFormula1->GetLen() == 1 )
         {
             // Single (constant number)?
-            FormulaToken* pToken = pFormula1->First();
+            FormulaToken* pToken = pFormula1->FirstToken();
             if ( pToken->GetOpCode() == ocPush )
             {
                 if ( pToken->GetType() == svDouble )
@@ -334,7 +336,7 @@ ScConditionEntry::ScConditionEntry( ScConditionMode eOper,
         if ( pFormula2->GetLen() == 1 )
         {
             // Single (constant number)?
-            FormulaToken* pToken = pFormula2->First();
+            FormulaToken* pToken = pFormula2->FirstToken();
             if ( pToken->GetOpCode() == ocPush )
             {
                 if ( pToken->GetType() == svDouble )
@@ -398,7 +400,7 @@ void ScConditionEntry::Compile( const OUString& rExpr1, const OUString& rExpr2,
                 if ( pFormula1->GetLen() == 1 )
                 {
                     // Single (constant number)?
-                    FormulaToken* pToken = pFormula1->First();
+                    FormulaToken* pToken = pFormula1->FirstToken();
                     if ( pToken->GetOpCode() == ocPush )
                     {
                         if ( pToken->GetType() == svDouble )
@@ -436,7 +438,7 @@ void ScConditionEntry::Compile( const OUString& rExpr1, const OUString& rExpr2,
                 if ( pFormula2->GetLen() == 1 )
                 {
                     // Sigle (constant number)?
-                    FormulaToken* pToken = pFormula2->First();
+                    FormulaToken* pToken = pFormula2->FirstToken();
                     if ( pToken->GetOpCode() == ocPush )
                     {
                         if ( pToken->GetType() == svDouble )
@@ -522,6 +524,12 @@ void ScConditionEntry::CompileXML()
     Compile( GetExpression(aSrcPos, 0, 0, eTempGrammar1),
              GetExpression(aSrcPos, 1, 0, eTempGrammar2),
              aStrNmsp1, aStrNmsp2, eTempGrammar1, eTempGrammar2, true );
+
+    // Importing ocDde/ocWebservice?
+    if (pFormula1)
+        mpDoc->CheckLinkFormulaNeedingCheck(*pFormula1);
+    if (pFormula2)
+        mpDoc->CheckLinkFormulaNeedingCheck(*pFormula2);
 }
 
 void ScConditionEntry::SetSrcString( const OUString& rNew )
@@ -627,7 +635,7 @@ void ScConditionEntry::UpdateInsertTab( sc::RefUpdateInsertTabContext& rCxt )
         DELETEZ(pFCell2);
     }
 
-    StartListening();
+    ScRangeUpdater::UpdateInsertTab(aSrcPos, rCxt);
 }
 
 void ScConditionEntry::UpdateDeleteTab( sc::RefUpdateDeleteTabContext& rCxt )
@@ -644,6 +652,7 @@ void ScConditionEntry::UpdateDeleteTab( sc::RefUpdateDeleteTabContext& rCxt )
         DELETEZ(pFCell2);
     }
 
+    ScRangeUpdater::UpdateDeleteTab(aSrcPos, rCxt);
     StartListening();
 }
 
@@ -864,8 +873,7 @@ void ScConditionEntry::FillCache() const
                     if (!lcl_GetCellContent(aCell, false, nVal, aStr, mpDoc))
                     {
                         std::pair<ScConditionEntryCache::StringCacheType::iterator, bool> aResult =
-                            mpCache->maStrings.insert(
-                                ScConditionEntryCache::StringCacheType::value_type(aStr, 1));
+                            mpCache->maStrings.emplace(aStr, 1);
 
                         if(!aResult.second)
                             aResult.first->second++;
@@ -873,8 +881,7 @@ void ScConditionEntry::FillCache() const
                     else
                     {
                         std::pair<ScConditionEntryCache::ValueCacheType::iterator, bool> aResult =
-                            mpCache->maValues.insert(
-                                ScConditionEntryCache::ValueCacheType::value_type(nVal, 1));
+                            mpCache->maValues.emplace(nVal, 1);
 
                         if(!aResult.second)
                             aResult.first->second++;
@@ -1046,26 +1053,26 @@ bool ScConditionEntry::IsValid( double nArg, const ScAddress& rPos ) const
     {
         switch( eOp )
         {
-            case SC_COND_BEGINS_WITH:
-            case SC_COND_ENDS_WITH:
-            case SC_COND_CONTAINS_TEXT:
-            case SC_COND_NOT_CONTAINS_TEXT:
+            case ScConditionMode::BeginsWith:
+            case ScConditionMode::EndsWith:
+            case ScConditionMode::ContainsText:
+            case ScConditionMode::NotContainsText:
                 break;
-            case SC_COND_NOTEQUAL:
+            case ScConditionMode::NotEqual:
                 return true;
             default:
                 return false;
         }
     }
 
-    if ( eOp == SC_COND_BETWEEN || eOp == SC_COND_NOTBETWEEN )
+    if ( eOp == ScConditionMode::Between || eOp == ScConditionMode::NotBetween )
         if ( bIsStr2 )
             return false;
 
     double nComp1 = nVal1; // Copy, so that it can be changed
     double nComp2 = nVal2;
 
-    if ( eOp == SC_COND_BETWEEN || eOp == SC_COND_NOTBETWEEN )
+    if ( eOp == ScConditionMode::Between || eOp == ScConditionMode::NotBetween )
         if ( nComp1 > nComp2 )
         {
             // Right order for value range
@@ -1076,73 +1083,73 @@ bool ScConditionEntry::IsValid( double nArg, const ScAddress& rPos ) const
     bool bValid = false;
     switch (eOp)
     {
-        case SC_COND_NONE:
+        case ScConditionMode::NONE:
             break;                  // Always sal_False
-        case SC_COND_EQUAL:
+        case ScConditionMode::Equal:
             bValid = ::rtl::math::approxEqual( nArg, nComp1 );
             break;
-        case SC_COND_NOTEQUAL:
+        case ScConditionMode::NotEqual:
             bValid = !::rtl::math::approxEqual( nArg, nComp1 );
             break;
-        case SC_COND_GREATER:
+        case ScConditionMode::Greater:
             bValid = ( nArg > nComp1 ) && !::rtl::math::approxEqual( nArg, nComp1 );
             break;
-        case SC_COND_EQGREATER:
+        case ScConditionMode::EqGreater:
             bValid = ( nArg >= nComp1 ) || ::rtl::math::approxEqual( nArg, nComp1 );
             break;
-        case SC_COND_LESS:
+        case ScConditionMode::Less:
             bValid = ( nArg < nComp1 ) && !::rtl::math::approxEqual( nArg, nComp1 );
             break;
-        case SC_COND_EQLESS:
+        case ScConditionMode::EqLess:
             bValid = ( nArg <= nComp1 ) || ::rtl::math::approxEqual( nArg, nComp1 );
             break;
-        case SC_COND_BETWEEN:
+        case ScConditionMode::Between:
             bValid = ( nArg >= nComp1 && nArg <= nComp2 ) ||
                      ::rtl::math::approxEqual( nArg, nComp1 ) || ::rtl::math::approxEqual( nArg, nComp2 );
             break;
-        case SC_COND_NOTBETWEEN:
+        case ScConditionMode::NotBetween:
             bValid = ( nArg < nComp1 || nArg > nComp2 ) &&
                      !::rtl::math::approxEqual( nArg, nComp1 ) && !::rtl::math::approxEqual( nArg, nComp2 );
             break;
-        case SC_COND_DUPLICATE:
-        case SC_COND_NOTDUPLICATE:
+        case ScConditionMode::Duplicate:
+        case ScConditionMode::NotDuplicate:
             if( pCondFormat )
             {
                 bValid = IsDuplicate( nArg, OUString() );
-                if( eOp == SC_COND_NOTDUPLICATE )
+                if( eOp == ScConditionMode::NotDuplicate )
                     bValid = !bValid;
             }
             break;
-        case SC_COND_DIRECT:
+        case ScConditionMode::Direct:
             bValid = nComp1 != 0.0;
             break;
-        case SC_COND_TOP10:
+        case ScConditionMode::Top10:
             bValid = IsTopNElement( nArg );
             break;
-        case SC_COND_BOTTOM10:
+        case ScConditionMode::Bottom10:
             bValid = IsBottomNElement( nArg );
             break;
-        case SC_COND_TOP_PERCENT:
+        case ScConditionMode::TopPercent:
             bValid = IsTopNPercent( nArg );
             break;
-        case SC_COND_BOTTOM_PERCENT:
+        case ScConditionMode::BottomPercent:
             bValid = IsBottomNPercent( nArg );
             break;
-        case SC_COND_ABOVE_AVERAGE:
-        case SC_COND_ABOVE_EQUAL_AVERAGE:
-            bValid = IsAboveAverage( nArg, eOp == SC_COND_ABOVE_EQUAL_AVERAGE );
+        case ScConditionMode::AboveAverage:
+        case ScConditionMode::AboveEqualAverage:
+            bValid = IsAboveAverage( nArg, eOp == ScConditionMode::AboveEqualAverage );
             break;
-        case SC_COND_BELOW_AVERAGE:
-        case SC_COND_BELOW_EQUAL_AVERAGE:
-            bValid = IsBelowAverage( nArg, eOp == SC_COND_BELOW_EQUAL_AVERAGE );
+        case ScConditionMode::BelowAverage:
+        case ScConditionMode::BelowEqualAverage:
+            bValid = IsBelowAverage( nArg, eOp == ScConditionMode::BelowEqualAverage );
             break;
-        case SC_COND_ERROR:
-        case SC_COND_NOERROR:
+        case ScConditionMode::Error:
+        case ScConditionMode::NoError:
             bValid = IsError( rPos );
-            if( eOp == SC_COND_NOERROR )
+            if( eOp == ScConditionMode::NoError )
                 bValid = !bValid;
             break;
-        case SC_COND_BEGINS_WITH:
+        case ScConditionMode::BeginsWith:
             if(aStrVal1.isEmpty())
             {
                 OUString aStr = OUString::number(nVal1);
@@ -1155,7 +1162,7 @@ bool ScConditionEntry::IsValid( double nArg, const ScAddress& rPos ) const
                 bValid = aStr2.startsWith(aStrVal1);
             }
             break;
-        case SC_COND_ENDS_WITH:
+        case ScConditionMode::EndsWith:
             if(aStrVal1.isEmpty())
             {
                 OUString aStr = OUString::number(nVal1);
@@ -1168,8 +1175,8 @@ bool ScConditionEntry::IsValid( double nArg, const ScAddress& rPos ) const
                 bValid = aStr2.endsWith(aStrVal1);
             }
             break;
-        case SC_COND_CONTAINS_TEXT:
-        case SC_COND_NOT_CONTAINS_TEXT:
+        case ScConditionMode::ContainsText:
+        case ScConditionMode::NotContainsText:
             if(aStrVal1.isEmpty())
             {
                 OUString aStr = OUString::number(nVal1);
@@ -1182,7 +1189,7 @@ bool ScConditionEntry::IsValid( double nArg, const ScAddress& rPos ) const
                 bValid = aStr2.indexOf(aStrVal1) != -1;
             }
 
-            if( eOp == SC_COND_NOT_CONTAINS_TEXT )
+            if( eOp == ScConditionMode::NotContainsText )
                 bValid = !bValid;
             break;
         default:
@@ -1196,31 +1203,31 @@ bool ScConditionEntry::IsValidStr( const OUString& rArg, const ScAddress& rPos )
 {
     bool bValid = false;
     // Interpret must already have been called
-    if ( eOp == SC_COND_DIRECT ) // Formula is independent from the content
+    if ( eOp == ScConditionMode::Direct ) // Formula is independent from the content
         return nVal1 != 0.0;
 
-    if ( eOp == SC_COND_DUPLICATE || eOp == SC_COND_NOTDUPLICATE )
+    if ( eOp == ScConditionMode::Duplicate || eOp == ScConditionMode::NotDuplicate )
     {
         if( pCondFormat && !rArg.isEmpty() )
         {
             bValid = IsDuplicate( 0.0, rArg );
-            if( eOp == SC_COND_NOTDUPLICATE )
+            if( eOp == ScConditionMode::NotDuplicate )
                 bValid = !bValid;
             return bValid;
         }
     }
 
     // If number contains condition, always false, except for "not equal".
-    if ( !bIsStr1 && (eOp != SC_COND_ERROR && eOp != SC_COND_NOERROR) )
-        return ( eOp == SC_COND_NOTEQUAL );
-    if ( eOp == SC_COND_BETWEEN || eOp == SC_COND_NOTBETWEEN )
+    if ( !bIsStr1 && (eOp != ScConditionMode::Error && eOp != ScConditionMode::NoError) )
+        return ( eOp == ScConditionMode::NotEqual );
+    if ( eOp == ScConditionMode::Between || eOp == ScConditionMode::NotBetween )
         if ( !bIsStr2 )
             return false;
 
     OUString aUpVal1( aStrVal1 ); //TODO: As a member? (Also set in Interpret)
     OUString aUpVal2( aStrVal2 );
 
-    if ( eOp == SC_COND_BETWEEN || eOp == SC_COND_NOTBETWEEN )
+    if ( eOp == ScConditionMode::Between || eOp == ScConditionMode::NotBetween )
         if (ScGlobal::GetCollator()->compareString( aUpVal1, aUpVal2 ) > 0)
         {
             // Right order for value range
@@ -1229,37 +1236,37 @@ bool ScConditionEntry::IsValidStr( const OUString& rArg, const ScAddress& rPos )
 
     switch ( eOp )
     {
-        case SC_COND_EQUAL:
+        case ScConditionMode::Equal:
             bValid = (ScGlobal::GetCollator()->compareString(
                 rArg, aUpVal1 ) == 0);
         break;
-        case SC_COND_NOTEQUAL:
+        case ScConditionMode::NotEqual:
             bValid = (ScGlobal::GetCollator()->compareString(
                 rArg, aUpVal1 ) != 0);
         break;
-        case SC_COND_TOP_PERCENT:
-        case SC_COND_BOTTOM_PERCENT:
-        case SC_COND_TOP10:
-        case SC_COND_BOTTOM10:
-        case SC_COND_ABOVE_AVERAGE:
-        case SC_COND_BELOW_AVERAGE:
+        case ScConditionMode::TopPercent:
+        case ScConditionMode::BottomPercent:
+        case ScConditionMode::Top10:
+        case ScConditionMode::Bottom10:
+        case ScConditionMode::AboveAverage:
+        case ScConditionMode::BelowAverage:
             return false;
-        case SC_COND_ERROR:
-        case SC_COND_NOERROR:
+        case ScConditionMode::Error:
+        case ScConditionMode::NoError:
             bValid = IsError( rPos );
-            if(eOp == SC_COND_NOERROR)
+            if(eOp == ScConditionMode::NoError)
                 bValid = !bValid;
         break;
-        case SC_COND_BEGINS_WITH:
+        case ScConditionMode::BeginsWith:
             bValid = rArg.startsWith(aUpVal1);
         break;
-        case SC_COND_ENDS_WITH:
+        case ScConditionMode::EndsWith:
             bValid = rArg.endsWith(aUpVal1);
         break;
-        case SC_COND_CONTAINS_TEXT:
-        case SC_COND_NOT_CONTAINS_TEXT:
+        case ScConditionMode::ContainsText:
+        case ScConditionMode::NotContainsText:
             bValid = rArg.indexOf(aUpVal1) != -1;
-            if(eOp == SC_COND_NOT_CONTAINS_TEXT)
+            if(eOp == ScConditionMode::NotContainsText)
                 bValid = !bValid;
         break;
         default:
@@ -1268,28 +1275,28 @@ bool ScConditionEntry::IsValidStr( const OUString& rArg, const ScAddress& rPos )
                 rArg, aUpVal1 );
             switch ( eOp )
             {
-                case SC_COND_GREATER:
+                case ScConditionMode::Greater:
                     bValid = ( nCompare > 0 );
                     break;
-                case SC_COND_EQGREATER:
+                case ScConditionMode::EqGreater:
                     bValid = ( nCompare >= 0 );
                     break;
-                case SC_COND_LESS:
+                case ScConditionMode::Less:
                     bValid = ( nCompare < 0 );
                     break;
-                case SC_COND_EQLESS:
+                case ScConditionMode::EqLess:
                     bValid = ( nCompare <= 0 );
                     break;
-                case SC_COND_BETWEEN:
-                case SC_COND_NOTBETWEEN:
+                case ScConditionMode::Between:
+                case ScConditionMode::NotBetween:
                     //  Test for NOTBETWEEN:
                     bValid = ( nCompare < 0 ||
                         ScGlobal::GetCollator()->compareString( rArg,
                         aUpVal2 ) > 0 );
-                    if ( eOp == SC_COND_BETWEEN )
+                    if ( eOp == ScConditionMode::Between )
                         bValid = !bValid;
                     break;
-                //  SC_COND_DIRECT already handled above
+                //  ScConditionMode::Direct already handled above
                 default:
                     SAL_WARN("sc", "unknown operation in ScConditionEntry");
                     bValid = false;
@@ -1314,7 +1321,7 @@ bool ScConditionEntry::IsCellValid( ScRefCellValue& rCell, const ScAddress& rPos
 }
 
 OUString ScConditionEntry::GetExpression( const ScAddress& rCursor, sal_uInt16 nIndex,
-                                        sal_uLong nNumFmt,
+                                        sal_uInt32 nNumFmt,
                                         const FormulaGrammar::Grammar eGrammar ) const
 {
     assert( nIndex <= 1);
@@ -1418,9 +1425,7 @@ ScAddress ScConditionEntry::GetValidSrcPos() const
         ScTokenArray* pFormula = nPass ? pFormula2 : pFormula1;
         if (pFormula)
         {
-            pFormula->Reset();
-            formula::FormulaToken* t;
-            while ( ( t = pFormula->GetNextReference() ) != nullptr )
+            for ( auto t: pFormula->References() )
             {
                 ScSingleRefData& rRef1 = *t->GetSingleRef();
                 ScAddress aAbs = rRef1.toAbs(aSrcPos);
@@ -1482,41 +1487,41 @@ ScFormatEntry* ScConditionEntry::Clone(ScDocument* pDoc) const
 
 ScConditionMode ScConditionEntry::GetModeFromApi(css::sheet::ConditionOperator nOperation)
 {
-    ScConditionMode eMode = SC_COND_NONE;
+    ScConditionMode eMode = ScConditionMode::NONE;
     switch ((sal_Int32)nOperation)
     {
         case css::sheet::ConditionOperator2::EQUAL:
-            eMode = SC_COND_EQUAL;
+            eMode = ScConditionMode::Equal;
             break;
         case css::sheet::ConditionOperator2::LESS:
-            eMode = SC_COND_LESS;
+            eMode = ScConditionMode::Less;
             break;
         case css::sheet::ConditionOperator2::GREATER:
-            eMode = SC_COND_GREATER;
+            eMode = ScConditionMode::Greater;
             break;
         case css::sheet::ConditionOperator2::LESS_EQUAL:
-            eMode = SC_COND_EQLESS;
+            eMode = ScConditionMode::EqLess;
             break;
         case css::sheet::ConditionOperator2::GREATER_EQUAL:
-            eMode = SC_COND_EQGREATER;
+            eMode = ScConditionMode::EqGreater;
             break;
         case css::sheet::ConditionOperator2::NOT_EQUAL:
-            eMode = SC_COND_NOTEQUAL;
+            eMode = ScConditionMode::NotEqual;
             break;
         case css::sheet::ConditionOperator2::BETWEEN:
-            eMode = SC_COND_BETWEEN;
+            eMode = ScConditionMode::Between;
             break;
         case css::sheet::ConditionOperator2::NOT_BETWEEN:
-            eMode = SC_COND_NOTBETWEEN;
+            eMode = ScConditionMode::NotBetween;
             break;
         case css::sheet::ConditionOperator2::FORMULA:
-            eMode = SC_COND_DIRECT;
+            eMode = ScConditionMode::Direct;
             break;
         case css::sheet::ConditionOperator2::DUPLICATE:
-            eMode = SC_COND_DUPLICATE;
+            eMode = ScConditionMode::Duplicate;
             break;
         case css::sheet::ConditionOperator2::NOT_DUPLICATE:
-            eMode = SC_COND_NOTDUPLICATE;
+            eMode = ScConditionMode::NotDuplicate;
             break;
         default:
             break;
@@ -1619,12 +1624,12 @@ bool ScCondDateFormatEntry::IsValid( const ScAddress& rPos ) const
 
     const Date& rActDate = *mpCache;
     SvNumberFormatter* pFormatter = mpDoc->GetFormatTable();
-    long nCurrentDate = rActDate - *(pFormatter->GetNullDate());
+    sal_Int32 nCurrentDate = rActDate - pFormatter->GetNullDate();
 
     double nVal = rCell.getValue();
-    long nCellDate = (long) ::rtl::math::approxFloor(nVal);
-    Date aCellDate = *(pFormatter->GetNullDate());
-    aCellDate += (long) ::rtl::math::approxFloor(nVal);
+    sal_Int32 nCellDate = static_cast<sal_Int32>(::rtl::math::approxFloor(nVal));
+    Date aCellDate = pFormatter->GetNullDate();
+    aCellDate.AddDays(nCellDate);
 
     switch(meType)
     {
@@ -1645,40 +1650,50 @@ bool ScCondDateFormatEntry::IsValid( const ScAddress& rPos ) const
                 return true;
             break;
         case condformat::LASTWEEK:
-            if( rActDate.GetDayOfWeek() != SUNDAY )
             {
-                Date aBegin(rActDate - 8 - static_cast<long>(rActDate.GetDayOfWeek()));
-                Date aEnd(rActDate - 2 -static_cast<long>(rActDate.GetDayOfWeek()));
-                return aCellDate.IsBetween( aBegin, aEnd );
-            }
-            else
-            {
-                Date aBegin(rActDate - 8);
-                Date aEnd(rActDate - 1);
-                return aCellDate.IsBetween( aBegin, aEnd );
+                const DayOfWeek eDay = rActDate.GetDayOfWeek();
+                if( eDay != SUNDAY )
+                {
+                    Date aBegin(rActDate - (8 + static_cast<sal_Int32>(eDay)));
+                    Date aEnd(rActDate - (2 + static_cast<sal_Int32>(eDay)));
+                    return aCellDate.IsBetween( aBegin, aEnd );
+                }
+                else
+                {
+                    Date aBegin(rActDate - 8);
+                    Date aEnd(rActDate - 1);
+                    return aCellDate.IsBetween( aBegin, aEnd );
+                }
             }
             break;
         case condformat::THISWEEK:
-            if( rActDate.GetDayOfWeek() != SUNDAY )
             {
-                Date aBegin(rActDate - 1 - static_cast<long>(rActDate.GetDayOfWeek()));
-                Date aEnd(rActDate + 5 - static_cast<long>(rActDate.GetDayOfWeek()));
-                return aCellDate.IsBetween( aBegin, aEnd );
-            }
-            else
-            {
-                Date aEnd( rActDate + 6);
-                return aCellDate.IsBetween( rActDate, aEnd );
+                const DayOfWeek eDay = rActDate.GetDayOfWeek();
+                if( eDay != SUNDAY )
+                {
+                    Date aBegin(rActDate - (1 + static_cast<sal_Int32>(eDay)));
+                    Date aEnd(rActDate + (5 - static_cast<sal_Int32>(eDay)));
+                    return aCellDate.IsBetween( aBegin, aEnd );
+                }
+                else
+                {
+                    Date aEnd( rActDate + 6);
+                    return aCellDate.IsBetween( rActDate, aEnd );
+                }
             }
             break;
         case condformat::NEXTWEEK:
-            if( rActDate.GetDayOfWeek() != SUNDAY )
             {
-                return aCellDate.IsBetween( rActDate + 6 - static_cast<long>(rActDate.GetDayOfWeek()), rActDate + 12 - static_cast<long>(rActDate.GetDayOfWeek()) );
-            }
-            else
-            {
-                return aCellDate.IsBetween( rActDate + 7, rActDate + 13 );
+                const DayOfWeek eDay = rActDate.GetDayOfWeek();
+                if( eDay != SUNDAY )
+                {
+                    return aCellDate.IsBetween( rActDate + (6 - static_cast<sal_Int32>(eDay)),
+                            rActDate + (12 - static_cast<sal_Int32>(eDay)) );
+                }
+                else
+                {
+                    return aCellDate.IsBetween( rActDate + 7, rActDate + 13 );
+                }
             }
             break;
         case condformat::LASTMONTH:
@@ -2256,7 +2271,7 @@ void ScConditionalFormatList::RemoveFromDocument(ScDocument* pDoc) const
     ScRangeList aRange = GetCombinedRange();
     ScMarkData aMark;
     aMark.MarkFromRangeList(aRange, true);
-    sal_uInt16 pItems[2] = { ATTR_CONDITIONAL,0};
+    sal_uInt16 const pItems[2] = { sal_uInt16(ATTR_CONDITIONAL),0};
     pDoc->ClearSelectionItems(pItems, aMark);
 }
 
