@@ -19,31 +19,32 @@
 
 #include <svl/intitem.hxx>
 #include <svl/zforlist.hxx>
+#include <svl/zformat.hxx>
 #include <formula/token.hxx>
 
-#include "document.hxx"
-#include "table.hxx"
-#include "globstr.hrc"
-#include "subtotal.hxx"
-#include "docoptio.hxx"
-#include "interpre.hxx"
-#include "markdata.hxx"
-#include "validat.hxx"
-#include "scitems.hxx"
-#include "stlpool.hxx"
-#include "poolhelp.hxx"
-#include "detdata.hxx"
-#include "patattr.hxx"
-#include "chgtrack.hxx"
-#include "progress.hxx"
-#include "paramisc.hxx"
-#include "compiler.hxx"
-#include "externalrefmgr.hxx"
-#include "colorscale.hxx"
-#include "attrib.hxx"
-#include "formulacell.hxx"
-#include "tokenarray.hxx"
-#include "scmatrix.hxx"
+#include <document.hxx>
+#include <table.hxx>
+#include <globstr.hrc>
+#include <subtotal.hxx>
+#include <docoptio.hxx>
+#include <interpre.hxx>
+#include <markdata.hxx>
+#include <validat.hxx>
+#include <scitems.hxx>
+#include <stlpool.hxx>
+#include <poolhelp.hxx>
+#include <detdata.hxx>
+#include <patattr.hxx>
+#include <chgtrack.hxx>
+#include <progress.hxx>
+#include <paramisc.hxx>
+#include <compiler.hxx>
+#include <externalrefmgr.hxx>
+#include <colorscale.hxx>
+#include <attrib.hxx>
+#include <formulacell.hxx>
+#include <tokenarray.hxx>
+#include <scmatrix.hxx>
 #include <tokenstringcontext.hxx>
 #include <memory>
 
@@ -146,7 +147,7 @@ bool ScDocument::Solver(SCCOL nFCol, SCROW nFRow, SCTAB nFTab,
                     sal_uInt16 nHorIter = 0;
                     const double fHorStepAngle = 5.0;
                     const double fHorMaxAngle = 80.0;
-                    int nHorMaxIter = static_cast<int>( fHorMaxAngle / fHorStepAngle );
+                    int const nHorMaxIter = static_cast<int>( fHorMaxAngle / fHorStepAngle );
                     bool bDoneHorMove = false;
 
                     while ( !bDoneHorMove && !bHorMoveError && nHorIter++ < nHorMaxIter )
@@ -270,15 +271,16 @@ void ScDocument::InsertMatrixFormula(SCCOL nCol1, SCROW nRow1,
         SAL_WARN("sc", "ScDocument::InsertMatrixFormula: No table marked");
         return;
     }
+    assert( ValidColRow( nCol1, nRow1) && ValidColRow( nCol2, nRow2));
 
     SCTAB nTab1 = *rMark.begin();
 
     ScFormulaCell* pCell;
     ScAddress aPos( nCol1, nRow1, nTab1 );
     if (pArr)
-        pCell = new ScFormulaCell(this, aPos, *pArr, eGram, MM_FORMULA);
+        pCell = new ScFormulaCell(this, aPos, *pArr, eGram, ScMatrixMode::Formula);
     else
-        pCell = new ScFormulaCell( this, aPos, rFormula, eGram, MM_FORMULA );
+        pCell = new ScFormulaCell( this, aPos, rFormula, eGram, ScMatrixMode::Formula );
     pCell->SetMatColsRows( nCol2 - nCol1 + 1, nRow2 - nRow1 + 1 );
     ScMarkData::const_iterator itr = rMark.begin(), itrEnd = rMark.end();
     SCTAB nMax = static_cast<SCTAB>(maTabs.size());
@@ -325,7 +327,7 @@ void ScDocument::InsertMatrixFormula(SCCOL nCol1, SCROW nRow1,
             *t->GetSingleRef() = aRefData;
         }
 
-        for (SCCOL nCol = nCol1; nCol <= nCol2; ++nCol)
+        for (SCCOL nCol : GetColumnsRange(nTab1, nCol1, nCol2))
         {
             for (SCROW nRow = nRow1; nRow <= nRow2; ++nRow)
             {
@@ -339,7 +341,7 @@ void ScDocument::InsertMatrixFormula(SCCOL nCol1, SCROW nRow1,
                 aRefData.SetAddress(aBasePos, aPos);
                 *t->GetSingleRef() = aRefData;
                 std::unique_ptr<ScTokenArray> pTokArr(aArr.Clone());
-                pCell = new ScFormulaCell(this, aPos, *pTokArr, eGram, MM_REFERENCE);
+                pCell = new ScFormulaCell(this, aPos, *pTokArr, eGram, ScMatrixMode::Reference);
                 pTab->SetFormulaCell(nCol, nRow, pCell);
             }
         }
@@ -352,6 +354,7 @@ void ScDocument::InsertTableOp(const ScTabOpParam& rParam,  // multiple (repeate
 {
     PutInOrder(nCol1, nCol2);
     PutInOrder(nRow1, nRow2);
+    assert( ValidColRow( nCol1, nRow1) && ValidColRow( nCol2, nRow2));
     SCTAB i, nTab1;
     SCCOL j;
     SCROW k;
@@ -426,7 +429,7 @@ void ScDocument::InsertTableOp(const ScTabOpParam& rParam,  // multiple (repeate
     aForString.append(ScCompiler::GetNativeSymbol( ocClose ));
 
     ScFormulaCell aRefCell( this, ScAddress( nCol1, nRow1, nTab1 ), aForString.makeStringAndClear(),
-           formula::FormulaGrammar::GRAM_NATIVE, MM_NONE );
+           formula::FormulaGrammar::GRAM_NATIVE, ScMatrixMode::NONE );
     for( j = nCol1; j <= nCol2; j++ )
         for( k = nRow1; k <= nRow2; k++ )
             for (i = 0; i < static_cast<SCTAB>(maTabs.size()); i++)
@@ -470,16 +473,16 @@ bool setCacheTableReferenced(formula::FormulaToken& rToken, ScExternalRefManager
 
 }
 
-bool ScDocument::MarkUsedExternalReferences( ScTokenArray& rArr, const ScAddress& rPos )
+bool ScDocument::MarkUsedExternalReferences( const ScTokenArray& rArr, const ScAddress& rPos )
 {
     if (!rArr.GetLen())
         return false;
 
     ScExternalRefManager* pRefMgr = nullptr;
-    rArr.Reset();
+    formula::FormulaTokenArrayPlainIterator aIter( rArr );
     formula::FormulaToken* t = nullptr;
     bool bAllMarked = false;
-    while (!bAllMarked && (t = rArr.GetNextReferenceOrName()) != nullptr)
+    while (!bAllMarked && (t = aIter.GetNextReferenceOrName()) != nullptr)
     {
         if (t->IsExternalRef())
         {
@@ -497,7 +500,8 @@ bool ScDocument::MarkUsedExternalReferences( ScTokenArray& rArr, const ScAddress
                 continue;
 
             ScTokenArray* pArray = pRangeData->GetCode();
-            for (t = pArray->First(); t; t = pArray->Next())
+            formula::FormulaTokenArrayPlainIterator aArrayIter(*pArray);
+            for (t = aArrayIter.First(); t; t = aArrayIter.Next())
             {
                 if (!t->IsExternalRef())
                     continue;
@@ -532,7 +536,7 @@ bool ScDocument::GetNextMarkedCell( SCCOL& rCol, SCROW& rRow, SCTAB nTab,
 
 void ScDocument::ReplaceStyle(const SvxSearchItem& rSearchItem,
                               SCCOL nCol, SCROW nRow, SCTAB nTab,
-                              ScMarkData& rMark)
+                              const ScMarkData& rMark)
 {
     if (nTab < static_cast<SCTAB>(maTabs.size()) && maTabs[nTab])
         maTabs[nTab]->ReplaceStyle(rSearchItem, nCol, nRow, rMark, true/*bIsUndoP*/);
@@ -651,14 +655,16 @@ bool ScDocument::GetSelectionFunction( ScSubTotalFunc eFunc,
 
 double ScDocument::RoundValueAsShown( double fVal, sal_uInt32 nFormat ) const
 {
+    const SvNumberformat* pFormat = GetFormatTable()->GetEntry( nFormat );
     short nType;
-    if ( (nType = GetFormatTable()->GetType( nFormat )) != css::util::NumberFormat::DATE
-      && nType != css::util::NumberFormat::TIME && nType != css::util::NumberFormat::DATETIME )
+    if (pFormat && (nType = pFormat->GetMaskedType()) != css::util::NumberFormat::DATE
+            && nType != css::util::NumberFormat::TIME && nType != css::util::NumberFormat::DATETIME )
     {
         short nPrecision;
         if ((nFormat % SV_COUNTRY_LANGUAGE_OFFSET) != 0)
         {
-            nPrecision = (short)GetFormatTable()->GetFormatPrecision( nFormat );
+            sal_uInt16 nIdx = pFormat->GetSubformatIndex( fVal );
+            nPrecision = (short)pFormat->GetFormatPrecision( nIdx );
             switch ( nType )
             {
                 case css::util::NumberFormat::PERCENT:      // 0.41% == 0.0041
@@ -666,10 +672,33 @@ double ScDocument::RoundValueAsShown( double fVal, sal_uInt32 nFormat ) const
                     break;
                 case css::util::NumberFormat::SCIENTIFIC:   // 1.23e-3 == 0.00123
                 {
+                    short nExp = 0;
                     if ( fVal > 0.0 )
-                        nPrecision = sal::static_int_cast<short>( nPrecision - (short)floor( log10( fVal ) ) );
+                        nExp = (short)floor( log10( fVal ) );
                     else if ( fVal < 0.0 )
-                        nPrecision = sal::static_int_cast<short>( nPrecision - (short)floor( log10( -fVal ) ) );
+                        nExp = (short)floor( log10( -fVal ) );
+                    nPrecision -= nExp;
+                    short nInteger = (short)pFormat->GetFormatIntegerDigits( nIdx );
+                    if ( nInteger > 1 ) // Engineering notation
+                    {
+                        short nIncrement = nExp % nInteger;
+                        if ( nIncrement != 0 )
+                        {
+                            nPrecision += nIncrement;
+                            if (nExp < 0 )
+                                nPrecision += nInteger;
+                        }
+                    }
+                    break;
+                }
+                case css::util::NumberFormat::FRACTION:     // get value of fraction representation
+                {
+                    return pFormat->GetRoundFractionValue( fVal );
+                }
+                case css::util::NumberFormat::NUMBER:
+                case css::util::NumberFormat::CURRENCY:
+                {   // tdf#106253 Thousands divisors for format "0,"
+                    nPrecision -=  pFormat->GetThousandDivisorPrecision( nIdx );
                     break;
                 }
             }
@@ -710,7 +739,10 @@ sal_uLong ScDocument::AddValidationEntry( const ScValidationData& rNew )
         return 0;                   // empty is always 0
 
     if (!pValidationList)
+    {
+        ScMutationGuard aGuard(this, ScMutationGuardFlags::CORE);
         pValidationList = new ScValidationDataList;
+    }
 
     sal_uLong nMax = 0;
     for( ScValidationDataList::iterator it = pValidationList->begin(); it != pValidationList->end(); ++it )
@@ -728,6 +760,7 @@ sal_uLong ScDocument::AddValidationEntry( const ScValidationData& rNew )
     sal_uLong nNewKey = nMax + 1;
     ScValidationData* pInsert = rNew.Clone(this);
     pInsert->SetKey( nNewKey );
+    ScMutationGuard aGuard(this, ScMutationGuardFlags::CORE);
     pValidationList->InsertNew( pInsert );
     return nNewKey;
 }
@@ -742,7 +775,7 @@ const SfxPoolItem* ScDocument::GetEffItem(
         const SfxPoolItem* pItem;
         if ( rSet.GetItemState( ATTR_CONDITIONAL, true, &pItem ) == SfxItemState::SET )
         {
-            const std::vector<sal_uInt32>& rIndex = static_cast<const ScCondFormatItem&>(pPattern->GetItem(ATTR_CONDITIONAL)).GetCondFormatData();
+            const std::vector<sal_uInt32>& rIndex = pPattern->GetItem(ATTR_CONDITIONAL).GetCondFormatData();
             ScConditionalFormatList* pCondFormList = GetCondFormList( nTab );
             if (!rIndex.empty() && pCondFormList)
             {
@@ -757,7 +790,7 @@ const SfxPoolItem* ScDocument::GetEffItem(
                         OUString aStyle = pForm->GetCellStyle(aCell, aPos);
                         if (!aStyle.isEmpty())
                         {
-                            SfxStyleSheetBase* pStyleSheet = xPoolHelper->GetStylePool()->Find(
+                            SfxStyleSheetBase* pStyleSheet = mxPoolHelper->GetStylePool()->Find(
                                     aStyle, SfxStyleFamily::Para );
                             if ( pStyleSheet && pStyleSheet->GetItemSet().GetItemState(
                                         nWhich, true, &pItem ) == SfxItemState::SET )
@@ -783,7 +816,7 @@ const SfxItemSet* ScDocument::GetCondResult( SCCOL nCol, SCROW nRow, SCTAB nTab
     ScRefCellValue aCell(const_cast<ScDocument&>(*this), aPos);
     const ScPatternAttr* pPattern = GetPattern( nCol, nRow, nTab );
     const std::vector<sal_uInt32>& rIndex =
-        static_cast<const ScCondFormatItem&>(pPattern->GetItem(ATTR_CONDITIONAL)).GetCondFormatData();
+        pPattern->GetItem(ATTR_CONDITIONAL).GetCondFormatData();
 
     return GetCondResult(aCell, aPos, *pFormatList, rIndex);
 }
@@ -803,7 +836,7 @@ const SfxItemSet* ScDocument::GetCondResult(
         if (!aStyle.isEmpty())
         {
             SfxStyleSheetBase* pStyleSheet =
-                xPoolHelper->GetStylePool()->Find(aStyle, SfxStyleFamily::Para);
+                mxPoolHelper->GetStylePool()->Find(aStyle, SfxStyleFamily::Para);
 
             if (pStyleSheet)
                 return &pStyleSheet->GetItemSet();
@@ -901,7 +934,7 @@ void ScDocument::SetDetOpList(ScDetOpList* pNew)
 
 sal_uInt16 ScDocument::RowDifferences( SCROW nThisRow, SCTAB nThisTab,
                                     ScDocument& rOtherDoc, SCROW nOtherRow, SCTAB nOtherTab,
-                                    SCCOL nMaxCol, SCCOLROW* pOtherCols )
+                                    SCCOL nMaxCol, const SCCOLROW* pOtherCols )
 {
     sal_uLong nDif = 0;
     sal_uLong nUsed = 0;
@@ -939,7 +972,7 @@ sal_uInt16 ScDocument::RowDifferences( SCROW nThisRow, SCTAB nThisTab,
 
 sal_uInt16 ScDocument::ColDifferences( SCCOL nThisCol, SCTAB nThisTab,
                                     ScDocument& rOtherDoc, SCCOL nOtherCol, SCTAB nOtherTab,
-                                    SCROW nMaxRow, SCCOLROW* pOtherRows )
+                                    SCROW nMaxRow, const SCCOLROW* pOtherRows )
 {
 
     //TODO: optimize e.g. with iterator?
@@ -980,7 +1013,7 @@ sal_uInt16 ScDocument::ColDifferences( SCCOL nThisCol, SCTAB nThisTab,
 
 void ScDocument::FindOrder( SCCOLROW* pOtherRows, SCCOLROW nThisEndRow, SCCOLROW nOtherEndRow,
                             bool bColumns, ScDocument& rOtherDoc, SCTAB nThisTab, SCTAB nOtherTab,
-                            SCCOLROW nEndCol, SCCOLROW* pTranslate, ScProgress* pProgress, sal_uLong nProAdd )
+                            SCCOLROW nEndCol, const SCCOLROW* pTranslate, ScProgress* pProgress, sal_uLong nProAdd )
 {
     //  bColumns=true: rows are columns and vice versa
 
@@ -1099,7 +1132,7 @@ void ScDocument::CompareDocument( ScDocument& rOtherDoc )
                 if (!rOtherDoc.IsScenario(nTemp))
                 {
                     rOtherDoc.GetName( nTemp, aOtherName );
-                    if ( aThisName.equals(aOtherName) )
+                    if ( aThisName == aOtherName )
                         nOtherTab = nTemp;
                 }
         }
@@ -1243,7 +1276,7 @@ void ScDocument::CompareDocument( ScDocument& rOtherDoc )
                     //  combine
                     if ( nThisCol == nThisEndCol || ValidCol(static_cast<SCCOL>(pOtherCols[nThisCol+1])) )
                     {
-                        SCCOL nFirstNew = static_cast<SCCOL>(nThisCol);
+                        SCCOL nFirstNew = nThisCol;
                         while ( nFirstNew > 0 && pOtherCols[nFirstNew-1] > MAXCOL )
                             --nFirstNew;
                         SCCOL nDiff = nThisCol - nFirstNew;
