@@ -17,9 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sheetevents.hxx"
+#include <sheetevents.hxx>
 #include <com/sun/star/script/vba/VBAEventId.hpp>
-#include <osl/diagnose.h>
 
 OUString ScSheetEvents::GetEventName(ScSheetEventId nEvent)
 {
