@@ -18,7 +18,7 @@
  */
 
 #include <memory>
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/eeitem.hxx>
 #include <i18nlangtag/mslangid.hxx>
 #include <svx/algitem.hxx>
@@ -44,19 +44,19 @@
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
 
-#include "sc.hrc"
-#include "attrib.hxx"
-#include "global.hxx"
-#include "globstr.hrc"
-#include "document.hxx"
-#include "docpool.hxx"
-#include "stlpool.hxx"
-#include "stlsheet.hxx"
-#include "rechead.hxx"
-#include "editutil.hxx"
-#include "patattr.hxx"
+#include <sc.hrc>
+#include <attrib.hxx>
+#include <global.hxx>
+#include <globstr.hrc>
+#include <document.hxx>
+#include <docpool.hxx>
+#include <stlpool.hxx>
+#include <stlsheet.hxx>
+#include <rechead.hxx>
+#include <editutil.hxx>
+#include <patattr.hxx>
 
-ScStyleSheetPool::ScStyleSheetPool( SfxItemPool&    rPoolP,
+ScStyleSheetPool::ScStyleSheetPool( const SfxItemPool& rPoolP,
                                     ScDocument*     pDocument )
     :   SfxStyleSheetPool( rPoolP ),
         pActualStyleSheet( nullptr ),
@@ -280,7 +280,7 @@ void ScStyleSheetPool::CreateStandardStyles()
     pSheet->SetHelpId( aHelpFile, HID_SC_SHEET_PAGE_STD );
 
     // distance to header/footer for the sheet
-    pHFSetItem = new SvxSetItem( static_cast<const SvxSetItem&>(pSet->Get( ATTR_PAGE_HEADERSET ) ) );
+    pHFSetItem = new SvxSetItem( pSet->Get( ATTR_PAGE_HEADERSET ) );
     pHFSetItem->SetWhich(ATTR_PAGE_HEADERSET);
     pSet->Put( *pHFSetItem );
     pHFSetItem->SetWhich(ATTR_PAGE_FOOTERSET);
@@ -335,7 +335,7 @@ void ScStyleSheetPool::CreateStandardStyles()
     aBoxInfoItem.SetTable( false );
     aBoxInfoItem.SetDist ( true );
 
-    pHFSetItem = new SvxSetItem( static_cast<const SvxSetItem&>(pSet->Get( ATTR_PAGE_HEADERSET ) ) );
+    pHFSetItem = new SvxSetItem( pSet->Get( ATTR_PAGE_HEADERSET ) );
     pHFSet = &(pHFSetItem->GetItemSet());
 
     pHFSet->Put( SvxBrushItem( aColGrey, ATTR_BACKGROUND ) );
