@@ -17,12 +17,12 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "excrecds.hxx"
+#include <excrecds.hxx>
 
 #include <map>
 #include <filter/msfilter/countryid.hxx>
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/eeitem.hxx>
 
 #include <sfx2/objsh.hxx>
@@ -51,34 +51,35 @@
 
 #include <string.h>
 
-#include "global.hxx"
-#include "globstr.hrc"
-#include "docpool.hxx"
-#include "patattr.hxx"
-#include "formulacell.hxx"
-#include "document.hxx"
-#include "scextopt.hxx"
-#include "attrib.hxx"
-#include "progress.hxx"
-#include "dociter.hxx"
-#include "rangenam.hxx"
-#include "dbdata.hxx"
-#include "stlsheet.hxx"
-#include "stlpool.hxx"
-#include "editutil.hxx"
+#include <global.hxx>
+#include <globstr.hrc>
+#include <docpool.hxx>
+#include <patattr.hxx>
+#include <formulacell.hxx>
+#include <document.hxx>
+#include <scextopt.hxx>
+#include <attrib.hxx>
+#include <progress.hxx>
+#include <dociter.hxx>
+#include <rangenam.hxx>
+#include <dbdata.hxx>
+#include <stlsheet.hxx>
+#include <stlpool.hxx>
+#include <editutil.hxx>
 #include <formula/errorcodes.hxx>
-#include "queryentry.hxx"
-#include "queryparam.hxx"
+#include <oox/export/utils.hxx>
+#include <queryentry.hxx>
+#include <queryparam.hxx>
 
-#include "excdoc.hxx"
-#include "xeescher.hxx"
-#include "xeformula.hxx"
-#include "xelink.hxx"
-#include "xename.hxx"
-#include "xecontent.hxx"
+#include <excdoc.hxx>
+#include <xeescher.hxx>
+#include <xeformula.hxx>
+#include <xelink.hxx>
+#include <xename.hxx>
+#include <xecontent.hxx>
 
-#include "xcl97rec.hxx"
-#include "tabprotection.hxx"
+#include <xcl97rec.hxx>
+#include <tabprotection.hxx>
 
 using namespace ::oox;
 
@@ -283,11 +284,11 @@ const sal_uInt8* ExcDummy_041::GetData() const
 
 //------------------------------------------------------------- class Exc1904 -
 
-Exc1904::Exc1904( ScDocument& rDoc )
+Exc1904::Exc1904( const ScDocument& rDoc )
 {
-    Date* pDate = rDoc.GetFormatTable()->GetNullDate();
-    bVal = pDate && (*pDate == Date( 1, 1, 1904 ));
-    bDateCompatibility = pDate && !( *pDate == Date( 30, 12, 1899 ));
+    const Date& rDate = rDoc.GetFormatTable()->GetNullDate();
+    bVal = (rDate == Date( 1, 1, 1904 ));
+    bDateCompatibility = !(rDate == Date( 30, 12, 1899 ));
 }
 
 sal_uInt16 Exc1904::GetNum() const
@@ -302,21 +303,21 @@ void Exc1904::SaveXml( XclExpXmlStream& rStrm )
     if( bISOIEC )
     {
         rStrm.WriteAttributes(
-            XML_dateCompatibility, XclXmlUtils::ToPsz( bDateCompatibility ),
+            XML_dateCompatibility, ToPsz( bDateCompatibility ),
             FSEND );
     }
 
     if( !bISOIEC || bDateCompatibility )
     {
         rStrm.WriteAttributes(
-            XML_date1904, XclXmlUtils::ToPsz( bVal ),
+            XML_date1904, ToPsz( bVal ),
             FSEND );
     }
 }
 
 //------------------------------------------------------ class ExcBundlesheet -
 
-ExcBundlesheetBase::ExcBundlesheetBase( RootData& rRootData, SCTAB nTabNum ) :
+ExcBundlesheetBase::ExcBundlesheetBase( const RootData& rRootData, SCTAB nTabNum ) :
     m_nStrPos( STREAM_SEEK_TO_END ),
     m_nOwnPos( STREAM_SEEK_TO_END ),
     nGrbit( rRootData.pER->GetTabInfo().IsVisibleTab( nTabNum ) ? 0x0000 : 0x0001 ),
@@ -345,7 +346,7 @@ sal_uInt16 ExcBundlesheetBase::GetNum() const
     return 0x0085;
 }
 
-ExcBundlesheet::ExcBundlesheet( RootData& rRootData, SCTAB _nTab ) :
+ExcBundlesheet::ExcBundlesheet( const RootData& rRootData, SCTAB _nTab ) :
     ExcBundlesheetBase( rRootData, _nTab )
 {
     OUString sTabName = rRootData.pER->GetTabInfo().GetScTabName( _nTab );
@@ -416,7 +417,7 @@ void XclExpXmlSheetPr::SaveXml( XclExpXmlStream& rStrm )
             // OOXTODO: XML_transitionEntry,
             // OOXTODO: XML_published,
             // OOXTODO: XML_codeName,
-            XML_filterMode, mpManager ? XclXmlUtils::ToPsz( mpManager->HasFilterMode( mnScTab ) ) : nullptr,
+            XML_filterMode, mpManager ? ToPsz( mpManager->HasFilterMode( mnScTab ) ) : nullptr,
             // OOXTODO: XML_enableFormatConditionsCalculation,
             FSEND );
 
@@ -430,7 +431,7 @@ void XclExpXmlSheetPr::SaveXml( XclExpXmlStream& rStrm )
 
     rWorksheet->singleElement(XML_pageSetUpPr,
             // OOXTODO: XML_autoPageBreaks,
-        XML_fitToPage,  XclXmlUtils::ToPsz(mbFitToPage), FSEND);
+        XML_fitToPage,  ToPsz(mbFitToPage), FSEND);
 
     rWorksheet->endElement( XML_sheetPr );
 }
@@ -445,7 +446,7 @@ XclExpWindowProtection::XclExpWindowProtection(bool bValue) :
 void XclExpWindowProtection::SaveXml( XclExpXmlStream& rStrm )
 {
     rStrm.WriteAttributes(
-            XML_lockWindows, XclXmlUtils::ToPsz( GetBool() ),
+            XML_lockWindows, ToPsz( GetBool() ),
             FSEND );
 }
 
@@ -479,23 +480,23 @@ void XclExpSheetProtection::SaveXml( XclExpXmlStream& rStrm )
         }
         sax_fastparser::FSHelperPtr& rWorksheet = rStrm.GetCurrentStream();
         rWorksheet->singleElement( XML_sheetProtection,
-            XML_sheet,  XclXmlUtils::ToPsz( true ),
+            XML_sheet,  ToPsz( true ),
             XML_password, sHash.isEmpty()? nullptr : sHash.getStr(),
-            XML_objects, pTabProtect->isOptionEnabled( ScTableProtection::OBJECTS ) ? nullptr : XclXmlUtils::ToPsz( true ),
-            XML_scenarios, pTabProtect->isOptionEnabled( ScTableProtection::SCENARIOS ) ? nullptr : XclXmlUtils::ToPsz( true ),
-            XML_formatCells, pTabProtect->isOptionEnabled( ScTableProtection::FORMAT_CELLS ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_formatColumns, pTabProtect->isOptionEnabled( ScTableProtection::FORMAT_COLUMNS ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_formatRows, pTabProtect->isOptionEnabled( ScTableProtection::FORMAT_ROWS ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_insertColumns, pTabProtect->isOptionEnabled( ScTableProtection::INSERT_COLUMNS ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_insertRows, pTabProtect->isOptionEnabled( ScTableProtection::INSERT_ROWS ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_insertHyperlinks, pTabProtect->isOptionEnabled( ScTableProtection::INSERT_HYPERLINKS ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_deleteColumns, pTabProtect->isOptionEnabled( ScTableProtection::DELETE_COLUMNS ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_deleteRows, pTabProtect->isOptionEnabled( ScTableProtection::DELETE_ROWS ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_selectLockedCells, pTabProtect->isOptionEnabled( ScTableProtection::SELECT_LOCKED_CELLS ) ? nullptr : XclXmlUtils::ToPsz( true ),
-            XML_sort, pTabProtect->isOptionEnabled( ScTableProtection::SORT ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_autoFilter, pTabProtect->isOptionEnabled( ScTableProtection::AUTOFILTER ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_pivotTables, pTabProtect->isOptionEnabled( ScTableProtection::PIVOT_TABLES ) ? XclXmlUtils::ToPsz( false ) : nullptr,
-            XML_selectUnlockedCells, pTabProtect->isOptionEnabled( ScTableProtection::SELECT_UNLOCKED_CELLS ) ? nullptr : XclXmlUtils::ToPsz( true ),
+            XML_objects, pTabProtect->isOptionEnabled( ScTableProtection::OBJECTS ) ? nullptr : ToPsz( true ),
+            XML_scenarios, pTabProtect->isOptionEnabled( ScTableProtection::SCENARIOS ) ? nullptr : ToPsz( true ),
+            XML_formatCells, pTabProtect->isOptionEnabled( ScTableProtection::FORMAT_CELLS ) ? ToPsz( false ) : nullptr,
+            XML_formatColumns, pTabProtect->isOptionEnabled( ScTableProtection::FORMAT_COLUMNS ) ? ToPsz( false ) : nullptr,
+            XML_formatRows, pTabProtect->isOptionEnabled( ScTableProtection::FORMAT_ROWS ) ? ToPsz( false ) : nullptr,
+            XML_insertColumns, pTabProtect->isOptionEnabled( ScTableProtection::INSERT_COLUMNS ) ? ToPsz( false ) : nullptr,
+            XML_insertRows, pTabProtect->isOptionEnabled( ScTableProtection::INSERT_ROWS ) ? ToPsz( false ) : nullptr,
+            XML_insertHyperlinks, pTabProtect->isOptionEnabled( ScTableProtection::INSERT_HYPERLINKS ) ? ToPsz( false ) : nullptr,
+            XML_deleteColumns, pTabProtect->isOptionEnabled( ScTableProtection::DELETE_COLUMNS ) ? ToPsz( false ) : nullptr,
+            XML_deleteRows, pTabProtect->isOptionEnabled( ScTableProtection::DELETE_ROWS ) ? ToPsz( false ) : nullptr,
+            XML_selectLockedCells, pTabProtect->isOptionEnabled( ScTableProtection::SELECT_LOCKED_CELLS ) ? nullptr : ToPsz( true ),
+            XML_sort, pTabProtect->isOptionEnabled( ScTableProtection::SORT ) ? ToPsz( false ) : nullptr,
+            XML_autoFilter, pTabProtect->isOptionEnabled( ScTableProtection::AUTOFILTER ) ? ToPsz( false ) : nullptr,
+            XML_pivotTables, pTabProtect->isOptionEnabled( ScTableProtection::PIVOT_TABLES ) ? ToPsz( false ) : nullptr,
+            XML_selectUnlockedCells, pTabProtect->isOptionEnabled( ScTableProtection::SELECT_UNLOCKED_CELLS ) ? nullptr : ToPsz( true ),
             FSEND );
 
         const ::std::vector<ScEnhancedProtection>& rProts( pTabProtect->getEnhancedProtection());
@@ -519,7 +520,7 @@ void XclExpSheetProtection::SaveXml( XclExpXmlStream& rStrm )
                         XML_hashValue, (*it).maHashValue.isEmpty() ? nullptr : XclXmlUtils::ToOString( (*it).maHashValue).getStr(),
                         XML_saltValue, (*it).maSaltValue.isEmpty() ? nullptr : XclXmlUtils::ToOString( (*it).maSaltValue).getStr(),
                         XML_spinCount, (*it).mnSpinCount ? OString::number( (*it).mnSpinCount).getStr() : nullptr,
-                        XML_sqref, (*it).maRangeList.Is() ? XclXmlUtils::ToOString( *(*it).maRangeList).getStr() : nullptr,
+                        XML_sqref, (*it).maRangeList.is() ? XclXmlUtils::ToOString( *(*it).maRangeList).getStr() : nullptr,
                         FSEND);
             }
             rWorksheet->endElement( XML_protectedRanges);
@@ -568,7 +569,6 @@ ExcFilterCondition::ExcFilterCondition() :
 
 ExcFilterCondition::~ExcFilterCondition()
 {
-    delete pText;
 }
 
 std::size_t ExcFilterCondition::GetTextBytes() const
@@ -576,14 +576,12 @@ std::size_t ExcFilterCondition::GetTextBytes() const
     return pText ? (1 + pText->GetBufferSize()) : 0;
 }
 
-void ExcFilterCondition::SetCondition( sal_uInt8 nTp, sal_uInt8 nOp, double fV, OUString* pT )
+void ExcFilterCondition::SetCondition( sal_uInt8 nTp, sal_uInt8 nOp, double fV, const OUString* pT )
 {
     nType = nTp;
     nOper = nOp;
     fVal = fV;
-
-    delete pText;
-    (pT) ? pText = new XclExpString( *pT, EXC_STR_8BITLENGTH ) : pText =  nullptr;
+    pText.reset( pT ? new XclExpString( *pT, XclStrFlags::EightBitLength ) : nullptr);
 }
 
 void ExcFilterCondition::Save( XclExpStream& rStrm )
@@ -621,7 +619,7 @@ static const char* lcl_GetOperator( sal_uInt8 nOper )
     }
 }
 
-static OString lcl_GetValue( sal_uInt8 nType, double fVal, XclExpString* pStr )
+static OString lcl_GetValue( sal_uInt8 nType, double fVal, const XclExpString* pStr )
 {
     switch( nType )
     {
@@ -639,7 +637,7 @@ void ExcFilterCondition::SaveXml( XclExpXmlStream& rStrm )
 
     rStrm.GetCurrentStream()->singleElement( XML_customFilter,
             XML_operator,   lcl_GetOperator( nOper ),
-            XML_val,        lcl_GetValue( nType, fVal, pText ).getStr(),
+            XML_val,        lcl_GetValue( nType, fVal, pText.get() ).getStr(),
             FSEND );
 }
 
@@ -663,7 +661,7 @@ XclExpAutofilter::XclExpAutofilter( const XclExpRoot& rRoot, sal_uInt16 nC ) :
 }
 
 bool XclExpAutofilter::AddCondition( ScQueryConnect eConn, sal_uInt8 nType, sal_uInt8 nOp,
-                                     double fVal, OUString* pText, bool bSimple )
+                                     double fVal, const OUString* pText, bool bSimple )
 {
     if( !aCond[ 1 ].IsEmpty() )
         return false;
@@ -739,7 +737,7 @@ bool XclExpAutofilter::AddEntry( const ScQueryEntry& rEntry )
         sal_uInt32  nIndex  = 0;
         bool bIsNum  = !bLen || GetFormatter().IsNumberFormat( sText, nIndex, fVal );
         OUString* pText;
-        (bIsNum) ? pText = nullptr : pText = &sText;
+        bIsNum ? pText = nullptr : pText = &sText;
 
         // top10 flags
         sal_uInt16 nNewFlags = 0x0000;
@@ -768,7 +766,7 @@ bool XclExpAutofilter::AddEntry( const ScQueryEntry& rEntry )
             {
                 if( fVal < 0 )      fVal = 0;
                 if( fVal >= 501 )   fVal = 500;
-                nFlags |= (nNewFlags | (sal_uInt16)(fVal) << 7);
+                nFlags |= (nNewFlags | (sal_uInt16)fVal << 7);
             }
             // normal condition
             else
@@ -841,15 +839,15 @@ void XclExpAutofilter::SaveXml( XclExpXmlStream& rStrm )
             if( HasTop10() )
             {
                 rWorksheet->singleElement( XML_top10,
-                        XML_top,        XclXmlUtils::ToPsz( get_flag( nFlags, EXC_AFFLAG_TOP10TOP ) ),
-                        XML_percent,    XclXmlUtils::ToPsz( get_flag( nFlags, EXC_AFFLAG_TOP10PERC ) ),
+                        XML_top,        ToPsz( get_flag( nFlags, EXC_AFFLAG_TOP10TOP ) ),
+                        XML_percent,    ToPsz( get_flag( nFlags, EXC_AFFLAG_TOP10PERC ) ),
                         XML_val,        OString::number(  (nFlags >> 7 ) ).getStr(),
                         // OOXTODO: XML_filterVal,
                         FSEND );
             }
 
             rWorksheet->startElement( XML_customFilters,
-                    XML_and,    XclXmlUtils::ToPsz( (nFlags & EXC_AFFLAG_ANDORMASK) == EXC_AFFLAG_AND ),
+                    XML_and,    ToPsz( (nFlags & EXC_AFFLAG_ANDORMASK) == EXC_AFFLAG_AND ),
                     FSEND );
             aCond[ 0 ].SaveXml( rStrm );
             aCond[ 1 ].SaveXml( rStrm );
@@ -877,9 +875,7 @@ void XclExpAutofilter::SaveXml( XclExpXmlStream& rStrm )
 
 ExcAutoFilterRecs::ExcAutoFilterRecs( const XclExpRoot& rRoot, SCTAB nTab, const ScDBData* pDefinedData ) :
     XclExpRoot( rRoot ),
-    pFilterMode( nullptr ),
-    pFilterInfo( nullptr )
-    , mbAutoFilter (false)
+    mbAutoFilter (false)
 {
     XclExpNameManager& rNameMgr = GetNameManager();
 
@@ -923,7 +919,7 @@ ExcAutoFilterRecs::ExcAutoFilterRecs( const XclExpRoot& rRoot, SCTAB nTab, const
                     rNameMgr.InsertBuiltInName( EXC_BUILTIN_EXTRACT, aDestRange );
             }
 
-            pFilterMode = new XclExpFiltermode;
+            m_pFilterMode.reset(new XclExpFiltermode);
         }
         // AutoFilter
         else
@@ -966,8 +962,8 @@ ExcAutoFilterRecs::ExcAutoFilterRecs( const XclExpRoot& rRoot, SCTAB nTab, const
                 maFilterList.RemoveAllRecords();
 
             if( !maFilterList.IsEmpty() )
-                pFilterMode = new XclExpFiltermode;
-            pFilterInfo = new XclExpAutofilterinfo( aRange.aStart, nColCnt );
+                m_pFilterMode.reset(new XclExpFiltermode);
+            m_pFilterInfo.reset(new XclExpAutofilterinfo( aRange.aStart, nColCnt ));
 
             if (maFilterList.IsEmpty () && !bConflict)
                 mbAutoFilter = true;
@@ -977,8 +973,6 @@ ExcAutoFilterRecs::ExcAutoFilterRecs( const XclExpRoot& rRoot, SCTAB nTab, const
 
 ExcAutoFilterRecs::~ExcAutoFilterRecs()
 {
-    delete pFilterMode;
-    delete pFilterInfo;
 }
 
 XclExpAutofilter* ExcAutoFilterRecs::GetByCol( SCCOL nCol )
@@ -1005,10 +999,10 @@ bool ExcAutoFilterRecs::IsFiltered( SCCOL nCol )
 
 void ExcAutoFilterRecs::AddObjRecs()
 {
-    if( pFilterInfo )
+    if( m_pFilterInfo )
     {
-        ScAddress aAddr( pFilterInfo->GetStartPos() );
-        for( SCCOL nObj = 0, nCount = pFilterInfo->GetColCount(); nObj < nCount; nObj++ )
+        ScAddress aAddr( m_pFilterInfo->GetStartPos() );
+        for( SCCOL nObj = 0, nCount = m_pFilterInfo->GetColCount(); nObj < nCount; nObj++ )
         {
             XclObj* pObjRec = new XclObjDropDown( GetObjectManager(), aAddr, IsFiltered( nObj ) );
             GetObjectManager().AddObj( pObjRec );
@@ -1019,10 +1013,10 @@ void ExcAutoFilterRecs::AddObjRecs()
 
 void ExcAutoFilterRecs::Save( XclExpStream& rStrm )
 {
-    if( pFilterMode )
-        pFilterMode->Save( rStrm );
-    if( pFilterInfo )
-        pFilterInfo->Save( rStrm );
+    if( m_pFilterMode )
+        m_pFilterMode->Save( rStrm );
+    if( m_pFilterInfo )
+        m_pFilterInfo->Save( rStrm );
     maFilterList.Save( rStrm );
 }
 
@@ -1043,7 +1037,7 @@ void ExcAutoFilterRecs::SaveXml( XclExpXmlStream& rStrm )
 
 bool ExcAutoFilterRecs::HasFilterMode() const
 {
-    return pFilterMode != nullptr;
+    return m_pFilterMode != nullptr;
 }
 
 XclExpFilterManager::XclExpFilterManager( const XclExpRoot& rRoot ) :
