@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "xeescher.hxx"
+#include <xeescher.hxx>
 
 #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <com/sun/star/frame/XModel.hpp>
@@ -26,18 +26,15 @@
 #include <com/sun/star/awt/ScrollBarOrientation.hpp>
 #include <com/sun/star/drawing/XShape.hpp>
 #include <com/sun/star/form/binding/XBindableValue.hpp>
-#include <com/sun/star/form/binding/XValueBinding.hpp>
 #include <com/sun/star/form/binding/XListEntrySink.hpp>
-#include <com/sun/star/form/binding/XListEntrySource.hpp>
 #include <com/sun/star/script/ScriptEventDescriptor.hpp>
 #include <com/sun/star/chart2/XChartDocument.hpp>
 #include <com/sun/star/awt/Point.hpp>
 #include <com/sun/star/awt/Size.hpp>
-#include <com/sun/star/container/XNamed.hpp>
 
 #include <set>
 #include <rtl/ustrbuf.h>
-#include <vcl/bmpacc.hxx>
+#include <vcl/bitmapaccess.hxx>
 #include <svx/svdoole2.hxx>
 #include <svx/svdocapt.hxx>
 #include <editeng/outlobj.hxx>
@@ -46,37 +43,40 @@
 #include <unotools/ucbstreamhelper.hxx>
 #include <svtools/embedhlp.hxx>
 
-#include "editutil.hxx"
-#include "unonames.hxx"
-#include "convuno.hxx"
-#include "postit.hxx"
+#include <editutil.hxx>
+#include <unonames.hxx>
+#include <convuno.hxx>
+#include <postit.hxx>
 
-#include "fapihelper.hxx"
-#include "xechart.hxx"
-#include "xeformula.hxx"
-#include "xelink.hxx"
-#include "xename.hxx"
-#include "xestyle.hxx"
-#include "userdat.hxx"
-#include "drwlayer.hxx"
+#include <fapihelper.hxx>
+#include <xechart.hxx>
+#include <xeformula.hxx>
+#include <xelink.hxx>
+#include <xename.hxx>
+#include <xestyle.hxx>
+#include <userdat.hxx>
+#include <drwlayer.hxx>
+#include <svl/itemset.hxx>
 #include <svx/unoapi.hxx>
 #include <svx/algitem.hxx>
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/justifyitem.hxx>
 #include <svx/sdtaitm.hxx>
-#include "attrib.hxx"
-#include "document.hxx"
+#include <attrib.hxx>
+#include <document.hxx>
 #include <svx/svdattr.hxx>
 #include <svx/sdr/properties/properties.hxx>
-#include "detfunc.hxx"
+#include <detfunc.hxx>
 #include <svx/xflclit.hxx>
 #include <svx/xlnstwit.hxx>
 #include <svx/xlnstit.hxx>
 
 #include <oox/token/tokens.hxx>
+#include <oox/token/relationship.hxx>
 #include <oox/export/drawingml.hxx>
 #include <oox/export/chartexport.hxx>
 #include <oox/export/utils.hxx>
+#include <oox/token/namespaces.hxx>
 #include <memory>
 
 using namespace com::sun::star;
@@ -88,27 +88,26 @@ using ::com::sun::star::beans::XPropertySet;
 using ::com::sun::star::drawing::XShape;
 using ::com::sun::star::drawing::XShapes;
 using ::com::sun::star::frame::XModel;
-using ::com::sun::star::embed::XEmbeddedObject;
 using ::com::sun::star::awt::XControlModel;
 using ::com::sun::star::form::binding::XBindableValue;
-using ::com::sun::star::form::binding::XValueBinding;
 using ::com::sun::star::form::binding::XListEntrySink;
-using ::com::sun::star::form::binding::XListEntrySource;
 using ::com::sun::star::script::ScriptEventDescriptor;
 using ::com::sun::star::table::CellAddress;
 using ::com::sun::star::table::CellRangeAddress;
 using ::com::sun::star::chart2::XChartDocument;
-using ::com::sun::star::container::XNamed;
 using ::oox::drawingml::DrawingML;
 using ::oox::drawingml::ChartExport;
 using namespace oox;
 
-#define  HMM2XL(x)        ((x)/26.5)+0.5
+namespace
+{
 
-#if 1//def XLSX_OOXML_FUTURE
-// these function are only used within that context
-// Static Function Helpers
-static const char *ToHorizAlign( SdrTextHorzAdjust eAdjust )
+inline long lcl_hmm2px(long nPixel)
+{
+    return static_cast<long>(nPixel*PIXEL_PER_INCH/1000.0/CM_PER_INCH)+0.5;
+}
+
+const char *ToHorizAlign( SdrTextHorzAdjust eAdjust )
 {
     switch( eAdjust )
     {
@@ -124,7 +123,7 @@ static const char *ToHorizAlign( SdrTextHorzAdjust eAdjust )
     }
 }
 
-static const char *ToVertAlign( SdrTextVertAdjust eAdjust )
+const char *ToVertAlign( SdrTextVertAdjust eAdjust )
 {
     switch( eAdjust )
     {
@@ -140,7 +139,7 @@ static const char *ToVertAlign( SdrTextVertAdjust eAdjust )
     }
 }
 
-static void lcl_WriteAnchorVertex( sax_fastparser::FSHelperPtr rComments, Rectangle &aRect )
+void lcl_WriteAnchorVertex( sax_fastparser::FSHelperPtr const & rComments, tools::Rectangle &aRect )
 {
     rComments->startElement( FSNS( XML_xdr, XML_col ), FSEND );
     rComments->writeEscaped( OUString::number( aRect.Left() ) );
@@ -155,9 +154,8 @@ static void lcl_WriteAnchorVertex( sax_fastparser::FSHelperPtr rComments, Rectan
     rComments->writeEscaped( OUString::number( aRect.Bottom() ) );
     rComments->endElement( FSNS( XML_xdr, XML_rowOff ) );
 }
-#endif
 
-static void lcl_GetFromTo( const XclExpRoot& rRoot, const Rectangle &aRect, sal_Int32 nTab, Rectangle &aFrom, Rectangle &aTo )
+void lcl_GetFromTo( const XclExpRoot& rRoot, const tools::Rectangle &aRect, sal_Int32 nTab, tools::Rectangle &aFrom, tools::Rectangle &aTo )
 {
     sal_Int32 nCol = 0, nRow = 0;
     sal_Int32 nColOff = 0, nRowOff= 0;
@@ -167,7 +165,7 @@ static void lcl_GetFromTo( const XclExpRoot& rRoot, const Rectangle &aRect, sal_
     {
         while(true)
         {
-            Rectangle r = rRoot.GetDocRef().GetMMRect( nCol,nRow,nCol,nRow,nTab );
+            tools::Rectangle r = rRoot.GetDocRef().GetMMRect( nCol,nRow,nCol,nRow,nTab );
             if( r.Left() <= aRect.Left() )
             {
                 nCol++;
@@ -180,8 +178,8 @@ static void lcl_GetFromTo( const XclExpRoot& rRoot, const Rectangle &aRect, sal_
             }
             if( r.Left() > aRect.Left() && r.Top() > aRect.Top() )
             {
-                aFrom = Rectangle( nCol-1, static_cast<long>(HMM2XL( nColOff )),
-                                   nRow-1, static_cast<long>(HMM2XL( nRowOff )) );
+                aFrom = tools::Rectangle( nCol-1, lcl_hmm2px( nColOff ),
+                                   nRow-1, lcl_hmm2px( nRowOff ) );
                 break;
             }
         }
@@ -190,7 +188,7 @@ static void lcl_GetFromTo( const XclExpRoot& rRoot, const Rectangle &aRect, sal_
     {
         while(true)
         {
-            Rectangle r = rRoot.GetDocRef().GetMMRect( nCol,nRow,nCol,nRow,nTab );
+            tools::Rectangle r = rRoot.GetDocRef().GetMMRect( nCol,nRow,nCol,nRow,nTab );
             if( r.Left() >= aRect.Left() )
             {
                 nCol++;
@@ -203,8 +201,8 @@ static void lcl_GetFromTo( const XclExpRoot& rRoot, const Rectangle &aRect, sal_
             }
             if( r.Left() < aRect.Left() && r.Top() > aRect.Top() )
             {
-                aFrom = Rectangle( nCol-1, static_cast<long>(HMM2XL( nColOff )),
-                                   nRow-1, static_cast<long>(HMM2XL( nRowOff )) );
+                aFrom = tools::Rectangle( nCol-1, lcl_hmm2px( nColOff ),
+                                   nRow-1, lcl_hmm2px( nRowOff ) );
                 break;
             }
         }
@@ -213,15 +211,15 @@ static void lcl_GetFromTo( const XclExpRoot& rRoot, const Rectangle &aRect, sal_
     {
         while(true)
         {
-            Rectangle r = rRoot.GetDocRef().GetMMRect( nCol,nRow,nCol,nRow,nTab );
+            tools::Rectangle r = rRoot.GetDocRef().GetMMRect( nCol,nRow,nCol,nRow,nTab );
             if( r.Right() < aRect.Right() )
                 nCol++;
             if( r.Bottom() < aRect.Bottom() )
                 nRow++;
             if( r.Right() >= aRect.Right() && r.Bottom() >= aRect.Bottom() )
             {
-                aTo = Rectangle( nCol, static_cast<long>(HMM2XL( aRect.Right() - r.Left() )),
-                                 nRow, static_cast<long>(HMM2XL( aRect.Bottom() - r.Top() )));
+                aTo = tools::Rectangle( nCol, lcl_hmm2px( aRect.Right() - r.Left() ),
+                                 nRow, lcl_hmm2px( aRect.Bottom() - r.Top() ));
                 break;
             }
         }
@@ -230,21 +228,23 @@ static void lcl_GetFromTo( const XclExpRoot& rRoot, const Rectangle &aRect, sal_
     {
         while(true)
         {
-            Rectangle r = rRoot.GetDocRef().GetMMRect( nCol,nRow,nCol,nRow,nTab );
+            tools::Rectangle r = rRoot.GetDocRef().GetMMRect( nCol,nRow,nCol,nRow,nTab );
             if( r.Right() >= aRect.Right() )
                 nCol++;
             if( r.Bottom() < aRect.Bottom() )
                 nRow++;
             if( r.Right() < aRect.Right() && r.Bottom() >= aRect.Bottom() )
             {
-                aTo = Rectangle( nCol, static_cast<long>(HMM2XL( r.Left() - aRect.Right() )),
-                                 nRow, static_cast<long>(HMM2XL( aRect.Bottom() - r.Top() )));
+                aTo = tools::Rectangle( nCol, lcl_hmm2px( r.Left() - aRect.Right() ),
+                                 nRow, lcl_hmm2px( aRect.Bottom() - r.Top() ));
                 break;
             }
         }
     }
 }
 
+} // namespace
+
 // Escher client anchor =======================================================
 
 XclExpDffAnchorBase::XclExpDffAnchorBase( const XclExpRoot& rRoot, sal_uInt16 nFlags ) :
@@ -261,7 +261,7 @@ void XclExpDffAnchorBase::SetFlags( const SdrObject& rSdrObj )
 void XclExpDffAnchorBase::SetSdrObject( const SdrObject& rSdrObj )
 {
     ImplSetFlags( rSdrObj );
-    ImplCalcAnchorRect( rSdrObj.GetCurrentBoundRect(), MAP_100TH_MM );
+    ImplCalcAnchorRect( rSdrObj.GetCurrentBoundRect(), MapUnit::Map100thMM );
 }
 
 void XclExpDffAnchorBase::WriteDffData( EscherEx& rEscherEx ) const
@@ -271,10 +271,10 @@ void XclExpDffAnchorBase::WriteDffData( EscherEx& rEscherEx ) const
     WriteXclObjAnchor( rEscherEx.GetStream(), maAnchor );
 }
 
-void XclExpDffAnchorBase::WriteData( EscherEx& rEscherEx, const Rectangle& rRect )
+void XclExpDffAnchorBase::WriteData( EscherEx& rEscherEx, const tools::Rectangle& rRect )
 {
     // the passed rectangle is in twips
-    ImplCalcAnchorRect( rRect, MAP_TWIP );
+    ImplCalcAnchorRect( rRect, MapUnit::MapTwip );
     WriteDffData( rEscherEx );
 }
 
@@ -283,7 +283,7 @@ void XclExpDffAnchorBase::ImplSetFlags( const SdrObject& )
     OSL_FAIL( "XclExpDffAnchorBase::ImplSetFlags - not implemented" );
 }
 
-void XclExpDffAnchorBase::ImplCalcAnchorRect( const Rectangle&, MapUnit )
+void XclExpDffAnchorBase::ImplCalcAnchorRect( const tools::Rectangle&, MapUnit )
 {
     OSL_FAIL( "XclExpDffAnchorBase::ImplCalcAnchorRect - not implemented" );
 }
@@ -303,7 +303,7 @@ void XclExpDffSheetAnchor::ImplSetFlags( const SdrObject& rSdrObj )
         mnFlags = EXC_ESC_ANCHOR_LOCKED;
 }
 
-void XclExpDffSheetAnchor::ImplCalcAnchorRect( const Rectangle& rRect, MapUnit eMapUnit )
+void XclExpDffSheetAnchor::ImplCalcAnchorRect( const tools::Rectangle& rRect, MapUnit eMapUnit )
 {
     maAnchor.SetRect( GetRoot(), mnScTab, rRect, eMapUnit );
 }
@@ -322,15 +322,15 @@ void XclExpDffEmbeddedAnchor::ImplSetFlags( const SdrObject& /*rSdrObj*/ )
     // TODO (unsupported feature): fixed size
 }
 
-void XclExpDffEmbeddedAnchor::ImplCalcAnchorRect( const Rectangle& rRect, MapUnit eMapUnit )
+void XclExpDffEmbeddedAnchor::ImplCalcAnchorRect( const tools::Rectangle& rRect, MapUnit eMapUnit )
 {
-    maAnchor.SetRect( maPageSize, mnScaleX, mnScaleY, rRect, eMapUnit, true );
+    maAnchor.SetRect( maPageSize, mnScaleX, mnScaleY, rRect, eMapUnit );
 }
 
-XclExpDffNoteAnchor::XclExpDffNoteAnchor( const XclExpRoot& rRoot, const Rectangle& rRect ) :
+XclExpDffNoteAnchor::XclExpDffNoteAnchor( const XclExpRoot& rRoot, const tools::Rectangle& rRect ) :
     XclExpDffAnchorBase( rRoot, EXC_ESC_ANCHOR_SIZELOCKED )
 {
-    maAnchor.SetRect( rRoot, rRoot.GetCurrScTab(), rRect, MAP_100TH_MM );
+    maAnchor.SetRect( rRoot, rRoot.GetCurrScTab(), rRect, MapUnit::Map100thMM );
 }
 
 XclExpDffDropDownAnchor::XclExpDffDropDownAnchor( const XclExpRoot& rRoot, const ScAddress& rScPos ) :
@@ -373,7 +373,7 @@ XclExpMsoDrawingGroup::XclExpMsoDrawingGroup( XclEscherEx& rEscherEx ) :
         0x00, 0x08
     };
     mrEscherEx.AddAtom( sizeof( spnDffOpt ), ESCHER_OPT, 3, 3 );
-    rDffStrm.Write( spnDffOpt, sizeof( spnDffOpt ) );
+    rDffStrm.WriteBytes(spnDffOpt, sizeof(spnDffOpt));
 
     // SPLITMENUCOLORS contains colors in toolbar
     static const sal_uInt8 spnDffSplitMenuColors[] = {
@@ -381,7 +381,7 @@ XclExpMsoDrawingGroup::XclExpMsoDrawingGroup( XclEscherEx& rEscherEx ) :
         0x17, 0x00, 0x00, 0x08, 0xF7, 0x00, 0x00, 0x10
     };
     mrEscherEx.AddAtom( sizeof( spnDffSplitMenuColors ), ESCHER_SplitMenuColors, 0, 4 );
-    rDffStrm.Write( spnDffSplitMenuColors, sizeof( spnDffSplitMenuColors ) );
+    rDffStrm.WriteBytes(spnDffSplitMenuColors, sizeof(spnDffSplitMenuColors));
 
     // close the DGGCONTAINER
     mrEscherEx.CloseContainer();
@@ -403,9 +403,10 @@ void XclExpImgData::Save( XclExpStream& rStrm )
 {
     Bitmap aBmp = maGraphic.GetBitmap();
     if( aBmp.GetBitCount() != 24 )
-        aBmp.Convert( BMP_CONVERSION_24BIT );
+        aBmp.Convert( BmpConversion::N24Bit );
 
-    if( BitmapReadAccess* pAccess = aBmp.AcquireReadAccess() )
+    Bitmap::ScopedReadAccess pAccess(aBmp);
+    if( pAccess )
     {
         sal_Int32 nWidth = ::std::min< sal_Int32 >( pAccess->Width(), 0xFFFF );
         sal_Int32 nHeight = ::std::min< sal_Int32 >( pAccess->Height(), 0xFFFF );
@@ -437,7 +438,6 @@ void XclExpImgData::Save( XclExpStream& rStrm )
 
             rStrm.EndRecord();
         }
-        Bitmap::ReleaseAccess( pAccess );
     }
 }
 
@@ -462,7 +462,7 @@ XclExpControlHelper::~XclExpControlHelper()
 {
 }
 
-void XclExpControlHelper::ConvertSheetLinks( Reference< XShape > xShape )
+void XclExpControlHelper::ConvertSheetLinks( Reference< XShape > const & xShape )
 {
     mxCellLink.reset();
     mxSrcRange.reset();
@@ -534,8 +534,8 @@ void XclExpControlHelper::WriteFormulaSubRec( XclExpStream& rStrm, sal_uInt16 nS
 //delete for exporting OCX
 //#if EXC_EXP_OCX_CTRL
 
-XclExpOcxControlObj::XclExpOcxControlObj( XclExpObjectManager& rObjMgr, Reference< XShape > xShape,
-        const Rectangle* pChildAnchor, const OUString& rClassName, sal_uInt32 nStrmStart, sal_uInt32 nStrmSize ) :
+XclExpOcxControlObj::XclExpOcxControlObj( XclExpObjectManager& rObjMgr, Reference< XShape > const & xShape,
+        const tools::Rectangle* pChildAnchor, const OUString& rClassName, sal_uInt32 nStrmStart, sal_uInt32 nStrmSize ) :
     XclObj( rObjMgr, EXC_OBJTYPE_PICTURE, true ),
     XclExpControlHelper( rObjMgr.GetRoot() ),
     maClassName( rClassName ),
@@ -552,8 +552,9 @@ XclExpOcxControlObj::XclExpOcxControlObj( XclExpObjectManager& rObjMgr, Referenc
 
     // fill DFF property set
     mrEscherEx.OpenContainer( ESCHER_SpContainer );
-    mrEscherEx.AddShape( ESCHER_ShpInst_HostControl, SHAPEFLAG_HAVESPT | SHAPEFLAG_HAVEANCHOR | SHAPEFLAG_OLESHAPE );
-    Rectangle aDummyRect;
+    mrEscherEx.AddShape( ESCHER_ShpInst_HostControl,
+                         ShapeFlag::HaveShapeProperty | ShapeFlag::HaveAnchor | ShapeFlag::OLEShape );
+    tools::Rectangle aDummyRect;
     EscherPropertyContainer aPropOpt( mrEscherEx.GetGraphicProvider(), mrEscherEx.QueryPictureStream(), aDummyRect );
     aPropOpt.AddOpt( ESCHER_Prop_FitTextToShape,    0x00080008 );   // bool field
     aPropOpt.AddOpt( ESCHER_Prop_lineColor,         0x08000040 );
@@ -578,7 +579,7 @@ XclExpOcxControlObj::XclExpOcxControlObj( XclExpObjectManager& rObjMgr, Referenc
     aPropOpt.Commit( mrEscherEx.GetStream() );
 
     // anchor
-    ImplWriteAnchor( GetRoot(), SdrObject::getSdrObjectFromXShape( xShape ), pChildAnchor );
+    ImplWriteAnchor( SdrObject::getSdrObjectFromXShape( xShape ), pChildAnchor );
 
     mrEscherEx.AddAtom( 0, ESCHER_ClientData );                       // OBJ record
     mrEscherEx.CloseContainer();  // ESCHER_SpContainer
@@ -615,7 +616,7 @@ void XclExpOcxControlObj::WriteSubRecs( XclExpStream& rStrm )
     sal_uInt16 nPictFmlaSize = nFirstPartSize + nCellLinkSize + nSrcRangeSize + 18;
     rStrm.StartRecord( EXC_ID_OBJPICTFMLA, nPictFmlaSize );
 
-    rStrm   << sal_uInt16( nFirstPartSize )             // size of first part
+    rStrm   << nFirstPartSize                           // size of first part
             << sal_uInt16( 5 )                          // formula size
             << sal_uInt32( 0 )                          // unknown ID
             << sal_uInt8( 0x02 ) << sal_uInt32( 0 )     // tTbl token with unknown ID
@@ -639,7 +640,7 @@ void XclExpOcxControlObj::WriteSubRecs( XclExpStream& rStrm )
 
 //#else
 
-XclExpTbxControlObj::XclExpTbxControlObj( XclExpObjectManager& rRoot, Reference< XShape > xShape , const Rectangle* pChildAnchor ) :
+XclExpTbxControlObj::XclExpTbxControlObj( XclExpObjectManager& rRoot, Reference< XShape > const & xShape , const tools::Rectangle* pChildAnchor ) :
     XclObj( rRoot, EXC_OBJTYPE_UNKNOWN, true ),
     XclMacroHelper( rRoot ),
     meEventType( EXC_TBX_EVENT_ACTION ),
@@ -697,7 +698,7 @@ XclExpTbxControlObj::XclExpTbxControlObj( XclExpObjectManager& rRoot, Reference<
 
     // fill DFF property set
     mrEscherEx.OpenContainer( ESCHER_SpContainer );
-    mrEscherEx.AddShape( ESCHER_ShpInst_HostControl, SHAPEFLAG_HAVEANCHOR | SHAPEFLAG_HAVESPT );
+    mrEscherEx.AddShape( ESCHER_ShpInst_HostControl, ShapeFlag::HaveAnchor | ShapeFlag::HaveShapeProperty );
     EscherPropertyContainer aPropOpt;
     bool bVisible = aCtrlProp.GetBoolProperty( "EnableVisible" );
     aPropOpt.AddOpt( ESCHER_Prop_fPrint, bVisible ? 0x00080000 : 0x00080002 ); // visible flag
@@ -728,7 +729,7 @@ XclExpTbxControlObj::XclExpTbxControlObj( XclExpObjectManager& rRoot, Reference<
     aPropOpt.Commit( mrEscherEx.GetStream() );
 
     // anchor
-    ImplWriteAnchor( GetRoot(), SdrObject::getSdrObjectFromXShape( xShape ), pChildAnchor );
+    ImplWriteAnchor( SdrObject::getSdrObjectFromXShape( xShape ), pChildAnchor );
 
     mrEscherEx.AddAtom( 0, ESCHER_ClientData );                       // OBJ record
     mrEscherEx.UpdateDffFragmentEnd();
@@ -1068,13 +1069,13 @@ void XclExpTbxControlObj::WriteSbs( XclExpStream& rStrm )
 
 //#endif
 
-XclExpChartObj::XclExpChartObj( XclExpObjectManager& rObjMgr, Reference< XShape > xShape, const Rectangle* pChildAnchor ) :
+XclExpChartObj::XclExpChartObj( XclExpObjectManager& rObjMgr, Reference< XShape > const & xShape, const tools::Rectangle* pChildAnchor ) :
     XclObj( rObjMgr, EXC_OBJTYPE_CHART ),
     XclExpRoot( rObjMgr.GetRoot() ), mxShape( xShape )
 {
     // create the MSODRAWING record contents for the chart object
     mrEscherEx.OpenContainer( ESCHER_SpContainer );
-    mrEscherEx.AddShape( ESCHER_ShpInst_HostControl, SHAPEFLAG_HAVEANCHOR | SHAPEFLAG_HAVESPT );
+    mrEscherEx.AddShape( ESCHER_ShpInst_HostControl, ShapeFlag::HaveAnchor | ShapeFlag::HaveShapeProperty );
     EscherPropertyContainer aPropOpt;
     aPropOpt.AddOpt( ESCHER_Prop_LockAgainstGrouping, 0x01040104 );
     aPropOpt.AddOpt( ESCHER_Prop_FitTextToShape, 0x00080008 );
@@ -1089,7 +1090,7 @@ XclExpChartObj::XclExpChartObj( XclExpObjectManager& rObjMgr, Reference< XShape
 
     // anchor
     SdrObject* pSdrObj = SdrObject::getSdrObjectFromXShape( xShape );
-    ImplWriteAnchor( GetRoot(), pSdrObj, pChildAnchor );
+    ImplWriteAnchor( pSdrObj, pChildAnchor );
 
     // client data (the following OBJ record)
     mrEscherEx.AddAtom( 0, ESCHER_ClientData );
@@ -1107,7 +1108,7 @@ XclExpChartObj::XclExpChartObj( XclExpObjectManager& rObjMgr, Reference< XShape
     mxChartDoc.set( xModel,UNO_QUERY );
     css::awt::Rectangle aBoundRect;
     aShapeProp.GetProperty( aBoundRect, "BoundRect" );
-    Rectangle aChartRect( Point( aBoundRect.X, aBoundRect.Y ), Size( aBoundRect.Width, aBoundRect.Height ) );
+    tools::Rectangle aChartRect( Point( aBoundRect.X, aBoundRect.Y ), Size( aBoundRect.Width, aBoundRect.Height ) );
     mxChart.reset( new XclExpChart( GetRoot(), xModel, aChartRect ) );
 }
 
@@ -1125,7 +1126,6 @@ void XclExpChartObj::Save( XclExpStream& rStrm )
 
 void XclExpChartObj::SaveXml( XclExpXmlStream& rStrm )
 {
-    OSL_TRACE("XclExpChartObj::SaveXml -- Entry point to export chart");
     sax_fastparser::FSHelperPtr pDrawing = rStrm.GetCurrentStream();
 
     // FIXME: two cell? it seems the two cell anchor is incorrect.
@@ -1140,7 +1140,8 @@ void XclExpChartObj::SaveXml( XclExpXmlStream& rStrm )
         ChartExport aChartExport(XML_xdr, pDrawing, xModel, &rStrm, drawingml::DOCUMENT_XLSX);
         static sal_Int32 nChartCount = 0;
         nChartCount++;
-        aChartExport.WriteChartObj( mxShape, nChartCount );
+        sal_Int32 nID = rStrm.GetUniqueId();
+        aChartExport.WriteChartObj( mxShape, nID, nChartCount );
         // TODO: get the correcto chart number
     }
 
@@ -1156,12 +1157,19 @@ const css::uno::Reference<css::chart::XChartDocument>& XclExpChartObj::GetChartD
     return mxChartDoc;
 }
 
-XclExpNote::XclExpNote( const XclExpRoot& rRoot, const ScAddress& rScPos,
-        const ScPostIt* pScNote, const OUString& rAddText ) :
-    XclExpRecord( EXC_ID_NOTE ),
-    maScPos( rScPos ),
-    mnObjId( EXC_OBJ_INVALID_ID ),
-    mbVisible( pScNote && pScNote->IsCaptionShown() )
+XclExpNote::XclExpNote(const XclExpRoot& rRoot, const ScAddress& rScPos,
+        const ScPostIt* pScNote, const OUString& rAddText)
+    : XclExpRecord(EXC_ID_NOTE)
+    , maScPos(rScPos)
+    , mnObjId(EXC_OBJ_INVALID_ID)
+    , mbVisible(pScNote && pScNote->IsCaptionShown())
+    , meTHA(SDRTEXTHORZADJUST_LEFT)
+    , meTVA(SDRTEXTVERTADJUST_TOP)
+    , mbAutoScale(false)
+    , mbLocked(false)
+    , mbAutoFill(false)
+    , mbColHidden(false)
+    , mbRowHidden(false)
 {
     // get the main note text
     OUString aNoteText;
@@ -1187,6 +1195,7 @@ XclExpNote::XclExpNote( const XclExpRoot& rRoot, const ScAddress& rScPos,
         {
             // TODO: additional text
             if( pScNote )
+            {
                 if( SdrCaptionObj* pCaption = pScNote->GetOrCreateCaption( maScPos ) )
                 {
                     lcl_GetFromTo( rRoot, pCaption->GetLogicRect(), maScPos.Tab(), maCommentFrom, maCommentTo );
@@ -1196,16 +1205,23 @@ XclExpNote::XclExpNote( const XclExpRoot& rRoot, const ScAddress& rScPos,
                     SfxItemSet aItemSet = pCaption->GetMergedItemSet();
                     meTVA       = pCaption->GetTextVerticalAdjust();
                     meTHA       = pCaption->GetTextHorizontalAdjust();
-                    mbAutoScale = pCaption->GetFitToSize() != SDRTEXTFIT_NONE;
+                    mbAutoScale = pCaption->GetFitToSize() != drawing::TextFitToSizeType_NONE;
                     mbLocked    = pCaption->IsMoveProtect() || pCaption->IsResizeProtect();
 
                     // AutoFill style would change if Postit.cxx object creation values are changed
-                    OUString aCol(((XFillColorItem &)GETITEM(aItemSet, XFillColorItem , XATTR_FILLCOLOR)).GetValue());
-                    mbAutoFill  = aCol.isEmpty() && (GETITEMVALUE(aItemSet, XFillStyleItem, XATTR_FILLSTYLE, sal_uLong) == drawing::FillStyle_SOLID);
-                    mbAutoLine  = true;
+                    OUString aCol(aItemSet.Get(XATTR_FILLCOLOR).GetValue());
+                    mbAutoFill  = aCol.isEmpty() && (aItemSet.Get(XATTR_FILLSTYLE).GetValue() == drawing::FillStyle_SOLID);
                     mbRowHidden = (rRoot.GetDoc().RowHidden(maScPos.Row(),maScPos.Tab()));
                     mbColHidden = (rRoot.GetDoc().ColHidden(maScPos.Col(),maScPos.Tab()));
                 }
+                // stAuthor (variable): An XLUnicodeString that specifies the name of the comment
+                // author. String length MUST be greater than or equal to 1 and less than or equal
+                // to 54.
+                if( pScNote->GetAuthor().isEmpty() )
+                    maAuthor = XclExpString( " " );
+                else
+                    maAuthor = XclExpString( pScNote->GetAuthor(), XclStrFlags::NONE, 54 );
+            }
 
             SetRecSize( 9 + maAuthor.GetSize() );
         }
@@ -1303,11 +1319,11 @@ void XclExpNote::WriteXml( sal_Int32 nAuthorId, XclExpXmlStream& rStrm )
         rComments->startElement( FSNS( XML_mc, XML_AlternateContent ), FSEND );
         rComments->startElement( FSNS( XML_mc, XML_Choice ), XML_Requires, "v2", FSEND );
         rComments->startElement( XML_commentPr,
-                XML_autoFill,       XclXmlUtils::ToPsz( mbAutoFill ),
-                XML_autoScale,      XclXmlUtils::ToPsz( mbAutoScale ),
-                XML_colHidden,      XclXmlUtils::ToPsz( mbColHidden ),
-                XML_locked,         XclXmlUtils::ToPsz( mbLocked ),
-                XML_rowHidden,      XclXmlUtils::ToPsz( mbRowHidden ),
+                XML_autoFill,       ToPsz( mbAutoFill ),
+                XML_autoScale,      ToPsz( mbAutoScale ),
+                XML_colHidden,      ToPsz( mbColHidden ),
+                XML_locked,         ToPsz( mbLocked ),
+                XML_rowHidden,      ToPsz( mbRowHidden ),
                 XML_textHAlign,     ToHorizAlign( meTHA ),
                 XML_textVAlign,     ToVertAlign( meTVA ) ,
                 FSEND );
@@ -1352,7 +1368,7 @@ void XclMacroHelper::WriteMacroSubRec( XclExpStream& rStrm )
 bool
 XclMacroHelper::SetMacroLink( const ScriptEventDescriptor& rEvent, const XclTbxEventType& nEventType )
 {
-    OUString aMacroName = XclControlHelper::ExtractFromMacroDescriptor( rEvent, nEventType, GetDocShell() );
+    OUString aMacroName = XclControlHelper::ExtractFromMacroDescriptor( rEvent, nEventType );
     if( !aMacroName.isEmpty() )
     {
         return SetMacroLink( aMacroName );
@@ -1363,7 +1379,6 @@ XclMacroHelper::SetMacroLink( const ScriptEventDescriptor& rEvent, const XclTbxE
 bool
 XclMacroHelper::SetMacroLink( const OUString& rMacroName )
 {
-    OSL_TRACE("SetMacroLink( macroname:=%s )", OUStringToOString( rMacroName, RTL_TEXTENCODING_UTF8 ).getStr() );
     if( !rMacroName.isEmpty() )
     {
         sal_uInt16 nExtSheet = GetLocalLinkManager().FindExtSheet( EXC_EXTSH_OWNDOC );
@@ -1374,7 +1389,7 @@ XclMacroHelper::SetMacroLink( const OUString& rMacroName )
     return false;
 }
 
-XclExpShapeObj::XclExpShapeObj( XclExpObjectManager& rRoot, css::uno::Reference< css::drawing::XShape > xShape, ScDocument* pDoc ) :
+XclExpShapeObj::XclExpShapeObj( XclExpObjectManager& rRoot, css::uno::Reference< css::drawing::XShape > const & xShape, ScDocument* pDoc ) :
     XclObjAny( rRoot, xShape, pDoc ),
     XclMacroHelper( rRoot )
 {
@@ -1403,14 +1418,6 @@ XclExpComments::XclExpComments( SCTAB nTab, XclExpRecordList< XclExpNote >& rNot
 {
 }
 
-struct OUStringLess : public std::binary_function<OUString, OUString, bool>
-{
-    bool operator()(const OUString& x, const OUString& y) const
-    {
-        return x.compareTo( y ) < 0;
-    }
-};
-
 void XclExpComments::SaveXml( XclExpXmlStream& rStrm )
 {
     if( mrNotes.IsEmpty() )
@@ -1421,26 +1428,26 @@ void XclExpComments::SaveXml( XclExpXmlStream& rStrm )
             XclXmlUtils::GetStreamName( "../", "comments", mnTab + 1 ),
             rStrm.GetCurrentStream()->getOutputStream(),
             "application/vnd.openxmlformats-officedocument.spreadsheetml.comments+xml",
-            "http://schemas.openxmlformats.org/officeDocument/2006/relationships/comments" );
+            rtl::OUStringToOString(oox::getRelationship(Relationship::COMMENTS), RTL_TEXTENCODING_UTF8).getStr());
     rStrm.PushStream( rComments );
 
     if( rStrm.getVersion() == oox::core::ISOIEC_29500_2008 )
         rComments->startElement( XML_comments,
-            XML_xmlns, "http://schemas.openxmlformats.org/spreadsheetml/2006/main",
-            FSNS( XML_xmlns, XML_mc ), "http://schemas.openxmlformats.org/markup-compatibility/2006",
-            FSNS( XML_xmlns, XML_xdr ), "http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing",
-            FSNS( XML_xmlns, XML_v2 ), "http://schemas.openxmlformats.org/spreadsheetml/2006/main/v2",
+            XML_xmlns, XclXmlUtils::ToOString(rStrm.getNamespaceURL(OOX_NS(xls))).getStr(),
+            FSNS( XML_xmlns, XML_mc ), XclXmlUtils::ToOString(rStrm.getNamespaceURL(OOX_NS(mce))).getStr(),
+            FSNS( XML_xmlns, XML_xdr ), XclXmlUtils::ToOString(rStrm.getNamespaceURL(OOX_NS(dmlSpreadDr))).getStr(),
+            FSNS( XML_xmlns, XML_v2 ), XclXmlUtils::ToOString(rStrm.getNamespaceURL(OOX_NS(mceTest))).getStr(),
             FSNS( XML_mc, XML_Ignorable ), "v2",
             FSEND );
     else
         rComments->startElement( XML_comments,
-            XML_xmlns, "http://schemas.openxmlformats.org/spreadsheetml/2006/main",
-            FSNS( XML_xmlns, XML_xdr ), "http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing",
+            XML_xmlns, XclXmlUtils::ToOString(rStrm.getNamespaceURL(OOX_NS(xls))).getStr(),
+            FSNS( XML_xmlns, XML_xdr ), XclXmlUtils::ToOString(rStrm.getNamespaceURL(OOX_NS(dmlSpreadDr))).getStr(),
             FSEND );
 
     rComments->startElement( XML_authors, FSEND );
 
-    typedef std::set< OUString, OUStringLess > Authors;
+    typedef std::set<OUString> Authors;
     Authors aAuthors;
 
     size_t nNotes = mrNotes.GetSize();
@@ -1510,7 +1517,7 @@ void XclExpObjectManager::StartSheet()
     mxObjList.reset( new XclExpObjList( GetRoot(), *mxEscherEx ) );
 }
 
-std::shared_ptr< XclExpRecordBase > XclExpObjectManager::ProcessDrawing( SdrPage* pSdrPage )
+std::shared_ptr< XclExpRecordBase > XclExpObjectManager::ProcessDrawing( const SdrPage* pSdrPage )
 {
     if( pSdrPage )
         mxEscherEx->AddSdrPage( *pSdrPage );
@@ -1569,7 +1576,7 @@ void XclExpObjectManager::InitStream( bool bTempFile )
         if( mxTempFile->IsValid() )
         {
             mxTempFile->EnableKillingFile();
-            mxDffStrm.reset( ::utl::UcbStreamHelper::CreateStream( mxTempFile->GetURL(), STREAM_STD_READWRITE ) );
+            mxDffStrm.reset( ::utl::UcbStreamHelper::CreateStream( mxTempFile->GetURL(), StreamMode::STD_READWRITE ) );
         }
     }
 
