@@ -21,10 +21,10 @@
 #include <cassert>
 
 #include <osl/diagnose.h>
-#include "xlstyle.hxx"
-#include "xestyle.hxx"
-#include "xestream.hxx"
-#include "xestring.hxx"
+#include <xlstyle.hxx>
+#include <xestyle.hxx>
+#include <xestream.hxx>
+#include <xestring.hxx>
 
 using namespace ::oox;
 
@@ -58,17 +58,17 @@ int lclCompareVectors( const ::std::vector< Type >& rLeft, const ::std::vector<
 /** Base class for value hashers.
     @descr  These function objects are used to hash any value to a sal_uInt32 value. */
 template< typename Type >
-struct XclHasher : public ::std::unary_function< Type, sal_uInt32 > {};
+struct XclHasher {};
 
 template< typename Type >
 struct XclDirectHasher : public XclHasher< Type >
 {
-    inline sal_uInt32   operator()( Type nVal ) const { return nVal; }
+    sal_uInt32   operator()( Type nVal ) const { return nVal; }
 };
 
 struct XclFormatRunHasher : public XclHasher< const XclFormatRun& >
 {
-    inline sal_uInt32   operator()( const XclFormatRun& rRun ) const
+    sal_uInt32   operator()( const XclFormatRun& rRun ) const
                             { return (rRun.mnChar << 8) ^ rRun.mnFontIdx; }
 };
 
@@ -113,9 +113,9 @@ void XclExpString::Assign( const OUString& rString, XclStrFlags nFlags, sal_uInt
     Build( rString.getStr(), rString.getLength(), nFlags, nMaxLen );
 }
 
-void XclExpString::Assign( sal_Unicode cChar, XclStrFlags nFlags, sal_uInt16 nMaxLen )
+void XclExpString::Assign( sal_Unicode cChar )
 {
-    Build( &cChar, 1, nFlags, nMaxLen );
+    Build( &cChar, 1, XclStrFlags::NONE, EXC_STR_MAXLEN );
 }
 
 void XclExpString::AssignByte(
@@ -164,7 +164,7 @@ void XclExpString::AppendFormat( sal_uInt16 nChar, sal_uInt16 nFontIdx, bool bDr
     OSL_ENSURE( maFormats.empty() || (maFormats.back().mnChar < nChar), "XclExpString::AppendFormat - invalid char index" );
     size_t nMaxSize = static_cast< size_t >( mbIsBiff8 ? EXC_STR_MAXLEN : EXC_STR_MAXLEN_8BIT );
     if( maFormats.empty() || ((maFormats.size() < nMaxSize) && (!bDropDuplicate || (maFormats.back().mnFontIdx != nFontIdx))) )
-        maFormats.push_back( XclFormatRun( nChar, nFontIdx ) );
+        maFormats.emplace_back( nChar, nFontIdx );
 }
 
 void XclExpString::AppendTrailingFormat( sal_uInt16 nFontIdx )
@@ -240,12 +240,12 @@ sal_uInt16 XclExpString::GetHeaderSize() const
         (IsWriteFormats() ? 2 : 0);     // richtext formattting count
 }
 
-sal_Size XclExpString::GetBufferSize() const
+std::size_t XclExpString::GetBufferSize() const
 {
-    return static_cast<sal_Size>(mnLen) * (mbIsUnicode ? 2 : 1);
+    return static_cast<std::size_t>(mnLen) * (mbIsUnicode ? 2 : 1);
 }
 
-sal_Size XclExpString::GetSize() const
+std::size_t XclExpString::GetSize() const
 {
     return
         GetHeaderSize() +                                   // header
@@ -410,7 +410,7 @@ static sal_uInt16 lcl_WriteRun( XclExpXmlStream& rStrm, const ScfUInt16Vec& rBuf
         rWorksheet->endElement( XML_rPr );
     }
     rWorksheet->startElement( XML_t,
-            FSEND );
+                FSNS(XML_xml, XML_space), "preserve", FSEND );
     rWorksheet->writeEscaped( XclXmlUtils::ToOUString( rBuffer, nStart, nLength ) );
     rWorksheet->endElement( XML_t );
     rWorksheet->endElement( XML_r );
@@ -496,12 +496,12 @@ void XclExpString::CharsToBuffer( const sal_Char* pcSource, sal_Int32 nBegin, sa
 void XclExpString::Init( sal_Int32 nCurrLen, XclStrFlags nFlags, sal_uInt16 nMaxLen, bool bBiff8 )
 {
     mbIsBiff8 = bBiff8;
-    mbIsUnicode = bBiff8 && ::get_flag( nFlags, EXC_STR_FORCEUNICODE );
-    mb8BitLen = ::get_flag( nFlags, EXC_STR_8BITLENGTH );
-    mbSmartFlags = bBiff8 && ::get_flag( nFlags, EXC_STR_SMARTFLAGS );
-    mbSkipFormats = ::get_flag( nFlags, EXC_STR_SEPARATEFORMATS );
+    mbIsUnicode = bBiff8 && ( nFlags & XclStrFlags::ForceUnicode );
+    mb8BitLen = bool( nFlags & XclStrFlags::EightBitLength );
+    mbSmartFlags = bBiff8 && ( nFlags & XclStrFlags::SmartFlags );
+    mbSkipFormats = bool( nFlags & XclStrFlags::SeparateFormats );
     mbWrapped = false;
-    mbSkipHeader = ::get_flag( nFlags, EXC_STR_NOHEADER );
+    mbSkipHeader = bool( nFlags & XclStrFlags::NoHeader );
     mnMaxLen = nMaxLen;
     SetStrLen( nCurrLen );
 
