@@ -17,114 +17,92 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <svx/algitem.hxx>
 #include <editeng/justifyitem.hxx>
 #include <svl/zforlist.hxx>
-#include <tools/solar.h>
 
-#include "rangenam.hxx"
-#include "compiler.hxx"
+#include <rangenam.hxx>
+#include <compiler.hxx>
 
-#include "tool.h"
-#include "decl.h"
-#include "root.hxx"
-#include "lotrange.hxx"
-#include "namebuff.hxx"
-#include "ftools.hxx"
-#include "stringutil.hxx"
-#include "tokenarray.hxx"
+#include <tool.h>
+#include <decl.h>
+#include <root.hxx>
+#include <lotrange.hxx>
+#include <namebuff.hxx>
+#include <ftools.hxx>
+#include <stringutil.hxx>
+#include <tokenarray.hxx>
+#include "lotfilter.hxx"
 
 #include <math.h>
 
-//--------------------------------------------------------- EXTERNE VARIABLEN -
-extern WKTYP                eTyp;           // -> filter.cxx, aktueller Dateityp
-extern ScDocument*          pDoc;           // -> filter.cxx, Aufhaenger zum Dokumentzugriff
-
-//--------------------------------------------------------- GLOBALE VARIABLEN -
-sal_uInt8                       nDefaultFormat; // -> op.cpp, Standard-Zellenformat
-
-extern SvxHorJustifyItem    *pAttrRight, *pAttrLeft, *pAttrCenter, *pAttrRepeat, *pAttrStandard;
-extern ScProtectionAttr*    pAttrUnprot;
-extern SfxUInt32Item**      pAttrValForms;
-
-SvxHorJustifyItem           *pAttrRight, *pAttrLeft, *pAttrCenter, *pAttrRepeat, *pAttrStandard;
-                                                    // -> in memory.cxx initialisiert
-ScProtectionAttr*           pAttrUnprot;            // ->  " memory.cxx    "
-
-extern FormCache*           pValueFormCache;        // -> in memory.cxx initialisiert
-FormCache*                  pValueFormCache;
-
-SCCOL                       LotusRangeList::nEingCol;
-SCROW                       LotusRangeList::nEingRow;
-
-
-
-
-void PutFormString( SCCOL nCol, SCROW nRow, SCTAB nTab, sal_Char* pString )
+void PutFormString(LotusContext& rContext, SCCOL nCol, SCROW nRow, SCTAB nTab, sal_Char* pString)
 {
-    // Label-Format-Auswertung
-    OSL_ENSURE( pString != NULL, "PutFormString(): pString == NULL" );
+    // evaluate Label-Format
+    SAL_WARN_IF( pString == nullptr, "sc", "PutFormString(): pString == NULL" );
     if (!pString)
         return;
 
     sal_Char            cForm;
-    SvxHorJustifyItem*  pJustify = NULL;
+    SvxHorJustifyItem*  pJustify = nullptr;
 
     cForm = *pString;
 
     switch( cForm )
     {
-        case '"':   // rechtsbuendig
-            pJustify = pAttrRight;
+        case '"':   // align-right
+            pJustify = rContext.pAttrRight;
             pString++;
             break;
-        case '\'':  // linksbuendig
-            pJustify = pAttrLeft;
+        case '\'':  // align-left
+            pJustify = rContext.pAttrLeft;
             pString++;
             break;
-        case '^':   // zentriert
-            pJustify = pAttrCenter;
+        case '^':   // centered
+            pJustify = rContext.pAttrCenter;
             pString++;
             break;
         case '|':   // printer command
-            pString = NULL;
+            pString = nullptr;
             break;
-        case '\\':  // Wiederholung
-            pJustify = pAttrRepeat;
+        case '\\':  // repetition
+            pJustify = rContext.pAttrRepeat;
             pString++;
             break;
-        default:    // kenn' ich nicht!
-            pJustify = pAttrStandard;
+        default:    // undefined case!
+            pJustify = rContext.pAttrStandard;
     }
 
-    pDoc->ApplyAttr( nCol, nRow, nTab, *pJustify );
+    if (!pString)
+        return;
+
+    nCol = SanitizeCol(nCol);
+    nRow = SanitizeRow(nRow);
+    nTab = SanitizeTab(nTab);
+
+    rContext.pDoc->ApplyAttr( nCol, nRow, nTab, *pJustify );
     ScSetStringParam aParam;
     aParam.setTextInput();
-    pDoc->SetString(ScAddress(nCol,nRow,nTab), OUString(pString, strlen(pString), pLotusRoot->eCharsetQ), &aParam);
+    rContext.pDoc->SetString(ScAddress(nCol,nRow,nTab), OUString(pString, strlen(pString), rContext.pLotusRoot->eCharsetQ), &aParam);
 }
 
-
-
-
-void SetFormat( SCCOL nCol, SCROW nRow, SCTAB nTab, sal_uInt8 nFormat, sal_uInt8 nSt )
+void SetFormat(LotusContext& rContext, SCCOL nCol, SCROW nRow, SCTAB nTab, sal_uInt8 nFormat, sal_uInt8 nSt)
 {
-    //  PREC:   nSt = Standard-Dezimalstellenanzahl
-    pDoc->ApplyAttr( nCol, nRow, nTab, *( pValueFormCache->GetAttr( nFormat, nSt ) ) );
+    nCol = SanitizeCol(nCol);
+    nRow = SanitizeRow(nRow);
+    nTab = SanitizeTab(nTab);
+
+    //  PREC:   nSt = default number of decimal places
+    rContext.pDoc->ApplyAttr(nCol, nRow, nTab, *(rContext.pValueFormCache->GetAttr(nFormat, nSt)));
 
     ScProtectionAttr aAttr;
 
     aAttr.SetProtection( nFormat & 0x80 );
 
-    pDoc->ApplyAttr( nCol, nRow, nTab, aAttr );
+    rContext.pDoc->ApplyAttr( nCol, nRow, nTab, aAttr );
 }
 
-void InitPage( void )
-{   // Seitenformat initialisieren, d.h. Default-Werte von SC holen
-    //scGetPageFormat( 0, &aPage );
-}
-
-
 double SnumToDouble( sal_Int16 nVal )
 {
     const double pFacts[ 8 ] = {
@@ -164,198 +142,180 @@ double Snum32ToDouble( sal_uInt32 nValue )
         fValue *= pow((double)10, temp);
     }
 
-    if ((nValue & 0x00000020))
+    if (nValue & 0x00000020)
         fValue = -fValue;
     return fValue;
 }
 
-
-FormCache::FormCache( ScDocument* pDoc1, sal_uInt8 nNewDefaultFormat )
-{   // Default-Format ist 'Default'
-    nDefaultFormat = nNewDefaultFormat;
+FormCache::FormCache( const ScDocument* pDoc1 )
+    : nIndex(0)
+{
     pFormTable = pDoc1->GetFormatTable();
-    for( sal_uInt16 nC = 0 ; nC < __nSize ; nC++ )
-        bValid[ nC ] = false;
+    for(bool & rb : bValid)
+        rb = false;
     eLanguage = ScGlobal::eLnge;
 }
 
-
 FormCache::~FormCache()
 {
-    for( sal_uInt16 nC = 0 ; nC < __nSize ; nC++ )
-        delete aIdents[ nC ].GetAttr();
 }
 
-
 SfxUInt32Item* FormCache::NewAttr( sal_uInt8 nFormat, sal_uInt8 nSt )
 {
-    // neues Format erzeugen
+    // setup new Format
     sal_uInt8       nL, nH; // Low-/High-Nibble
-    sal_uInt8       nForm = nFormat;
-    OUString          aFormString;
-    sal_Int16       eType = NUMBERFORMAT_ALL;
+    OUString        aFormString;
+    sal_Int16       eType = css::util::NumberFormat::ALL;
     sal_uInt32      nIndex1;
     sal_uInt32      nHandle;
     NfIndexTableOffset eIndexTableOffset = NF_NUMERIC_START;
-    sal_Bool        bDefault = false;
+    bool            bDefault = false;
 
-    if( nForm == 0xFF ) // Default-Format?
-        nForm = nDefaultFormat;
-
-    // Aufdroeseln in Low- und High-Nibble
+    // split into Low and High byte
     nL = nFormat & 0x0F;
     nH = ( nFormat & 0xF0 ) / 16;
 
-    nH &= 0x07;     // Bits 4-6 'rausziehen
+    nH &= 0x07;     // extract bits 4-6
     switch( nH )
     {
-        case 0x00:  // Festkommaformat (fixed)
+        case 0x00:  // fixed-point number
             //fStandard;nL;
             nIndex1 = pFormTable->GetStandardFormat(
-                NUMBERFORMAT_NUMBER, eLanguage );
+                css::util::NumberFormat::NUMBER, eLanguage );
             aFormString = pFormTable->GenerateFormat(nIndex1,
-                eLanguage, false, false, nL, 1);
+                eLanguage, false, false, nL);
             break;
-        case 0x01:  // Exponentdarstellung (scientific notation)
+        case 0x01:  // scientific notation
             //fExponent;nL;
             nIndex1 = pFormTable->GetStandardFormat(
-                NUMBERFORMAT_SCIENTIFIC, eLanguage );
+                css::util::NumberFormat::SCIENTIFIC, eLanguage );
             aFormString = pFormTable->GenerateFormat(nIndex1,
-                eLanguage, false, false, nL, 1);
+                eLanguage, false, false, nL);
             break;
-        case 0x02:  // Waehrungsdarstellung (currency)
+        case 0x02:  // currency
             //fMoney;nL;
             nIndex1 = pFormTable->GetStandardFormat(
-                NUMBERFORMAT_CURRENCY, eLanguage );
+                css::util::NumberFormat::CURRENCY, eLanguage );
             aFormString = pFormTable->GenerateFormat(nIndex1,
-                eLanguage, false, false, nL, 1);
+                eLanguage, false, false, nL);
             break;
-        case 0x03:  // Prozent
+        case 0x03:  // percentage
             //fPercent;nL;
             nIndex1 = pFormTable->GetStandardFormat(
-                NUMBERFORMAT_PERCENT, eLanguage );
+                css::util::NumberFormat::PERCENT, eLanguage );
             aFormString = pFormTable->GenerateFormat(nIndex1,
-                eLanguage, false, false, nL, 1);
+                eLanguage, false, false, nL);
             break;
-        case 0x04:  // Komma
+        case 0x04:  // Decimal
             //fStandard;nL;
             nIndex1 = pFormTable->GetStandardFormat(
-                NUMBERFORMAT_NUMBER, eLanguage );
+                css::util::NumberFormat::NUMBER, eLanguage );
             aFormString = pFormTable->GenerateFormat(nIndex1,
-                eLanguage, sal_True, false, nL, 1);
+                eLanguage, true, false, nL);
             break;
-        case 0x05:  // frei
+        case 0x05:  // unspecified
             //fStandard;nL;
             nIndex1 = pFormTable->GetStandardFormat(
-                NUMBERFORMAT_NUMBER, eLanguage );
+                css::util::NumberFormat::NUMBER, eLanguage );
             aFormString = pFormTable->GenerateFormat(nIndex1,
-                eLanguage, false, false, nL, 1);
+                eLanguage, false, false, nL);
             break;
-        case 0x06:  // frei
+        case 0x06:  // unspecified
             //fStandard;nL;
             nIndex1 = pFormTable->GetStandardFormat(
-                NUMBERFORMAT_NUMBER, eLanguage );
+                css::util::NumberFormat::NUMBER, eLanguage );
             aFormString = pFormTable->GenerateFormat(nIndex1,
-                eLanguage, false, false, nL, 1);
-            nIndex1 = 0;
+                eLanguage, false, false, nL);
             break;
-        case 0x07:  // Spezialformat
+        case 0x07:  // Special format
             switch( nL )
             {
                 case 0x00:  // +/-
                     //fStandard;nSt;
                     nIndex1 = pFormTable->GetStandardFormat(
-                        NUMBERFORMAT_NUMBER, eLanguage );
+                        css::util::NumberFormat::NUMBER, eLanguage );
                     aFormString = pFormTable->GenerateFormat(nIndex1,
-                        eLanguage, false, sal_True, nSt, 1);
+                        eLanguage, false, true, nSt);
                     break;
-                case 0x01:  // generelles Format
+                case 0x01:  // general Format
                     //fStandard;nSt;
                     nIndex1 = pFormTable->GetStandardFormat(
-                        NUMBERFORMAT_NUMBER, eLanguage );
+                        css::util::NumberFormat::NUMBER, eLanguage );
                     aFormString = pFormTable->GenerateFormat(nIndex1,
-                        eLanguage, false, false, nSt, 1);
+                        eLanguage, false, false, nSt);
                     break;
-                case 0x02:  // Datum: Tag, Monat, Jahr
+                case 0x02:  // Date: Day, Month, Year
                     //fDate;dfDayMonthYearLong;
-                    eType = NUMBERFORMAT_DATE;
+                    eType = css::util::NumberFormat::DATE;
                     eIndexTableOffset = NF_DATE_SYS_DDMMYYYY;
                     break;
-                case 0x03:  // Datum: Tag, Monat
+                case 0x03:  // Date: Day, Month
                     //fDate;dfDayMonthLong;
-                    eType = NUMBERFORMAT_DATE;
+                    eType = css::util::NumberFormat::DATE;
                     aFormString = pFormTable->GetKeyword( eLanguage, NF_KEY_DD);
                     aFormString += pFormTable->GetDateSep();    // matches last eLanguage
                     aFormString += pFormTable->GetKeyword( eLanguage, NF_KEY_MMMM);
                     break;
-                case 0x04:  // Datum: Monat, Jahr
+                case 0x04:  // Date: Month, Year
                     //fDate;dfMonthYearLong;
-                    eType = NUMBERFORMAT_DATE;
+                    eType = css::util::NumberFormat::DATE;
                     aFormString = pFormTable->GetKeyword( eLanguage, NF_KEY_MM);
                     aFormString += pFormTable->GetDateSep();    // matches last eLanguage
                     aFormString += pFormTable->GetKeyword( eLanguage, NF_KEY_YYYY);
                     break;
-                case 0x05:  // Textformate
+                case 0x05:  // Text formats
                     //fString;nSt;
-                    eType = NUMBERFORMAT_TEXT;
+                    eType = css::util::NumberFormat::TEXT;
                     eIndexTableOffset = NF_TEXT;
                     break;
-                case 0x06:  // versteckt
+                case 0x06:  // hidden
                     //wFlag |= paHideAll;bSetFormat = sal_False;
-                    eType = NUMBERFORMAT_NUMBER;
+                    eType = css::util::NumberFormat::NUMBER;
                     aFormString = "\"\"";
                     break;
                 case 0x07:  // Time: hour, min, sec
                     //fTime;tfHourMinSec24;
-                    eType = NUMBERFORMAT_TIME;
+                    eType = css::util::NumberFormat::TIME;
                     eIndexTableOffset = NF_TIME_HHMMSS;
                     break;
                 case 0x08:  // Time: hour, min
                     //fTime;tfHourMin24;
-                    eType = NUMBERFORMAT_TIME;
+                    eType = css::util::NumberFormat::TIME;
                     eIndexTableOffset = NF_TIME_HHMM;
                     break;
                 case 0x09:  // Date, intern sal_Int32 1
                     //fDate;dfDayMonthYearLong;
-                    eType = NUMBERFORMAT_DATE;
+                    eType = css::util::NumberFormat::DATE;
                     eIndexTableOffset = NF_DATE_SYS_DDMMYYYY;
                     break;
                 case 0x0A:  // Date, intern sal_Int32 2
                     //fDate;dfDayMonthYearLong;
-                    eType = NUMBERFORMAT_DATE;
+                    eType = css::util::NumberFormat::DATE;
                     eIndexTableOffset = NF_DATE_SYS_DDMMYYYY;
                     break;
                 case 0x0B:  // Time, intern sal_Int32 1
                     //fTime;tfHourMinSec24;
-                    eType = NUMBERFORMAT_TIME;
+                    eType = css::util::NumberFormat::TIME;
                     eIndexTableOffset = NF_TIME_HHMMSS;
                     break;
                 case 0x0C:  // Time, intern sal_Int32 2
                     //fTime;tfHourMinSec24;
-                    eType = NUMBERFORMAT_TIME;
+                    eType = css::util::NumberFormat::TIME;
                     eIndexTableOffset = NF_TIME_HHMMSS;
                     break;
-                case 0x0F:  // Standardeinstellung
+                case 0x0F:  // Default
                     //fStandard;nSt;
-                    bDefault = sal_True;
+                    bDefault = true;
                     break;
                 default:
                     //fStandard;nSt;
-                    bDefault = sal_True;
+                    bDefault = true;
                     break;
             }
             break;
-        default:
-            //fStandard;nL;
-            nIndex1 = pFormTable->GetStandardFormat(
-                NUMBERFORMAT_NUMBER, eLanguage );
-            aFormString = pFormTable->GenerateFormat(nIndex1,
-                eLanguage, false, false, nL, 1);
-            nIndex1 = 0;
-            break;
     }
 
-    // Format in Table schieben
+    // push Format into table
     if( bDefault )
         nHandle = 0;
     else if (eIndexTableOffset != NF_NUMERIC_START)
@@ -366,13 +326,10 @@ SfxUInt32Item* FormCache::NewAttr( sal_uInt8 nFormat, sal_uInt8 nSt )
         pFormTable->PutEntry( aFormString, nDummy, eType, nHandle, eLanguage );
     }
 
-    return new SfxUInt32Item( ATTR_VALUE_FORMAT, ( sal_uInt32 ) nHandle );
+    return new SfxUInt32Item( ATTR_VALUE_FORMAT, nHandle );
 }
 
-
-
-
-void LotusRange::MakeHash( void )
+void LotusRange::MakeHash()
 {
     // 33222222222211111111110000000000
     // 10987654321098765432109876543210
@@ -386,7 +343,6 @@ void LotusRange::MakeHash( void )
     nHash += static_cast<sal_uInt32>(nRowEnd ) << 16;
 }
 
-
 LotusRange::LotusRange( SCCOL nCol, SCROW nRow )
 {
     nColStart = nColEnd = nCol;
@@ -395,7 +351,6 @@ LotusRange::LotusRange( SCCOL nCol, SCROW nRow )
     MakeHash();
 }
 
-
 LotusRange::LotusRange( SCCOL nCS, SCROW nRS, SCCOL nCE, SCROW nRE )
 {
     nColStart = nCS;
@@ -406,17 +361,13 @@ LotusRange::LotusRange( SCCOL nCS, SCROW nRS, SCCOL nCE, SCROW nRE )
     MakeHash();
 }
 
-
 LotusRange::LotusRange( const LotusRange& rCpy )
 {
     Copy( rCpy );
 }
 
-
-
-
-
-LotusRangeList::LotusRangeList( void )
+LotusRangeList::LotusRangeList(LOTUS_ROOT* pLotRoot)
+    : m_pLotRoot(pLotRoot)
 {
     aComplRef.InitFlags();
 
@@ -455,10 +406,9 @@ LR_ID LotusRangeList::GetIndex( const LotusRange &rRef )
     return ID_FAIL;
 }
 
-
 void LotusRangeList::Append( LotusRange* pLR, const OUString& rName )
 {
-    OSL_ENSURE( pLR, "*LotusRangeList::Append(): das wird nichts!" );
+    SAL_WARN_IF( !pLR, "sc", "*LotusRangeList::Append(): no pointer!" );
     maRanges.push_back(pLR);
 
     ScTokenArray    aTokArray;
@@ -479,31 +429,26 @@ void LotusRangeList::Append( LotusRange* pLR, const OUString& rName )
     }
 
     ScRangeData*    pData = new ScRangeData(
-        pLotusRoot->pDoc, rName, aTokArray );
+        m_pLotRoot->pDoc, rName, aTokArray );
 
-    pLotusRoot->pScRangeName->insert( pData );
+    m_pLotRoot->pScRangeName->insert( pData );
 
     pLR->SetId( nIdCnt );
 
     nIdCnt++;
 }
 
-
-
-
-RangeNameBufferWK3::RangeNameBufferWK3( void )
+RangeNameBufferWK3::RangeNameBufferWK3(LOTUS_ROOT* pLotRoot)
+    : m_pLotRoot(pLotRoot)
+    , pScTokenArray( new ScTokenArray )
 {
-    pScTokenArray = new ScTokenArray;
     nIntCount = 1;
 }
 
-
 RangeNameBufferWK3::~RangeNameBufferWK3()
 {
-    delete pScTokenArray;
 }
 
-
 void RangeNameBufferWK3::Add( const OUString& rOrgName, const ScComplexRefData& rCRD )
 {
     OUString aScName = ScfTools::ConvertToScDefinedName(rOrgName);
@@ -527,18 +472,17 @@ void RangeNameBufferWK3::Add( const OUString& rOrgName, const ScComplexRefData&
         aInsert.bSingleRef = false;
     }
 
-    ScRangeData*        pData = new ScRangeData( pLotusRoot->pDoc, aScName, *pScTokenArray );
+    ScRangeData*        pData = new ScRangeData( m_pLotRoot->pDoc, aScName, *pScTokenArray );
 
     aInsert.nRelInd = nIntCount;
     pData->SetIndex( nIntCount );
     nIntCount++;
 
     maEntries.push_back( aInsert );
-    pLotusRoot->pScRangeName->insert( pData );
+    m_pLotRoot->pScRangeName->insert( pData );
 }
 
-
-sal_Bool RangeNameBufferWK3::FindRel( const OUString& rRef, sal_uInt16& rIndex )
+bool RangeNameBufferWK3::FindRel( const OUString& rRef, sal_uInt16& rIndex )
 {
     StringHashEntry     aRef( rRef );
 
@@ -555,19 +499,18 @@ sal_Bool RangeNameBufferWK3::FindRel( const OUString& rRef, sal_uInt16& rIndex )
     return false;
 }
 
-
-sal_Bool RangeNameBufferWK3::FindAbs( const OUString& rRef, sal_uInt16& rIndex )
+bool RangeNameBufferWK3::FindAbs( const OUString& rRef, sal_uInt16& rIndex )
 {
     OUString            aTmp( rRef );
     aTmp = aTmp.copy(1);
-    StringHashEntry     aRef( aTmp ); // ohne '$' suchen!
+    StringHashEntry     aRef( aTmp ); // search w/o '$'!
 
     std::vector<Entry>::iterator itr;
     for ( itr = maEntries.begin(); itr != maEntries.end(); ++itr )
     {
         if ( aRef == itr->aStrHashEntry )
         {
-            // eventuell neuen Range Name aufbauen
+            // setup new range if needed
             if( itr->nAbsInd )
                 rIndex = itr->nAbsInd;
             else
@@ -577,7 +520,7 @@ sal_Bool RangeNameBufferWK3::FindAbs( const OUString& rRef, sal_uInt16& rIndex )
 
                 pRef->SetColRel( false );
                 pRef->SetRowRel( false );
-                pRef->SetTabRel( sal_True );
+                pRef->SetTabRel( true );
 
                 if( itr->bSingleRef )
                     pScTokenArray->AddSingleReference( *pRef );
@@ -586,17 +529,17 @@ sal_Bool RangeNameBufferWK3::FindAbs( const OUString& rRef, sal_uInt16& rIndex )
                     pRef = &itr->aScComplexRefDataRel.Ref2;
                     pRef->SetColRel( false );
                     pRef->SetRowRel( false );
-                    pRef->SetTabRel( sal_True );
+                    pRef->SetTabRel( true );
                     pScTokenArray->AddDoubleReference( itr->aScComplexRefDataRel );
                 }
 
-                ScRangeData*    pData = new ScRangeData( pLotusRoot->pDoc, itr->aScAbsName, *pScTokenArray );
+                ScRangeData*    pData = new ScRangeData( m_pLotRoot->pDoc, itr->aScAbsName, *pScTokenArray );
 
                 rIndex = itr->nAbsInd = nIntCount;
                 pData->SetIndex( rIndex );
                 nIntCount++;
 
-                pLotusRoot->pScRangeName->insert( pData );
+                m_pLotRoot->pScRangeName->insert( pData );
             }
 
             return true;
@@ -606,5 +549,4 @@ sal_Bool RangeNameBufferWK3::FindAbs( const OUString& rRef, sal_uInt16& rIndex )
     return false;
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
