@@ -17,8 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "autofilterbuffer.hxx"
+#include <autofilterbuffer.hxx>
 
+#include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/sheet/FilterConnection.hpp>
 #include <com/sun/star/sheet/FilterOperator2.hpp>
 #include <com/sun/star/sheet/TableFilterField3.hpp>
@@ -26,13 +27,16 @@
 #include <com/sun/star/sheet/XSheetFilterDescriptor3.hpp>
 #include <com/sun/star/table/TableOrientation.hpp>
 #include <rtl/ustrbuf.hxx>
+#include <osl/diagnose.h>
 #include <oox/helper/attributelist.hxx>
 #include <oox/helper/containerhelper.hxx>
 #include <oox/helper/propertyset.hxx>
+#include <oox/helper/binaryinputstream.hxx>
+#include <oox/token/namespaces.hxx>
 #include <oox/token/properties.hxx>
-#include "addressconverter.hxx"
-#include "biffinputstream.hxx"
-#include "defnamesbuffer.hxx"
+#include <oox/token/tokens.hxx>
+#include <addressconverter.hxx>
+#include <defnamesbuffer.hxx>
 
 namespace oox {
 namespace xls {
@@ -41,7 +45,6 @@ using namespace ::com::sun::star::sheet;
 using namespace ::com::sun::star::table;
 using namespace ::com::sun::star::uno;
 
-
 namespace {
 
 const sal_uInt8 BIFF12_TOP10FILTER_TOP              = 0x01;
@@ -147,7 +150,7 @@ ApiFilterSettings::ApiFilterSettings()
 
 void ApiFilterSettings::appendField( bool bAnd, sal_Int32 nOperator, double fValue )
 {
-    maFilterFields.resize( maFilterFields.size() + 1 );
+    maFilterFields.emplace_back();
     TableFilterField3& rFilterField = maFilterFields.back();
     rFilterField.Connection = bAnd ? FilterConnection_AND : FilterConnection_OR;
     rFilterField.Operator = nOperator;
@@ -158,7 +161,7 @@ void ApiFilterSettings::appendField( bool bAnd, sal_Int32 nOperator, double fVal
 
 void ApiFilterSettings::appendField( bool bAnd, sal_Int32 nOperator, const OUString& rValue )
 {
-    maFilterFields.resize( maFilterFields.size() + 1 );
+    maFilterFields.emplace_back();
     TableFilterField3& rFilterField = maFilterFields.back();
     rFilterField.Connection = bAnd ? FilterConnection_AND : FilterConnection_OR;
     rFilterField.Operator = nOperator;
@@ -169,7 +172,7 @@ void ApiFilterSettings::appendField( bool bAnd, sal_Int32 nOperator, const OUStr
 
 void ApiFilterSettings::appendField( bool bAnd, const std::vector<OUString>& rValues )
 {
-    maFilterFields.resize( maFilterFields.size() + 1 );
+    maFilterFields.emplace_back();
     TableFilterField3& rFilterField = maFilterFields.back();
     rFilterField.Connection = bAnd ? FilterConnection_AND : FilterConnection_OR;
     rFilterField.Operator = FilterOperator2::EQUAL;
@@ -233,7 +236,8 @@ void DiscreteFilter::importRecord( sal_Int32 nRecId, SequenceInputStream& rStrm
         case BIFF12_ID_DISCRETEFILTERS:
         {
             sal_Int32 nShowBlank, nCalendarType;
-            rStrm >> nShowBlank >> nCalendarType;
+            nShowBlank = rStrm.readInt32();
+            nCalendarType = rStrm.readInt32();
 
             static const sal_Int32 spnCalendarTypes[] = {
                 XML_none, XML_gregorian, XML_gregorianUs, XML_japan, XML_taiwan, XML_korea, XML_hijri, XML_thai, XML_hebrew,
@@ -298,7 +302,8 @@ void Top10Filter::importRecord( sal_Int32 nRecId, SequenceInputStream& rStrm )
     if( nRecId == BIFF12_ID_TOP10FILTER )
     {
         sal_uInt8 nFlags;
-        rStrm >> nFlags >> mfValue;
+        nFlags = rStrm.readuChar();
+        mfValue = rStrm.readDouble();
         mbTop = getFlag( nFlags, BIFF12_TOP10FILTER_TOP );
         mbPercent = getFlag( nFlags, BIFF12_TOP10FILTER_PERCENT );
     }
@@ -316,8 +321,7 @@ ApiFilterSettings Top10Filter::finalizeImport( sal_Int32 /*nMaxCount*/ )
 
 FilterCriterionModel::FilterCriterionModel() :
     mnOperator( XML_equal ),
-    mnDataType( BIFF_FILTER_DATATYPE_NONE ),
-    mnStrLen( 0 )
+    mnDataType( BIFF_FILTER_DATATYPE_NONE )
 {
 }
 
@@ -331,7 +335,8 @@ void FilterCriterionModel::setBiffOperator( sal_uInt8 nOperator )
 void FilterCriterionModel::readBiffData( SequenceInputStream& rStrm )
 {
     sal_uInt8 nOperator;
-    rStrm >> mnDataType >> nOperator;
+    mnDataType = rStrm.readuChar();
+    nOperator = rStrm.readuChar();
     setBiffOperator( nOperator );
 
     switch( mnDataType )
@@ -503,7 +508,8 @@ void FilterColumn::importFilterColumn( const AttributeList& rAttribs )
 void FilterColumn::importFilterColumn( SequenceInputStream& rStrm )
 {
     sal_uInt16 nFlags;
-    rStrm >> mnColId >> nFlags;
+    mnColId = rStrm.readInt32();
+    nFlags = rStrm.readuInt16();
     mbHiddenButton = getFlag( nFlags, BIFF12_FILTERCOLUMN_HIDDENBUTTON );
     mbShowButton = getFlag( nFlags, BIFF12_FILTERCOLUMN_SHOWBUTTON );
 }
@@ -530,14 +536,14 @@ AutoFilter::AutoFilter( const WorkbookHelper& rHelper ) :
 void AutoFilter::importAutoFilter( const AttributeList& rAttribs, sal_Int16 nSheet )
 {
     OUString aRangeStr = rAttribs.getString( XML_ref, OUString() );
-    getAddressConverter().convertToCellRangeUnchecked( maRange, aRangeStr, nSheet );
+    AddressConverter::convertToCellRangeUnchecked( maRange, aRangeStr, nSheet );
 }
 
 void AutoFilter::importAutoFilter( SequenceInputStream& rStrm, sal_Int16 nSheet )
 {
     BinRange aBinRange;
     rStrm >> aBinRange;
-    getAddressConverter().convertToCellRangeUnchecked( maRange, aBinRange, nSheet );
+    AddressConverter::convertToCellRangeUnchecked( maRange, aBinRange, nSheet );
 }
 
 FilterColumn& AutoFilter::createFilterColumn()
@@ -645,8 +651,8 @@ void AutoFilterBuffer::finalizeImport( sal_Int16 nSheet )
     // rely on existence of the defined name '_FilterDatabase' containing the range address of the filtered area
     if( const DefinedName* pFilterDBName = getDefinedNames().getByBuiltinId( BIFF_DEFNAME_FILTERDATABASE, nSheet ).get() )
     {
-        CellRangeAddress aFilterRange;
-        if( pFilterDBName->getAbsoluteRange( aFilterRange ) && (aFilterRange.Sheet == nSheet) )
+        ScRange aFilterRange;
+        if( pFilterDBName->getAbsoluteRange( aFilterRange ) && (aFilterRange.aStart.Tab() == nSheet) )
         {
             // use the same name for the database range as used for the defined name '_FilterDatabase'
             Reference< XDatabaseRange > xDatabaseRange = createUnnamedDatabaseRangeObject( aFilterRange );
@@ -658,7 +664,7 @@ void AutoFilterBuffer::finalizeImport( sal_Int16 nSheet )
                 // the built-in defined name 'Criteria' must exist
                 if( const DefinedName* pCriteriaName = getDefinedNames().getByBuiltinId( BIFF_DEFNAME_CRITERIA, nSheet ).get() )
                 {
-                    CellRangeAddress aCriteriaRange;
+                    ScRange aCriteriaRange;
                     if( pCriteriaName->getAbsoluteRange( aCriteriaRange ) )
                     {
                         // set some common properties for the filter descriptor
@@ -672,13 +678,13 @@ void AutoFilterBuffer::finalizeImport( sal_Int16 nSheet )
 
                         // position of output data (if built-in defined name 'Extract' exists)
                         DefinedNameRef xExtractName = getDefinedNames().getByBuiltinId( BIFF_DEFNAME_EXTRACT, nSheet );
-                        CellRangeAddress aOutputRange;
+                        ScRange aOutputRange;
                         bool bHasOutputRange = xExtractName.get() && xExtractName->getAbsoluteRange( aOutputRange );
                         aDescProps.setProperty( PROP_CopyOutputData, bHasOutputRange );
                         if( bHasOutputRange )
                         {
                             aDescProps.setProperty( PROP_SaveOutputPosition, true );
-                            aDescProps.setProperty( PROP_OutputPosition, CellAddress( aOutputRange.Sheet, aOutputRange.StartColumn, aOutputRange.StartRow ) );
+                            aDescProps.setProperty( PROP_OutputPosition, CellAddress( aOutputRange.aStart.Tab(), aOutputRange.aStart.Col(), aOutputRange.aStart.Row() ) );
                         }
 
                         /*  Properties of the database range (must be set after
@@ -687,7 +693,10 @@ void AutoFilterBuffer::finalizeImport( sal_Int16 nSheet )
                             deleted). */
                         PropertySet aRangeProps( xDatabaseRange );
                         aRangeProps.setProperty( PROP_AutoFilter, false );
-                        aRangeProps.setProperty( PROP_FilterCriteriaSource, aCriteriaRange );
+                        aRangeProps.setProperty( PROP_FilterCriteriaSource,
+                                                 CellRangeAddress( aCriteriaRange.aStart.Tab(),
+                                                                   aCriteriaRange.aStart.Col(), aCriteriaRange.aStart.Row(),
+                                                                   aCriteriaRange.aEnd.Col(), aCriteriaRange.aEnd.Row() ));
                     }
                 }
             }
@@ -720,7 +729,7 @@ AutoFilter* AutoFilterBuffer::getActiveAutoFilter()
     // Excel expects not more than one auto filter per sheet or table
     OSL_ENSURE( maAutoFilters.size() <= 1, "AutoFilterBuffer::getActiveAutoFilter - too many auto filters" );
     // stick to the last imported auto filter
-    return maAutoFilters.empty() ? 0 : maAutoFilters.back().get();
+    return maAutoFilters.empty() ? nullptr : maAutoFilters.back().get();
 }
 
 } // namespace xls
