@@ -17,20 +17,20 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "externallinkfragment.hxx"
+#include <externallinkfragment.hxx>
 
 #include <com/sun/star/sheet/XExternalSheetCache.hpp>
 #include <oox/helper/attributelist.hxx>
-#include "biffinputstream.hxx"
-#include "defnamesbuffer.hxx"
-#include "sheetdatacontext.hxx"
-#include "unitconverter.hxx"
+#include <oox/token/namespaces.hxx>
+#include <oox/token/tokens.hxx>
+#include <defnamesbuffer.hxx>
+#include <sheetdatacontext.hxx>
+#include <unitconverter.hxx>
 
 namespace oox {
 namespace xls {
 
 using namespace ::com::sun::star::sheet;
-using namespace ::com::sun::star::table;
 using namespace ::com::sun::star::uno;
 using namespace ::oox::core;
 
@@ -57,7 +57,7 @@ ContextHandlerRef ExternalSheetDataContext::onCreateContext( sal_Int32 nElement,
             if( nElement == XLS_TOKEN( v ) ) return this;   // collect characters in onCharacters()
         break;
     }
-    return 0;
+    return nullptr;
 }
 
 void ExternalSheetDataContext::onCharacters( const OUString& rChars )
@@ -86,7 +86,7 @@ ContextHandlerRef ExternalSheetDataContext::onCreateRecordContext( sal_Int32 nRe
     switch( getCurrentElement() )
     {
         case BIFF12_ID_EXTSHEETDATA:
-            if( nRecId == BIFF12_ID_EXTROW ) { maCurrPos.Row = rStrm.readInt32(); return this; }
+            if( nRecId == BIFF12_ID_EXTROW ) { maCurrPos.SetRow( rStrm.readInt32() ); return this; }
         break;
         case BIFF12_ID_EXTROW:
             switch( nRecId )
@@ -99,7 +99,7 @@ ContextHandlerRef ExternalSheetDataContext::onCreateRecordContext( sal_Int32 nRe
             }
         break;
     }
-    return 0;
+    return nullptr;
 }
 
 // private --------------------------------------------------------------------
@@ -114,32 +114,32 @@ void ExternalSheetDataContext::importCell( const AttributeList& rAttribs )
 
 void ExternalSheetDataContext::importExtCellBlank( SequenceInputStream& rStrm )
 {
-    maCurrPos.Column = rStrm.readInt32();
+    maCurrPos.SetCol( rStrm.readInt32() );
     setCellValue( Any( OUString() ) );
 }
 
 void ExternalSheetDataContext::importExtCellBool( SequenceInputStream& rStrm )
 {
-    maCurrPos.Column = rStrm.readInt32();
+    maCurrPos.SetCol( rStrm.readInt32() );
     double fValue = (rStrm.readuInt8() == 0) ? 0.0 : 1.0;
     setCellValue( Any( fValue ) );
 }
 
 void ExternalSheetDataContext::importExtCellDouble( SequenceInputStream& rStrm )
 {
-    maCurrPos.Column = rStrm.readInt32();
+    maCurrPos.SetCol( rStrm.readInt32() );
     setCellValue( Any( rStrm.readDouble() ) );
 }
 
 void ExternalSheetDataContext::importExtCellError( SequenceInputStream& rStrm )
 {
-    maCurrPos.Column = rStrm.readInt32();
+    maCurrPos.SetCol( rStrm.readInt32() );
     setCellValue( Any( BiffHelper::calcDoubleFromError( rStrm.readuInt8() ) ) );
 }
 
 void ExternalSheetDataContext::importExtCellString( SequenceInputStream& rStrm )
 {
-    maCurrPos.Column = rStrm.readInt32();
+    maCurrPos.SetCol( rStrm.readInt32() );
     setCellValue( Any( BiffHelper::readString( rStrm ) ) );
 }
 
@@ -147,7 +147,7 @@ void ExternalSheetDataContext::setCellValue( const Any& rValue )
 {
     if( mxSheetCache.is() && getAddressConverter().checkCellAddress( maCurrPos, false ) ) try
     {
-        mxSheetCache->setCellValue( maCurrPos.Column, maCurrPos.Row, rValue );
+        mxSheetCache->setCellValue( maCurrPos.Col(), maCurrPos.Row(), rValue );
     }
     catch( Exception& )
     {
@@ -195,7 +195,7 @@ ContextHandlerRef ExternalLinkFragment::onCreateContext( sal_Int32 nElement, con
             if( nElement == XLS_TOKEN( definedName ) ) mrExtLink.importDefinedName( rAttribs );
         break;
         case XLS_TOKEN( sheetDataSet ):
-            if( (nElement == XLS_TOKEN( sheetData )) && (mrExtLink.getLinkType() == LINKTYPE_EXTERNAL) )
+            if( (nElement == XLS_TOKEN( sheetData )) && (mrExtLink.getLinkType() == ExternalLinkType::External) )
                 return createSheetDataContext( rAttribs.getInteger( XML_sheetId, -1 ) );
         break;
 
@@ -234,7 +234,7 @@ ContextHandlerRef ExternalLinkFragment::onCreateContext( sal_Int32 nElement, con
             if( nElement == XLS_TOKEN( oleItem ) ) mxExtName = mrExtLink.importOleItem( rAttribs );
         break;
     }
-    return 0;
+    return nullptr;
 }
 
 void ExternalLinkFragment::onCharacters( const OUString& rChars )
@@ -280,7 +280,7 @@ ContextHandlerRef ExternalLinkFragment::onCreateRecordContext( sal_Int32 nRecId,
             switch( nRecId )
             {
                 case BIFF12_ID_EXTSHEETDATA:
-                    if( mrExtLink.getLinkType() == LINKTYPE_EXTERNAL )
+                    if( mrExtLink.getLinkType() == ExternalLinkType::External )
                         return createSheetDataContext( rStrm.readInt32() );
                 break;
 
@@ -307,7 +307,7 @@ ContextHandlerRef ExternalLinkFragment::onCreateRecordContext( sal_Int32 nRecId,
             }
         break;
     }
-    return 0;
+    return nullptr;
 }
 
 ContextHandlerRef ExternalLinkFragment::createSheetDataContext( sal_Int32 nSheetId )
