@@ -17,34 +17,22 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sheetdatacontext.hxx"
+#include <sheetdatacontext.hxx>
 
-#include <com/sun/star/table/CellContentType.hpp>
-#include <com/sun/star/table/XCell.hpp>
-#include <com/sun/star/table/XCellRange.hpp>
-#include <com/sun/star/text/XText.hpp>
-#include "oox/helper/attributelist.hxx"
-#include "oox/helper/propertyset.hxx"
-#include "addressconverter.hxx"
-#include "biffinputstream.hxx"
-#include "formulaparser.hxx"
-#include "richstringcontext.hxx"
-#include "unitconverter.hxx"
+#include <oox/helper/attributelist.hxx>
+#include <oox/helper/propertyset.hxx>
+#include <oox/token/namespaces.hxx>
+#include <oox/token/tokens.hxx>
+#include <addressconverter.hxx>
+#include <formulaparser.hxx>
+#include <richstringcontext.hxx>
+#include <unitconverter.hxx>
 
 namespace oox {
 namespace xls {
 
-// ============================================================================
-
-using namespace ::com::sun::star::sheet;
-using namespace ::com::sun::star::table;
-using namespace ::com::sun::star::text;
-using namespace ::com::sun::star::uno;
-
 using ::oox::core::ContextHandlerRef;
 
-// ============================================================================
-
 namespace {
 
 // record constants -----------------------------------------------------------
@@ -66,22 +54,18 @@ const sal_uInt8 BIFF12_ROW_SHOWPHONETIC     = 0x01;
 
 } // namespace
 
-// ============================================================================
-
 SheetDataContextBase::SheetDataContextBase( const WorksheetHelper& rHelper ) :
     mrAddressConv( rHelper.getAddressConverter() ),
-    mrFormulaParser( rHelper.getFormulaParser() ),
     mrSheetData( rHelper.getSheetData() ),
     mnSheet( rHelper.getSheetIndex() )
 {
+    mxFormulaParser.reset(rHelper.createFormulaParser());
 }
 
 SheetDataContextBase::~SheetDataContextBase()
 {
 }
 
-// ============================================================================
-
 SheetDataContext::SheetDataContext( WorksheetFragmentBase& rFragment ) :
     WorksheetContextBase( rFragment ),
     SheetDataContextBase( rFragment ),
@@ -90,12 +74,12 @@ SheetDataContext::SheetDataContext( WorksheetFragmentBase& rFragment ) :
     mnRow( -1 ),
     mnCol( -1 )
 {
-    SAL_INFO( "sc.filter",  "start safe sheet data context - unlock\n" );
+    SAL_INFO( "sc.filter",  "start safe sheet data context - unlock" );
 }
 
 SheetDataContext::~SheetDataContext()
 {
-    SAL_INFO( "sc.filter",  "end safe sheet data context - relock\n" );
+    SAL_INFO( "sc.filter",  "end safe sheet data context - relock" );
 }
 
 ContextHandlerRef SheetDataContext::onCreateContext( sal_Int32 nElement, const AttributeList& rAttribs )
@@ -126,7 +110,7 @@ ContextHandlerRef SheetDataContext::onCreateContext( sal_Int32 nElement, const A
             }
         break;
     }
-    return 0;
+    return nullptr;
 }
 
 void SheetDataContext::onCharacters( const OUString& rChars )
@@ -169,7 +153,7 @@ void SheetDataContext::onEndElement()
                 if( maFmlaData.mnSharedId >= 0 )
                 {
                     if( mbValidRange && maFmlaData.isValidSharedRef( maCellData.maCellAddr ) )
-                        createSharedFormulaMapEntry(maCellData.maCellAddr, maFmlaData.maFormulaRef, maFmlaData.mnSharedId, maFormulaStr);
+                        createSharedFormulaMapEntry(maCellData.maCellAddr, maFmlaData.mnSharedId, maFormulaStr);
 
                     setCellFormula(maCellData.maCellAddr, maFmlaData.mnSharedId, maCellValue, maCellData.mnCellType);
                     mrSheetData.setCellFormat( maCellData );
@@ -180,7 +164,9 @@ void SheetDataContext::onEndElement()
             break;
             case XML_array:
                 if( mbValidRange && maFmlaData.isValidArrayRef( maCellData.maCellAddr ) )
+                {
                     setCellArrayFormula( maFmlaData.maFormulaRef, maCellData.maCellAddr, maFormulaStr );
+                }
                 // set cell formatting, but do not set result as cell value
                 mrSheetData.setBlankCell( maCellData );
             break;
@@ -271,7 +257,7 @@ ContextHandlerRef SheetDataContext::onCreateRecordContext( sal_Int32 nRecId, Seq
             }
         break;
     }
-    return 0;
+    return nullptr;
 }
 
 // private --------------------------------------------------------------------
@@ -287,6 +273,7 @@ void SheetDataContext::importRow( const AttributeList& rAttribs )
     }
     else
         aModel.mnRow = ++mnRow;
+    mrAddressConv.checkRow( mnRow, true);
     mnCol = -1;
 
     aModel.mfHeight       = rAttribs.getDouble( XML_ht, -1.0 );
@@ -302,7 +289,7 @@ void SheetDataContext::importRow( const AttributeList& rAttribs )
 
     // decode the column spans (space-separated list of colon-separated integer pairs)
     OUString aColSpansText = rAttribs.getString( XML_spans, OUString() );
-    sal_Int32 nMaxCol = mrAddressConv.getMaxApiAddress().Column;
+    sal_Int32 nMaxCol = mrAddressConv.getMaxApiAddress().Col();
     sal_Int32 nIndex = 0;
     while( nIndex >= 0 )
     {
@@ -311,8 +298,14 @@ void SheetDataContext::importRow( const AttributeList& rAttribs )
         if( (0 < nSepPos) && (nSepPos + 1 < aColSpanToken.getLength()) )
         {
             // OOXML uses 1-based integer column indexes, row model expects 0-based colspans
-            sal_Int32 nLastCol = ::std::min( aColSpanToken.copy( nSepPos + 1 ).toInt32() - 1, nMaxCol );
-            aModel.insertColSpan( ValueRange( aColSpanToken.copy( 0, nSepPos ).toInt32() - 1, nLastCol ) );
+            const sal_Int32 nCol1 = aColSpanToken.copy( 0, nSepPos ).toInt32() - 1;
+            const bool bValid1 = mrAddressConv.checkCol( nCol1, true);
+            if (bValid1)
+            {
+                const sal_Int32 nCol2 = aColSpanToken.copy( nSepPos + 1 ).toInt32() - 1;
+                mrAddressConv.checkCol( nCol2, true);
+                aModel.insertColSpan( ValueRange( nCol1, ::std::min( nCol2, nMaxCol )));
+            }
         }
     }
 
@@ -328,12 +321,14 @@ bool SheetDataContext::importCell( const AttributeList& rAttribs )
     if (!p)
     {
         ++mnCol;
-        maCellData.maCellAddr = CellAddress( mnSheet, mnCol, mnRow );
+        ScAddress aAddress( mnCol, mnRow, mnSheet );
+        bValid = mrAddressConv.checkCellAddress( aAddress, true );
+        maCellData.maCellAddr = aAddress;
     }
     else
     {
         bValid = mrAddressConv.convertToCellAddress(maCellData.maCellAddr, p, mnSheet, true);
-        mnCol = maCellData.maCellAddr.Column;
+        mnCol = maCellData.maCellAddr.Col();
     }
 
     if( bValid )
@@ -343,7 +338,7 @@ bool SheetDataContext::importCell( const AttributeList& rAttribs )
         maCellData.mbShowPhonetic = rAttribs.getBool( XML_ph, false );
 
         // reset cell value, formula settings, and inline string
-        maCellValue = OUString();
+        maCellValue.clear();
         mxInlineStr.reset();
         mbHasFormula = false;
 
@@ -371,7 +366,7 @@ void SheetDataContext::importFormula( const AttributeList& rAttribs )
         maTableData.mbRef2Deleted = rAttribs.getBool( XML_del2, false );
     }
 
-    maFormulaStr = OUString();
+    maFormulaStr.clear();
 }
 
 void SheetDataContext::importRow( SequenceInputStream& rStrm )
@@ -380,9 +375,15 @@ void SheetDataContext::importRow( SequenceInputStream& rStrm )
     sal_Int32 nSpanCount;
     sal_uInt16 nHeight, nFlags1;
     sal_uInt8 nFlags2;
-    rStrm >> maCurrPos.mnRow >> aModel.mnXfId >> nHeight >> nFlags1 >> nFlags2 >> nSpanCount;
+    maCurrPos.mnRow = rStrm.readInt32();
+    aModel.mnXfId = rStrm.readInt32();
+    nHeight = rStrm.readuInt16();
+    nFlags1 = rStrm.readuInt16();
+    nFlags2 = rStrm.readuChar();
+    nSpanCount = rStrm.readInt32();
     maCurrPos.mnCol = 0;
 
+    mrAddressConv.checkRow( maCurrPos.mnRow, true);
     // row index is 0-based in BIFF12, but RowModel expects 1-based
     aModel.mnRow          = maCurrPos.mnRow + 1;
     // row height is in twips in BIFF12, convert to points
@@ -397,12 +398,16 @@ void SheetDataContext::importRow( SequenceInputStream& rStrm )
     aModel.mbThickBottom  = getFlag( nFlags1, BIFF12_ROW_THICKBOTTOM );
 
     // read the column spans
-    sal_Int32 nMaxCol = mrAddressConv.getMaxApiAddress().Column;
+    sal_Int32 nMaxCol = mrAddressConv.getMaxApiAddress().Col();
     for( sal_Int32 nSpanIdx = 0; (nSpanIdx < nSpanCount) && !rStrm.isEof(); ++nSpanIdx )
     {
         sal_Int32 nFirstCol, nLastCol;
-        rStrm >> nFirstCol >> nLastCol;
-        aModel.insertColSpan( ValueRange( nFirstCol, ::std::min( nLastCol, nMaxCol ) ) );
+        nFirstCol = rStrm.readInt32();
+        const bool bValid1 = mrAddressConv.checkCol( nFirstCol, true);
+        nLastCol = rStrm.readInt32();
+        mrAddressConv.checkCol( nLastCol, true);
+        if (bValid1)
+            aModel.insertColSpan( ValueRange( nFirstCol, ::std::min( nLastCol, nMaxCol ) ) );
     }
 
     // set row properties in the current sheet
@@ -414,12 +419,11 @@ bool SheetDataContext::readCellHeader( SequenceInputStream& rStrm, CellType eCel
     switch( eCellType )
     {
         case CELLTYPE_VALUE:
-        case CELLTYPE_FORMULA:  rStrm >> maCurrPos.mnCol;   break;
+        case CELLTYPE_FORMULA:  maCurrPos.mnCol = rStrm.readInt32();   break;
         case CELLTYPE_MULTI:    ++maCurrPos.mnCol;          break;
     }
 
-    sal_uInt32 nXfId;
-    rStrm >> nXfId;
+    sal_uInt32 nXfId = rStrm.readuInt32();
 
     bool bValidAddr = mrAddressConv.convertToCellAddress( maCellData.maCellAddr, maCurrPos, mnSheet, true );
     maCellData.mnXfId = extractValue< sal_Int32 >( nXfId, 0, 24 );
@@ -434,7 +438,7 @@ bool SheetDataContext::readCellHeader( SequenceInputStream& rStrm, CellType eCel
 ApiTokenSequence SheetDataContext::readCellFormula( SequenceInputStream& rStrm )
 {
     rStrm.skip( 2 );
-    return mrFormulaParser.importFormula( maCellData.maCellAddr, FORMULATYPE_CELL, rStrm );
+    return mxFormulaParser->importFormula( maCellData.maCellAddr, FormulaType::Cell, rStrm );
 }
 
 bool SheetDataContext::readFormulaRef( SequenceInputStream& rStrm )
@@ -544,7 +548,7 @@ void SheetDataContext::importArray( SequenceInputStream& rStrm )
     if( readFormulaRef( rStrm ) && maFmlaData.isValidArrayRef( maCellData.maCellAddr ) )
     {
         rStrm.skip( 1 );
-        ApiTokenSequence aTokens = mrFormulaParser.importFormula( maCellData.maCellAddr, FORMULATYPE_ARRAY, rStrm );
+        ApiTokenSequence aTokens = mxFormulaParser->importFormula( maCellData.maCellAddr, FormulaType::Array, rStrm );
         mrSheetData.createArrayFormula( maFmlaData.maFormulaRef, aTokens );
     }
 }
@@ -555,7 +559,8 @@ void SheetDataContext::importDataTable( SequenceInputStream& rStrm )
     {
         BinAddress aRef1, aRef2;
         sal_uInt8 nFlags;
-        rStrm >> aRef1 >> aRef2 >> nFlags;
+        rStrm >> aRef1 >> aRef2;
+        nFlags = rStrm.readuChar();
         maTableData.maRef1        = FormulaProcessorBase::generateAddress2dString( aRef1, false );
         maTableData.maRef2        = FormulaProcessorBase::generateAddress2dString( aRef2, false );
         maTableData.mbRowTable    = getFlag( nFlags, BIFF12_DATATABLE_ROW );
@@ -566,8 +571,13 @@ void SheetDataContext::importDataTable( SequenceInputStream& rStrm )
     }
 }
 
-void SheetDataContext::importSharedFmla( SequenceInputStream& /*rStrm*/ )
+void SheetDataContext::importSharedFmla( SequenceInputStream& rStrm )
 {
+    if( readFormulaRef( rStrm ) && maFmlaData.isValidSharedRef( maCellData.maCellAddr ) )
+    {
+        ApiTokenSequence aTokens = mxFormulaParser->importFormula( maCellData.maCellAddr, FormulaType::SharedFormula, rStrm );
+        mrSheetData.createSharedFormula( maCellData.maCellAddr, aTokens );
+    }
 }
 
 } // namespace xls
