@@ -17,37 +17,33 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "XMLConverter.hxx"
 #include <com/sun/star/util/DateTime.hpp>
+#include <com/sun/star/sheet/GeneralFunction2.hpp>
 #include <tools/datetime.hxx>
 #include <sax/tools/converter.hxx>
 #include <xmloff/xmltoken.hxx>
-#include "rangelst.hxx"
-#include "rangeutl.hxx"
-#include "docuno.hxx"
-#include "convuno.hxx"
-#include "document.hxx"
-#include "ftools.hxx"
+#include <rangelst.hxx>
+#include <rangeutl.hxx>
+#include <docuno.hxx>
+#include <convuno.hxx>
+#include <document.hxx>
+#include <ftools.hxx>
+#include <generalfunction.hxx>
 
 using namespace ::com::sun::star;
 using namespace xmloff::token;
 
-
-//___________________________________________________________________
-
-ScDocument* ScXMLConverter::GetScDocument( uno::Reference< frame::XModel > xModel )
+ScDocument* ScXMLConverter::GetScDocument( const uno::Reference< frame::XModel >& xModel )
 {
     if (xModel.is())
     {
         ScModelObj* pDocObj = ScModelObj::getImplementation( xModel );
-        return pDocObj ? pDocObj->GetDocument() : NULL;
+        return pDocObj ? pDocObj->GetDocument() : nullptr;
     }
-    return NULL;
+    return nullptr;
 }
 
-
-//___________________________________________________________________
 sheet::GeneralFunction ScXMLConverter::GetFunctionFromString( const OUString& sFunction )
 {
     if( IsXMLToken(sFunction, XML_SUM ) )
@@ -77,6 +73,37 @@ sheet::GeneralFunction ScXMLConverter::GetFunctionFromString( const OUString& sF
     return sheet::GeneralFunction_NONE;
 }
 
+ScGeneralFunction ScXMLConverter::GetFunctionFromString2( const OUString& sFunction )
+{
+    if( IsXMLToken(sFunction, XML_SUM ) )
+        return ScGeneralFunction::SUM;
+    if( IsXMLToken(sFunction, XML_AUTO ) )
+        return ScGeneralFunction::AUTO;
+    if( IsXMLToken(sFunction, XML_COUNT ) )
+        return ScGeneralFunction::COUNT;
+    if( IsXMLToken(sFunction, XML_COUNTNUMS ) )
+        return ScGeneralFunction::COUNTNUMS;
+    if( IsXMLToken(sFunction, XML_PRODUCT ) )
+        return ScGeneralFunction::PRODUCT;
+    if( IsXMLToken(sFunction, XML_AVERAGE ) )
+        return ScGeneralFunction::AVERAGE;
+    if( IsXMLToken(sFunction, XML_MEDIAN ) )
+        return ScGeneralFunction::MEDIAN;
+    if( IsXMLToken(sFunction, XML_MAX ) )
+        return ScGeneralFunction::MAX;
+    if( IsXMLToken(sFunction, XML_MIN ) )
+        return ScGeneralFunction::MIN;
+    if( IsXMLToken(sFunction, XML_STDEV ) )
+        return ScGeneralFunction::STDEV;
+    if( IsXMLToken(sFunction, XML_STDEVP ) )
+        return ScGeneralFunction::STDEVP;
+    if( IsXMLToken(sFunction, XML_VAR ) )
+        return ScGeneralFunction::VAR;
+    if( IsXMLToken(sFunction, XML_VARP ) )
+        return ScGeneralFunction::VARP;
+    return ScGeneralFunction::NONE;
+}
+
 ScSubTotalFunc ScXMLConverter::GetSubTotalFuncFromString( const OUString& sFunction )
 {
     if( IsXMLToken(sFunction, XML_SUM ) )
@@ -89,6 +116,8 @@ ScSubTotalFunc ScXMLConverter::GetSubTotalFuncFromString( const OUString& sFunct
         return SUBTOTAL_FUNC_PROD;
     if( IsXMLToken(sFunction, XML_AVERAGE ) )
         return SUBTOTAL_FUNC_AVE;
+    if( IsXMLToken(sFunction, XML_MEDIAN ) )
+        return SUBTOTAL_FUNC_MED;
     if( IsXMLToken(sFunction, XML_MAX ) )
         return SUBTOTAL_FUNC_MAX;
     if( IsXMLToken(sFunction, XML_MIN ) )
@@ -104,47 +133,44 @@ ScSubTotalFunc ScXMLConverter::GetSubTotalFuncFromString( const OUString& sFunct
     return SUBTOTAL_FUNC_NONE;
 }
 
-
-//___________________________________________________________________
-
 void ScXMLConverter::GetStringFromFunction(
         OUString& rString,
-        const sheet::GeneralFunction eFunction,
-        bool bAppendStr )
+        sal_Int16 eFunction )
 {
     OUString sFuncStr;
     switch( eFunction )
     {
-        case sheet::GeneralFunction_AUTO:       sFuncStr = GetXMLToken( XML_AUTO );         break;
-        case sheet::GeneralFunction_AVERAGE:    sFuncStr = GetXMLToken( XML_AVERAGE );      break;
-        case sheet::GeneralFunction_COUNT:      sFuncStr = GetXMLToken( XML_COUNT );        break;
-        case sheet::GeneralFunction_COUNTNUMS:  sFuncStr = GetXMLToken( XML_COUNTNUMS );    break;
-        case sheet::GeneralFunction_MAX:        sFuncStr = GetXMLToken( XML_MAX );          break;
-        case sheet::GeneralFunction_MIN:        sFuncStr = GetXMLToken( XML_MIN );          break;
-        case sheet::GeneralFunction_NONE:       sFuncStr = GetXMLToken( XML_NONE );         break;
-        case sheet::GeneralFunction_PRODUCT:    sFuncStr = GetXMLToken( XML_PRODUCT );      break;
-        case sheet::GeneralFunction_STDEV:      sFuncStr = GetXMLToken( XML_STDEV );        break;
-        case sheet::GeneralFunction_STDEVP:     sFuncStr = GetXMLToken( XML_STDEVP );       break;
-        case sheet::GeneralFunction_SUM:        sFuncStr = GetXMLToken( XML_SUM );          break;
-        case sheet::GeneralFunction_VAR:        sFuncStr = GetXMLToken( XML_VAR );          break;
-        case sheet::GeneralFunction_VARP:       sFuncStr = GetXMLToken( XML_VARP );         break;
+        case sheet::GeneralFunction2::AUTO:       sFuncStr = GetXMLToken( XML_AUTO );         break;
+        case sheet::GeneralFunction2::AVERAGE:    sFuncStr = GetXMLToken( XML_AVERAGE );      break;
+        case sheet::GeneralFunction2::MEDIAN:     sFuncStr = GetXMLToken( XML_MEDIAN );       break;
+        case sheet::GeneralFunction2::COUNT:      sFuncStr = GetXMLToken( XML_COUNT );        break;
+        case sheet::GeneralFunction2::COUNTNUMS:  sFuncStr = GetXMLToken( XML_COUNTNUMS );    break;
+        case sheet::GeneralFunction2::MAX:        sFuncStr = GetXMLToken( XML_MAX );          break;
+        case sheet::GeneralFunction2::MIN:        sFuncStr = GetXMLToken( XML_MIN );          break;
+        case sheet::GeneralFunction2::NONE:       sFuncStr = GetXMLToken( XML_NONE );         break;
+        case sheet::GeneralFunction2::PRODUCT:    sFuncStr = GetXMLToken( XML_PRODUCT );      break;
+        case sheet::GeneralFunction2::STDEV:      sFuncStr = GetXMLToken( XML_STDEV );        break;
+        case sheet::GeneralFunction2::STDEVP:     sFuncStr = GetXMLToken( XML_STDEVP );       break;
+        case sheet::GeneralFunction2::SUM:        sFuncStr = GetXMLToken( XML_SUM );          break;
+        case sheet::GeneralFunction2::VAR:        sFuncStr = GetXMLToken( XML_VAR );          break;
+        case sheet::GeneralFunction2::VARP:       sFuncStr = GetXMLToken( XML_VARP );         break;
         default:
         {
-            // added to avoid warnings
+            assert(false);
         }
     }
-    ScRangeStringConverter::AssignString( rString, sFuncStr, bAppendStr );
+    ScRangeStringConverter::AssignString( rString, sFuncStr, false );
 }
 
 void ScXMLConverter::GetStringFromFunction(
         OUString& rString,
-        const ScSubTotalFunc eFunction,
-        bool bAppendStr )
+        const ScSubTotalFunc eFunction )
 {
     OUString sFuncStr;
     switch( eFunction )
     {
         case SUBTOTAL_FUNC_AVE:     sFuncStr = GetXMLToken( XML_AVERAGE );      break;
+        case SUBTOTAL_FUNC_MED:     sFuncStr = GetXMLToken( XML_MEDIAN );       break;
         case SUBTOTAL_FUNC_CNT:     sFuncStr = GetXMLToken( XML_COUNT );        break;
         case SUBTOTAL_FUNC_CNT2:    sFuncStr = GetXMLToken( XML_COUNTNUMS );    break;
         case SUBTOTAL_FUNC_MAX:     sFuncStr = GetXMLToken( XML_MAX );          break;
@@ -160,12 +186,9 @@ void ScXMLConverter::GetStringFromFunction(
         case SUBTOTAL_FUNC_VAR:     sFuncStr = GetXMLToken( XML_VAR );          break;
         case SUBTOTAL_FUNC_VARP:    sFuncStr = GetXMLToken( XML_VARP );         break;
     }
-    ScRangeStringConverter::AssignString( rString, sFuncStr, bAppendStr );
+    ScRangeStringConverter::AssignString( rString, sFuncStr, false );
 }
 
-
-//___________________________________________________________________
-
 sheet::DataPilotFieldOrientation ScXMLConverter::GetOrientationFromString(
     const OUString& rString )
 {
@@ -180,13 +203,9 @@ sheet::DataPilotFieldOrientation ScXMLConverter::GetOrientationFromString(
     return sheet::DataPilotFieldOrientation_HIDDEN;
 }
 
-
-//___________________________________________________________________
-
 void ScXMLConverter::GetStringFromOrientation(
     OUString& rString,
-    const sheet::DataPilotFieldOrientation eOrientation,
-    bool bAppendStr )
+    const sheet::DataPilotFieldOrientation eOrientation )
 {
     OUString sOrientStr;
     switch( eOrientation )
@@ -211,12 +230,9 @@ void ScXMLConverter::GetStringFromOrientation(
             // added to avoid warnings
         }
     }
-    ScRangeStringConverter::AssignString( rString, sOrientStr, bAppendStr );
+    ScRangeStringConverter::AssignString( rString, sOrientStr, false );
 }
 
-
-//___________________________________________________________________
-
 ScDetectiveObjType ScXMLConverter::GetDetObjTypeFromString( const OUString& rString )
 {
     if( IsXMLToken(rString, XML_FROM_SAME_TABLE ) )
@@ -245,13 +261,9 @@ bool ScXMLConverter::GetDetOpTypeFromString( ScDetOpType& rDetOpType, const OUSt
     return true;
 }
 
-
-//___________________________________________________________________
-
 void ScXMLConverter::GetStringFromDetObjType(
         OUString& rString,
-        const ScDetectiveObjType eObjType,
-        bool bAppendStr )
+        const ScDetectiveObjType eObjType )
 {
     OUString sTypeStr;
     switch( eObjType )
@@ -270,13 +282,12 @@ void ScXMLConverter::GetStringFromDetObjType(
             // added to avoid warnings
         }
     }
-    ScRangeStringConverter::AssignString( rString, sTypeStr, bAppendStr );
+    ScRangeStringConverter::AssignString( rString, sTypeStr, false );
 }
 
 void ScXMLConverter::GetStringFromDetOpType(
         OUString& rString,
-        const ScDetOpType eOpType,
-        bool bAppendStr )
+        const ScDetOpType eOpType )
 {
     OUString sTypeStr;
     switch( eOpType )
@@ -297,74 +308,38 @@ void ScXMLConverter::GetStringFromDetOpType(
             sTypeStr = GetXMLToken( XML_REMOVE_PRECEDENTS );
         break;
     }
-    ScRangeStringConverter::AssignString( rString, sTypeStr, bAppendStr );
+    ScRangeStringConverter::AssignString( rString, sTypeStr, false );
 }
 
-
-//___________________________________________________________________
-
-void ScXMLConverter::ParseFormula(OUString& sFormula, const bool bIsFormula)
+void ScXMLConverter::ConvertCellRangeAddress(OUString& sFormula)
 {
     OUStringBuffer sBuffer(sFormula.getLength());
     bool bInQuotationMarks(false);
-    bool bInDoubleQuotationMarks(false);
-    sal_Int16 nCountBraces(0);
     sal_Unicode chPrevious('=');
-    for (sal_Int32 i = 0; i < sFormula.getLength(); ++i)
+    const sal_Unicode* p = sFormula.getStr();
+    const sal_Unicode* const pStop = p + sFormula.getLength();
+    for ( ; p < pStop; ++p)
     {
-        if (sFormula[i] == '\'' && !bInDoubleQuotationMarks &&
-            chPrevious != '\\')
+        const sal_Unicode c = *p;
+        if (c == '\'')
             bInQuotationMarks = !bInQuotationMarks;
-        else if (sFormula[i] == '"' && !bInQuotationMarks)
-            bInDoubleQuotationMarks = !bInDoubleQuotationMarks;
-        if (bInQuotationMarks || bInDoubleQuotationMarks)
-            sBuffer.append(sFormula[i]);
-        else if (sFormula[i] == '[')
-            ++nCountBraces;
-        else if (sFormula[i] == ']')
-            nCountBraces--;
-        else if ((sFormula[i] != '.') ||
-                ((nCountBraces == 0) && bIsFormula) ||
-                !((chPrevious == '[') || (chPrevious == ':') || (chPrevious == ' ') || (chPrevious == '=')))
-                sBuffer.append(sFormula[i]);
-        chPrevious = sFormula[i];
+        if (bInQuotationMarks)
+            sBuffer.append(c);
+        else if ((c != '.') ||
+                !((chPrevious == ':') || (chPrevious == ' ') || (chPrevious == '=')))
+            sBuffer.append(c);
+        chPrevious = c;
     }
 
-    OSL_ENSURE(nCountBraces == 0, "there are some braces still open");
     sFormula = sBuffer.makeStringAndClear();
 }
 
-
-//_____________________________________________________________________
-
 void ScXMLConverter::ConvertDateTimeToString(const DateTime& aDateTime, OUStringBuffer& sDate)
 {
-    util::DateTime aAPIDateTime;
-    ConvertCoreToAPIDateTime(aDateTime, aAPIDateTime);
-    ::sax::Converter::convertDateTime(sDate, aAPIDateTime, 0);
+    css::util::DateTime aAPIDateTime = aDateTime.GetUNODateTime();
+    ::sax::Converter::convertDateTime(sDate, aAPIDateTime, nullptr);
 }
 
-void ScXMLConverter::ConvertCoreToAPIDateTime(const DateTime& aDateTime, util::DateTime& rDateTime)
-{
-    rDateTime.Year = aDateTime.GetYear();
-    rDateTime.Month = aDateTime.GetMonth();
-    rDateTime.Day = aDateTime.GetDay();
-    rDateTime.Hours = aDateTime.GetHour();
-    rDateTime.Minutes = aDateTime.GetMin();
-    rDateTime.Seconds = aDateTime.GetSec();
-    rDateTime.NanoSeconds = aDateTime.GetNanoSec();
-}
-
-void ScXMLConverter::ConvertAPIToCoreDateTime(const util::DateTime& aDateTime, DateTime& rDateTime)
-{
-    Date aDate(aDateTime.Day, aDateTime.Month, aDateTime.Year);
-    Time aTime(aDateTime.Hours, aDateTime.Minutes, aDateTime.Seconds, aDateTime.NanoSeconds);
-    DateTime aTempDateTime (aDate, aTime);
-    rDateTime = aTempDateTime;
-}
-
-// ============================================================================
-
 namespace {
 
 /** Enumerates different types of condition tokens. */
@@ -420,11 +395,12 @@ const ScXMLConditionInfo* lclGetConditionInfo( const sal_Unicode*& rpcString, co
 
     // search the table for an entry
     if( nLength > 0 )
-        for( const ScXMLConditionInfo* pInfo = spConditionInfos; pInfo < STATIC_ARRAY_END( spConditionInfos ); ++pInfo )
-            if( (nLength == pInfo->mnIdentLength) && (::rtl_ustr_ascii_shortenedCompare_WithLength( pcIdStart, nLength, pInfo->mpcIdentifier, nLength ) == 0) )
-                return pInfo;
+        for(auto const &rInfo : spConditionInfos)
+            if((nLength == rInfo.mnIdentLength)
+               && (::rtl_ustr_ascii_shortenedCompare_WithLength(pcIdStart, nLength, rInfo.mpcIdentifier, nLength) == 0) )
+                return &rInfo;
 
-    return 0;
+    return nullptr;
 }
 
 sheet::ConditionOperator lclGetConditionOperator( const sal_Unicode*& rpcString, const sal_Unicode* pcEnd )
@@ -560,8 +536,6 @@ bool lclSkipEmptyParentheses( const sal_Unicode*& rpcString, const sal_Unicode*
 
 } // namespace
 
-// ----------------------------------------------------------------------------
-
 void ScXMLConditionHelper::parseCondition(
         ScXMLConditionParseResult& rParseResult, const OUString& rAttribute, sal_Int32 nStartIndex )
 {
@@ -650,6 +624,4 @@ OUString ScXMLConditionHelper::getExpression( const sal_Unicode*& rpcString, con
     return aExp;
 }
 
-// ============================================================================
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
