@@ -26,20 +26,20 @@
 #include <rtl/math.hxx>
 #include "xmlexprt.hxx"
 #include "XMLConverter.hxx"
-#include "document.hxx"
-#include "dpobject.hxx"
-#include "dociter.hxx"
-#include "attrib.hxx"
-#include "patattr.hxx"
-#include "scitems.hxx"
-#include "dpsave.hxx"
-#include "dpshttab.hxx"
-#include "dpsdbtab.hxx"
-#include "dpdimsave.hxx"
-#include "dpgroup.hxx"
-#include "dputil.hxx"
-#include "rangeutl.hxx"
-#include "queryentry.hxx"
+#include <document.hxx>
+#include <dpobject.hxx>
+#include <dociter.hxx>
+#include <attrib.hxx>
+#include <patattr.hxx>
+#include <scitems.hxx>
+#include <dpsave.hxx>
+#include <dpshttab.hxx>
+#include <dpsdbtab.hxx>
+#include <dpdimsave.hxx>
+#include <dpgroup.hxx>
+#include <dputil.hxx>
+#include <rangeutl.hxx>
+#include <queryentry.hxx>
 #include <com/sun/star/sheet/DataImportMode.hpp>
 #include <com/sun/star/sheet/DataPilotFieldReference.hpp>
 #include <com/sun/star/sheet/DataPilotFieldReferenceType.hpp>
@@ -73,14 +73,14 @@ OUString ScXMLExportDataPilot::getDPOperatorXML(
     {
         case SC_EQUAL :
         {
-            if (eSearchType == utl::SearchParam::SRCH_REGEXP)
+            if (eSearchType == utl::SearchParam::SearchType::Regexp)
                 return GetXMLToken(XML_MATCH);
             else
                 return OUString("=");
         }
         case SC_NOT_EQUAL :
         {
-            if (eSearchType == utl::SearchParam::SRCH_REGEXP)
+            if (eSearchType == utl::SearchParam::SearchType::Regexp)
                 return GetXMLToken(XML_NOMATCH);
             else
                 return OUString("!=");
@@ -267,7 +267,7 @@ void ScXMLExportDataPilot::WriteDPFilter(const ScQueryParam& aQueryParam)
     }
 }
 
-void ScXMLExportDataPilot::WriteFieldReference(ScDPSaveDimension* pDim)
+void ScXMLExportDataPilot::WriteFieldReference(const ScDPSaveDimension* pDim)
 {
     const sheet::DataPilotFieldReference* pRef = pDim->GetReferenceValue();
     if (pRef)
@@ -334,7 +334,7 @@ void ScXMLExportDataPilot::WriteFieldReference(ScDPSaveDimension* pDim)
     rExport.CheckAttrList();
 }
 
-void ScXMLExportDataPilot::WriteSortInfo(ScDPSaveDimension* pDim)
+void ScXMLExportDataPilot::WriteSortInfo(const ScDPSaveDimension* pDim)
 {
     const sheet::DataPilotFieldSortInfo* pSortInfo = pDim->GetSortInfo();
     if (pSortInfo)
@@ -368,7 +368,7 @@ void ScXMLExportDataPilot::WriteSortInfo(ScDPSaveDimension* pDim)
     }
 }
 
-void ScXMLExportDataPilot::WriteAutoShowInfo(ScDPSaveDimension* pDim)
+void ScXMLExportDataPilot::WriteAutoShowInfo(const ScDPSaveDimension* pDim)
 {
     const sheet::DataPilotFieldAutoShowInfo* pAutoInfo = pDim->GetAutoShowInfo();
     if (pAutoInfo)
@@ -391,9 +391,7 @@ void ScXMLExportDataPilot::WriteAutoShowInfo(ScDPSaveDimension* pDim)
         if (!sValueStr.isEmpty())
             rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_DISPLAY_MEMBER_MODE, sValueStr);
 
-        OUStringBuffer sBuffer;
-        ::sax::Converter::convertNumber(sBuffer, pAutoInfo->ItemCount);
-        rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_MEMBER_COUNT, sBuffer.makeStringAndClear());
+        rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_MEMBER_COUNT, OUString::number(pAutoInfo->ItemCount));
 
         rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_DATA_FIELD, pAutoInfo->DataField);
 
@@ -401,7 +399,7 @@ void ScXMLExportDataPilot::WriteAutoShowInfo(ScDPSaveDimension* pDim)
     }
 }
 
-void ScXMLExportDataPilot::WriteLayoutInfo(ScDPSaveDimension* pDim)
+void ScXMLExportDataPilot::WriteLayoutInfo(const ScDPSaveDimension* pDim)
 {
     const sheet::DataPilotFieldLayoutInfo* pLayoutInfo = pDim->GetLayoutInfo();
     if (pLayoutInfo)
@@ -430,7 +428,7 @@ void ScXMLExportDataPilot::WriteLayoutInfo(ScDPSaveDimension* pDim)
     }
 }
 
-void ScXMLExportDataPilot::WriteSubTotals(ScDPSaveDimension* pDim)
+void ScXMLExportDataPilot::WriteSubTotals(const ScDPSaveDimension* pDim)
 {
     sal_Int32 nSubTotalCount = pDim->GetSubTotalsCount();
     const OUString* pLayoutName = nullptr;
@@ -455,7 +453,7 @@ void ScXMLExportDataPilot::WriteSubTotals(ScDPSaveDimension* pDim)
     }
 }
 
-void ScXMLExportDataPilot::WriteMembers(ScDPSaveDimension* pDim)
+void ScXMLExportDataPilot::WriteMembers(const ScDPSaveDimension* pDim)
 {
     const ScDPSaveDimension::MemberList &rMembers = pDim->GetMembers();
     if (!rMembers.empty())
@@ -464,7 +462,7 @@ void ScXMLExportDataPilot::WriteMembers(ScDPSaveDimension* pDim)
         rExport.CheckAttrList();
         for (ScDPSaveDimension::MemberList::const_iterator i=rMembers.begin(); i != rMembers.end() ; ++i)
         {
-            rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_NAME, OUString((*i)->GetName()));
+            rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_NAME, (*i)->GetName());
 
             if (rExport.getDefaultVersion() > SvtSaveOptions::ODFVER_012)
             {
@@ -485,7 +483,7 @@ void ScXMLExportDataPilot::WriteMembers(ScDPSaveDimension* pDim)
     }
 }
 
-void ScXMLExportDataPilot::WriteLevels(ScDPSaveDimension* pDim)
+void ScXMLExportDataPilot::WriteLevels(const ScDPSaveDimension* pDim)
 {
     // #i114202# GetShowEmpty is only valid if HasShowEmpty is true.
     if (pDim->HasShowEmpty())
@@ -630,7 +628,7 @@ void ScXMLExportDataPilot::WriteNumGroupDim(const ScDPSaveNumGroupDimension* pNu
     }
 }
 
-void ScXMLExportDataPilot::WriteGroupDimElements(ScDPSaveDimension* pDim, const ScDPDimensionSaveData* pDimData)
+void ScXMLExportDataPilot::WriteGroupDimElements(const ScDPSaveDimension* pDim, const ScDPDimensionSaveData* pDimData)
 {
     const ScDPSaveGroupDimension* pGroupDim = nullptr;
     const ScDPSaveNumGroupDimension* pNumGroupDim = nullptr;
@@ -672,7 +670,7 @@ void ScXMLExportDataPilot::WriteGroupDimElements(ScDPSaveDimension* pDim, const
     }
 }
 
-void ScXMLExportDataPilot::WriteDimension(ScDPSaveDimension* pDim, const ScDPDimensionSaveData* pDimData)
+void ScXMLExportDataPilot::WriteDimension(const ScDPSaveDimension* pDim, const ScDPDimensionSaveData* pDimData)
 {
     OUString aSrcDimName = ScDPUtil::getSourceDimensionName(pDim->GetName());
     rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_SOURCE_FIELD_NAME, aSrcDimName);
@@ -694,9 +692,7 @@ void ScXMLExportDataPilot::WriteDimension(ScDPSaveDimension* pDim, const ScDPDim
         rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_ORIENTATION, sValueStr );
     if (pDim->GetUsedHierarchy() != 1)
     {
-        OUStringBuffer sBuffer;
-        ::sax::Converter::convertNumber(sBuffer, pDim->GetUsedHierarchy());
-        rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_USED_HIERARCHY, sBuffer.makeStringAndClear());
+        rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_USED_HIERARCHY, OUString::number(pDim->GetUsedHierarchy()));
     }
     ScXMLConverter::GetStringFromFunction( sValueStr, static_cast<sal_Int16>(pDim->GetFunction()) );
     rExport.AddAttribute(XML_NAMESPACE_TABLE, XML_FUNCTION, sValueStr);
@@ -717,7 +713,7 @@ void ScXMLExportDataPilot::WriteDimension(ScDPSaveDimension* pDim, const ScDPDim
         WriteGroupDimElements(pDim, pDimData);
 }
 
-void ScXMLExportDataPilot::WriteDimensions(ScDPSaveData* pDPSave)
+void ScXMLExportDataPilot::WriteDimensions(const ScDPSaveData* pDPSave)
 {
     const ScDPSaveData::DimsType& rDimensions = pDPSave->GetDimensions();
     for (auto const& iter : rDimensions)
@@ -737,7 +733,7 @@ void ScXMLExportDataPilot::WriteGrandTotal(::xmloff::token::XMLTokenEnum eOrient
     SvXMLElementExport aElemGrandTotal(rExport, XML_NAMESPACE_TABLE_EXT, XML_DATA_PILOT_GRAND_TOTAL, true, true);
 }
 
-void ScXMLExportDataPilot::WriteDataPilots(const uno::Reference <sheet::XSpreadsheetDocument>& /* xSpreadDoc */)
+void ScXMLExportDataPilot::WriteDataPilots()
 {
     pDoc = rExport.GetDocument();
     if (!pDoc)
@@ -771,7 +767,7 @@ void ScXMLExportDataPilot::WriteDataPilots(const uno::Reference <sheet::XSpreads
         const ScPatternAttr* pAttr = aAttrItr.GetNext(nCol, nRow1, nRow2);
         while (pAttr)
         {
-            const ScMergeFlagAttr& rItem = static_cast<const ScMergeFlagAttr&>(pAttr->GetItem(ATTR_MERGE_FLAG));
+            const ScMergeFlagAttr& rItem = pAttr->GetItem(ATTR_MERGE_FLAG);
             if (rItem.HasPivotButton())
             {
                 for (SCROW nButtonRow = nRow1; nButtonRow <= nRow2; ++nButtonRow)
@@ -884,6 +880,7 @@ void ScXMLExportDataPilot::WriteDataPilots(const uno::Reference <sheet::XSpreads
                     rExport.CheckAttrList();
                 }
                 break;
+                default: break;
             }
         }
         else if ((*pDPs)[i].IsServiceData())
