@@ -30,8 +30,6 @@
 using namespace com::sun::star;
 using namespace xmloff::token;
 
-//------------------------------------------------------------------
-
 ScXMLAnnotationData::ScXMLAnnotationData() :
     mbUseShapePos( false ),
     mbShown( false )
@@ -42,29 +40,24 @@ ScXMLAnnotationData::~ScXMLAnnotationData()
 {
 }
 
-//------------------------------------------------------------------
-
 ScXMLAnnotationContext::ScXMLAnnotationContext( ScXMLImport& rImport,
                                       sal_uInt16 nPrfx,
                                       const OUString& rLName,
                                       const uno::Reference<xml::sax::XAttributeList>& xAttrList,
-                                      ScXMLAnnotationData& rAnnotationData,
-                                      ScXMLTableRowCellContext* pTempCellContext) :
-    SvXMLImportContext( rImport, nPrfx, rLName ),
+                                      ScXMLAnnotationData& rAnnotationData) :
+    ScXMLImportContext( rImport, nPrfx, rLName ),
     mrAnnotationData( rAnnotationData ),
-    pCellContext(pTempCellContext),
-    pShapeContext(NULL)
+    pShapeContext(nullptr)
 {
     uno::Reference<drawing::XShapes> xLocalShapes (GetScImport().GetTables().GetCurrentXShapes());
     if (xLocalShapes.is())
     {
-        XMLTableShapeImportHelper* pTableShapeImport = (XMLTableShapeImportHelper*)GetScImport().GetShapeImport().get();
+        XMLTableShapeImportHelper* pTableShapeImport = static_cast<XMLTableShapeImportHelper*>(GetScImport().GetShapeImport().get());
         pTableShapeImport->SetAnnotation(this);
         pShapeContext = GetScImport().GetShapeImport()->CreateGroupChildContext(
             GetScImport(), nPrfx, rLName, xAttrList, xLocalShapes, true);
     }
 
-    pCellContext = pTempCellContext;
     sal_Int16 nAttrCount = xAttrList.is() ? xAttrList->getLength() : 0;
     const SvXMLTokenMap& rAttrTokenMap = GetScImport().GetTableAnnotationAttrTokenMap();
     for( sal_Int16 i=0; i < nAttrCount; ++i )
@@ -115,42 +108,41 @@ ScXMLAnnotationContext::~ScXMLAnnotationContext()
 {
 }
 
-void ScXMLAnnotationContext::StartElement(const com::sun::star::uno::Reference< com::sun::star::xml::sax::XAttributeList>& xAttrList)
+void ScXMLAnnotationContext::StartElement(const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList)
 {
     if (pShapeContext)
         pShapeContext->StartElement(xAttrList);
 }
 
-SvXMLImportContext *ScXMLAnnotationContext::CreateChildContext( sal_uInt16 nPrefix,
+SvXMLImportContextRef ScXMLAnnotationContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const OUString& rLName,
-                                            const ::com::sun::star::uno::Reference<
-                                          ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
+                                            const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
 {
-    SvXMLImportContext *pContext = 0;
+    SvXMLImportContextRef xContext;
 
     if( XML_NAMESPACE_DC == nPrefix )
     {
         if( IsXMLToken( rLName, XML_CREATOR ) )
-            pContext = new ScXMLContentContext(GetScImport(), nPrefix,
-                                            rLName, xAttrList, maAuthorBuffer);
+            xContext = new ScXMLContentContext(GetScImport(), nPrefix,
+                                            rLName, maAuthorBuffer);
         else if( IsXMLToken( rLName, XML_DATE ) )
-            pContext = new ScXMLContentContext(GetScImport(), nPrefix,
-                                            rLName, xAttrList, maCreateDateBuffer);
+            xContext = new ScXMLContentContext(GetScImport(), nPrefix,
+                                            rLName, maCreateDateBuffer);
     }
     else if( XML_NAMESPACE_META == nPrefix )
     {
         if( IsXMLToken( rLName, XML_DATE_STRING ) )
-            pContext = new ScXMLContentContext(GetScImport(), nPrefix,
-                                            rLName, xAttrList, maCreateDateStringBuffer);
+            xContext = new ScXMLContentContext(GetScImport(), nPrefix,
+                                            rLName, maCreateDateStringBuffer);
     }
 
-    if( !pContext && pShapeContext )
-        pContext = pShapeContext->CreateChildContext(nPrefix, rLName, xAttrList);
+    if( !xContext && pShapeContext )
+        xContext = pShapeContext->CreateChildContext(nPrefix, rLName, xAttrList);
 
-    if( !pContext )
-        pContext = new SvXMLImportContext( GetImport(), nPrefix, rLName );
+    if (!xContext)
+        xContext = new SvXMLImportContext( GetImport(), nPrefix, rLName );
 
-    return pContext;
+    return xContext;
 }
 
 void ScXMLAnnotationContext::Characters( const OUString& rChars )
@@ -164,7 +156,7 @@ void ScXMLAnnotationContext::EndElement()
     {
         pShapeContext->EndElement();
         delete pShapeContext;
-        pShapeContext = NULL;
+        pShapeContext = nullptr;
     }
 
     mrAnnotationData.maAuthor = maAuthorBuffer.makeStringAndClear();
@@ -173,8 +165,8 @@ void ScXMLAnnotationContext::EndElement()
         mrAnnotationData.maCreateDate = maCreateDateStringBuffer.makeStringAndClear();
     mrAnnotationData.maSimpleText = maTextBuffer.makeStringAndClear();
 
-    XMLTableShapeImportHelper* pTableShapeImport = (XMLTableShapeImportHelper*)GetScImport().GetShapeImport().get();
-    pTableShapeImport->SetAnnotation(NULL);
+    XMLTableShapeImportHelper* pTableShapeImport = static_cast<XMLTableShapeImportHelper*>(GetScImport().GetShapeImport().get());
+    pTableShapeImport->SetAnnotation(nullptr);
 }
 
 void ScXMLAnnotationContext::SetShape( const uno::Reference< drawing::XShape >& rxShape, const uno::Reference< drawing::XShapes >& rxShapes,
@@ -188,7 +180,7 @@ void ScXMLAnnotationContext::SetShape( const uno::Reference< drawing::XShape >&
 
 void ScXMLAnnotationContext::AddContentStyle( sal_uInt16 nFamily, const OUString& rName, const ESelection& rSelection )
 {
-    mrAnnotationData.maContentStyles.push_back( ScXMLAnnotationStyleEntry( nFamily, rName, rSelection ) );
+    mrAnnotationData.maContentStyles.emplace_back( nFamily, rName, rSelection );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
