@@ -17,13 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <rsc/rscsfx.hxx>
+#include <vcl/errinf.hxx>
+#include <svl/style.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/objsh.hxx>
 #include <sot/storage.hxx>
 #include <osl/diagnose.h>
 #include <comphelper/processfactory.hxx>
+#include <comphelper/propertysequence.hxx>
 #include <unotools/streamwrap.hxx>
+#include <svx/dialmgr.hxx>
+#include <svx/strings.hrc>
 #include <svx/xmlgrhlp.hxx>
 #include <svtools/sfxecode.hxx>
 #include <sfx2/frame.hxx>
@@ -34,12 +38,14 @@
 #include <com/sun/star/beans/XPropertySetInfo.hpp>
 #include <com/sun/star/xml/sax/InputSource.hpp>
 #include <com/sun/star/xml/sax/Parser.hpp>
+#include <com/sun/star/xml/sax/XFastParser.hpp>
 #include <com/sun/star/xml/sax/Writer.hpp>
 #include <com/sun/star/frame/XModel.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <comphelper/extract.hxx>
 #include <comphelper/propertysetinfo.hxx>
 #include <comphelper/genericpropertyset.hxx>
+#include <com/sun/star/packages/WrongPasswordException.hpp>
 #include <com/sun/star/packages/zip/ZipIOException.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <com/sun/star/script/vba/XVBACompatibility.hpp>
@@ -52,16 +58,16 @@
 #include <rtl/strbuf.hxx>
 #include <unotools/saveopt.hxx>
 
-#include "document.hxx"
-#include "xmlwrap.hxx"
+#include <document.hxx>
+#include <xmlwrap.hxx>
 #include "xmlimprt.hxx"
 #include "xmlexprt.hxx"
-#include "global.hxx"
-#include "globstr.hrc"
-#include "scerrors.hxx"
+#include <global.hxx>
+#include <globstr.hrc>
+#include <scerrors.hxx>
 #include "XMLExportSharedData.hxx"
-#include "docuno.hxx"
-#include "sheetdata.hxx"
+#include <docuno.hxx>
+#include <sheetdata.hxx>
 #include "XMLCodeNameProvider.hxx"
 #include <docsh.hxx>
 #include <unonames.hxx>
@@ -85,7 +91,7 @@ uno::Reference <task::XStatusIndicator> ScXMLImportWrapper::GetStatusIndicator()
         SfxItemSet* pSet = pMedium->GetItemSet();
         if (pSet)
         {
-            const SfxUnoAnyItem* pItem = static_cast<const SfxUnoAnyItem*>(pSet->GetItem(SID_PROGRESS_STATUSBAR_CONTROL));
+            const SfxUnoAnyItem* pItem = pSet->GetItem<SfxUnoAnyItem>(SID_PROGRESS_STATUSBAR_CONTROL);
             if (pItem)
                 xStatusIndicator.set(pItem->GetValue(), uno::UNO_QUERY);
         }
@@ -93,11 +99,11 @@ uno::Reference <task::XStatusIndicator> ScXMLImportWrapper::GetStatusIndicator()
     return xStatusIndicator;
 }
 
-sal_uInt32 ScXMLImportWrapper::ImportFromComponent(const uno::Reference<uno::XComponentContext>& xContext,
-    uno::Reference<frame::XModel>& xModel, uno::Reference<xml::sax::XParser>& xParser,
+ErrCode ScXMLImportWrapper::ImportFromComponent(const uno::Reference<uno::XComponentContext>& xContext,
+    const uno::Reference<frame::XModel>& xModel, const uno::Reference<xml::sax::XParser>& xParser,
     xml::sax::InputSource& aParserInput,
     const OUString& sComponentName, const OUString& sDocName,
-    const OUString& sOldDocName, uno::Sequence<uno::Any>& aArgs,
+    const OUString& sOldDocName, const uno::Sequence<uno::Any>& aArgs,
     bool bMustBeSuccessfull)
 {
     uno::Reference < io::XStream > xDocStream;
@@ -119,7 +125,7 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(const uno::Reference<uno::XCo
                 sStream = sOldDocName;
             }
             else
-                return SCERR_NONE;
+                return ERRCODE_NONE;
 
             aParserInput.aInputStream = xDocStream->getInputStream();
             uno::Reference < beans::XPropertySet > xSet( xDocStream, uno::UNO_QUERY );
@@ -150,12 +156,11 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(const uno::Reference<uno::XCo
     OSL_ENSURE( xInfoSet.is(), "missing property set" );
     if( xInfoSet.is() )
     {
-        OUString sPropName("StreamName");
-        xInfoSet->setPropertyValue( sPropName, uno::makeAny( sStream ) );
+        xInfoSet->setPropertyValue( "StreamName", uno::makeAny( sStream ) );
     }
 
-    sal_uInt32 nReturn = SCERR_NONE;
-    rDoc.SetRangeOverflowType(0);   // is modified by the importer if limits are exceeded
+    ErrCode nReturn = ERRCODE_NONE;
+    rDoc.SetRangeOverflowType(ERRCODE_NONE);   // is modified by the importer if limits are exceeded
 
     uno::Reference<xml::sax::XDocumentHandler> xDocHandler(
         xContext->getServiceManager()->createInstanceWithArgumentsAndContext(
@@ -172,11 +177,16 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(const uno::Reference<uno::XCo
         pImporterImpl->SetPostProcessData(&maPostProcessData);
 
     // connect parser and filter
+    uno::Reference< xml::sax::XFastParser > xFastParser = dynamic_cast<
+                            xml::sax::XFastParser* >( xDocHandler.get() );
     xParser->setDocumentHandler( xDocHandler );
 
     try
     {
-        xParser->parseStream( aParserInput );
+        if( xFastParser.is() )
+            xFastParser->parseStream( aParserInput );
+        else
+            xParser->parseStream( aParserInput );
     }
     catch( const xml::sax::SAXParseException& r )
     {
@@ -201,7 +211,7 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(const uno::Reference<uno::XCo
             nReturn = ERRCODE_SFX_WRONGPASSWORD;
         else
         {
-            SAL_WARN("sc.filter", "SAX parse exception caught while importing: " << r.Message);
+            SAL_WARN("sc.filter", "SAX parse exception caught while importing: " << r);
 
             OUString sErr = OUString::number( r.LineNumber ) +
                           "," +
@@ -213,13 +223,13 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(const uno::Reference<uno::XCo
                                 (bMustBeSuccessfull ? SCERR_IMPORT_FILE_ROWCOL
                                                         : SCWARN_IMPORT_FILE_ROWCOL),
                                 sDocName, sErr,
-                                ERRCODE_BUTTON_OK | ERRCODE_MSG_ERROR );
+                                DialogMask::ButtonsOk | DialogMask::MessageError );
             }
             else
             {
                 OSL_ENSURE( bMustBeSuccessfull, "Warnings are not supported" );
                 nReturn = *new StringErrorInfo( SCERR_IMPORT_FORMAT_ROWCOL, sErr,
-                                 ERRCODE_BUTTON_OK | ERRCODE_MSG_ERROR );
+                                 DialogMask::ButtonsOk | DialogMask::MessageError );
             }
         }
     }
@@ -232,26 +242,26 @@ sal_uInt32 ScXMLImportWrapper::ImportFromComponent(const uno::Reference<uno::XCo
             nReturn = ERRCODE_SFX_WRONGPASSWORD;
         else
         {
-            SAL_WARN("sc.filter", "SAX exception caught while importing: " << r.Message);
+            SAL_WARN("sc.filter", "SAX exception caught while importing: " << r);
 
             nReturn = SCERR_IMPORT_FORMAT;
         }
     }
     catch( const packages::zip::ZipIOException& r )
     {
-        SAL_WARN("sc.filter", "Zip exception caught while importing: " << r.Message);
+        SAL_WARN("sc.filter", "Zip exception caught while importing: " << r);
 
         nReturn = ERRCODE_IO_BROKENPACKAGE;
     }
     catch( const io::IOException& r )
     {
-        SAL_WARN("sc.filter", "IO exception caught while importing: " << r.Message);
+        SAL_WARN("sc.filter", "IO exception caught while importing: " << r);
 
         nReturn = SCERR_IMPORT_OPEN;
     }
     catch( const uno::Exception& r )
     {
-        SAL_WARN("sc.filter", "uno exception caught while importing: " << r.Message);
+        SAL_WARN("sc.filter", "uno exception caught while importing: " << r);
 
         nReturn = SCERR_IMPORT_UNKNOWN;
     }
@@ -334,12 +344,12 @@ bool ScXMLImportWrapper::Import( ImportFlags nMode, ErrCode& rError )
     if (xStatusIndicator.is())
     {
         sal_Int32 nProgressRange(1000000);
-        xStatusIndicator->start(ScGlobal::GetRscString(STR_LOAD_DOC), nProgressRange);
+        xStatusIndicator->start(SvxResId(RID_SVXSTR_DOC_LOAD), nProgressRange);
         xInfoSet->setPropertyValue("ProgressRange", uno::makeAny(nProgressRange));
     }
 
     // Set base URI
-    OSL_ENSURE( pMedium, "There is no medium to get MediaDescriptor from!\n" );
+    OSL_ENSURE( pMedium, "There is no medium to get MediaDescriptor from!" );
     OUString aBaseURL = pMedium ? pMedium->GetBaseURL() : OUString();
     // needed for relative URLs, but in clipboard copy/paste there may be none
     SAL_INFO_IF(aBaseURL.isEmpty(), "sc.filter", "ScXMLImportWrapper: no base URL");
@@ -406,7 +416,7 @@ bool ScXMLImportWrapper::Import( ImportFlags nMode, ErrCode& rError )
     }
 
     // #i103539#: always read meta.xml for generator
-    sal_uInt32 nMetaRetval(0);
+    ErrCode nMetaRetval(ERRCODE_NONE);
     if (nMode & ImportFlags::Metadata)
     {
         uno::Sequence<uno::Any> aMetaArgs(1);
@@ -424,19 +434,19 @@ bool ScXMLImportWrapper::Import( ImportFlags nMode, ErrCode& rError )
         SAL_INFO( "sc.filter", "meta import end" );
     }
 
-    SvXMLGraphicHelper* pGraphicHelper = nullptr;
+    rtl::Reference<SvXMLGraphicHelper> xGraphicHelper;
     uno::Reference< document::XGraphicObjectResolver > xGrfContainer;
 
     uno::Reference< document::XEmbeddedObjectResolver > xObjectResolver;
-    SvXMLEmbeddedObjectHelper *pObjectHelper = nullptr;
+    rtl::Reference<SvXMLEmbeddedObjectHelper> xObjectHelper;
 
     if( xStorage.is() )
     {
-        pGraphicHelper = SvXMLGraphicHelper::Create( xStorage, SvXMLGraphicHelperMode::Read );
-        xGrfContainer = pGraphicHelper;
+        xGraphicHelper = SvXMLGraphicHelper::Create( xStorage, SvXMLGraphicHelperMode::Read );
+        xGrfContainer = xGraphicHelper.get();
 
-        pObjectHelper = SvXMLEmbeddedObjectHelper::Create(xStorage, mrDocShell, SvXMLEmbeddedObjectHelperMode::Read, false);
-        xObjectResolver = pObjectHelper;
+        xObjectHelper = SvXMLEmbeddedObjectHelper::Create(xStorage, mrDocShell, SvXMLEmbeddedObjectHelperMode::Read);
+        xObjectResolver = xObjectHelper.get();
     }
     uno::Sequence<uno::Any> aStylesArgs(4);
     uno::Any* pStylesArgs = aStylesArgs.getArray();
@@ -445,7 +455,7 @@ bool ScXMLImportWrapper::Import( ImportFlags nMode, ErrCode& rError )
     pStylesArgs[2] <<= xStatusIndicator;
     pStylesArgs[3] <<= xObjectResolver;
 
-    sal_uInt32 nSettingsRetval(0);
+    ErrCode nSettingsRetval(ERRCODE_NONE);
     if (nMode & ImportFlags::Settings)
     {
         //  Settings must be loaded first because of the printer setting,
@@ -466,7 +476,7 @@ bool ScXMLImportWrapper::Import( ImportFlags nMode, ErrCode& rError )
         SAL_INFO( "sc.filter", "settings import end" );
     }
 
-    sal_uInt32 nStylesRetval(0);
+    ErrCode nStylesRetval(ERRCODE_NONE);
     if (nMode & ImportFlags::Styles)
     {
         SAL_INFO( "sc.filter", "styles import start" );
@@ -480,7 +490,7 @@ bool ScXMLImportWrapper::Import( ImportFlags nMode, ErrCode& rError )
         SAL_INFO( "sc.filter", "styles import end" );
     }
 
-    sal_uInt32 nDocRetval(0);
+    ErrCode nDocRetval(ERRCODE_NONE);
     if (nMode & ImportFlags::Content)
     {
         if (mrDocShell.GetCreateMode() == SfxObjectCreateMode::INTERNAL)
@@ -505,11 +515,13 @@ bool ScXMLImportWrapper::Import( ImportFlags nMode, ErrCode& rError )
 
         SAL_INFO( "sc.filter", "content import end" );
     }
-    if( pGraphicHelper )
-        SvXMLGraphicHelper::Destroy( pGraphicHelper );
+    if( xGraphicHelper.is() )
+        xGraphicHelper->dispose();
+    xGraphicHelper.clear();
 
-    if( pObjectHelper )
-        SvXMLEmbeddedObjectHelper::Destroy( pObjectHelper );
+    if( xObjectHelper.is() )
+        xObjectHelper->dispose();
+    xObjectHelper.clear();
 
     if (xStatusIndicator.is())
         xStatusIndicator->end();
@@ -576,7 +588,7 @@ bool ScXMLImportWrapper::Import( ImportFlags nMode, ErrCode& rError )
     return bRet;//!bStylesOnly ? bDocRetval : bStylesRetval;
 }
 
-static bool lcl_HasValidStream(ScDocument& rDoc)
+static bool lcl_HasValidStream(const ScDocument& rDoc)
 {
     SfxObjectShell* pObjSh = rDoc.GetDocumentShell();
     if ( pObjSh->IsDocShared() )
@@ -596,10 +608,10 @@ static bool lcl_HasValidStream(ScDocument& rDoc)
 }
 
 bool ScXMLImportWrapper::ExportToComponent(const uno::Reference<uno::XComponentContext>& xContext,
-    uno::Reference<frame::XModel>& xModel, uno::Reference<xml::sax::XWriter>& xWriter,
-    uno::Sequence<beans::PropertyValue>& aDescriptor, const OUString& sName,
+    const uno::Reference<frame::XModel>& xModel, const uno::Reference<xml::sax::XWriter>& xWriter,
+    const uno::Sequence<beans::PropertyValue>& aDescriptor, const OUString& sName,
     const OUString& sMediaType, const OUString& sComponentName,
-    uno::Sequence<uno::Any>& aArgs, ScMySharedData*& pSharedData)
+    const uno::Sequence<uno::Any>& aArgs, ScMySharedData*& pSharedData)
 {
     bool bRet(false);
     uno::Reference<io::XOutputStream> xOut;
@@ -619,10 +631,9 @@ bool ScXMLImportWrapper::ExportToComponent(const uno::Reference<uno::XComponentC
         if (xSet.is())
         {
             xSet->setPropertyValue("MediaType", uno::makeAny(sMediaType));
-            OUString aUseCommonPassPropName("UseCommonStoragePasswordEncryption");
 
             // advise storage impl to use common encryption
-            xSet->setPropertyValue( aUseCommonPassPropName, uno::makeAny(true) );
+            xSet->setPropertyValue( "UseCommonStoragePasswordEncryption", uno::makeAny(true) );
         }
 
         xOut = xStream->getOutputStream();
@@ -635,8 +646,7 @@ bool ScXMLImportWrapper::ExportToComponent(const uno::Reference<uno::XComponentC
     OSL_ENSURE( xInfoSet.is(), "missing property set" );
     if( xInfoSet.is() )
     {
-        OUString sPropName("StreamName");
-        xInfoSet->setPropertyValue( sPropName, uno::makeAny( sName ) );
+        xInfoSet->setPropertyValue( "StreamName", uno::makeAny( sName ) );
     }
 
     xWriter->setOutputStream( xOut );
@@ -696,8 +706,7 @@ bool ScXMLImportWrapper::ExportToComponent(const uno::Reference<uno::XComponentC
             {
                 SCTAB nTabCount = rDoc.GetTableCount();
                 for (SCTAB nTab=0; nTab<nTabCount; nTab++)
-                    if (rDoc.IsStreamValid(nTab))
-                        rDoc.SetStreamValid(nTab, false);
+                    rDoc.SetStreamValid(nTab, false);
             }
         }
         else
@@ -739,10 +748,9 @@ bool ScXMLImportWrapper::Export(bool bStylesOnly)
     if (pMedium)
         sFileName = pMedium->GetName();
     SfxObjectShell* pObjSh = rDoc.GetDocumentShell();
-    uno::Sequence<beans::PropertyValue> aDescriptor(1);
-    beans::PropertyValue* pProps = aDescriptor.getArray();
-    pProps[0].Name = "FileName";
-    pProps[0].Value <<= sFileName;
+    uno::Sequence<beans::PropertyValue> aDescriptor( comphelper::InitPropertySequence({
+            { "FileName", uno::Any(sFileName) }
+        }));
 
     /** property map for export info set */
     comphelper::PropertyMapEntry const aExportInfoMap[] =
@@ -778,7 +786,7 @@ bool ScXMLImportWrapper::Export(bool bStylesOnly)
         const OUString sTargetStorage("TargetStorage");
         xInfoSet->setPropertyValue( sTargetStorage, uno::Any( xStorage ) );
 
-        OSL_ENSURE( pMedium, "There is no medium to get MediaDescriptor from!\n" );
+        OSL_ENSURE( pMedium, "There is no medium to get MediaDescriptor from!" );
         OUString aBaseURL = pMedium ? pMedium->GetBaseURL( true ) : OUString();
         OUString sPropName("BaseURI");
         xInfoSet->setPropertyValue( sPropName, uno::makeAny( aBaseURL ) );
@@ -856,21 +864,21 @@ bool ScXMLImportWrapper::Export(bool bStylesOnly)
         }
 
         uno::Reference< document::XEmbeddedObjectResolver > xObjectResolver;
-        SvXMLEmbeddedObjectHelper *pObjectHelper = nullptr;
+        rtl::Reference<SvXMLEmbeddedObjectHelper> xObjectHelper;
 
         uno::Reference< document::XGraphicObjectResolver > xGrfContainer;
-        SvXMLGraphicHelper* pGraphicHelper = nullptr;
+        rtl::Reference<SvXMLGraphicHelper> xGraphicHelper;
 
         if( xStorage.is() )
         {
-            pGraphicHelper = SvXMLGraphicHelper::Create( xStorage, SvXMLGraphicHelperMode::Write, false );
-            xGrfContainer = pGraphicHelper;
+            xGraphicHelper = SvXMLGraphicHelper::Create( xStorage, SvXMLGraphicHelperMode::Write, false );
+            xGrfContainer = xGraphicHelper.get();
         }
 
         if( pObjSh )
         {
-            pObjectHelper = SvXMLEmbeddedObjectHelper::Create( xStorage, *pObjSh, SvXMLEmbeddedObjectHelperMode::Write, false );
-            xObjectResolver = pObjectHelper;
+            xObjectHelper = SvXMLEmbeddedObjectHelper::Create( xStorage, *pObjSh, SvXMLEmbeddedObjectHelperMode::Write );
+            xObjectResolver = xObjectHelper.get();
         }
 
         // styles export
@@ -920,11 +928,13 @@ bool ScXMLImportWrapper::Export(bool bStylesOnly)
             SAL_INFO( "sc.filter", "content export end" );
         }
 
-        if( pGraphicHelper )
-            SvXMLGraphicHelper::Destroy( pGraphicHelper );
+        if( xGraphicHelper )
+            xGraphicHelper->dispose();
+        xGraphicHelper.clear();
 
-        if( pObjectHelper )
-            SvXMLEmbeddedObjectHelper::Destroy( pObjectHelper );
+        if( xObjectHelper )
+            xObjectHelper->dispose();
+        xObjectHelper.clear();
 
         // settings export
 
