@@ -19,8 +19,8 @@
 
 #include <svl/urlbmk.hxx>
 
-#include "lnktrans.hxx"
-#include "scmod.hxx"
+#include <lnktrans.hxx>
+#include <scmod.hxx>
 
 using namespace com::sun::star;
 
@@ -65,11 +65,6 @@ bool ScLinkTransferObj::GetData(
     return bOK;
 }
 
-void ScLinkTransferObj::ObjectReleased()
-{
-    TransferableHelper::ObjectReleased();
-}
-
 void ScLinkTransferObj::DragFinished( sal_Int8 nDropAction )
 {
     ScModule* pScMod = SC_MOD();
