@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/eeitem.hxx>
 #include <editeng/justifyitem.hxx>
 
@@ -31,46 +31,50 @@
 #include <sot/storage.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/virdev.hxx>
-#include <osl/mutex.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/docfile.hxx>
 
-#include "transobj.hxx"
-#include "document.hxx"
-#include "viewopti.hxx"
-#include "editutil.hxx"
-#include "impex.hxx"
-#include "formulacell.hxx"
-#include "printfun.hxx"
-#include "docfunc.hxx"
-#include "scmod.hxx"
-#include "dragdata.hxx"
-#include "clipdata.hxx"
-#include "clipparam.hxx"
+#include <transobj.hxx>
+#include <patattr.hxx>
+#include <cellvalue.hxx>
+#include <cellform.hxx>
+#include <document.hxx>
+#include <viewopti.hxx>
+#include <editutil.hxx>
+#include <impex.hxx>
+#include <formulacell.hxx>
+#include <printfun.hxx>
+#include <docfunc.hxx>
+#include <scmod.hxx>
+#include <dragdata.hxx>
+#include <clipdata.hxx>
+#include <clipparam.hxx>
 
 #include <editeng/paperinf.hxx>
 #include <editeng/sizeitem.hxx>
+#include <formula/errorcodes.hxx>
 #include <svx/algitem.hxx>
 #include <svl/intitem.hxx>
 #include <svl/zforlist.hxx>
-#include "docsh.hxx"
-#include "markdata.hxx"
-#include "stlpool.hxx"
-#include "viewdata.hxx"
-#include "dociter.hxx"
-#include "cellsuno.hxx"
-#include "stringutil.hxx"
-#include "formulaiter.hxx"
+#include <docsh.hxx>
+#include <markdata.hxx>
+#include <stlpool.hxx>
+#include <viewdata.hxx>
+#include <dociter.hxx>
+#include <cellsuno.hxx>
+#include <stringutil.hxx>
+#include <formulaiter.hxx>
 #include <gridwin.hxx>
 
 using namespace com::sun::star;
 
-#define SCTRANS_TYPE_IMPEX          SotClipboardFormatId::STRING
-#define SCTRANS_TYPE_EDIT_RTF       SotClipboardFormatId::BITMAP
-#define SCTRANS_TYPE_EDIT_BIN       SotClipboardFormatId::GDIMETAFILE
-#define SCTRANS_TYPE_EMBOBJ         SotClipboardFormatId::PRIVATE
+constexpr sal_uInt32 SCTRANS_TYPE_IMPEX              = 1;
+constexpr sal_uInt32 SCTRANS_TYPE_EDIT_RTF           = 2;
+constexpr sal_uInt32 SCTRANS_TYPE_EDIT_BIN           = 3;
+constexpr sal_uInt32 SCTRANS_TYPE_EMBOBJ             = 4;
+constexpr sal_uInt32 SCTRANS_TYPE_EDIT_ODF_TEXT_FLAT = 5;
 
-void ScTransferObj::GetAreaSize( ScDocument* pDoc, SCTAB nTab1, SCTAB nTab2, SCROW& nRow, SCCOL& nCol )
+void ScTransferObj::GetAreaSize( const ScDocument* pDoc, SCTAB nTab1, SCTAB nTab2, SCROW& nRow, SCCOL& nCol )
 {
     SCCOL nMaxCol = 0;
     SCROW nMaxRow = 0;
@@ -92,13 +96,13 @@ void ScTransferObj::GetAreaSize( ScDocument* pDoc, SCTAB nTab1, SCTAB nTab2, SCR
 }
 
 void ScTransferObj::PaintToDev( OutputDevice* pDev, ScDocument* pDoc, double nPrintFactor,
-                                const ScRange& rBlock, bool bMetaFile )
+                                const ScRange& rBlock )
 {
     if (!pDoc)
         return;
 
     Point aPoint;
-    Rectangle aBound( aPoint, pDev->GetOutputSize() );      //! use size from clip area?
+    tools::Rectangle aBound( aPoint, pDev->GetOutputSize() );      //! use size from clip area?
 
     ScViewData aViewData(nullptr,nullptr);
     aViewData.InitData( pDoc );
@@ -107,7 +111,7 @@ void ScTransferObj::PaintToDev( OutputDevice* pDev, ScDocument* pDoc, double nPr
     aViewData.SetScreen( rBlock.aStart.Col(), rBlock.aStart.Row(),
                             rBlock.aEnd.Col(), rBlock.aEnd.Row() );
 
-    ScPrintFunc::DrawToDev( pDoc, pDev, nPrintFactor, aBound, &aViewData, bMetaFile );
+    ScPrintFunc::DrawToDev( pDoc, pDev, nPrintFactor, aBound, &aViewData, false/*bMetaFile*/ );
 }
 
 ScTransferObj::ScTransferObj( ScDocument* pClipDoc, const TransferableObjectDescriptor& rDesc ) :
@@ -116,7 +120,9 @@ ScTransferObj::ScTransferObj( ScDocument* pClipDoc, const TransferableObjectDesc
     aObjDesc( rDesc ),
     nDragHandleX( 0 ),
     nDragHandleY( 0 ),
-    nDragSourceFlags( 0 ),
+    nSourceCursorX( MAXCOL + 1 ),
+    nSourceCursorY( MAXROW + 1 ),
+    nDragSourceFlags( ScDragSrc::Undefined ),
     bDragWasInternal( false ),
     bUsedForLink( false ),
     bUseInApi( false )
@@ -168,7 +174,7 @@ ScTransferObj::ScTransferObj( ScDocument* pClipDoc, const TransferableObjectDesc
     aBlock = ScRange( nCol1, nRow1, nTab1, nCol2, nRow2, nTab2 );
     nVisibleTab = nTab1;    // valid table as default
 
-    Rectangle aMMRect = pDoc->GetMMRect( nCol1,nRow1, nCol2,nRow2, nTab1 );
+    tools::Rectangle aMMRect = pDoc->GetMMRect( nCol1,nRow1, nCol2,nRow2, nTab1 );
     aObjDesc.maSize = aMMRect.GetSize();
     PrepareOLE( aObjDesc );
 }
@@ -191,9 +197,9 @@ ScTransferObj::~ScTransferObj()
 
     delete pDoc;        // ScTransferObj is owner of clipboard document
 
-    aDocShellRef.Clear();   // before releasing the mutex
+    aDocShellRef.clear();   // before releasing the mutex
 
-    aDrawPersistRef.Clear();                    // after the model
+    aDrawPersistRef.clear();                    // after the model
 
 }
 
@@ -232,10 +238,14 @@ void ScTransferObj::AddSupportedFormats()
     AddFormat( SotClipboardFormatId::LINK );
     AddFormat( SotClipboardFormatId::DIF );
     AddFormat( SotClipboardFormatId::STRING );
+    AddFormat( SotClipboardFormatId::STRING_TSVC );
 
     AddFormat( SotClipboardFormatId::RTF );
+    AddFormat( SotClipboardFormatId::RICHTEXT );
     if ( aBlock.aStart == aBlock.aEnd )
-        AddFormat( SotClipboardFormatId::EDITENGINE );
+    {
+        AddFormat( SotClipboardFormatId::EDITENGINE_ODF_TEXT_FLAT );
+    }
 }
 
 bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUString& /*rDestDoc*/ )
@@ -247,10 +257,10 @@ bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUSt
     {
         if ( nFormat == SotClipboardFormatId::LINKSRCDESCRIPTOR || nFormat == SotClipboardFormatId::OBJECTDESCRIPTOR )
         {
-            bOK = SetTransferableObjectDescriptor( aObjDesc, rFlavor );
+            bOK = SetTransferableObjectDescriptor( aObjDesc );
         }
-        else if ( ( nFormat == SotClipboardFormatId::RTF || nFormat == SotClipboardFormatId::EDITENGINE ) &&
-                        aBlock.aStart == aBlock.aEnd )
+        else if ( ( nFormat == SotClipboardFormatId::RTF || nFormat == SotClipboardFormatId::RICHTEXT ||
+            nFormat == SotClipboardFormatId::EDITENGINE_ODF_TEXT_FLAT ) && aBlock.aStart == aBlock.aEnd )
         {
             //  RTF from a single cell is handled by EditEngine
 
@@ -261,24 +271,31 @@ bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUSt
 
             const ScPatternAttr* pPattern = pDoc->GetPattern( nCol, nRow, nTab );
             ScTabEditEngine aEngine( *pPattern, pDoc->GetEditPool() );
-            if (pDoc->GetCellType(aPos) == CELLTYPE_EDIT)
+            ScRefCellValue aCell(*pDoc, aPos);
+            if (aCell.meType == CELLTYPE_EDIT)
             {
-                const EditTextObject* pObj = pDoc->GetEditText(aPos);
-                if (pObj)
-                    aEngine.SetText(*pObj);
+                const EditTextObject* pObj = aCell.mpEditText;
+                aEngine.SetText(*pObj);
             }
             else
             {
-                OUString aText = pDoc->GetString(nCol, nRow, nTab);
+                SvNumberFormatter* pFormatter = pDoc->GetFormatTable();
+                sal_uInt32 nNumFmt = pPattern->GetNumberFormat(pFormatter);
+                OUString aText;
+                Color* pColor;
+                ScCellFormat::GetString(aCell, nNumFmt, aText, &pColor, *pFormatter, pDoc);
                 if (!aText.isEmpty())
                     aEngine.SetText(aText);
             }
 
             bOK = SetObject( &aEngine,
-                            (nFormat == SotClipboardFormatId::RTF) ? SCTRANS_TYPE_EDIT_RTF : SCTRANS_TYPE_EDIT_BIN,
-                            rFlavor );
+                    ((nFormat == SotClipboardFormatId::RTF) ? SCTRANS_TYPE_EDIT_RTF :
+                     ((nFormat == SotClipboardFormatId::EDITENGINE_ODF_TEXT_FLAT) ?
+                      SCTRANS_TYPE_EDIT_ODF_TEXT_FLAT : SCTRANS_TYPE_EDIT_BIN)),
+                    rFlavor );
         }
-        else if ( ScImportExport::IsFormatSupported( nFormat ) || nFormat == SotClipboardFormatId::RTF )
+        else if ( ScImportExport::IsFormatSupported( nFormat ) || nFormat == SotClipboardFormatId::RTF
+            || nFormat == SotClipboardFormatId::RICHTEXT )
         {
             //  if this transfer object was used to create a DDE link, filtered rows
             //  have to be included for subsequent calls (to be consistent with link data)
@@ -287,7 +304,8 @@ bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUSt
 
             bool bIncludeFiltered = pDoc->IsCutMode() || bUsedForLink;
 
-            bool bReduceBlockFormat = nFormat == SotClipboardFormatId::HTML || nFormat == SotClipboardFormatId::RTF;
+            bool bReduceBlockFormat = nFormat == SotClipboardFormatId::HTML || nFormat == SotClipboardFormatId::RTF
+                || nFormat == SotClipboardFormatId::RICHTEXT;
             ScRange aReducedBlock = aBlock;
             if (bReduceBlockFormat && (aBlock.aEnd.Col() == MAXCOL || aBlock.aEnd.Row() == MAXROW) && aBlock.aStart.Tab() == aBlock.aEnd.Tab())
             {
@@ -302,10 +320,27 @@ bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUSt
             }
 
             ScImportExport aObj( pDoc, aReducedBlock );
-            ScExportTextOptions aTextOptions(ScExportTextOptions::None, 0, true);
-            if ( bUsedForLink )
+            // Plain text ("Unformatted text") may contain embedded tabs and
+            // line breaks but is not enclosed in quotes. Which makes it
+            // unsuitable for multiple cells, especially if one of them is
+            // multi-line, but otherwise is expected behavior for plain text.
+            // For multiple cells replace embedded line breaks (and tabs) with
+            // space character, otherwise pasting would yield odd results.
+            /* XXX: it's debatable whether this is actually expected, but
+             * there's no way to satisfy all possible requirements when
+             * copy/pasting unformatted text. */
+            const bool bPlainMulti = (nFormat == SotClipboardFormatId::STRING &&
+                    aReducedBlock.aStart != aReducedBlock.aEnd);
+            // Add quotes only for STRING_TSVC.
+            /* TODO: a possible future STRING_TSV should not contain embedded
+             * line breaks nor tab (separator) characters and not be quoted.
+             * A possible STRING_CSV should. */
+            ScExportTextOptions aTextOptions( ScExportTextOptions::None, 0,
+                    (nFormat == SotClipboardFormatId::STRING_TSVC));
+            if ( bPlainMulti || bUsedForLink )
             {
-                // For a DDE link, convert line breaks and separators to space.
+                // For a DDE link or plain text multiple cells, convert line
+                // breaks and separators to space.
                 aTextOptions.meNewlineConversion = ScExportTextOptions::ToSpace;
                 aTextOptions.mcSeparatorConvertTo = ' ';
                 aTextOptions.mbAddQuotes = false;
@@ -334,15 +369,15 @@ bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUSt
         }
         else if ( nFormat == SotClipboardFormatId::BITMAP || nFormat == SotClipboardFormatId::PNG )
         {
-            Rectangle aMMRect = pDoc->GetMMRect( aBlock.aStart.Col(), aBlock.aStart.Row(),
+            tools::Rectangle aMMRect = pDoc->GetMMRect( aBlock.aStart.Col(), aBlock.aStart.Row(),
                                                  aBlock.aEnd.Col(), aBlock.aEnd.Row(),
                                                  aBlock.aStart.Tab() );
             ScopedVclPtrInstance< VirtualDevice > pVirtDev;
-            pVirtDev->SetOutputSizePixel( pVirtDev->LogicToPixel( aMMRect.GetSize(), MAP_100TH_MM ) );
+            pVirtDev->SetOutputSizePixel(pVirtDev->LogicToPixel(aMMRect.GetSize(), MapMode(MapUnit::Map100thMM)));
 
-            PaintToDev( pVirtDev, pDoc, 1.0, aBlock, false );
+            PaintToDev( pVirtDev, pDoc, 1.0, aBlock );
 
-            pVirtDev->SetMapMode( MapMode( MAP_PIXEL ) );
+            pVirtDev->SetMapMode( MapMode( MapUnit::MapPixel ) );
             Bitmap aBmp = pVirtDev->GetBitmap( Point(), pVirtDev->GetOutputSize() );
             bOK = SetBitmapEx( aBmp, rFlavor );
         }
@@ -354,13 +389,13 @@ bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUSt
             // created.
             InitDocShell(false);
 
-            SfxObjectShell* pEmbObj = aDocShellRef;
+            SfxObjectShell* pEmbObj = aDocShellRef.get();
 
             // like SvEmbeddedTransfer::GetData:
             GDIMetaFile     aMtf;
             ScopedVclPtrInstance< VirtualDevice > pVDev;
             MapMode         aMapMode( pEmbObj->GetMapUnit() );
-            Rectangle       aVisArea( pEmbObj->GetVisArea( ASPECT_CONTENT ) );
+            tools::Rectangle       aVisArea( pEmbObj->GetVisArea( ASPECT_CONTENT ) );
 
             pVDev->EnableOutput( false );
             pVDev->SetMapMode( aMapMode );
@@ -373,7 +408,7 @@ bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUSt
             aMtf.Stop();
             aMtf.WindStart();
 
-            bOK = SetGDIMetaFile( aMtf, rFlavor );
+            bOK = SetGDIMetaFile( aMtf );
         }
         else if ( nFormat == SotClipboardFormatId::EMBED_SOURCE )
         {
@@ -381,14 +416,14 @@ bool ScTransferObj::GetData( const datatransfer::DataFlavor& rFlavor, const OUSt
             // #i123405# Do limit visual size calculation to PageSize
             InitDocShell(true);         // set aDocShellRef
 
-            SfxObjectShell* pEmbObj = aDocShellRef;
+            SfxObjectShell* pEmbObj = aDocShellRef.get();
             bOK = SetObject( pEmbObj, SCTRANS_TYPE_EMBOBJ, rFlavor );
         }
     }
     return bOK;
 }
 
-bool ScTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* pUserObject, SotClipboardFormatId nUserObjectId,
+bool ScTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* pUserObject, sal_uInt32 nUserObjectId,
                                         const datatransfer::DataFlavor& rFlavor )
 {
     // called from SetObject, put data into stream
@@ -435,6 +470,17 @@ bool ScTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* p
             }
             break;
 
+        case SCTRANS_TYPE_EDIT_ODF_TEXT_FLAT:
+            {
+                ScTabEditEngine* pEngine = static_cast<ScTabEditEngine*>(pUserObject);
+                if ( nUserObjectId == SCTRANS_TYPE_EDIT_ODF_TEXT_FLAT )
+                {
+                    pEngine->Write( *rxOStm, EE_FORMAT_XML );
+                    bRet = ( rxOStm->GetError() == ERRCODE_NONE );
+                }
+            }
+            break;
+
         case SCTRANS_TYPE_EMBOBJ:
             {
                 // TODO/MBA: testing
@@ -449,7 +495,7 @@ bool ScTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* p
 
                 // mba: no relative URLs for clipboard!
                 SfxMedium aMedium( xWorkStore, OUString() );
-                bRet = pEmbObj->DoSaveObjectAs( aMedium, false );
+                pEmbObj->DoSaveObjectAs( aMedium, false );
                 pEmbObj->DoSaveCompleted();
 
                 uno::Reference< embed::XTransactedObject > xTransact( xWorkStore, uno::UNO_QUERY );
@@ -481,7 +527,7 @@ bool ScTransferObj::WriteObject( tools::SvRef<SotStorageStream>& rxOStm, void* p
 void ScTransferObj::ObjectReleased()
 {
     ScModule* pScMod = SC_MOD();
-    if ( pScMod->GetClipData().pCellClipboard == this )
+    if ( pScMod && pScMod->GetClipData().pCellClipboard == this )
         pScMod->SetClipObject( nullptr, nullptr );
 
     TransferableHelper::ObjectReleased();
@@ -489,7 +535,7 @@ void ScTransferObj::ObjectReleased()
 
 void ScTransferObj::DragFinished( sal_Int8 nDropAction )
 {
-    if ( nDropAction == DND_ACTION_MOVE && !bDragWasInternal && !(nDragSourceFlags & SC_DROP_NAVIGATOR) )
+    if ( nDropAction == DND_ACTION_MOVE && !bDragWasInternal && !(nDragSourceFlags & ScDragSrc::Navigator) )
     {
         //  move: delete source data
         ScDocShell* pSourceSh = GetSourceDocShell();
@@ -517,6 +563,19 @@ void ScTransferObj::SetDragHandlePos( SCCOL nX, SCROW nY )
     nDragHandleY = nY;
 }
 
+void ScTransferObj::SetSourceCursorPos( SCCOL nX, SCROW nY )
+{
+    nSourceCursorX = nX;
+    nSourceCursorY = nY;
+}
+
+bool ScTransferObj::WasSourceCursorInSelection() const
+{
+    return
+        nSourceCursorX >= aBlock.aStart.Col() && nSourceCursorX <= aBlock.aEnd.Col() &&
+        nSourceCursorY >= aBlock.aStart.Row() && nSourceCursorY <= aBlock.aEnd.Row();
+}
+
 void ScTransferObj::SetVisibleTab( SCTAB nNew )
 {
     nVisibleTab = nNew;
@@ -534,7 +593,7 @@ void ScTransferObj::SetDragSource( ScDocShell* pSourceShell, const ScMarkData& r
     xDragSourceRanges = new ScCellRangesObj( pSourceShell, aRanges );
 }
 
-void ScTransferObj::SetDragSourceFlags( sal_uInt16 nFlags )
+void ScTransferObj::SetDragSourceFlags(ScDragSrc nFlags)
 {
     nDragSourceFlags = nFlags;
 }
@@ -585,7 +644,7 @@ ScMarkData ScTransferObj::GetSourceMarkData()
 
 void ScTransferObj::InitDocShell(bool bLimitToPageSize)
 {
-    if ( !aDocShellRef.Is() )
+    if ( !aDocShellRef.is() )
     {
         ScDocShell* pDocSh = new ScDocShell;
         aDocShellRef = pDocSh;      // ref must be there before InitNew
@@ -600,7 +659,7 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
 
         OUString aTabName;
         pDoc->GetName( aBlock.aStart.Tab(), aTabName );
-        rDestDoc.RenameTab( 0, aTabName, false );          // no UpdateRef (empty)
+        rDestDoc.RenameTab( 0, aTabName );
 
         rDestDoc.CopyStdStylesFrom( pDoc );
 
@@ -661,15 +720,15 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
         Size aPaperSize = SvxPaperInfo::GetPaperSize( PAPER_A4 );       // Twips
         ScStyleSheetPool* pStylePool = pDoc->GetStyleSheetPool();
         OUString aStyleName = pDoc->GetPageStyle( aBlock.aStart.Tab() );
-        SfxStyleSheetBase* pStyleSheet = pStylePool->Find( aStyleName, SFX_STYLE_FAMILY_PAGE );
+        SfxStyleSheetBase* pStyleSheet = pStylePool->Find( aStyleName, SfxStyleFamily::Page );
         if (pStyleSheet)
         {
             const SfxItemSet& rSourceSet = pStyleSheet->GetItemSet();
-            aPaperSize = static_cast<const SvxSizeItem&>( rSourceSet.Get(ATTR_PAGE_SIZE)).GetSize();
+            aPaperSize = rSourceSet.Get(ATTR_PAGE_SIZE).GetSize();
 
-            //  CopyStyleFrom kopiert SetItems mit richtigem Pool
+            // CopyStyleFrom copies SetItems with correct pool
             ScStyleSheetPool* pDestPool = rDestDoc.GetStyleSheetPool();
-            pDestPool->CopyStyleFrom( pStylePool, aStyleName, SFX_STYLE_FAMILY_PAGE );
+            pDestPool->CopyStyleFrom( pStylePool, aStyleName, SfxStyleFamily::Page );
         }
 
         ScViewData aViewData( pDocSh, nullptr );
@@ -715,7 +774,7 @@ void ScTransferObj::InitDocShell(bool bLimitToPageSize)
 
 //      pDocSh->SetVisAreaSize( Size(nSizeX,nSizeY) );
 
-        Rectangle aNewArea( Point(nPosX,nPosY), Size(nSizeX,nSizeY) );
+        tools::Rectangle aNewArea( Point(nPosX,nPosY), Size(nSizeX,nSizeY) );
         //TODO/LATER: why twice?!
         //pDocSh->SvInPlaceObject::SetVisArea( aNewArea );
         pDocSh->SetVisArea( aNewArea );
@@ -732,7 +791,7 @@ SfxObjectShell* ScTransferObj::SetDrawClipDoc( bool bAnyOle )
 {
     // update ScGlobal::xDrawClipDocShellRef
 
-    ScGlobal::xDrawClipDocShellRef.Clear();
+    ScGlobal::xDrawClipDocShellRef.clear();
     if (bAnyOle)
     {
         ScGlobal::xDrawClipDocShellRef = new ScDocShell(SfxModelFlags::EMBEDDED_OBJECT | SfxModelFlags::DISABLE_EMBEDDED_SCRIPTS); // there must be a ref
@@ -741,19 +800,18 @@ SfxObjectShell* ScTransferObj::SetDrawClipDoc( bool bAnyOle )
     }
     else
     {
-        ScGlobal::xDrawClipDocShellRef.Clear();
+        ScGlobal::xDrawClipDocShellRef.clear();
         return nullptr;
     }
 }
 
 void ScTransferObj::StripRefs( ScDocument* pDoc,
                     SCCOL nStartX, SCROW nStartY, SCCOL nEndX, SCROW nEndY,
-                    ScDocument* pDestDoc, SCCOL nSubX, SCROW nSubY )
+                    ScDocument* pDestDoc )
 {
     if (!pDestDoc)
     {
         pDestDoc = pDoc;
-        OSL_ENSURE(nSubX==0&&nSubY==0, "can't move within the document");
     }
 
     //  In a clipboard doc the data don't have to be on the first sheet
@@ -791,18 +849,18 @@ void ScTransferObj::StripRefs( ScDocument* pDoc,
         }
         if (bOut)
         {
-            SCCOL nCol = aIter.GetPos().Col() - nSubX;
-            SCROW nRow = aIter.GetPos().Row() - nSubY;
+            SCCOL nCol = aIter.GetPos().Col();
+            SCROW nRow = aIter.GetPos().Row();
 
-            sal_uInt16 nErrCode = pFCell->GetErrCode();
+            FormulaError nErrCode = pFCell->GetErrCode();
             ScAddress aPos(nCol, nRow, nDestTab);
-            if (nErrCode)
+            if (nErrCode != FormulaError::NONE)
             {
                 if ( static_cast<const SvxHorJustifyItem*>(pDestDoc->GetAttr(
                         nCol,nRow,nDestTab, ATTR_HOR_JUSTIFY))->GetValue() ==
-                        SVX_HOR_JUSTIFY_STANDARD )
+                        SvxCellHorJustify::Standard )
                     pDestDoc->ApplyAttr( nCol,nRow,nDestTab,
-                            SvxHorJustifyItem(SVX_HOR_JUSTIFY_RIGHT, ATTR_HOR_JUSTIFY) );
+                            SvxHorJustifyItem(SvxCellHorJustify::Right, ATTR_HOR_JUSTIFY) );
 
                 ScSetStringParam aParam;
                 aParam.setTextInput();
@@ -842,7 +900,7 @@ const css::uno::Sequence< sal_Int8 >& ScTransferObj::getUnoTunnelId()
     return theScTransferUnoTunnelId::get().getSeq();
 }
 
-sal_Int64 SAL_CALL ScTransferObj::getSomething( const css::uno::Sequence< sal_Int8 >& rId ) throw( css::uno::RuntimeException, std::exception )
+sal_Int64 SAL_CALL ScTransferObj::getSomething( const css::uno::Sequence< sal_Int8 >& rId )
 {
     sal_Int64 nRet;
     if( ( rId.getLength() == 16 ) &&
