@@ -17,32 +17,55 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #undef SC_DLLIMPLEMENTATION
 
 #include "scdlgfact.hxx"
-#include "sal/types.h"
+#include <corodlg.hxx>
+#include <condformatmgr.hxx>
+#include <dapitype.hxx>
+#include <dapidata.hxx>
+#include <datafdlg.hxx>
+#include <delcodlg.hxx>
+#include <delcldlg.hxx>
+#include <dpgroupdlg.hxx>
+#include <filldlg.hxx>
+#include <groupdlg.hxx>
+#include <linkarea.hxx>
+#include <lbseldlg.hxx>
+#include <inscldlg.hxx>
+#include <instbdlg.hxx>
+#include <inscodlg.hxx>
+#include <mtrindlg.hxx>
+#include <mvtabdlg.hxx>
+#include <namecrea.hxx>
+#include <namepast.hxx>
+#include <pfiltdlg.hxx>
+#include <pvfundlg.hxx>
+#include <shtabdlg.hxx>
+#include <scendlg.hxx>
+#include <scuiasciiopt.hxx>
+#include <scuiautofmt.hxx>
+#include <scuiimoptdlg.hxx>
+#include <sortdlg.hxx>
+#include <strindlg.hxx>
+#include <tabbgcolordlg.hxx>
+#include <textimportoptions.hxx>
+#include <sal/types.h>
 
 namespace scui
 {
-    static ScAbstractDialogFactory_Impl* pFactory=NULL;
+    static ScAbstractDialogFactory_Impl* pFactory=nullptr;
     ScAbstractDialogFactory_Impl* GetFactory()
     {
         if ( !pFactory )
             pFactory = new ScAbstractDialogFactory_Impl;
-        //if ( !pSwResMgr)
-        //  ScDialogsResMgr::GetResMgr();
         return pFactory;
     }
 }
 
-#ifdef DISABLE_DYNLOADING
-#define CreateDialogFactory ScCreateDialogFactory
-#endif
-
 extern "C"
 {
-    SAL_DLLPUBLIC_EXPORT ScAbstractDialogFactory* CreateDialogFactory()
+    SAL_DLLPUBLIC_EXPORT ScAbstractDialogFactory* ScCreateDialogFactory()
     {
         return ::scui::GetFactory();
     }
