@@ -7,7 +7,7 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include "condformatdlg.hxx"
+#include <condformatdlg.hxx>
 
 #include <vcl/vclevent.hxx>
 #include <svl/style.hxx>
@@ -21,20 +21,20 @@
 #include <vcl/builderfactory.hxx>
 #include <libxml/tree.h>
 
-#include "anyrefdg.hxx"
-#include "document.hxx"
-#include "conditio.hxx"
-#include "stlpool.hxx"
-#include "tabvwsh.hxx"
-#include "colorscale.hxx"
-#include "colorformat.hxx"
-#include "reffact.hxx"
-#include "docsh.hxx"
-#include "docfunc.hxx"
-#include "condformatdlgentry.hxx"
-#include "condformatdlgitem.hxx"
+#include <anyrefdg.hxx>
+#include <document.hxx>
+#include <conditio.hxx>
+#include <stlpool.hxx>
+#include <tabvwsh.hxx>
+#include <colorscale.hxx>
+#include <colorformat.hxx>
+#include <reffact.hxx>
+#include <docsh.hxx>
+#include <docfunc.hxx>
+#include <condformatdlgentry.hxx>
+#include <condformatdlgitem.hxx>
 
-#include "globstr.hrc"
+#include <globstr.hrc>
 
 ScCondFormatList::ScCondFormatList(vcl::Window* pParent, WinBits nStyle)
     : Control(pParent, nStyle | WB_DIALOGCONTROL)
@@ -88,7 +88,7 @@ void ScCondFormatList::init(ScDocument* pDoc, ScCondFormatDlg* pDialogParent,
                 case condformat::CONDITION:
                     {
                         const ScCondFormatEntry* pConditionEntry = static_cast<const ScCondFormatEntry*>( pEntry );
-                        if(pConditionEntry->GetOperation() != SC_COND_DIRECT)
+                        if(pConditionEntry->GetOperation() != ScConditionMode::Direct)
                             maEntries.push_back(VclPtr<ScConditionFrmtEntry>::Create( this, mpDoc, pDialogParent, maPos, pConditionEntry ) );
                         else
                             maEntries.push_back(VclPtr<ScFormulaFrmtEntry>::Create( this, mpDoc, pDialogParent, maPos, pConditionEntry ) );
@@ -156,7 +156,7 @@ VCL_BUILDER_FACTORY_CONSTRUCTOR(ScCondFormatList, 0)
 
 Size ScCondFormatList::GetOptimalSize() const
 {
-    return LogicToPixel(Size(300, 185), MapUnit::MapAppFont);
+    return LogicToPixel(Size(300, 185), MapMode(MapUnit::MapAppFont));
 }
 
 void ScCondFormatList::Resize()
@@ -261,7 +261,7 @@ IMPL_LINK(ScCondFormatList, ColFormatTypeHdl, ListBox&, rBox, void)
     if(itr == maEntries.end())
         return;
 
-    sal_Int32 nPos = rBox.GetSelectEntryPos();
+    sal_Int32 nPos = rBox.GetSelectedEntryPos();
     switch(nPos)
     {
         case 0:
@@ -326,7 +326,7 @@ IMPL_LINK(ScCondFormatList, AfterTypeListHdl, void*, p, void)
     if(itr == maEntries.end())
         return;
 
-    sal_Int32 nPos = pBox->GetSelectEntryPos();
+    sal_Int32 nPos = pBox->GetSelectedEntryPos();
     switch(nPos)
     {
         case 0:
@@ -772,9 +772,15 @@ IMPL_LINK( ScCondFormatDlg, EdRangeModifyHdl, Edit&, rEdit, void )
     ScRefFlags nFlags = aRange.Parse(aRangeStr, mpViewData->GetDocument(),
         mpViewData->GetDocument()->GetAddressConvention());
     if(nFlags & ScRefFlags::VALID)
+    {
         rEdit.SetControlBackground(GetSettings().GetStyleSettings().GetWindowColor());
+        mpBtnOk->Enable(true);
+    }
     else
+    {
         rEdit.SetControlBackground(COL_LIGHTRED);
+        mpBtnOk->Enable(false);
+    }
 
     updateTitle();
 }
