@@ -17,51 +17,46 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #undef SC_DLLIMPLEMENTATION
 
 #include <vcl/waitobj.hxx>
 
-#include "viewdata.hxx"
-#include "document.hxx"
-#include "uiitems.hxx"
-#include "global.hxx"
-#include "globalnames.hxx"
-#include "dbdata.hxx"
-#include "scresid.hxx"
-#include "queryentry.hxx"
-#include "typedstrdata.hxx"
+#include <viewdata.hxx>
+#include <document.hxx>
+#include <uiitems.hxx>
+#include <global.hxx>
+#include <globalnames.hxx>
+#include <dbdata.hxx>
+#include <scresid.hxx>
+#include <queryentry.hxx>
+#include <filterentries.hxx>
 
-#include "sc.hrc"
-#include "filter.hrc"
-#include "globstr.hrc"
+#include <sc.hrc>
+#include <strings.hrc>
+#include <globstr.hrc>
 
-#define _PFILTDLG_CXX
-#include "pfiltdlg.hxx"
-#undef _PFILTDLG_CXX
+#include <pfiltdlg.hxx>
 #include <svl/zforlist.hxx>
 #include <svl/sharedstringpool.hxx>
 
-ScPivotFilterDlg::ScPivotFilterDlg(Window* pParent, const SfxItemSet& rArgSet,
+ScPivotFilterDlg::ScPivotFilterDlg(vcl::Window* pParent, const SfxItemSet& rArgSet,
     SCTAB nSourceTab )
     :   ModalDialog(pParent, "PivotFilterDialog",
             "modules/scalc/ui/pivotfilterdialog.ui" )
     ,
 
-        aStrUndefined   ( SC_RESSTR(SCSTR_UNDEFINED) ),
-        aStrNone        ( SC_RESSTR(SCSTR_NONE) ),
-        aStrEmpty       ( SC_RESSTR(SCSTR_FILTER_EMPTY) ),
-        aStrNotEmpty    ( SC_RESSTR(SCSTR_FILTER_NOTEMPTY) ),
-        aStrColumn      ( SC_RESSTR(SCSTR_COLUMN) ),
+        aStrNone        ( ScResId(SCSTR_NONE) ),
+        aStrEmpty       ( ScResId(SCSTR_FILTER_EMPTY) ),
+        aStrNotEmpty    ( ScResId(SCSTR_FILTER_NOTEMPTY) ),
+        aStrColumn      ( ScResId(SCSTR_COLUMN) ),
 
         nWhichQuery     ( rArgSet.GetPool()->GetWhich( SID_QUERY ) ),
-        theQueryData    ( ((const ScQueryItem&)
+        theQueryData    ( static_cast<const ScQueryItem&>(
                            rArgSet.Get( nWhichQuery )).GetQueryData() ),
-        pOutItem        ( NULL ),
-        pViewData       ( NULL ),
-        pDoc            ( NULL ),
-        nSrcTab         ( nSourceTab ),     // ist nicht im QueryParam
-        nFieldCount     ( 0 )
+        pOutItem        ( nullptr ),
+        pViewData       ( nullptr ),
+        pDoc            ( nullptr ),
+        nSrcTab         ( nSourceTab )     // is not in QueryParam
 {
     get(m_pLbField1, "field1");
     get(m_pLbCond1, "cond1");
@@ -79,24 +74,44 @@ ScPivotFilterDlg::ScPivotFilterDlg(Window* pParent, const SfxItemSet& rArgSet,
     get(m_pBtnUnique, "unique");
     get(m_pFtDbArea, "dbarea");
 
-    for (sal_uInt16 i=0; i<=MAXCOL; i++)
-        pEntryLists[i] = NULL;
-
     Init( rArgSet );
 }
 
 ScPivotFilterDlg::~ScPivotFilterDlg()
 {
-    for (sal_uInt16 i=0; i<=MAXCOL; i++)
-        delete pEntryLists[i];
+    disposeOnce();
+}
+
+void ScPivotFilterDlg::dispose()
+{
+    for (auto& a : m_pEntryLists) a.reset();
 
     delete pOutItem;
+    m_pLbField1.clear();
+    m_pLbCond1.clear();
+    m_pEdVal1.clear();
+    m_pLbConnect1.clear();
+    m_pLbField2.clear();
+    m_pLbCond2.clear();
+    m_pEdVal2.clear();
+    m_pLbConnect2.clear();
+    m_pLbField3.clear();
+    m_pLbCond3.clear();
+    m_pEdVal3.clear();
+    m_pBtnCase.clear();
+    m_pBtnRegExp.clear();
+    m_pBtnUnique.clear();
+    m_pFtDbArea.clear();
+    for (auto& a : aValueEdArr) a.clear();
+    for (auto& a : aFieldLbArr) a.clear();
+    for (auto& a : aCondLbArr) a.clear();
+    ModalDialog::dispose();
 }
 
 void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
 {
-    const ScQueryItem& rQueryItem = (const ScQueryItem&)
-                                    rArgSet.Get( nWhichQuery );
+    const ScQueryItem& rQueryItem = static_cast<const ScQueryItem&>(
+                                    rArgSet.Get( nWhichQuery ));
 
     m_pBtnCase->SetClickHdl    ( LINK( this, ScPivotFilterDlg, CheckBoxHdl ) );
 
@@ -107,13 +122,13 @@ void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
     m_pLbConnect2->SetSelectHdl( LINK( this, ScPivotFilterDlg, LbSelectHdl ) );
 
     m_pBtnCase->Check( theQueryData.bCaseSens );
-    m_pBtnRegExp->Check( theQueryData.bRegExp );
+    m_pBtnRegExp->Check( theQueryData.eSearchType == utl::SearchParam::SearchType::Regexp );
     m_pBtnUnique->Check( !theQueryData.bDuplicate );
 
     pViewData   = rQueryItem.GetViewData();
-    pDoc        = pViewData ? pViewData->GetDocument() : NULL;
+    pDoc        = pViewData ? pViewData->GetDocument() : nullptr;
 
-    // fuer leichteren Zugriff:
+    // for easier access:
     aFieldLbArr  [0] = m_pLbField1;
     aFieldLbArr  [1] = m_pLbField2;
     aFieldLbArr  [2] = m_pLbField3;
@@ -133,12 +148,9 @@ void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
                                                 theQueryData.nRow2,
                                                 nSrcTab ) );
         ScDBCollection* pDBColl     = pDoc->GetDBCollection();
-        OUString theDbName = OUString(STR_DB_LOCAL_NONAME);
+        OUString theDbName = STR_DB_LOCAL_NONAME;
 
-        /*
-         * Ueberpruefen, ob es sich bei dem uebergebenen
-         * Bereich um einen Datenbankbereich handelt:
-         */
+         // Check if the passed range is a database range
 
         if ( pDBColl )
         {
@@ -152,7 +164,7 @@ void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
         }
 
         OUStringBuffer aBuf;
-        aBuf.appendAscii(" (");
+        aBuf.append(" (");
         aBuf.append(theDbName);
         aBuf.append(')');
         m_pFtDbArea->SetText(aBuf.makeStringAndClear());
@@ -162,7 +174,7 @@ void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
         m_pFtDbArea->SetText( EMPTY_OUSTRING );
     }
 
-    // Feldlisten einlesen und Eintraege selektieren:
+    // Read the field lists and select the entries:
 
     FillFieldLists();
 
@@ -184,53 +196,53 @@ void ScPivotFilterDlg::Init( const SfxItemSet& rArgSet )
             aCondLbArr [i]->SelectEntryPos( nCondPos );
             UpdateValueList( static_cast<sal_uInt16>(i+1) );
             aValueEdArr[i]->SetText( aValStr );
-            if (aValStr.equals(aStrEmpty) || aValStr.equals(aStrNotEmpty))
+            if (aValStr == aStrEmpty || aValStr == aStrNotEmpty)
                 aCondLbArr[i]->Disable();
         }
         else
         {
-            aFieldLbArr[i]->SelectEntryPos( 0 ); // "keiner" selektieren
-            aCondLbArr [i]->SelectEntryPos( 0 ); // "=" selektieren
+            aFieldLbArr[i]->SelectEntryPos( 0 ); // "none" selected
+            aCondLbArr [i]->SelectEntryPos( 0 ); // "=" selected
             UpdateValueList( static_cast<sal_uInt16>(i) );
             aValueEdArr[i]->SetText( EMPTY_OUSTRING );
         }
         aValueEdArr[i]->SetModifyHdl( LINK( this, ScPivotFilterDlg, ValModifyHdl ) );
     }
 
-    // Disable/Enable Logik:
+    // disable/enable logic:
 
-       (m_pLbField1->GetSelectEntryPos() != 0)
-    && (m_pLbField2->GetSelectEntryPos() != 0)
+       (m_pLbField1->GetSelectedEntryPos() != 0)
+    && (m_pLbField2->GetSelectedEntryPos() != 0)
         ? m_pLbConnect1->SelectEntryPos( (sal_uInt16)theQueryData.GetEntry(1).eConnect )
         : m_pLbConnect1->SetNoSelection();
 
-       (m_pLbField2->GetSelectEntryPos() != 0)
-    && (m_pLbField3->GetSelectEntryPos() != 0)
+       (m_pLbField2->GetSelectedEntryPos() != 0)
+    && (m_pLbField3->GetSelectedEntryPos() != 0)
         ? m_pLbConnect2->SelectEntryPos( (sal_uInt16)theQueryData.GetEntry(2).eConnect )
         : m_pLbConnect2->SetNoSelection();
 
-    if ( m_pLbField1->GetSelectEntryPos() == 0 )
+    if ( m_pLbField1->GetSelectedEntryPos() == 0 )
     {
         m_pLbConnect1->Disable();
         m_pLbField2->Disable();
         m_pLbCond2->Disable();
         m_pEdVal2->Disable();
     }
-    else if ( m_pLbConnect1->GetSelectEntryCount() == 0 )
+    else if ( m_pLbConnect1->GetSelectedEntryCount() == 0 )
     {
         m_pLbField2->Disable();
         m_pLbCond2->Disable();
         m_pEdVal2->Disable();
     }
 
-    if ( m_pLbField2->GetSelectEntryPos() == 0 )
+    if ( m_pLbField2->GetSelectedEntryPos() == 0 )
     {
         m_pLbConnect2->Disable();
         m_pLbField3->Disable();
         m_pLbCond3->Disable();
         m_pEdVal3->Disable();
     }
-    else if ( m_pLbConnect2->GetSelectEntryCount() == 0 )
+    else if ( m_pLbConnect2->GetSelectedEntryCount() == 0 )
     {
         m_pLbField3->Disable();
         m_pLbCond3->Disable();
@@ -269,7 +281,6 @@ void ScPivotFilterDlg::FillFieldLists()
             m_pLbField3->InsertEntry( aFieldName, i );
             i++;
         }
-        nFieldCount = i;
     }
 }
 
@@ -277,8 +288,8 @@ void ScPivotFilterDlg::UpdateValueList( sal_uInt16 nList )
 {
     if ( pDoc && nList>0 && nList<=3 )
     {
-        ComboBox*   pValList        = aValueEdArr[nList-1];
-        sal_Int32   nFieldSelPos    = aFieldLbArr[nList-1]->GetSelectEntryPos();
+        ComboBox*   pValList        = aValueEdArr[nList-1].get();
+        sal_Int32   nFieldSelPos    = aFieldLbArr[nList-1]->GetSelectedEntryPos();
         sal_Int32   nListPos        = 0;
         OUString    aCurValue       = pValList->GetText();
 
@@ -290,7 +301,7 @@ void ScPivotFilterDlg::UpdateValueList( sal_uInt16 nList )
         if ( pDoc && nFieldSelPos )
         {
             SCCOL nColumn = theQueryData.nCol1 + static_cast<SCCOL>(nFieldSelPos) - 1;
-            if (!pEntryLists[nColumn])
+            if (!m_pEntryLists[nColumn])
             {
                 WaitObject aWaiter( this );
 
@@ -298,14 +309,13 @@ void ScPivotFilterDlg::UpdateValueList( sal_uInt16 nList )
                 SCROW   nFirstRow   = theQueryData.nRow1;
                 SCROW   nLastRow    = theQueryData.nRow2;
                 nFirstRow++;
-                bool bHasDates = false;
                 bool bCaseSens = m_pBtnCase->IsChecked();
-                pEntryLists[nColumn] = new std::vector<ScTypedStrData>;
+                m_pEntryLists[nColumn].reset( new ScFilterEntries);
                 pDoc->GetFilterEntriesArea(
-                    nColumn, nFirstRow, nLastRow, nTab, bCaseSens, *pEntryLists[nColumn], bHasDates);
+                    nColumn, nFirstRow, nLastRow, nTab, bCaseSens, *m_pEntryLists[nColumn]);
             }
 
-            std::vector<ScTypedStrData>* pColl = pEntryLists[nColumn];
+            const ScFilterEntries* pColl = m_pEntryLists[nColumn].get();
             std::vector<ScTypedStrData>::const_iterator it = pColl->begin(), itEnd = pColl->end();
             for (; it != itEnd; ++it)
             {
@@ -321,7 +331,7 @@ void ScPivotFilterDlg::ClearValueList( sal_uInt16 nList )
 {
     if ( nList>0 && nList<=3 )
     {
-        ComboBox* pValList = aValueEdArr[nList-1];
+        ComboBox* pValList = aValueEdArr[nList-1].get();
         pValList->Clear();
         pValList->InsertEntry( aStrNotEmpty, 0 );
         pValList->InsertEntry( aStrEmpty, 1 );
@@ -340,17 +350,17 @@ sal_uInt16 ScPivotFilterDlg::GetFieldSelPos( SCCOL nField )
 const ScQueryItem& ScPivotFilterDlg::GetOutputItem()
 {
     ScQueryParam    theParam( theQueryData );
-    sal_Int32          nConnect1 = m_pLbConnect1->GetSelectEntryPos();
-    sal_Int32          nConnect2 = m_pLbConnect2->GetSelectEntryPos();
+    sal_Int32          nConnect1 = m_pLbConnect1->GetSelectedEntryPos();
+    sal_Int32          nConnect2 = m_pLbConnect2->GetSelectedEntryPos();
 
     svl::SharedStringPool& rPool = pViewData->GetDocument()->GetSharedStringPool();
 
     for ( SCSIZE i=0; i<3; i++ )
     {
-        sal_uInt16      nField  = aFieldLbArr[i]->GetSelectEntryPos();
-        ScQueryOp   eOp     = (ScQueryOp)aCondLbArr[i]->GetSelectEntryPos();
+        const sal_Int32 nField = aFieldLbArr[i]->GetSelectedEntryPos();
+        ScQueryOp   eOp     = (ScQueryOp)aCondLbArr[i]->GetSelectedEntryPos();
 
-        bool bDoThis = (aFieldLbArr[i]->GetSelectEntryPos() != 0);
+        bool bDoThis = (aFieldLbArr[i]->GetSelectedEntryPos() != 0);
         theParam.GetEntry(i).bDoQuery = bDoThis;
 
         if ( bDoThis )
@@ -361,16 +371,16 @@ const ScQueryItem& ScPivotFilterDlg::GetOutputItem()
             OUString aStrVal = aValueEdArr[i]->GetText();
 
             /*
-             * Dialog liefert die ausgezeichneten Feldwerte "leer"/"nicht leer"
-             * als Konstanten in nVal in Verbindung mit dem Schalter
-             * bQueryByString auf FALSE.
+             * The dialog returns the specific field values "empty"/"non empty"
+             * as constant in nVal in connection with the bQueryByString switch
+             * set to false
              */
-            if ( aStrVal.equals(aStrEmpty) )
+            if ( aStrVal == aStrEmpty )
             {
                 OSL_ASSERT(eOp == SC_EQUAL);
                 rEntry.SetQueryByEmpty();
             }
-            else if ( aStrVal.equals(aStrNotEmpty) )
+            else if ( aStrVal == aStrNotEmpty )
             {
                 OSL_ASSERT(eOp == SC_EQUAL);
                 rEntry.SetQueryByNonEmpty();
@@ -396,13 +406,13 @@ const ScQueryItem& ScPivotFilterDlg::GetOutputItem()
                                     : SC_AND;
 
     theParam.bInplace   = false;
-    theParam.nDestTab   = 0;    // Woher kommen diese Werte?
+    theParam.nDestTab   = 0;    // Where do those values come from?
     theParam.nDestCol   = 0;
     theParam.nDestRow   = 0;
 
     theParam.bDuplicate     = !m_pBtnUnique->IsChecked();
     theParam.bCaseSens      = m_pBtnCase->IsChecked();
-    theParam.bRegExp        = m_pBtnRegExp->IsChecked();
+    theParam.eSearchType    = m_pBtnRegExp->IsChecked() ? utl::SearchParam::SearchType::Regexp : utl::SearchParam::SearchType::Normal;
 
     if ( pOutItem ) DELETEZ( pOutItem );
     pOutItem = new ScQueryItem( nWhichQuery, &theParam );
@@ -410,18 +420,16 @@ const ScQueryItem& ScPivotFilterDlg::GetOutputItem()
     return *pOutItem;
 }
 
-
 // Handler:
 
-
-IMPL_LINK( ScPivotFilterDlg, LbSelectHdl, ListBox*, pLb )
+IMPL_LINK( ScPivotFilterDlg, LbSelectHdl, ListBox&, rLb, void )
 {
+
     /*
-     * Behandlung der Enable/Disable-Logik,
-     * abhaengig davon, welche ListBox angefasst wurde:
+     * Handling the enable/disable logic based on which ListBox was touched:
      */
 
-    if (pLb == m_pLbConnect1)
+    if (&rLb == m_pLbConnect1)
     {
         if ( !m_pLbField2->IsEnabled() )
         {
@@ -430,7 +438,7 @@ IMPL_LINK( ScPivotFilterDlg, LbSelectHdl, ListBox*, pLb )
             m_pEdVal2->Enable();
         }
     }
-    else if (pLb == m_pLbConnect2)
+    else if (&rLb == m_pLbConnect2)
     {
         if ( !m_pLbField3->IsEnabled() )
         {
@@ -439,9 +447,9 @@ IMPL_LINK( ScPivotFilterDlg, LbSelectHdl, ListBox*, pLb )
             m_pEdVal3->Enable();
         }
     }
-    else if (pLb == m_pLbField1)
+    else if (&rLb == m_pLbField1)
     {
-        if ( m_pLbField1->GetSelectEntryPos() == 0 )
+        if ( m_pLbField1->GetSelectedEntryPos() == 0 )
         {
             m_pLbConnect1->SetNoSelection();
             m_pLbConnect2->SetNoSelection();
@@ -471,9 +479,9 @@ IMPL_LINK( ScPivotFilterDlg, LbSelectHdl, ListBox*, pLb )
             }
         }
     }
-    else if (pLb == m_pLbField2)
+    else if (&rLb == m_pLbField2)
     {
-        if ( m_pLbField2->GetSelectEntryPos() == 0 )
+        if ( m_pLbField2->GetSelectedEntryPos() == 0 )
         {
             m_pLbConnect2->SetNoSelection();
             m_pLbField3->SelectEntryPos( 0 );
@@ -495,24 +503,22 @@ IMPL_LINK( ScPivotFilterDlg, LbSelectHdl, ListBox*, pLb )
             }
         }
     }
-    else if (pLb == m_pLbField3)
+    else if (&rLb == m_pLbField3)
     {
-        ( m_pLbField3->GetSelectEntryPos() == 0 )
+        ( m_pLbField3->GetSelectedEntryPos() == 0 )
             ? ClearValueList( 3 )
             : UpdateValueList( 3 );
     }
-
-    return 0;
 }
 
-IMPL_LINK( ScPivotFilterDlg, CheckBoxHdl, CheckBox*, pBox )
+IMPL_LINK( ScPivotFilterDlg, CheckBoxHdl, Button*, pBox, void )
 {
-    //  bei Gross-/Kleinschreibung die Werte-Listen aktualisieren
+    // update the value lists when dealing with uppercase/lowercase
 
-    if (pBox == m_pBtnCase)                    // Wertlisten
+    if (pBox == m_pBtnCase)                    // value lists
     {
-        for (sal_uInt16 i=0; i<=MAXCOL; i++)
-            DELETEZ( pEntryLists[i] );
+        for (auto& a : m_pEntryLists)
+            a.reset();
 
         OUString aCurVal1 = m_pEdVal1->GetText();
         OUString aCurVal2 = m_pEdVal2->GetText();
@@ -524,34 +530,26 @@ IMPL_LINK( ScPivotFilterDlg, CheckBoxHdl, CheckBox*, pBox )
         m_pEdVal2->SetText( aCurVal2 );
         m_pEdVal3->SetText( aCurVal3 );
     }
-
-    return 0;
 }
 
-IMPL_LINK( ScPivotFilterDlg, ValModifyHdl, ComboBox*, pEd )
+IMPL_LINK( ScPivotFilterDlg, ValModifyHdl, Edit&, rEd, void )
 {
-    if ( pEd )
+    OUString aStrVal = rEd.GetText();
+    ListBox* pLb = m_pLbCond1;
+
+    if ( &rEd == m_pEdVal2 ) pLb = m_pLbCond2;
+    else if ( &rEd == m_pEdVal3 ) pLb = m_pLbCond3;
+
+    // if cond of the special values "empty"/"non-empty" was chosen only the
+    // =-operand makes sense:
+
+    if ( aStrEmpty == aStrVal || aStrNotEmpty == aStrVal )
     {
-        OUString aStrVal = pEd->GetText();
-        ListBox* pLb = m_pLbCond1;
-
-        if ( pEd == m_pEdVal2 ) pLb = m_pLbCond2;
-        else if ( pEd == m_pEdVal3 ) pLb = m_pLbCond3;
-
-        // wenn einer der Sonderwerte leer/nicht-leer
-        // gewaehlt wird, so macht nur der =-Operator Sinn:
-
-        if ( aStrEmpty.equals(aStrVal) || aStrNotEmpty.equals(aStrVal) )
-        {
-            pLb->SelectEntry(OUString('='));
-            pLb->Disable();
-        }
-        else
-            pLb->Enable();
+        pLb->SelectEntry(OUString('='));
+        pLb->Disable();
     }
-
-    return 0;
+    else
+        pLb->Enable();
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
