@@ -27,7 +27,7 @@
 #include <documentlinkmgr.hxx>
 #include <o3tl/enumarray.hxx>
 
-#include "officecfg/Office/Calc.hxx"
+#include <officecfg/Office/Calc.hxx>
 
 
 #if defined(_WIN32)
@@ -71,7 +71,7 @@ public:
     static void begin_row() {}
     static void end_row() {}
 
-    void cell(const char* p, size_t n)
+    void cell(const char* p, size_t n, bool /*transient*/)
     {
         if (mnCols >= mnColCount)
             return;
@@ -363,7 +363,6 @@ void DataStream::Decode(const OUString& rURL, const ScRange& rRange,
         sal_Int32 nLimit, MoveType eMove, const sal_uInt32 nSettings)
 {
     msURL = rURL;
-    mnLimit = nLimit;
     meMove = eMove;
     meOrigMove = eMove;
     mnSettings = nSettings;
@@ -402,11 +401,7 @@ void DataStream::StartImport()
 
     if (!mxReaderThread.is())
     {
-        SvStream *pStream = nullptr;
-        if (mnSettings & SCRIPT_STREAM)
-            pStream = new SvScriptStream(msURL);
-        else
-            pStream = new SvFileStream(msURL, StreamMode::READ);
+        SvStream *pStream = new SvFileStream(msURL, StreamMode::READ);
         mxReaderThread = new datastreams::ReaderThread(pStream, maStartRange.aEnd.Col() - maStartRange.aStart.Col() + 1);
         mxReaderThread->launch();
     }
