@@ -29,48 +29,31 @@
 #include <sfx2/dispatch.hxx>
 #include <sfx2/viewfrm.hxx>
 
-#include "sc.hrc"
-#include "fudraw.hxx"
-#include "futext.hxx"
-#include "tabvwsh.hxx"
-#include "drwlayer.hxx"
-#include "scresid.hxx"
-#include "userdat.hxx"
-#include "docsh.hxx"
-#include "postit.hxx"
-#include "globstr.hrc"
-#include "drawview.hxx"
-
-/*************************************************************************
-|*
-|* base class for draw module specific functions
-|*
-\************************************************************************/
+#include <sc.hrc>
+#include <fudraw.hxx>
+#include <futext.hxx>
+#include <tabvwsh.hxx>
+#include <drwlayer.hxx>
+#include <scresid.hxx>
+#include <userdat.hxx>
+#include <docsh.hxx>
+#include <postit.hxx>
+#include <globstr.hrc>
+#include <drawview.hxx>
 
+// base class for draw module specific functions
 FuDraw::FuDraw(ScTabViewShell* pViewSh, vcl::Window* pWin, ScDrawView* pViewP,
-               SdrModel* pDoc, SfxRequest& rReq) :
+               SdrModel* pDoc, const SfxRequest& rReq) :
     FuPoor      (pViewSh, pWin, pViewP, pDoc, rReq),
     aNewPointer ( PointerStyle::Arrow ),
     aOldPointer ( PointerStyle::Arrow )
 {
 }
 
-/*************************************************************************
-|*
-|* destructor
-|*
-\************************************************************************/
-
 FuDraw::~FuDraw()
 {
 }
 
-/*************************************************************************
-|*
-|* evaluate modifier keys
-|*
-\************************************************************************/
-
 void FuDraw::DoModifiers(const MouseEvent& rMEvt)
 {
     //  Shift   = Ortho and AngleSnap
@@ -128,12 +111,6 @@ void FuDraw::ResetModifiers()
         pView->SetResizeAtCenter(false);
 }
 
-/*************************************************************************
-|*
-|* MouseButtonDown-event
-|*
-\************************************************************************/
-
 bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
 {
     // remember button state for creation of own MouseEvents
@@ -143,12 +120,6 @@ bool FuDraw::MouseButtonDown(const MouseEvent& rMEvt)
     return false;
 }
 
-/*************************************************************************
-|*
-|* MouseMove-event
-|*
-\************************************************************************/
-
 bool FuDraw::MouseMove(const MouseEvent& rMEvt)
 {
     //  evaluate modifiers only if in a drawing layer action
@@ -159,12 +130,6 @@ bool FuDraw::MouseMove(const MouseEvent& rMEvt)
     return false;
 }
 
-/*************************************************************************
-|*
-|* MouseButtonUp-event
-|*
-\************************************************************************/
-
 bool FuDraw::MouseButtonUp(const MouseEvent& rMEvt)
 {
     // remember button state for creation of own MouseEvents
@@ -174,15 +139,7 @@ bool FuDraw::MouseButtonUp(const MouseEvent& rMEvt)
     return false;
 }
 
-/*************************************************************************
-|*
-|* process keyboard events
-|*
-|* if a keyevent is processed -> returns sal_True
-|*                            -> else  FALSE
-|*
-\************************************************************************/
-
+// Process Keyboard events. Return true if an event is being handled
 static bool lcl_KeyEditMode( SdrObject* pObj, ScTabViewShell* pViewShell, const KeyEvent* pInitialKey )
 {
     bool bReturn = false;
@@ -337,7 +294,7 @@ bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                     const SdrHdlList& rHdlList = pView->GetHdlList();
                     bool bForward(!rKEvt.GetKeyCode().IsShift());
 
-                    ((SdrHdlList&)rHdlList).TravelFocusHdl(bForward);
+                    const_cast<SdrHdlList&>(rHdlList).TravelFocusHdl(bForward);
 
                     // guarantee visibility of focused handle
                     SdrHdl* pHdl = rHdlList.GetFocusHdl();
@@ -345,7 +302,7 @@ bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                     if(pHdl)
                     {
                         Point aHdlPosition(pHdl->GetPos());
-                        Rectangle aVisRect(aHdlPosition - Point(100, 100), Size(200, 200));
+                        tools::Rectangle aVisRect(aHdlPosition - Point(100, 100), Size(200, 200));
                         pView->MakeVisible(aVisRect, *pWindow);
                     }
 
@@ -489,11 +446,11 @@ bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                             if(pView->IsMoveAllowed())
                             {
                                 // restrict movement to WorkArea
-                                const Rectangle& rWorkArea = pView->GetWorkArea();
+                                const tools::Rectangle& rWorkArea = pView->GetWorkArea();
 
                                 if(!rWorkArea.IsEmpty())
                                 {
-                                    Rectangle aMarkRect(pView->GetMarkedObjRect());
+                                    tools::Rectangle aMarkRect(pView->GetMarkedObjRect());
                                     aMarkRect.Move(nX, nY);
 
                                     if(!aMarkRect.IsInside(rWorkArea))
@@ -549,7 +506,7 @@ bool FuDraw::KeyInput(const KeyEvent& rKEvt)
 
                                     // switch snapping off
                                     if(!bWasNoSnap)
-                                        ((SdrDragStat&)rDragStat).SetNoSnap();
+                                        const_cast<SdrDragStat&>(rDragStat).SetNoSnap();
                                     if(bWasSnapEnabled)
                                         pView->SetSnapEnabled(false);
 
@@ -558,13 +515,13 @@ bool FuDraw::KeyInput(const KeyEvent& rKEvt)
 
                                     // restore snap
                                     if(!bWasNoSnap)
-                                        ((SdrDragStat&)rDragStat).SetNoSnap(bWasNoSnap);
+                                        const_cast<SdrDragStat&>(rDragStat).SetNoSnap(bWasNoSnap);
                                     if(bWasSnapEnabled)
                                         pView->SetSnapEnabled(bWasSnapEnabled);
                                 }
 
                                 // make moved handle visible
-                                Rectangle aVisRect(aEndPoint - Point(100, 100), Size(200, 200));
+                                tools::Rectangle aVisRect(aEndPoint - Point(100, 100), Size(200, 200));
                                 pView->MakeVisible(aVisRect, *pWindow);
 
                                 bReturn = true;
@@ -586,7 +543,7 @@ bool FuDraw::KeyInput(const KeyEvent& rKEvt)
 
                 if(pHdl)
                 {
-                    if(pHdl->GetKind() == HDL_POLY)
+                    if(pHdl->GetKind() == SdrHdlKind::Poly)
                     {
                         // rescue ID of point with focus
                         sal_uInt32 nPol(pHdl->GetPolyNum());
@@ -619,7 +576,7 @@ bool FuDraw::KeyInput(const KeyEvent& rKEvt)
                                 SdrHdl* pAct = rHdlList.GetHdl(a);
 
                                 if(pAct
-                                    && pAct->GetKind() == HDL_POLY
+                                    && pAct->GetKind() == SdrHdlKind::Poly
                                     && pAct->GetPolyNum() == nPol
                                     && pAct->GetPointNum() == nPnt)
                                 {
@@ -629,7 +586,7 @@ bool FuDraw::KeyInput(const KeyEvent& rKEvt)
 
                             if(pNewOne)
                             {
-                                ((SdrHdlList&)rHdlList).SetFocusHdl(pNewOne);
+                                const_cast<SdrHdlList&>(rHdlList).SetFocusHdl(pNewOne);
                             }
                         }
 
@@ -664,47 +621,20 @@ bool FuDraw::KeyInput(const KeyEvent& rKEvt)
     return bReturn;
 }
 
-/*************************************************************************
-|*
-|* enable function
-|*
-\************************************************************************/
-
-void FuDraw::Activate()
-{
-    FuPoor::Activate();
-}
-
-/*************************************************************************
-|*
-|* disable function
-|*
-\************************************************************************/
-
-void FuDraw::Deactivate()
-{
-    FuPoor::Deactivate();
-}
-
-/*************************************************************************
-|*
-|* toggle mouse-pointer
-|*
-\************************************************************************/
-
-static bool lcl_UrlHit( SdrView* pView, const Point& rPosPixel, vcl::Window* pWindow )
+// toggle mouse-pointer
+static bool lcl_UrlHit( const SdrView* pView, const Point& rPosPixel, const vcl::Window* pWindow )
 {
     SdrViewEvent aVEvt;
     MouseEvent aMEvt( rPosPixel, 1, MouseEventModifiers::NONE, MOUSE_LEFT );
     SdrHitKind eHit = pView->PickAnything( aMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt );
 
-    if ( eHit != SDRHIT_NONE && aVEvt.pObj != nullptr )
+    if ( eHit != SdrHitKind::NONE && aVEvt.pObj != nullptr )
     {
         if ( ScDrawLayer::GetIMapInfo( aVEvt.pObj ) && ScDrawLayer::GetHitIMapObject(
                                 aVEvt.pObj, pWindow->PixelToLogic(rPosPixel), *pWindow ) )
             return true;
 
-        if ( aVEvt.eEvent == SDREVENT_EXECUTEURL )
+        if ( aVEvt.eEvent == SdrEventKind::ExecuteUrl )
             return true;
     }
 
@@ -719,16 +649,16 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
         bool bAlt       = pMEvt && pMEvt->IsMod2();
         Point aPnt      = pWindow->PixelToLogic( aPosPixel );
         SdrHdl* pHdl    = pView->PickHandle(aPnt);
-        SdrObject* pObj;
         SdrPageView* pPV;
 
         ScMacroInfo* pInfo = nullptr;
-        if ( pView->PickObj(aPnt, pView->getHitTolLog(), pObj, pPV, SdrSearchOptions::ALSOONMASTER) )
+        SdrObject* pObj = pView->PickObj(aPnt, pView->getHitTolLog(), pPV, SdrSearchOptions::ALSOONMASTER);
+        if (pObj)
         {
             if ( pObj->IsGroupObject() )
             {
-                SdrObject* pHit = nullptr;
-                if ( pView->PickObj(aMDPos, pView->getHitTolLog(), pHit, pPV, SdrSearchOptions::DEEP ) )
+                SdrObject* pHit = pView->PickObj(aMDPos, pView->getHitTolLog(), pPV, SdrSearchOptions::DEEP);
+                if (pHit)
                     pObj = pHit;
             }
             pInfo = ScDrawLayer::GetMacroInfo( pObj );
@@ -753,7 +683,7 @@ void FuDraw::ForcePointer(const MouseEvent* pMEvt)
             //  could be suppressed with ALT
             pWindow->SetPointer( Pointer( PointerStyle::RefHand ) );          // Text-URL / ImageMap
         }
-        else if ( !bAlt && pView->PickObj(aPnt, pView->getHitTolLog(), pObj, pPV, SdrSearchOptions::PICKMACRO) )
+        else if ( !bAlt && (pObj = pView->PickObj(aPnt, pView->getHitTolLog(), pPV, SdrSearchOptions::PICKMACRO)) )
         {
             //  could be suppressed with ALT
             SdrObjMacroHitRec aHitRec;  //! something missing ????
