@@ -17,25 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "global.hxx"
-#include "reffact.hxx"
-#include "document.hxx"
-#include "docsh.hxx"
-#include "scresid.hxx"
-#include "globstr.hrc"
+#include <global.hxx>
+#include <reffact.hxx>
+#include <document.hxx>
+#include <docsh.hxx>
+#include <scresid.hxx>
+#include <globstr.hrc>
 
-#include "highred.hxx"
+#include <highred.hxx>
 #include <vcl/msgbox.hxx>
 #include <sfx2/app.hxx>
 
-// defines -------------------------------------------------------------------
-
-#define ABS_SREF          SCA_VALID \
-                        | SCA_COL_ABSOLUTE | SCA_ROW_ABSOLUTE | SCA_TAB_ABSOLUTE
-#define ABS_DREF          ABS_SREF \
-                        | SCA_COL2_ABSOLUTE | SCA_ROW2_ABSOLUTE | SCA_TAB2_ABSOLUTE
-#define ABS_DREF3D      ABS_DREF | SCA_TAB_3D
-
 //  class ScHighlightChgDlg
 
 ScHighlightChgDlg::ScHighlightChgDlg( SfxBindings* pB, SfxChildWindow* pCW, vcl::Window* pParent,
@@ -44,7 +36,6 @@ ScHighlightChgDlg::ScHighlightChgDlg( SfxBindings* pB, SfxChildWindow* pCW, vcl:
         "modules/scalc/ui/showchangesdialog.ui")
     , pViewData(ptrViewData)
     , pDoc(ptrViewData->GetDocument())
-    , aLocalRangeName(*(pDoc->GetRangeName()))
 {
     m_pFilterCtr = VclPtr<SvxTPFilter>::Create(get<VclContainer>("box"));
     get(m_pHighlightBox, "showchanges");
@@ -87,12 +78,10 @@ void ScHighlightChgDlg::dispose()
 
 void ScHighlightChgDlg::Init()
 {
-    ScRange aRange;
-
-    OSL_ENSURE( pViewData && pDoc, "ViewData oder Document nicht gefunden!" );
+    OSL_ENSURE( pViewData && pDoc, "ViewData or Document not found!" );
 
     ScChangeTrack* pChanges=pDoc->GetChangeTrack();
-    if(pChanges!=NULL)
+    if(pChanges!=nullptr)
     {
         aChangeViewSet.SetTheAuthorToShow(pChanges->GetUser());
         m_pFilterCtr->ClearAuthors();
@@ -104,7 +93,7 @@ void ScHighlightChgDlg::Init()
 
     ScChangeViewSettings* pViewSettings=pDoc->GetChangeViewSettings();
 
-    if(pViewSettings!=NULL)
+    if(pViewSettings!=nullptr)
         aChangeViewSet=*pViewSettings;
     m_pHighlightBox->Check(aChangeViewSet.ShowChanges());
     m_pFilterCtr->CheckDate(aChangeViewSet.HasDate());
@@ -135,10 +124,10 @@ void ScHighlightChgDlg::Init()
     if ( !aChangeViewSet.GetTheRangeList().empty() )
     {
         const ScRange* pRangeEntry = aChangeViewSet.GetTheRangeList().front();
-        OUString aRefStr(pRangeEntry->Format(ABS_DREF3D, pDoc));
+        OUString aRefStr(pRangeEntry->Format(ScRefFlags::RANGE_ABS_3D, pDoc));
         m_pFilterCtr->SetRange(aRefStr);
     }
-    m_pFilterCtr->Enable(true,true);
+    m_pFilterCtr->Enable();
     HighlightHandle(m_pHighlightBox);
 }
 
@@ -151,7 +140,7 @@ void ScHighlightChgDlg::SetReference( const ScRange& rRef, ScDocument* pDocP )
     {
         if ( rRef.aStart != rRef.aEnd )
             RefInputStart(m_pEdAssign);
-        OUString aRefStr(rRef.Format(ABS_DREF3D, pDocP, pDocP->GetAddressConvention()));
+        OUString aRefStr(rRef.Format(ScRefFlags::RANGE_ABS_3D, pDocP, pDocP->GetAddressConvention()));
         m_pEdAssign->SetRefString( aRefStr );
         m_pFilterCtr->SetRange(aRefStr);
     }
@@ -183,29 +172,28 @@ bool ScHighlightChgDlg::IsRefInputMode() const
     return m_pEdAssign->IsVisible();
 }
 
-IMPL_LINK( ScHighlightChgDlg, HighlightHandle, CheckBox*, pCb )
+IMPL_LINK( ScHighlightChgDlg, HighlightHandle, Button*, pCb, void )
 {
-    if(pCb!=NULL)
+    if(pCb!=nullptr)
     {
         if(m_pHighlightBox->IsChecked())
         {
-            m_pFilterCtr->Enable(true,true);
+            m_pFilterCtr->Enable();
             m_pCbAccept->Enable();
             m_pCbReject->Enable();
         }
         else
         {
-            m_pFilterCtr->Disable(true);
+            m_pFilterCtr->Disable();
             m_pCbAccept->Disable();
             m_pCbReject->Disable();
         }
     }
-    return 0;
 }
 
-IMPL_LINK( ScHighlightChgDlg, RefHandle, SvxTPFilter*, pRef )
+IMPL_LINK( ScHighlightChgDlg, RefHandle, SvxTPFilter*, pRef, void )
 {
-    if(pRef!=NULL)
+    if(pRef!=nullptr)
     {
         SetDispatcherLock( true );
         m_pEdAssign->Show();
@@ -214,10 +202,9 @@ IMPL_LINK( ScHighlightChgDlg, RefHandle, SvxTPFilter*, pRef )
         m_pEdAssign->GrabFocus();
         ScAnyRefDlg::RefInputStart(m_pEdAssign, m_pRbAssign);
     }
-    return 0;
 }
 
-IMPL_LINK( ScHighlightChgDlg, OKBtnHdl, PushButton*, pOKBtn )
+IMPL_LINK( ScHighlightChgDlg, OKBtnHdl, Button*, pOKBtn, void )
 {
     if (pOKBtn == m_pOkButton)
     {
@@ -246,7 +233,6 @@ IMPL_LINK( ScHighlightChgDlg, OKBtnHdl, PushButton*, pOKBtn )
         pViewData->GetDocShell()->PostPaintGridAll();
         Close();
     }
-    return 0;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
