@@ -20,19 +20,13 @@
 #include <vcl/msgbox.hxx>
 #include <sfx2/app.hxx>
 
-#include "reffact.hxx"
-#include "document.hxx"
-#include "scresid.hxx"
-#include "globstr.hrc"
-#include "rangenam.hxx"
-#include "simpref.hxx"
-#include "scmod.hxx"
-
-#define ABS_SREF          SCA_VALID \
-                        | SCA_COL_ABSOLUTE | SCA_ROW_ABSOLUTE | SCA_TAB_ABSOLUTE
-#define ABS_DREF          ABS_SREF \
-                        | SCA_COL2_ABSOLUTE | SCA_ROW2_ABSOLUTE | SCA_TAB2_ABSOLUTE
-#define ABS_DREF3D      ABS_DREF | SCA_TAB_3D
+#include <reffact.hxx>
+#include <document.hxx>
+#include <scresid.hxx>
+#include <globstr.hrc>
+#include <rangenam.hxx>
+#include <simpref.hxx>
+#include <scmod.hxx>
 
 ScSimpleRefDlg::ScSimpleRefDlg(SfxBindings* pB, SfxChildWindow* pCW, vcl::Window* pParent)
     : ScAnyRefDlg(pB, pCW, pParent, "SimpleRefDialog", "modules/scalc/ui/simplerefdialog.ui")
@@ -105,10 +99,10 @@ void ScSimpleRefDlg::SetReference( const ScRange& rRef, ScDocument* pDocP )
         if ( bSingleCell )
         {
             ScAddress aAdr = rRef.aStart;
-            aRefStr = aAdr.Format(SCA_ABS_3D, pDocP, pDocP->GetAddressConvention());
+            aRefStr = aAdr.Format(ScRefFlags::ADDR_ABS_3D, pDocP, pDocP->GetAddressConvention());
         }
         else
-            aRefStr = theCurArea.Format(ABS_DREF3D, pDocP, pDocP->GetAddressConvention());
+            aRefStr = theCurArea.Format(ScRefFlags::RANGE_ABS_3D, pDocP, pDocP->GetAddressConvention());
 
         if ( bMultiSelection )
         {
@@ -191,7 +185,7 @@ void ScSimpleRefDlg::RefInputDone( bool bForced)
 
 // Handler:
 
-IMPL_LINK_NOARG_TYPED(ScSimpleRefDlg, OkBtnHdl, Button*, void)
+IMPL_LINK_NOARG(ScSimpleRefDlg, OkBtnHdl, Button*, void)
 {
     bAutoReOpen=false;
     OUString aResult=m_pEdAssign->GetText();
@@ -201,7 +195,7 @@ IMPL_LINK_NOARG_TYPED(ScSimpleRefDlg, OkBtnHdl, Button*, void)
     aUnoLink.Call( aResult );
 }
 
-IMPL_LINK_NOARG_TYPED(ScSimpleRefDlg, CancelBtnHdl, Button*, void)
+IMPL_LINK_NOARG(ScSimpleRefDlg, CancelBtnHdl, Button*, void)
 {
     bAutoReOpen=false;
     OUString aResult=m_pEdAssign->GetText();
