@@ -17,19 +17,19 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "rangelst.hxx"
-#include "scitems.hxx"
+#include <rangelst.hxx>
+#include <scitems.hxx>
 #include <sfx2/dispatch.hxx>
 #include <svl/zforlist.hxx>
 #include <vcl/msgbox.hxx>
 
-#include "uiitems.hxx"
-#include "reffact.hxx"
-#include "document.hxx"
-#include "scresid.hxx"
-#include "globstr.hrc"
-#include "sc.hrc"
-#include "solvrdlg.hxx"
+#include <uiitems.hxx>
+#include <reffact.hxx>
+#include <document.hxx>
+#include <scresid.hxx>
+#include <globstr.hrc>
+#include <sc.hrc>
+#include <solvrdlg.hxx>
 
 namespace
 {
@@ -41,7 +41,7 @@ namespace
 
 ScSolverDlg::ScSolverDlg( SfxBindings* pB, SfxChildWindow* pCW, vcl::Window* pParent,
                           ScDocument* pDocument,
-                          ScAddress aCursorPos )
+                          const ScAddress& aCursorPos )
 
     : ScAnyRefDlg(pB, pCW, pParent, "GoalSeekDialog", "modules/scalc/ui/goalseekdlg.ui")
     , theFormulaCell(aCursorPos)
@@ -199,7 +199,7 @@ bool ScSolverDlg::CheckTargetValue( const OUString& rStrVal )
 
 // Handler:
 
-IMPL_LINK_TYPED( ScSolverDlg, BtnHdl, Button*, pBtn, void )
+IMPL_LINK( ScSolverDlg, BtnHdl, Button*, pBtn, void )
 {
     if (pBtn == m_pBtnOk)
     {
@@ -255,7 +255,7 @@ IMPL_LINK_TYPED( ScSolverDlg, BtnHdl, Button*, pBtn, void )
     }
 }
 
-IMPL_LINK_TYPED( ScSolverDlg, GetFocusHdl, Control&, rCtrl, void )
+IMPL_LINK( ScSolverDlg, GetFocusHdl, Control&, rCtrl, void )
 {
     Edit* pEdit = nullptr;
     pEdActive = nullptr;
@@ -271,7 +271,7 @@ IMPL_LINK_TYPED( ScSolverDlg, GetFocusHdl, Control&, rCtrl, void )
         pEdit->SetSelection( Selection( 0, SELECTION_MAX ) );
 }
 
-IMPL_LINK_NOARG_TYPED(ScSolverDlg, LoseFocusHdl, Control&, void)
+IMPL_LINK_NOARG(ScSolverDlg, LoseFocusHdl, Control&, void)
 {
     bDlgLostFocus = !IsActive();
 }
