@@ -17,26 +17,22 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #undef SC_DLLIMPLEMENTATION
 
 #include <svl/eitem.hxx>
 
-#include "tpprint.hxx"
-#include "printopt.hxx"
-#include "scmod.hxx"
-#include "scresid.hxx"
-#include "sc.hrc"
-#include "optdlg.hrc"
+#include <tpprint.hxx>
+#include <printopt.hxx>
+#include <scmod.hxx>
+#include <scresid.hxx>
+#include <sc.hrc>
 
-// -----------------------------------------------------------------------
-
-ScTpPrintOptions::ScTpPrintOptions( Window*           pParent,
+ScTpPrintOptions::ScTpPrintOptions( vcl::Window*           pParent,
                                     const SfxItemSet& rCoreAttrs )
     :   SfxTabPage      ( pParent,
                           "optCalcPrintPage",
                           "modules/scalc/ui/optdlg.ui",
-                          rCoreAttrs )
+                          &rCoreAttrs )
 {
     get( m_pSkipEmptyPagesCB , "suppressCB" );
     get( m_pSelectedSheetsCB , "printCB" );
@@ -45,39 +41,46 @@ ScTpPrintOptions::ScTpPrintOptions( Window*           pParent,
 
 ScTpPrintOptions::~ScTpPrintOptions()
 {
+    disposeOnce();
 }
 
-SfxTabPage* ScTpPrintOptions::Create( Window* pParent, const SfxItemSet& rAttrSet )
+void ScTpPrintOptions::dispose()
 {
-    return new ScTpPrintOptions( pParent, rAttrSet );
+    m_pSkipEmptyPagesCB.clear();
+    m_pSelectedSheetsCB.clear();
+    m_pForceBreaksCB.clear();
+    SfxTabPage::dispose();
 }
 
-int ScTpPrintOptions::DeactivatePage( SfxItemSet* pSetP )
+VclPtr<SfxTabPage> ScTpPrintOptions::Create( vcl::Window* pParent, const SfxItemSet* rAttrSet )
+{
+    return VclPtr<ScTpPrintOptions>::Create( pParent, *rAttrSet );
+}
+
+DeactivateRC ScTpPrintOptions::DeactivatePage( SfxItemSet* pSetP )
 {
     if ( pSetP )
-        FillItemSet( *pSetP );
+        FillItemSet( pSetP );
 
-    return LEAVE_PAGE;
+    return DeactivateRC::LeavePage;
 }
 
-// -----------------------------------------------------------------------
-
-void ScTpPrintOptions::Reset( const SfxItemSet& rCoreSet )
+void ScTpPrintOptions::Reset( const SfxItemSet* rCoreSet )
 {
     ScPrintOptions aOptions;
 
     const SfxPoolItem* pItem;
-    if(SFX_ITEM_SET == rCoreSet.GetItemState(SID_SCPRINTOPTIONS, false , &pItem))
-        aOptions = ((const ScTpPrintItem*)pItem)->GetPrintOptions();
+    if(SfxItemState::SET == rCoreSet->GetItemState(SID_SCPRINTOPTIONS, false , &pItem))
+        aOptions = static_cast<const ScTpPrintItem*>(pItem)->GetPrintOptions();
     else
     {
         // when called from print dialog and no options set, use configuration
         aOptions = SC_MOD()->GetPrintOptions();
     }
 
-    if ( SFX_ITEM_SET == rCoreSet.GetItemState( SID_PRINT_SELECTEDSHEET, false , &pItem ) )
+    if ( SfxItemState::SET == rCoreSet->GetItemState( SID_PRINT_SELECTEDSHEET, false , &pItem ) )
     {
-        sal_Bool bChecked = ( (const SfxBoolItem*)pItem )->GetValue();
+        bool bChecked = static_cast<const SfxBoolItem*>(pItem)->GetValue();
         m_pSelectedSheetsCB->Check( bChecked );
     }
     else
@@ -92,15 +95,13 @@ void ScTpPrintOptions::Reset( const SfxItemSet& rCoreSet )
     m_pForceBreaksCB->SaveValue();
 }
 
-// -----------------------------------------------------------------------
-
-sal_Bool ScTpPrintOptions::FillItemSet( SfxItemSet& rCoreAttrs )
+bool ScTpPrintOptions::FillItemSet( SfxItemSet* rCoreAttrs )
 {
-    rCoreAttrs.ClearItem( SID_PRINT_SELECTEDSHEET );
+    rCoreAttrs->ClearItem( SID_PRINT_SELECTEDSHEET );
 
-    bool bSkipEmptyChanged = ( m_pSkipEmptyPagesCB->GetSavedValue() != m_pSkipEmptyPagesCB->IsChecked() );
-    bool bSelectedSheetsChanged = ( m_pSelectedSheetsCB->GetSavedValue() != m_pSelectedSheetsCB->IsChecked() );
-    bool bForceBreaksChanged = ( m_pForceBreaksCB->GetSavedValue() != m_pForceBreaksCB->IsChecked() );
+    bool bSkipEmptyChanged = m_pSkipEmptyPagesCB->IsValueChangedFromSaved();
+    bool bSelectedSheetsChanged = m_pSelectedSheetsCB->IsValueChangedFromSaved();
+    bool bForceBreaksChanged = m_pForceBreaksCB->IsValueChangedFromSaved();
 
     if ( bSkipEmptyChanged || bSelectedSheetsChanged || bForceBreaksChanged )
     {
@@ -108,12 +109,12 @@ sal_Bool ScTpPrintOptions::FillItemSet( SfxItemSet& rCoreAttrs )
         aOpt.SetSkipEmpty( m_pSkipEmptyPagesCB->IsChecked() );
         aOpt.SetAllSheets( !m_pSelectedSheetsCB->IsChecked() );
         aOpt.SetForceBreaks( m_pForceBreaksCB->IsChecked() );
-        rCoreAttrs.Put( ScTpPrintItem( SID_SCPRINTOPTIONS, aOpt ) );
+        rCoreAttrs->Put( ScTpPrintItem( aOpt ) );
         if ( bSelectedSheetsChanged )
         {
-            rCoreAttrs.Put( SfxBoolItem( SID_PRINT_SELECTEDSHEET, m_pSelectedSheetsCB->IsChecked() ) );
+            rCoreAttrs->Put( SfxBoolItem( SID_PRINT_SELECTEDSHEET, m_pSelectedSheetsCB->IsChecked() ) );
         }
-        return sal_True;
+        return true;
     }
     else
     {
