@@ -19,7 +19,7 @@
 
 #undef SC_DLLIMPLEMENTATION
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/eeitem.hxx>
 
 #include <editeng/editobj.hxx>
@@ -34,24 +34,20 @@
 
 #include <unotools/useroptions.hxx>
 
-#include "editutil.hxx"
-#include "global.hxx"
-#include "attrib.hxx"
-#include "patattr.hxx"
-#include "scresid.hxx"
-#include "sc.hrc"
-#include "globstr.hrc"
-#include "tabvwsh.hxx"
-#include "prevwsh.hxx"
-#include "textdlgs.hxx"
-#include "AccessibleEditObject.hxx"
+#include <editutil.hxx>
+#include <global.hxx>
+#include <attrib.hxx>
+#include <patattr.hxx>
+#include <scresid.hxx>
+#include <sc.hrc>
+#include <globstr.hrc>
+#include <tabvwsh.hxx>
+#include <prevwsh.hxx>
+#include <textdlgs.hxx>
+#include <AccessibleEditObject.hxx>
 
-#include "scuitphfedit.hxx"
-#include <boost/scoped_ptr.hpp>
-
-// STATIC DATA -----------------------------------------------------------
-
-static VclPtr<ScEditWindow> pActiveEdWnd = NULL;
+#include <scuitphfedit.hxx>
+#include <memory>
 
 // class ScHFEditPage
 
@@ -60,6 +56,7 @@ ScHFEditPage::ScHFEditPage( vcl::Window*             pParent,
                             sal_uInt16          nWhichId,
                             bool                bHeader  )
     : SfxTabPage( pParent, "HeaderFooterContent", "modules/scalc/ui/headerfootercontent.ui", &rCoreAttrs )
+    , m_pEditFocus(nullptr)
     , nWhich( nWhichId )
 {
     get(m_pWndLeft,"textviewWND_LEFT");
@@ -132,28 +129,34 @@ ScHFEditPage::ScHFEditPage( vcl::Window*             pParent,
     m_pWndCenter->SetFont( aPatAttr );
     m_pWndRight->SetFont( aPatAttr );
 
-    // Set size request of 1 widget, the other two will follow as they are
-    // in the same grid
-    Size aSize = LogicToPixel(Size(80, 120), MAP_APPFONT);
-    m_pWndLeft->set_width_request(aSize.Width());
-    m_pWndLeft->set_height_request(aSize.Height());
+    // Set size request for all 3 widgets
+    Size aSize = LogicToPixel(Size(80, 120), MapMode(MapUnit::MapAppFont));
+    VclPtr<ScEditWindow> aEditWindows[] = {m_pWndLeft, m_pWndCenter, m_pWndRight};
+
+    for (auto &pEditWindow : aEditWindows)
+    {
+        pEditWindow->set_width_request(aSize.Width());
+        pEditWindow->set_height_request(aSize.Height());
+    }
 
     m_pWndLeft->SetObjectSelectHdl( LINK(this,ScHFEditPage,ObjectSelectHdl) );
     m_pWndCenter->SetObjectSelectHdl( LINK(this,ScHFEditPage,ObjectSelectHdl) );
     m_pWndRight->SetObjectSelectHdl( LINK(this,ScHFEditPage,ObjectSelectHdl) );
-    FillCmdArr();
+    auto setEditFocus = [this](ScEditWindow & rEdit) { this->m_pEditFocus = &rEdit; };
+    m_pWndLeft->SetGetFocusHdl(setEditFocus);
+    m_pWndCenter->SetGetFocusHdl(setEditFocus);
+    m_pWndRight->SetGetFocusHdl(setEditFocus);
 
     m_pWndLeft->GrabFocus();
+    m_pEditFocus = m_pWndLeft; // there's no event from GrabFocus()
 
     InitPreDefinedList();
 
 }
 
-IMPL_LINK( ScHFEditPage, ObjectSelectHdl, ScEditWindow*, pEdit )
+IMPL_LINK_NOARG( ScHFEditPage, ObjectSelectHdl, ScEditWindow&, void )
 {
-    (void)pEdit;
     m_pBtnText->GrabFocus();
-    return 0;
 }
 
 ScHFEditPage::~ScHFEditPage()
@@ -195,7 +198,7 @@ void ScHFEditPage::SetNumType(SvxNumType eNumType)
 
 void ScHFEditPage::Reset( const SfxItemSet* rCoreSet )
 {
-    const SfxPoolItem* pItem = NULL;
+    const SfxPoolItem* pItem = nullptr;
     if ( rCoreSet->HasItem(nWhich, &pItem) )
     {
         const ScPageHFItem& rItem = static_cast<const ScPageHFItem&>(*pItem);
@@ -230,33 +233,12 @@ bool ScHFEditPage::FillItemSet( SfxItemSet* rCoreSet )
     return true;
 }
 
-#define SET_CMD(i,id) \
-    aCmd  = aDel;                           \
-    aCmd += ScGlobal::GetRscString( id );   \
-    aCmd += aDel;                           \
-    aCmdArr[i] = aCmd;
-
-void ScHFEditPage::FillCmdArr()
-{
-    OUString aDel( ScGlobal::GetRscString( STR_HFCMD_DELIMITER ) );
-    OUString aCmd;
-
-    SET_CMD( 0, STR_HFCMD_PAGE )
-    SET_CMD( 1, STR_HFCMD_PAGES )
-    SET_CMD( 2, STR_HFCMD_DATE )
-    SET_CMD( 3, STR_HFCMD_TIME )
-    SET_CMD( 4, STR_HFCMD_FILE )
-    SET_CMD( 5, STR_HFCMD_TABLE )
-}
-
-#undef SET_CMD
-
 void ScHFEditPage::InitPreDefinedList()
 {
     SvtUserOptions aUserOpt;
 
-    Color* pTxtColour = NULL;
-    Color* pFldColour = NULL;
+    Color* pTxtColour = nullptr;
+    Color* pFldColour = nullptr;
 
     // Get the all field values at the outset.
     OUString aPageFieldValue(m_pWndLeft->GetEditEngine()->CalcFieldValue(SvxFieldItem(SvxPageField(), EE_FEATURE_FIELD), 0,0, pTxtColour, pFldColour));
@@ -304,7 +286,7 @@ void ScHFEditPage::InitPreDefinedList()
 
 void ScHFEditPage::InsertToDefinedList()
 {
-    sal_uInt16 nCount =  m_pLbDefined->GetEntryCount();
+    const sal_Int32 nCount =  m_pLbDefined->GetEntryCount();
     if(nCount == eEntryCount)
     {
         m_pLbDefined->InsertEntry( m_pFtCustomized->GetText() );
@@ -314,7 +296,7 @@ void ScHFEditPage::InsertToDefinedList()
 
 void ScHFEditPage::RemoveFromDefinedList()
 {
-    sal_uInt16 nCount =  m_pLbDefined->GetEntryCount();
+    const sal_Int32 nCount =  m_pLbDefined->GetEntryCount();
     if(nCount > eEntryCount )
         m_pLbDefined->RemoveEntry( nCount-1);
 }
@@ -327,9 +309,9 @@ void ScHFEditPage::SetSelectDefinedList()
     // default to customized
     ScHFEntryId eSelectEntry = eEntryCount;
 
-    boost::scoped_ptr< EditTextObject > pLeftObj;
-    boost::scoped_ptr< EditTextObject > pCenterObj;
-    boost::scoped_ptr< EditTextObject > pRightObj;
+    std::unique_ptr< EditTextObject > pLeftObj;
+    std::unique_ptr< EditTextObject > pCenterObj;
+    std::unique_ptr< EditTextObject > pRightObj;
 
     OUString aLeftEntry;
     OUString aCenterEntry;
@@ -341,9 +323,8 @@ void ScHFEditPage::SetSelectDefinedList()
 
     bool bFound = false;
 
-    sal_uInt16 i;
-    sal_uInt16 nCount =  m_pLbDefined->GetEntryCount();
-    for(i = 0; i < nCount && !bFound; i++)
+    const sal_Int32 nCount = m_pLbDefined->GetEntryCount();
+    for(sal_Int32 i = 0; i < nCount && !bFound; ++i)
     {
         switch(static_cast<ScHFEntryId>(i))
         {
@@ -394,7 +375,7 @@ void ScHFEditPage::SetSelectDefinedList()
                         if(pFieldItem)
                         {
                             const SvxFieldData* pField = pFieldItem->GetField();
-                            if(pField && pField->ISA(SvxTableField))
+                            if(pField && dynamic_cast<const SvxTableField*>( pField) !=  nullptr)
                             {
                                 eSelectEntry = eSheetEntry;
                                 bFound = true;
@@ -505,7 +486,7 @@ void ScHFEditPage::SetSelectDefinedList()
     m_pLbDefined->SelectEntryPos( sal::static_int_cast<sal_uInt16>( eSelectEntry ) );
 }
 
-bool ScHFEditPage::IsPageEntry(EditEngine*pEngine, EditTextObject* pTextObj)
+bool ScHFEditPage::IsPageEntry(EditEngine*pEngine, const EditTextObject* pTextObj)
 {
     if(!pEngine || !pTextObj)
         return false;
@@ -525,7 +506,7 @@ bool ScHFEditPage::IsPageEntry(EditEngine*pEngine, EditTextObject* pTextObj)
             {
                 aSel.nStartPos = aSel.nEndPos;
                 aSel.nEndPos++;
-                boost::scoped_ptr< EditTextObject > pPageObj;
+                std::unique_ptr< EditTextObject > pPageObj;
                 pPageObj.reset(pEngine->CreateTextObject(aSel));
                 if(pPageObj.get() && pPageObj->IsFieldObject() )
                 {
@@ -533,7 +514,7 @@ bool ScHFEditPage::IsPageEntry(EditEngine*pEngine, EditTextObject* pTextObj)
                     if(pFieldItem)
                     {
                         const SvxFieldData* pField = pFieldItem->GetField();
-                        if(pField && pField->ISA(SvxPageField))
+                        if(pField && dynamic_cast<const SvxPageField*>( pField) !=  nullptr)
                             bReturn = true;
                     }
                 }
@@ -543,7 +524,7 @@ bool ScHFEditPage::IsPageEntry(EditEngine*pEngine, EditTextObject* pTextObj)
     return bReturn;
 }
 
-bool ScHFEditPage::IsDateEntry(EditTextObject* pTextObj)
+bool ScHFEditPage::IsDateEntry(const EditTextObject* pTextObj)
 {
     if(!pTextObj)
         return false;
@@ -555,14 +536,14 @@ bool ScHFEditPage::IsDateEntry(EditTextObject* pTextObj)
         if(pFieldItem)
         {
             const SvxFieldData* pField = pFieldItem->GetField();
-            if(pField && pField->ISA(SvxDateField))
+            if(pField && dynamic_cast<const SvxDateField*>( pField) !=  nullptr)
                 bReturn = true;
         }
     }
     return bReturn;
 }
 
-bool ScHFEditPage::IsExtFileNameEntry(EditTextObject* pTextObj)
+bool ScHFEditPage::IsExtFileNameEntry(const EditTextObject* pTextObj)
 {
     if(!pTextObj)
         return false;
@@ -573,7 +554,7 @@ bool ScHFEditPage::IsExtFileNameEntry(EditTextObject* pTextObj)
         if(pFieldItem)
     {
             const SvxFieldData* pField = pFieldItem->GetField();
-            if(pField && pField->ISA(SvxExtFileField))
+            if(pField && dynamic_cast<const SvxExtFileField*>( pField) !=  nullptr)
                 bReturn = true;
         }
     }
@@ -583,7 +564,7 @@ bool ScHFEditPage::IsExtFileNameEntry(EditTextObject* pTextObj)
 void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
 {
     SvtUserOptions aUserOpt;
-    boost::scoped_ptr< EditTextObject > pTextObj;
+    std::unique_ptr< EditTextObject > pTextObj;
 
     switch(eSel)
     {
@@ -637,7 +618,7 @@ void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
             ClearTextAreas();
             OUString aConfidentialEntry(aUserOpt.GetCompany() + " " + m_pFtConfidential->GetText());
             m_pWndLeft->GetEditEngine()->SetText(aConfidentialEntry);
-            m_pWndCenter->InsertField( SvxFieldItem(SvxDateField(Date( Date::SYSTEM ),SVXDATETYPE_VAR), EE_FEATURE_FIELD) );
+            m_pWndCenter->InsertField( SvxFieldItem(SvxDateField(Date( Date::SYSTEM ),SvxDateType::Var), EE_FEATURE_FIELD) );
 
             OUString aPageEntry( m_pFtPage->GetText() + " ");
             m_pWndRight->GetEditEngine()->SetText(aPageEntry);
@@ -668,7 +649,7 @@ void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
         case eExtFileNameEntry:
             ClearTextAreas();
             m_pWndCenter->InsertField( SvxFieldItem( SvxExtFileField(
-                EMPTY_OUSTRING, SVXFILETYPE_VAR, SVXFILEFORMAT_FULLPATH ), EE_FEATURE_FIELD ) );
+                EMPTY_OUSTRING, SvxFileType::Var, SvxFileFormat::PathFull ), EE_FEATURE_FIELD ) );
             if(!bTravelling)
                 m_pWndCenter->GrabFocus();
         break;
@@ -721,7 +702,7 @@ void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
             m_pWndCenter->GetEditEngine()->SetText(aPageEntry);
             m_pWndCenter->InsertField( SvxFieldItem(SvxPageField(), EE_FEATURE_FIELD) );
             m_pWndRight->InsertField( SvxFieldItem( SvxExtFileField(
-                EMPTY_OUSTRING, SVXFILETYPE_VAR, SVXFILEFORMAT_FULLPATH ), EE_FEATURE_FIELD ) );
+                EMPTY_OUSTRING, SvxFileType::Var, SvxFileFormat::PathFull ), EE_FEATURE_FIELD ) );
             if(!bTravelling)
                 m_pWndRight->GrabFocus();
         }
@@ -736,7 +717,7 @@ void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
             //aPageEntry += " ";
             m_pWndCenter->GetEditEngine()->SetText(aPageEntry);
             m_pWndCenter->InsertField( SvxFieldItem(SvxPageField(), EE_FEATURE_FIELD) );
-            m_pWndRight->InsertField( SvxFieldItem(SvxDateField(Date( Date::SYSTEM ),SVXDATETYPE_VAR), EE_FEATURE_FIELD) );
+            m_pWndRight->InsertField( SvxFieldItem(SvxDateField(Date( Date::SYSTEM ),SvxDateType::Var), EE_FEATURE_FIELD) );
             if(!bTravelling)
                 m_pWndRight->GrabFocus();
         }
@@ -747,7 +728,7 @@ void ScHFEditPage::ProcessDefinedListSel(ScHFEntryId eSel, bool bTravelling)
             ClearTextAreas();
             OUString aCreatedByEntry( m_pFtCreatedBy->GetText() + " " + aUserOpt.GetFirstName() + " " + aUserOpt.GetLastName());
             m_pWndLeft->GetEditEngine()->SetText(aCreatedByEntry);
-            m_pWndCenter->InsertField( SvxFieldItem(SvxDateField(Date( Date::SYSTEM ),SVXDATETYPE_VAR), EE_FEATURE_FIELD) );
+            m_pWndCenter->InsertField( SvxFieldItem(SvxDateField(Date( Date::SYSTEM ),SvxDateType::Var), EE_FEATURE_FIELD) );
             OUString aPageEntry( m_pFtPage->GetText() );
             aPageEntry += " ";
             m_pWndRight->GetEditEngine()->SetText(aPageEntry);
@@ -774,14 +755,14 @@ void ScHFEditPage::ClearTextAreas()
 
 // Handler:
 
-IMPL_LINK( ScHFEditPage, ListHdl_Impl, ListBox*, pList )
+IMPL_LINK( ScHFEditPage, ListHdl_Impl, ListBox&, rList, void )
 {
-    if ( pList && pList == m_pLbDefined )
+    if ( &rList == m_pLbDefined )
     {
-        ScHFEntryId eSel = static_cast<ScHFEntryId>(m_pLbDefined->GetSelectEntryPos());
+        ScHFEntryId eSel = static_cast<ScHFEntryId>(m_pLbDefined->GetSelectedEntryPos());
         if(!m_pLbDefined->IsTravelSelect())
         {
-            ProcessDefinedListSel(eSel);
+            ProcessDefinedListSel(eSel, false);
 
             // check if we need to remove the customized entry.
             if(eSel < eEntryCount)
@@ -792,69 +773,60 @@ IMPL_LINK( ScHFEditPage, ListHdl_Impl, ListBox*, pList )
             ProcessDefinedListSel(eSel, true);
         }
     }
-    return 0;
 }
 
-IMPL_LINK( ScHFEditPage, ClickHdl, PushButton*, pBtn )
+IMPL_LINK( ScHFEditPage, ClickHdl, Button*, pBtn, void )
 {
-    pActiveEdWnd = ::GetScEditWindow();
-    if ( !pActiveEdWnd )
-        return 0;
+    if (!m_pEditFocus)
+        return;
 
     if ( pBtn == m_pBtnText )
     {
-        pActiveEdWnd->SetCharAttributes();
+        m_pEditFocus->SetCharAttributes();
     }
     else
     {
         if ( pBtn == m_pBtnPage )
-            pActiveEdWnd->InsertField( SvxFieldItem(SvxPageField(), EE_FEATURE_FIELD) );
+            m_pEditFocus->InsertField(SvxFieldItem(SvxPageField(), EE_FEATURE_FIELD));
         else if ( pBtn == m_pBtnLastPage )
-            pActiveEdWnd->InsertField( SvxFieldItem(SvxPagesField(), EE_FEATURE_FIELD) );
+            m_pEditFocus->InsertField(SvxFieldItem(SvxPagesField(), EE_FEATURE_FIELD));
         else if ( pBtn == m_pBtnDate )
-            pActiveEdWnd->InsertField( SvxFieldItem(SvxDateField(Date( Date::SYSTEM ),SVXDATETYPE_VAR), EE_FEATURE_FIELD) );
+            m_pEditFocus->InsertField(SvxFieldItem(SvxDateField(Date(Date::SYSTEM),SvxDateType::Var), EE_FEATURE_FIELD));
         else if ( pBtn == m_pBtnTime )
-            pActiveEdWnd->InsertField( SvxFieldItem(SvxTimeField(), EE_FEATURE_FIELD) );
+            m_pEditFocus->InsertField(SvxFieldItem(SvxTimeField(), EE_FEATURE_FIELD));
         else if ( pBtn == m_pBtnFile )
         {
-            pActiveEdWnd->InsertField( SvxFieldItem( SvxFileField(), EE_FEATURE_FIELD ) );
+            m_pEditFocus->InsertField(SvxFieldItem(SvxFileField(), EE_FEATURE_FIELD));
         }
         else if ( pBtn == m_pBtnTable )
-            pActiveEdWnd->InsertField( SvxFieldItem(SvxTableField(), EE_FEATURE_FIELD) );
+            m_pEditFocus->InsertField(SvxFieldItem(SvxTableField(), EE_FEATURE_FIELD));
     }
     InsertToDefinedList();
-    pActiveEdWnd->GrabFocus();
-
-    return 0;
+    m_pEditFocus->GrabFocus();
 }
 
-IMPL_STATIC_LINK( ScHFEditPage, MenuHdl, ScExtIButton*, pBtn )
+IMPL_LINK( ScHFEditPage, MenuHdl, ScExtIButton&, rBtn, void )
 {
-    pActiveEdWnd = ::GetScEditWindow();
-    if ( !pActiveEdWnd )
-        return 0;
+    if (!m_pEditFocus)
+        return;
 
-    if(pBtn!=NULL)
+    SAL_WARN_IF(rBtn.GetSelected() == 0, "sc.ui", "nothing selected");
+    OString sSelectedId = rBtn.GetSelectedIdent();
+
+    if (sSelectedId == "title")
     {
-        SAL_WARN_IF(pBtn->GetSelected() == 0, "sc.ui", "nothing selected");
-        OString sSelectedId = pBtn->GetSelectedIdent();
-
-        if (sSelectedId == "title")
-        {
-            pActiveEdWnd->InsertField( SvxFieldItem( SvxFileField(), EE_FEATURE_FIELD ) );
-        }
-        else if (sSelectedId == "filename")
-        {
-            pActiveEdWnd->InsertField( SvxFieldItem( SvxExtFileField(
-                OUString(), SVXFILETYPE_VAR, SVXFILEFORMAT_NAME_EXT ), EE_FEATURE_FIELD ) );
-        }
-        else if (sSelectedId == "pathname")
-        {
-            pActiveEdWnd->InsertField( SvxFieldItem( SvxExtFileField(
-                OUString(), SVXFILETYPE_VAR, SVXFILEFORMAT_FULLPATH ), EE_FEATURE_FIELD ) );
-        }
+        m_pEditFocus->InsertField(SvxFieldItem(SvxFileField(), EE_FEATURE_FIELD));
+    }
+    else if (sSelectedId == "filename")
+    {
+        m_pEditFocus->InsertField( SvxFieldItem( SvxExtFileField(
+            OUString(), SvxFileType::Var, SvxFileFormat::NameAndExt ), EE_FEATURE_FIELD ) );
+    }
+    else if (sSelectedId == "pathname")
+    {
+        m_pEditFocus->InsertField( SvxFieldItem( SvxExtFileField(
+            OUString(), SvxFileType::Var, SvxFileFormat::PathFull ), EE_FEATURE_FIELD ) );
     }
-    return 0;
 }
 
 // class ScRightHeaderEditPage
