@@ -17,61 +17,33 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #undef SC_DLLIMPLEMENTATION
 
+#include <scitems.hxx>
 
+#include <vcl/settings.hxx>
 
-//------------------------------------------------------------------
+#include <tptable.hxx>
+#include <global.hxx>
+#include <attrib.hxx>
+#include <scresid.hxx>
+#include <sc.hrc>
+#include <bitmaps.hlst>
 
-#include "scitems.hxx"
+// Static Data
 
-#include "tptable.hxx"
-#include "global.hxx"
-#include "attrib.hxx"
-#include "scresid.hxx"
-#include "sc.hrc"
-#include "pagedlg.hrc"
-
-// =======================================================================
-
-void EmptyNumericField::Modify()
-{
-    if( !GetText().isEmpty() )
-        NumericField::Modify();
-    else
-        SetEmptyFieldValue();
-}
-
-void EmptyNumericField::SetValue( sal_Int64 nValue )
-{
-    if( nValue == 0 )
-        SetEmptyFieldValue();
-    else
-        NumericField::SetValue( nValue );
-}
-
-sal_Int64 EmptyNumericField::GetValue() const
-{
-    return IsEmptyFieldValue() ? 0 : NumericField::GetValue();
-}
-
-// =======================================================================
-
-// STATIC DATA -----------------------------------------------------------
-
-static sal_uInt16 pPageTableRanges[] =
+const sal_uInt16 ScTablePage::pPageTableRanges[] =
 {
     ATTR_PAGE_NOTES, ATTR_PAGE_FIRSTPAGENO,
     0
 };
 
-static sal_Bool lcl_PutVObjModeItem( sal_uInt16            nWhich,
+static bool lcl_PutVObjModeItem( sal_uInt16            nWhich,
                           SfxItemSet&       rCoreSet,
                           const SfxItemSet& rOldSet,
                           const CheckBox&   rBtn );
 
-static sal_Bool lcl_PutScaleItem( sal_uInt16               nWhich,
+static bool lcl_PutScaleItem( sal_uInt16               nWhich,
                        SfxItemSet&          rCoreSet,
                        const SfxItemSet&    rOldSet,
                        const ListBox&       rListBox,
@@ -79,41 +51,45 @@ static sal_Bool lcl_PutScaleItem( sal_uInt16               nWhich,
                        const SpinField&     rEd,
                        sal_uInt16               nValue );
 
-static sal_Bool lcl_PutScaleItem2( sal_uInt16               nWhich,
+static bool lcl_PutScaleItem2( sal_uInt16               nWhich,
                        SfxItemSet&          rCoreSet,
                        const SfxItemSet&    rOldSet,
                        const ListBox&       rListBox,
-                       sal_uInt16               nLBEntry,
+                       sal_uInt16           nLBEntry,
                        const NumericField&  rEd1,
-                       const NumericField&  rEd2 );
+                       sal_uInt16           nOrigScalePageWidth,
+                       const NumericField&  rEd2,
+                       sal_uInt16           nOrigScalePageHeight );
 
-static sal_Bool lcl_PutBoolItem( sal_uInt16            nWhich,
+static bool lcl_PutBoolItem( sal_uInt16            nWhich,
                       SfxItemSet&       rCoreSet,
                       const SfxItemSet& rOldSet,
-                      sal_Bool              bIsChecked,
-                      sal_Bool              bSavedValue );
-
-//------------------------------------------------------------------------
+                      bool              bIsChecked,
+                      bool              bSavedValue );
 
 #define PAGENO_HDL          LINK(this,ScTablePage,PageNoHdl)
 #define PAGEDIR_HDL         LINK(this,ScTablePage,PageDirHdl)
-#define SCALE_HDL           LINK(this,ScTablePage,ScaleHdl)
 
-#define WAS_DEFAULT(w,s)    (SFX_ITEM_DEFAULT==(s).GetItemState((w),sal_True))
-#define GET_BOOL(sid,set)   ((const SfxBoolItem&)((set).Get(GetWhich((sid))))).GetValue()
-#define GET_USHORT(sid,set) (sal_uInt16)((const SfxUInt16Item&)((set).Get(GetWhich((sid))))).GetValue()
-#define GET_SHOW(sid,set)   ( ScVObjMode( ((const ScViewObjectModeItem&)((set).Get(GetWhich((sid))))).GetValue() ) \
+namespace {
+
+bool WAS_DEFAULT(sal_uInt16 w, SfxItemSet const & s)
+{ return SfxItemState::DEFAULT==s.GetItemState(w); }
+
+}
+
+#define GET_BOOL(sid,set)   static_cast<const SfxBoolItem&>((set).Get(GetWhich((sid)))).GetValue()
+#define GET_USHORT(sid,set) static_cast<const SfxUInt16Item&>((set).Get(GetWhich((sid)))).GetValue()
+#define GET_SHOW(sid,set)   ( static_cast<const ScViewObjectModeItem&>((set).Get(GetWhich((sid)))).GetValue() \
                               == VOBJ_MODE_SHOW )
 // List box entries "Scaling mode"
 #define SC_TPTABLE_SCALE_PERCENT    0
 #define SC_TPTABLE_SCALE_TO         1
 #define SC_TPTABLE_SCALE_TO_PAGES   2
 
-//========================================================================
-
-ScTablePage::ScTablePage( Window* pParent, const SfxItemSet& rCoreAttrs ) :
-
-        SfxTabPage( pParent, "SheetPrintPage","modules/scalc/ui/sheetprintpage.ui", rCoreAttrs )
+ScTablePage::ScTablePage(vcl::Window* pParent, const SfxItemSet& rCoreAttrs)
+    : SfxTabPage(pParent, "SheetPrintPage","modules/scalc/ui/sheetprintpage.ui", &rCoreAttrs)
+    , m_nOrigScalePageWidth(0)
+    , m_nOrigScalePageHeight(0)
 {
     get(m_pBtnTopDown,"radioBTN_TOPDOWN");
     get(m_pBtnLeftRight,"radioBTN_LEFTRIGHT");
@@ -135,7 +111,9 @@ ScTablePage::ScTablePage( Window* pParent, const SfxItemSet& rCoreAttrs ) :
     get(m_pEdScaleAll,"spinED_SCALEALL");
     get(m_pGrHeightWidth,"gridWH");
     get(m_pEdScalePageWidth,"spinED_SCALEPAGEWIDTH");
+    get(m_pCbScalePageWidth,"unsetwidth");
     get(m_pEdScalePageHeight,"spinED_SCALEPAGEHEIGHT");
+    get(m_pCbScalePageHeight,"unsetheight");
     get(m_pBxScalePageNum,"boxNP");
     get(m_pEdScalePageNum,"spinED_SCALEPAGENUM");
 
@@ -144,111 +122,119 @@ ScTablePage::ScTablePage( Window* pParent, const SfxItemSet& rCoreAttrs ) :
     m_pBtnPageNo->SetClickHdl( PAGENO_HDL );
     m_pBtnTopDown->SetClickHdl( PAGEDIR_HDL );
     m_pBtnLeftRight->SetClickHdl( PAGEDIR_HDL );
-    m_pLbScaleMode->SetSelectHdl( SCALE_HDL );
-
+    m_pLbScaleMode->SetSelectHdl( LINK(this,ScTablePage,ScaleHdl) );
+    m_pCbScalePageWidth->SetToggleHdl(LINK(this, ScTablePage, ToggleHdl));
+    m_pCbScalePageHeight->SetToggleHdl(LINK(this, ScTablePage, ToggleHdl));
 }
 
-// -----------------------------------------------------------------------
-
 void ScTablePage::ShowImage()
 {
-    Image aImg = Image( ScResId( (m_pBtnLeftRight->IsChecked()) ? IMG_LEFTRIGHT : IMG_TOPDOWN ) );
+    Image aImg(BitmapEx(m_pBtnLeftRight->IsChecked() ? OUString(BMP_LEFTRIGHT) : OUString(BMP_TOPDOWN)));
     m_pBmpPageDir->SetImage( aImg );
     m_pBmpPageDir->SetOutputSizePixel( aImg.GetSizePixel() );
 }
 
-// -----------------------------------------------------------------------
-
 ScTablePage::~ScTablePage()
 {
+    disposeOnce();
 }
 
-//------------------------------------------------------------------------
-
-sal_uInt16* ScTablePage::GetRanges()
+void ScTablePage::dispose()
 {
-    return pPageTableRanges;
+    m_pBtnTopDown.clear();
+    m_pBtnLeftRight.clear();
+    m_pBmpPageDir.clear();
+    m_pBtnPageNo.clear();
+    m_pEdPageNo.clear();
+    m_pBtnHeaders.clear();
+    m_pBtnGrid.clear();
+    m_pBtnNotes.clear();
+    m_pBtnObjects.clear();
+    m_pBtnCharts.clear();
+    m_pBtnDrawings.clear();
+    m_pBtnFormulas.clear();
+    m_pBtnNullVals.clear();
+    m_pLbScaleMode.clear();
+    m_pBxScaleAll.clear();
+    m_pEdScaleAll.clear();
+    m_pGrHeightWidth.clear();
+    m_pCbScalePageWidth.clear();
+    m_pEdScalePageWidth.clear();
+    m_pCbScalePageHeight.clear();
+    m_pEdScalePageHeight.clear();
+    m_pBxScalePageNum.clear();
+    m_pEdScalePageNum.clear();
+    SfxTabPage::dispose();
 }
 
-// -----------------------------------------------------------------------
-
-SfxTabPage* ScTablePage::Create( Window* pParent, const SfxItemSet& rCoreSet )
+VclPtr<SfxTabPage> ScTablePage::Create( vcl::Window* pParent, const SfxItemSet* rCoreSet )
 {
-    return ( new ScTablePage( pParent, rCoreSet ) );
+    return VclPtr<ScTablePage>::Create( pParent, *rCoreSet );
 }
 
-// -----------------------------------------------------------------------
-
-void ScTablePage::Reset( const SfxItemSet& rCoreSet )
+void ScTablePage::Reset( const SfxItemSet* rCoreSet )
 {
-    sal_Bool    bTopDown = GET_BOOL( SID_SCATTR_PAGE_TOPDOWN, rCoreSet );
+    bool    bTopDown = GET_BOOL( SID_SCATTR_PAGE_TOPDOWN, *rCoreSet );
     sal_uInt16  nWhich   = 0;
 
-    //-----------
-    // sal_Bool-Flags
-    //-----------
-    m_pBtnNotes->Check( GET_BOOL(SID_SCATTR_PAGE_NOTES,rCoreSet) );
-    m_pBtnGrid->Check( GET_BOOL(SID_SCATTR_PAGE_GRID,rCoreSet) );
-    m_pBtnHeaders->Check( GET_BOOL(SID_SCATTR_PAGE_HEADERS,rCoreSet) );
-    m_pBtnFormulas->Check( GET_BOOL(SID_SCATTR_PAGE_FORMULAS,rCoreSet) );
-    m_pBtnNullVals->Check( GET_BOOL(SID_SCATTR_PAGE_NULLVALS,rCoreSet) );
+    // sal_Bool flags
+    m_pBtnNotes->Check( GET_BOOL(SID_SCATTR_PAGE_NOTES,*rCoreSet) );
+    m_pBtnGrid->Check( GET_BOOL(SID_SCATTR_PAGE_GRID,*rCoreSet) );
+    m_pBtnHeaders->Check( GET_BOOL(SID_SCATTR_PAGE_HEADERS,*rCoreSet) );
+    m_pBtnFormulas->Check( GET_BOOL(SID_SCATTR_PAGE_FORMULAS,*rCoreSet) );
+    m_pBtnNullVals->Check( GET_BOOL(SID_SCATTR_PAGE_NULLVALS,*rCoreSet) );
     m_pBtnTopDown->Check( bTopDown );
     m_pBtnLeftRight->Check( !bTopDown );
 
-    //------------------
-    // Erste Druckseite:
-    //------------------
-    sal_uInt16 nPage = GET_USHORT(SID_SCATTR_PAGE_FIRSTPAGENO,rCoreSet);
+    // first printed page:
+    sal_uInt16 nPage = GET_USHORT(SID_SCATTR_PAGE_FIRSTPAGENO,*rCoreSet);
     m_pBtnPageNo->Check( nPage != 0 );
     m_pEdPageNo->SetValue( (nPage != 0) ? nPage : 1 );
-    PageNoHdl( NULL );
+    PageNoHdl( nullptr );
 
-    //-------------------
-    // Objektdarstellung:
-    //-------------------
-    m_pBtnCharts->Check( GET_SHOW( SID_SCATTR_PAGE_CHARTS, rCoreSet ) );
-    m_pBtnObjects->Check( GET_SHOW( SID_SCATTR_PAGE_OBJECTS, rCoreSet ) );
-    m_pBtnDrawings->Check( GET_SHOW( SID_SCATTR_PAGE_DRAWINGS, rCoreSet ) );
-
-    //------------
-    // Skalierung:
-    //------------
+    // object representation:
+    m_pBtnCharts->Check( GET_SHOW( SID_SCATTR_PAGE_CHARTS, *rCoreSet ) );
+    m_pBtnObjects->Check( GET_SHOW( SID_SCATTR_PAGE_OBJECTS, *rCoreSet ) );
+    m_pBtnDrawings->Check( GET_SHOW( SID_SCATTR_PAGE_DRAWINGS, *rCoreSet ) );
 
+    // scaling:
     nWhich = GetWhich(SID_SCATTR_PAGE_SCALE);
-    if ( rCoreSet.GetItemState( nWhich, sal_True ) >= SFX_ITEM_AVAILABLE )
+    if ( rCoreSet->GetItemState( nWhich ) >= SfxItemState::DEFAULT )
     {
-        sal_uInt16 nScale = ((const SfxUInt16Item&)rCoreSet.Get(nWhich)).GetValue();
+        sal_uInt16 nScale = static_cast<const SfxUInt16Item&>(rCoreSet->Get(nWhich)).GetValue();
         if( nScale > 0 )
             m_pLbScaleMode->SelectEntryPos( SC_TPTABLE_SCALE_PERCENT );
         m_pEdScaleAll->SetValue( (nScale > 0) ? nScale : 100 );
     }
 
     nWhich = GetWhich(SID_SCATTR_PAGE_SCALETO);
-    if ( rCoreSet.GetItemState( nWhich, sal_True ) >= SFX_ITEM_AVAILABLE )
+    if ( rCoreSet->GetItemState( nWhich ) >= SfxItemState::DEFAULT )
     {
-        const ScPageScaleToItem& rItem = static_cast< const ScPageScaleToItem& >( rCoreSet.Get( nWhich ) );
+        const ScPageScaleToItem& rItem = static_cast< const ScPageScaleToItem& >( rCoreSet->Get( nWhich ) );
         sal_uInt16 nWidth = rItem.GetWidth();
         sal_uInt16 nHeight = rItem.GetHeight();
 
         /*  width==0 and height==0 is invalid state, used as "not selected".
             Dialog shows width=height=1 then. */
         bool bValid = nWidth || nHeight;
-        if( bValid )
+        if (bValid)
             m_pLbScaleMode->SelectEntryPos( SC_TPTABLE_SCALE_TO );
         m_pEdScalePageWidth->SetValue( bValid ? nWidth : 1 );
         m_pEdScalePageHeight->SetValue( bValid ? nHeight : 1 );
+        m_pCbScalePageWidth->Check(bValid && !nWidth);
+        m_pCbScalePageHeight->Check(bValid && !nHeight);
     }
 
     nWhich = GetWhich(SID_SCATTR_PAGE_SCALETOPAGES);
-    if ( rCoreSet.GetItemState( nWhich, sal_True ) >= SFX_ITEM_AVAILABLE )
+    if ( rCoreSet->GetItemState( nWhich ) >= SfxItemState::DEFAULT )
     {
-        sal_uInt16 nPages = ((const SfxUInt16Item&)rCoreSet.Get(nWhich)).GetValue();
+        sal_uInt16 nPages = static_cast<const SfxUInt16Item&>(rCoreSet->Get(nWhich)).GetValue();
         if( nPages > 0 )
             m_pLbScaleMode->SelectEntryPos( SC_TPTABLE_SCALE_TO_PAGES );
         m_pEdScalePageNum->SetValue( (nPages > 0) ? nPages : 1 );
     }
 
-    if( m_pLbScaleMode->GetSelectEntryCount() == 0 )
+    if( m_pLbScaleMode->GetSelectedEntryCount() == 0 )
     {
         // fall back to 100%
         OSL_FAIL( "ScTablePage::Reset - missing scaling item" );
@@ -256,10 +242,10 @@ void ScTablePage::Reset( const SfxItemSet& rCoreSet )
         m_pEdScaleAll->SetValue( 100 );
     }
 
-    PageDirHdl( NULL );
-    ScaleHdl( NULL );
+    PageDirHdl( nullptr );
+    ScaleHdl( *m_pLbScaleMode.get() );
 
-    // merken fuer FillItemSet
+    // remember for FillItemSet
     m_pBtnFormulas->SaveValue();
     m_pBtnNullVals->SaveValue();
     m_pBtnNotes->SaveValue();
@@ -274,64 +260,57 @@ void ScTablePage::Reset( const SfxItemSet& rCoreSet )
     m_pBtnPageNo->SaveValue();
     m_pEdPageNo->SaveValue();
     m_pEdScaleAll->SaveValue();
-    m_pEdScalePageWidth->SaveValue();
-    m_pEdScalePageHeight->SaveValue();
+    m_nOrigScalePageWidth = m_pEdScalePageWidth->IsEnabled() ? m_pEdScalePageWidth->GetValue() : 0;
+    m_nOrigScalePageHeight = m_pEdScalePageHeight->IsEnabled() ? m_pEdScalePageHeight->GetValue() : 0;
     m_pEdScalePageNum->SaveValue();
 }
 
-// -----------------------------------------------------------------------
-
-sal_Bool ScTablePage::FillItemSet( SfxItemSet& rCoreSet )
+bool ScTablePage::FillItemSet( SfxItemSet* rCoreSet )
 {
     const SfxItemSet&   rOldSet      = GetItemSet();
     sal_uInt16              nWhichPageNo = GetWhich(SID_SCATTR_PAGE_FIRSTPAGENO);
-    sal_Bool                bDataChanged = false;
-
-    //-----------
-    // sal_Bool-Flags
-    //-----------
+    bool                bDataChanged = false;
 
+    // sal_Bool flags
     bDataChanged |= lcl_PutBoolItem( GetWhich(SID_SCATTR_PAGE_NOTES),
-                                     rCoreSet, rOldSet,
+                                     *rCoreSet, rOldSet,
                                      m_pBtnNotes->IsChecked(),
-                                     m_pBtnNotes->GetSavedValue() != STATE_NOCHECK );
+                                     m_pBtnNotes->GetSavedValue() != TRISTATE_FALSE );
 
     bDataChanged |= lcl_PutBoolItem( GetWhich(SID_SCATTR_PAGE_GRID),
-                                     rCoreSet, rOldSet,
+                                     *rCoreSet, rOldSet,
                                      m_pBtnGrid->IsChecked(),
-                                     m_pBtnGrid->GetSavedValue() != STATE_NOCHECK );
+                                     m_pBtnGrid->GetSavedValue() != TRISTATE_FALSE );
 
     bDataChanged |= lcl_PutBoolItem( GetWhich(SID_SCATTR_PAGE_HEADERS),
-                                     rCoreSet, rOldSet,
+                                     *rCoreSet, rOldSet,
                                      m_pBtnHeaders->IsChecked(),
-                                     m_pBtnHeaders->GetSavedValue() != STATE_NOCHECK );
+                                     m_pBtnHeaders->GetSavedValue() != TRISTATE_FALSE );
 
     bDataChanged |= lcl_PutBoolItem( GetWhich(SID_SCATTR_PAGE_TOPDOWN),
-                                     rCoreSet, rOldSet,
+                                     *rCoreSet, rOldSet,
                                      m_pBtnTopDown->IsChecked(),
                                      m_pBtnTopDown->GetSavedValue() );
 
     bDataChanged |= lcl_PutBoolItem( GetWhich(SID_SCATTR_PAGE_FORMULAS),
-                                     rCoreSet, rOldSet,
+                                     *rCoreSet, rOldSet,
                                      m_pBtnFormulas->IsChecked(),
-                                     m_pBtnFormulas->GetSavedValue() != STATE_NOCHECK );
+                                     m_pBtnFormulas->GetSavedValue() != TRISTATE_FALSE );
 
     bDataChanged |= lcl_PutBoolItem( GetWhich(SID_SCATTR_PAGE_NULLVALS),
-                                     rCoreSet, rOldSet,
+                                     *rCoreSet, rOldSet,
                                      m_pBtnNullVals->IsChecked(),
-                                     m_pBtnNullVals->GetSavedValue() != STATE_NOCHECK );
+                                     m_pBtnNullVals->GetSavedValue() != TRISTATE_FALSE );
 
-    //------------------
-    // Erste Druckseite:
-    //------------------
-    sal_Bool bUseValue = m_pBtnPageNo->IsChecked();
+    // first printed page:
+    bool bUseValue = m_pBtnPageNo->IsChecked();
 
     if (   WAS_DEFAULT(nWhichPageNo,rOldSet)
-        && (    (!bUseValue && bUseValue == m_pBtnPageNo->GetSavedValue())
-            || (   bUseValue && bUseValue == m_pBtnPageNo->GetSavedValue()
-                   && m_pEdPageNo->GetText() == m_pEdPageNo->GetSavedValue() ) ) )
+        && (    (!bUseValue && 0 == m_pBtnPageNo->GetSavedValue())
+            || (   bUseValue && 1 == m_pBtnPageNo->GetSavedValue()
+                   && ! m_pEdPageNo->IsValueChangedFromSaved() ) ) )
     {
-            rCoreSet.ClearItem( nWhichPageNo );
+            rCoreSet->ClearItem( nWhichPageNo );
     }
     else
     {
@@ -339,83 +318,69 @@ sal_Bool ScTablePage::FillItemSet( SfxItemSet& rCoreSet )
                                     ? m_pEdPageNo->GetValue()
                                     : 0 );
 
-        rCoreSet.Put( SfxUInt16Item( nWhichPageNo, nPage ) );
-        bDataChanged = sal_True;
+        rCoreSet->Put( SfxUInt16Item( nWhichPageNo, nPage ) );
+        bDataChanged = true;
     }
 
-    //-------------------
-    // Objektdarstellung:
-    //-------------------
-
+    // object representation:
     bDataChanged |= lcl_PutVObjModeItem( GetWhich(SID_SCATTR_PAGE_CHARTS),
-                                         rCoreSet, rOldSet, *m_pBtnCharts );
+                                         *rCoreSet, rOldSet, *m_pBtnCharts );
 
     bDataChanged |= lcl_PutVObjModeItem( GetWhich(SID_SCATTR_PAGE_OBJECTS),
-                                         rCoreSet, rOldSet, *m_pBtnObjects );
+                                         *rCoreSet, rOldSet, *m_pBtnObjects );
 
     bDataChanged |= lcl_PutVObjModeItem( GetWhich(SID_SCATTR_PAGE_DRAWINGS),
-                                         rCoreSet, rOldSet, *m_pBtnDrawings );
+                                         *rCoreSet, rOldSet, *m_pBtnDrawings );
 
-    //------------
-    // Skalierung:
-    //------------
-
-    if( !m_pEdScalePageWidth->GetValue() && !m_pEdScalePageHeight->GetValue() )
+    // scaling:
+    if( !m_pEdScalePageWidth->IsEnabled() && !m_pEdScalePageHeight->IsEnabled() )
     {
         m_pLbScaleMode->SelectEntryPos( SC_TPTABLE_SCALE_PERCENT );
         m_pEdScaleAll->SetValue( 100 );
     }
 
     bDataChanged |= lcl_PutScaleItem( GetWhich(SID_SCATTR_PAGE_SCALE),
-                                      rCoreSet, rOldSet,
+                                      *rCoreSet, rOldSet,
                                       *m_pLbScaleMode, SC_TPTABLE_SCALE_PERCENT,
                                       *m_pEdScaleAll, (sal_uInt16)m_pEdScaleAll->GetValue() );
 
     bDataChanged |= lcl_PutScaleItem2( GetWhich(SID_SCATTR_PAGE_SCALETO),
-                                      rCoreSet, rOldSet,
+                                      *rCoreSet, rOldSet,
                                       *m_pLbScaleMode, SC_TPTABLE_SCALE_TO,
-                                      *m_pEdScalePageWidth, *m_pEdScalePageHeight );
+                                      *m_pEdScalePageWidth, m_nOrigScalePageWidth,
+                                      *m_pEdScalePageHeight, m_nOrigScalePageHeight );
 
     bDataChanged |= lcl_PutScaleItem( GetWhich(SID_SCATTR_PAGE_SCALETOPAGES),
-                                      rCoreSet, rOldSet,
+                                      *rCoreSet, rOldSet,
                                       *m_pLbScaleMode, SC_TPTABLE_SCALE_TO_PAGES,
                                       *m_pEdScalePageNum, (sal_uInt16)m_pEdScalePageNum->GetValue() );
 
     return bDataChanged;
 }
 
-//------------------------------------------------------------------------
-
-int ScTablePage::DeactivatePage( SfxItemSet* pSetP )
+DeactivateRC ScTablePage::DeactivatePage( SfxItemSet* pSetP )
 {
     if ( pSetP )
-        FillItemSet( *pSetP );
+        FillItemSet( pSetP );
 
-    return LEAVE_PAGE;
+    return DeactivateRC::LeavePage;
 }
 
-//------------------------------------------------------------------------
-
 void ScTablePage::DataChanged( const DataChangedEvent& rDCEvt )
 {
-    if( (rDCEvt.GetType() == DATACHANGED_SETTINGS) && (rDCEvt.GetFlags() & SETTINGS_STYLE) )
+    if( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) && (rDCEvt.GetFlags() & AllSettingsFlags::STYLE) )
         ShowImage();
     SfxTabPage::DataChanged( rDCEvt );
 }
 
-//------------------------------------------------------------------------
 // Handler:
-//------------------------------------------------------------------------
 
-IMPL_LINK_NOARG(ScTablePage, PageDirHdl)
+IMPL_LINK_NOARG(ScTablePage, PageDirHdl, Button*, void)
 {
     ShowImage();
-    return 0;
 }
 
-//------------------------------------------------------------------------
-
-IMPL_LINK( ScTablePage, PageNoHdl, CheckBox*, pBtn )
+IMPL_LINK( ScTablePage, PageNoHdl, Button*, pBtn, void )
 {
     if ( m_pBtnPageNo->IsChecked() )
     {
@@ -425,37 +390,59 @@ IMPL_LINK( ScTablePage, PageNoHdl, CheckBox*, pBtn )
     }
     else
         m_pEdPageNo->Disable();
-
-    return 0;
 }
 
-//------------------------------------------------------------------------
-
-IMPL_LINK_NOARG(ScTablePage, ScaleHdl)
+IMPL_LINK_NOARG(ScTablePage, ScaleHdl, ListBox&, void)
 {
     // controls for Box "Reduce/enlarge"
-    m_pBxScaleAll->Show(m_pLbScaleMode->GetSelectEntryPos() == SC_TPTABLE_SCALE_PERCENT);
+    m_pBxScaleAll->Show(m_pLbScaleMode->GetSelectedEntryPos() == SC_TPTABLE_SCALE_PERCENT);
 
     // controls for Grid "Scale to width/height"
-    m_pGrHeightWidth->Show(m_pLbScaleMode->GetSelectEntryPos() == SC_TPTABLE_SCALE_TO);
+    m_pGrHeightWidth->Show(m_pLbScaleMode->GetSelectedEntryPos() == SC_TPTABLE_SCALE_TO);
 
     // controls for Box "Scale to pages"
-    m_pBxScalePageNum->Show(m_pLbScaleMode->GetSelectEntryPos() == SC_TPTABLE_SCALE_TO_PAGES);
-
-    return 0;
+    m_pBxScalePageNum->Show(m_pLbScaleMode->GetSelectedEntryPos() == SC_TPTABLE_SCALE_TO_PAGES);
 }
 
-//========================================================================
-// Hilfsfunktionen fuer FillItemSet:
-//========================================================================
+IMPL_LINK(ScTablePage, ToggleHdl, CheckBox&, rBox, void)
+{
+    if (&rBox == m_pCbScalePageWidth)
+    {
+        if (rBox.IsChecked())
+        {
+            m_pEdScalePageWidth->SetText(OUString());
+            m_pEdScalePageWidth->Disable();
+        }
+        else
+        {
+            m_pEdScalePageWidth->SetValue(1);
+            m_pEdScalePageWidth->Enable();
+        }
+    }
+    else
+    {
+        if (rBox.IsChecked())
+        {
+            m_pEdScalePageHeight->SetText(OUString());
+            m_pEdScalePageHeight->Disable();
+        }
+        else
+        {
+            m_pEdScalePageHeight->SetValue(1);
+            m_pEdScalePageHeight->Enable();
+        }
+    }
+}
 
-static sal_Bool lcl_PutBoolItem( sal_uInt16            nWhich,
+// Helper functions for FillItemSet:
+
+static bool lcl_PutBoolItem( sal_uInt16            nWhich,
                      SfxItemSet&        rCoreSet,
                      const SfxItemSet&  rOldSet,
-                     sal_Bool               bIsChecked,
-                     sal_Bool               bSavedValue )
+                     bool               bIsChecked,
+                     bool               bSavedValue )
 {
-    sal_Bool bDataChanged = (   bSavedValue == bIsChecked
+    bool bDataChanged = (   bSavedValue == bIsChecked
                          && WAS_DEFAULT(nWhich,rOldSet) );
 
     if ( bDataChanged )
@@ -466,16 +453,14 @@ static sal_Bool lcl_PutBoolItem( sal_uInt16            nWhich,
     return bDataChanged;
 }
 
-//------------------------------------------------------------------------
-
-static sal_Bool lcl_PutVObjModeItem( sal_uInt16            nWhich,
+static bool lcl_PutVObjModeItem( sal_uInt16            nWhich,
                          SfxItemSet&        rCoreSet,
                          const SfxItemSet&  rOldSet,
                          const CheckBox&    rBtn )
 {
-    sal_Bool bIsChecked   = rBtn.IsChecked();
-    sal_Bool bDataChanged = (   rBtn.GetSavedValue() == bIsChecked
-                         && WAS_DEFAULT(nWhich,rOldSet) );
+    bool bIsChecked   = rBtn.IsChecked();
+    bool bDataChanged =     rBtn.GetSavedValue() == (bIsChecked ? 1 : 0)
+                         && WAS_DEFAULT(nWhich,rOldSet);
 
     if ( bDataChanged )
         rCoreSet.ClearItem( nWhich );
@@ -487,9 +472,7 @@ static sal_Bool lcl_PutVObjModeItem( sal_uInt16            nWhich,
     return bDataChanged;
 }
 
-//------------------------------------------------------------------------
-
-static sal_Bool lcl_PutScaleItem( sal_uInt16               nWhich,
+static bool lcl_PutScaleItem( sal_uInt16               nWhich,
                       SfxItemSet&           rCoreSet,
                       const SfxItemSet&     rOldSet,
                       const ListBox&        rListBox,
@@ -497,9 +480,9 @@ static sal_Bool lcl_PutScaleItem( sal_uInt16               nWhich,
                       const SpinField&      rEd,
                       sal_uInt16                nValue )
 {
-    sal_Bool bIsSel = (rListBox.GetSelectEntryPos() == nLBEntry);
-    sal_Bool bDataChanged = (rListBox.GetSavedValue() != nLBEntry) ||
-        (rEd.GetSavedValue() != rEd.GetText()) ||
+    bool bIsSel = (rListBox.GetSelectedEntryPos() == nLBEntry);
+    bool bDataChanged = (rListBox.GetSavedValue() != nLBEntry) ||
+                        rEd.IsValueChangedFromSaved() ||
                         !WAS_DEFAULT( nWhich, rOldSet );
 
     if( bDataChanged )
@@ -510,21 +493,22 @@ static sal_Bool lcl_PutScaleItem( sal_uInt16               nWhich,
     return bDataChanged;
 }
 
-
-static sal_Bool lcl_PutScaleItem2( sal_uInt16               nWhich,
+static bool lcl_PutScaleItem2( sal_uInt16               nWhich,
                       SfxItemSet&           rCoreSet,
                       const SfxItemSet&     rOldSet,
                       const ListBox&        rListBox,
-                      sal_uInt16                nLBEntry,
+                      sal_uInt16            nLBEntry,
                       const NumericField&   rEd1,
-                      const NumericField&   rEd2 )
+                      sal_uInt16            nOrigScalePageWidth,
+                      const NumericField&   rEd2,
+                      sal_uInt16            nOrigScalePageHeight )
 {
-    sal_uInt16 nValue1 = (sal_uInt16)rEd1.GetValue();
-    sal_uInt16 nValue2 = (sal_uInt16)rEd2.GetValue();
-    sal_Bool bIsSel = (rListBox.GetSelectEntryPos() == nLBEntry);
-    sal_Bool bDataChanged = (rListBox.GetSavedValue() != nLBEntry) ||
-        (rEd1.GetSavedValue() != rEd1.GetText()) ||
-        (rEd2.GetSavedValue() != rEd2.GetText()) ||
+    sal_uInt16 nValue1 = rEd1.IsEnabled() ? rEd1.GetValue() : 0;
+    sal_uInt16 nValue2 = rEd2.IsEnabled() ? rEd2.GetValue() : 0;
+    bool bIsSel = (rListBox.GetSelectedEntryPos() == nLBEntry);
+    bool bDataChanged = (rListBox.GetSavedValue() != nLBEntry) ||
+                        nValue1 != nOrigScalePageWidth ||
+                        nValue1 != nOrigScalePageHeight ||
                         !WAS_DEFAULT( nWhich, rOldSet );
 
     if( bDataChanged )
@@ -540,6 +524,4 @@ static sal_Bool lcl_PutScaleItem2( sal_uInt16               nWhich,
     return bDataChanged;
 }
 
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
