@@ -23,13 +23,8 @@
 using namespace ::ooo::vba;
 using namespace ::com::sun::star;
 
-void
-ScVbaDialogs::Dummy() throw (uno::RuntimeException)
-{
-}
-
 uno::Any
-ScVbaDialogs::Item( const uno::Any &aItem ) throw (uno::RuntimeException)
+ScVbaDialogs::Item( const uno::Any &aItem )
 {
     sal_Int32 nIndex = 0;
     aItem >>= nIndex;
