@@ -17,9 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 #include "vbapagesetup.hxx"
-#include "cellsuno.hxx"
-#include "convuno.hxx"
-#include "rangelst.hxx"
+#include <cellsuno.hxx>
+#include <convuno.hxx>
+#include <rangelst.hxx>
 #include "excelvbahelper.hxx"
 #include "vbarange.hxx"
 #include <com/sun/star/sheet/XPrintAreas.hpp>
@@ -30,6 +30,7 @@
 #include <ooo/vba/excel/XlPageOrientation.hpp>
 #include <ooo/vba/excel/XlOrder.hpp>
 #include <ooo/vba/excel/Constants.hpp>
+#include <basic/sberrors.hxx>
 #include <i18nutil/paper.hxx>
 #include <sal/macros.h>
 #include <algorithm>
@@ -44,7 +45,7 @@ using namespace ::ooo::vba;
 ScVbaPageSetup::ScVbaPageSetup(const uno::Reference< XHelperInterface >& xParent,
                 const uno::Reference< uno::XComponentContext >& xContext,
                 const uno::Reference< sheet::XSpreadsheet >& xSheet,
-                const uno::Reference< frame::XModel >& xModel) throw (uno::RuntimeException):
+                const uno::Reference< frame::XModel >& xModel):
            ScVbaPageSetup_BASE( xParent, xContext ), mxSheet( xSheet ), mbIsLandscape( false )
 {
     // query for current page style
@@ -63,7 +64,7 @@ ScVbaPageSetup::ScVbaPageSetup(const uno::Reference< XHelperInterface >& xParent
     mxPageProps->getPropertyValue("IsLandscape") >>= mbIsLandscape;
 }
 
-OUString SAL_CALL ScVbaPageSetup::getPrintArea() throw (css::uno::RuntimeException, std::exception)
+OUString SAL_CALL ScVbaPageSetup::getPrintArea()
 {
     OUString aPrintArea;
     uno::Reference< sheet::XPrintAreas > xPrintAreas( mxSheet, uno::UNO_QUERY_THROW );
@@ -72,8 +73,6 @@ OUString SAL_CALL ScVbaPageSetup::getPrintArea() throw (css::uno::RuntimeExcepti
     if( nCount )
     {
         ScAddress::Details aDetails( formula::FormulaGrammar::CONV_XL_A1, 0, 0 );
-        sal_uInt16 nFlags = SCA_VALID;
-        nFlags |= ( SCA_TAB_ABSOLUTE | SCA_COL_ABSOLUTE | SCA_ROW_ABSOLUTE | SCA_TAB2_ABSOLUTE | SCA_COL2_ABSOLUTE | SCA_ROW2_ABSOLUTE );
         ScRangeList aRangeList;
         for( sal_Int32 i=0; i<nCount; i++ )
         {
@@ -82,13 +81,13 @@ OUString SAL_CALL ScVbaPageSetup::getPrintArea() throw (css::uno::RuntimeExcepti
             aRangeList.Append( aRange );
         }
         ScDocument& rDoc = excel::getDocShell( mxModel )->GetDocument();
-        aRangeList.Format( aPrintArea, nFlags, &rDoc, formula::FormulaGrammar::CONV_XL_A1, ','  );
+        aRangeList.Format( aPrintArea, ScRefFlags::RANGE_ABS, &rDoc, formula::FormulaGrammar::CONV_XL_A1, ','  );
     }
 
     return aPrintArea;
 }
 
-void SAL_CALL ScVbaPageSetup::setPrintArea( const OUString& rAreas ) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setPrintArea( const OUString& rAreas )
 {
     uno::Reference< sheet::XPrintAreas > xPrintAreas( mxSheet, uno::UNO_QUERY_THROW );
     if( rAreas.isEmpty() ||
@@ -117,32 +116,32 @@ void SAL_CALL ScVbaPageSetup::setPrintArea( const OUString& rAreas ) throw (css:
     }
 }
 
-double SAL_CALL ScVbaPageSetup::getHeaderMargin() throw (css::uno::RuntimeException)
+double SAL_CALL ScVbaPageSetup::getHeaderMargin()
 {
     return VbaPageSetupBase::getHeaderMargin();
 }
 
-void SAL_CALL ScVbaPageSetup::setHeaderMargin( double margin ) throw (css::uno::RuntimeException)
+void SAL_CALL ScVbaPageSetup::setHeaderMargin( double margin )
 {
     VbaPageSetupBase::setHeaderMargin( margin );
 }
 
-double SAL_CALL ScVbaPageSetup::getFooterMargin() throw (css::uno::RuntimeException)
+double SAL_CALL ScVbaPageSetup::getFooterMargin()
 {
     return VbaPageSetupBase::getFooterMargin();
 }
 
-void SAL_CALL ScVbaPageSetup::setFooterMargin( double margin ) throw (css::uno::RuntimeException)
+void SAL_CALL ScVbaPageSetup::setFooterMargin( double margin )
 {
     VbaPageSetupBase::setFooterMargin( margin );
 }
 
-uno::Any SAL_CALL ScVbaPageSetup::getFitToPagesTall() throw (css::uno::RuntimeException, std::exception)
+uno::Any SAL_CALL ScVbaPageSetup::getFitToPagesTall()
 {
     return mxPageProps->getPropertyValue("ScaleToPagesY");
 }
 
-void SAL_CALL ScVbaPageSetup::setFitToPagesTall( const uno::Any& fitToPagesTall) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setFitToPagesTall( const uno::Any& fitToPagesTall)
 {
     sal_uInt16 scaleToPageY = 0;
     try
@@ -160,12 +159,12 @@ void SAL_CALL ScVbaPageSetup::setFitToPagesTall( const uno::Any& fitToPagesTall)
     }
 }
 
-uno::Any SAL_CALL ScVbaPageSetup::getFitToPagesWide() throw (css::uno::RuntimeException, std::exception)
+uno::Any SAL_CALL ScVbaPageSetup::getFitToPagesWide()
 {
     return mxPageProps->getPropertyValue("ScaleToPagesX");
 }
 
-void SAL_CALL ScVbaPageSetup::setFitToPagesWide( const uno::Any& fitToPagesWide) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setFitToPagesWide( const uno::Any& fitToPagesWide)
 {
     sal_uInt16 scaleToPageX = 0;
     try
@@ -183,12 +182,12 @@ void SAL_CALL ScVbaPageSetup::setFitToPagesWide( const uno::Any& fitToPagesWide)
     }
 }
 
-uno::Any SAL_CALL ScVbaPageSetup::getZoom() throw (css::uno::RuntimeException, std::exception)
+uno::Any SAL_CALL ScVbaPageSetup::getZoom()
 {
     return mxPageProps->getPropertyValue("PageScale");
 }
 
-void SAL_CALL ScVbaPageSetup::setZoom( const uno::Any& zoom) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setZoom( const uno::Any& zoom)
 {
     sal_uInt16 pageScale = 0;
     try
@@ -199,7 +198,7 @@ void SAL_CALL ScVbaPageSetup::setZoom( const uno::Any& zoom) throw (css::uno::Ru
             zoom >>= aValue;
             if( aValue )
             {
-                DebugHelper::runtimeexception(ERRCODE_BASIC_BAD_PARAMETER, OUString() );
+                DebugHelper::runtimeexception(ERRCODE_BASIC_BAD_PARAMETER);
             }
         }
         else
@@ -207,7 +206,7 @@ void SAL_CALL ScVbaPageSetup::setZoom( const uno::Any& zoom) throw (css::uno::Ru
             zoom >>= pageScale;
             if(( pageScale < ZOOM_IN )||( pageScale > ZOOM_MAX ))
             {
-                DebugHelper::runtimeexception(ERRCODE_BASIC_BAD_PARAMETER, OUString() );
+                DebugHelper::runtimeexception(ERRCODE_BASIC_BAD_PARAMETER);
             }
         }
 
@@ -221,7 +220,7 @@ void SAL_CALL ScVbaPageSetup::setZoom( const uno::Any& zoom) throw (css::uno::Ru
     {
         if( pageScale == 0 )
         {
-            DebugHelper::runtimeexception(ERRCODE_BASIC_BAD_PARAMETER, OUString() );
+            DebugHelper::runtimeexception(ERRCODE_BASIC_BAD_PARAMETER);
         }
     }
     catch (const uno::Exception&)
@@ -231,7 +230,7 @@ void SAL_CALL ScVbaPageSetup::setZoom( const uno::Any& zoom) throw (css::uno::Ru
     mxPageProps->setPropertyValue("PageScale", uno::makeAny( pageScale ));
 }
 
-OUString SAL_CALL ScVbaPageSetup::getLeftHeader() throw (css::uno::RuntimeException, std::exception)
+OUString SAL_CALL ScVbaPageSetup::getLeftHeader()
 {
     OUString leftHeader;
     try
@@ -250,7 +249,7 @@ OUString SAL_CALL ScVbaPageSetup::getLeftHeader() throw (css::uno::RuntimeExcept
     return leftHeader;
 }
 
-void SAL_CALL ScVbaPageSetup::setLeftHeader( const OUString& leftHeader) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setLeftHeader( const OUString& leftHeader)
 {
     try
     {
@@ -267,7 +266,7 @@ void SAL_CALL ScVbaPageSetup::setLeftHeader( const OUString& leftHeader) throw (
     }
 }
 
-OUString SAL_CALL ScVbaPageSetup::getCenterHeader() throw (css::uno::RuntimeException, std::exception)
+OUString SAL_CALL ScVbaPageSetup::getCenterHeader()
 {
     OUString centerHeader;
     try
@@ -286,7 +285,7 @@ OUString SAL_CALL ScVbaPageSetup::getCenterHeader() throw (css::uno::RuntimeExce
     return centerHeader;
 }
 
-void SAL_CALL ScVbaPageSetup::setCenterHeader( const OUString& centerHeader) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setCenterHeader( const OUString& centerHeader)
 {
     try
     {
@@ -303,7 +302,7 @@ void SAL_CALL ScVbaPageSetup::setCenterHeader( const OUString& centerHeader) thr
     }
 }
 
-OUString SAL_CALL ScVbaPageSetup::getRightHeader() throw (css::uno::RuntimeException, std::exception)
+OUString SAL_CALL ScVbaPageSetup::getRightHeader()
 {
     OUString rightHeader;
     try
@@ -322,7 +321,7 @@ OUString SAL_CALL ScVbaPageSetup::getRightHeader() throw (css::uno::RuntimeExcep
     return rightHeader;
 }
 
-void SAL_CALL ScVbaPageSetup::setRightHeader( const OUString& rightHeader) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setRightHeader( const OUString& rightHeader)
 {
     try
     {
@@ -339,7 +338,7 @@ void SAL_CALL ScVbaPageSetup::setRightHeader( const OUString& rightHeader) throw
     }
 }
 
-OUString SAL_CALL ScVbaPageSetup::getLeftFooter() throw (css::uno::RuntimeException, std::exception)
+OUString SAL_CALL ScVbaPageSetup::getLeftFooter()
 {
     OUString leftFooter;
     try
@@ -358,7 +357,7 @@ OUString SAL_CALL ScVbaPageSetup::getLeftFooter() throw (css::uno::RuntimeExcept
     return leftFooter;
 }
 
-void SAL_CALL ScVbaPageSetup::setLeftFooter( const OUString& leftFooter) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setLeftFooter( const OUString& leftFooter)
 {
     try
     {
@@ -375,7 +374,7 @@ void SAL_CALL ScVbaPageSetup::setLeftFooter( const OUString& leftFooter) throw (
     }
 }
 
-OUString SAL_CALL ScVbaPageSetup::getCenterFooter() throw (css::uno::RuntimeException, std::exception)
+OUString SAL_CALL ScVbaPageSetup::getCenterFooter()
 {
     OUString centerFooter;
     try
@@ -394,7 +393,7 @@ OUString SAL_CALL ScVbaPageSetup::getCenterFooter() throw (css::uno::RuntimeExce
     return centerFooter;
 }
 
-void SAL_CALL ScVbaPageSetup::setCenterFooter( const OUString& centerFooter) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setCenterFooter( const OUString& centerFooter)
 {
     try
     {
@@ -412,7 +411,7 @@ void SAL_CALL ScVbaPageSetup::setCenterFooter( const OUString& centerFooter) thr
 
 }
 
-OUString SAL_CALL ScVbaPageSetup::getRightFooter() throw (css::uno::RuntimeException, std::exception)
+OUString SAL_CALL ScVbaPageSetup::getRightFooter()
 {
     OUString rightFooter;
     try
@@ -431,7 +430,7 @@ OUString SAL_CALL ScVbaPageSetup::getRightFooter() throw (css::uno::RuntimeExcep
     return rightFooter;
 }
 
-void SAL_CALL ScVbaPageSetup::setRightFooter( const OUString& rightFooter) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setRightFooter( const OUString& rightFooter)
 {
     try
     {
@@ -448,7 +447,7 @@ void SAL_CALL ScVbaPageSetup::setRightFooter( const OUString& rightFooter) throw
     }
 }
 
-sal_Int32 SAL_CALL ScVbaPageSetup::getOrder() throw (css::uno::RuntimeException, std::exception)
+sal_Int32 SAL_CALL ScVbaPageSetup::getOrder()
 {
     sal_Int32 order = excel::XlOrder::xlDownThenOver;
     try
@@ -466,7 +465,7 @@ sal_Int32 SAL_CALL ScVbaPageSetup::getOrder() throw (css::uno::RuntimeException,
     return order;
 }
 
-void SAL_CALL ScVbaPageSetup::setOrder(sal_Int32 order) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setOrder(sal_Int32 order)
 {
     bool bOrder = true;
     switch( order )
@@ -477,7 +476,7 @@ void SAL_CALL ScVbaPageSetup::setOrder(sal_Int32 order) throw (css::uno::Runtime
             bOrder = false;
             break;
         default:
-            DebugHelper::runtimeexception(ERRCODE_BASIC_BAD_PARAMETER, OUString() );
+            DebugHelper::runtimeexception(ERRCODE_BASIC_BAD_PARAMETER);
     }
 
     try
@@ -489,7 +488,7 @@ void SAL_CALL ScVbaPageSetup::setOrder(sal_Int32 order) throw (css::uno::Runtime
     }
 }
 
-sal_Int32 SAL_CALL ScVbaPageSetup::getFirstPageNumber() throw (css::uno::RuntimeException, std::exception)
+sal_Int32 SAL_CALL ScVbaPageSetup::getFirstPageNumber()
 {
     sal_Int16 number = 0;
     try
@@ -509,7 +508,7 @@ sal_Int32 SAL_CALL ScVbaPageSetup::getFirstPageNumber() throw (css::uno::Runtime
     return number;
 }
 
-void SAL_CALL ScVbaPageSetup::setFirstPageNumber( sal_Int32 firstPageNumber) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setFirstPageNumber( sal_Int32 firstPageNumber)
 {
     if( firstPageNumber == excel::Constants::xlAutomatic )
         firstPageNumber = 0;
@@ -525,7 +524,7 @@ void SAL_CALL ScVbaPageSetup::setFirstPageNumber( sal_Int32 firstPageNumber) thr
     }
 }
 
-sal_Bool SAL_CALL ScVbaPageSetup::getCenterVertically() throw (css::uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL ScVbaPageSetup::getCenterVertically()
 {
     bool centerVertically = false;
     try
@@ -539,7 +538,7 @@ sal_Bool SAL_CALL ScVbaPageSetup::getCenterVertically() throw (css::uno::Runtime
     return centerVertically;
 }
 
-void SAL_CALL ScVbaPageSetup::setCenterVertically( sal_Bool centerVertically) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setCenterVertically( sal_Bool centerVertically)
 {
     try
     {
@@ -550,7 +549,7 @@ void SAL_CALL ScVbaPageSetup::setCenterVertically( sal_Bool centerVertically) th
     }
 }
 
-sal_Bool SAL_CALL ScVbaPageSetup::getCenterHorizontally() throw (css::uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL ScVbaPageSetup::getCenterHorizontally()
 {
     bool centerHorizontally = false;
     try
@@ -564,7 +563,7 @@ sal_Bool SAL_CALL ScVbaPageSetup::getCenterHorizontally() throw (css::uno::Runti
     return centerHorizontally;
 }
 
-void SAL_CALL ScVbaPageSetup::setCenterHorizontally( sal_Bool centerHorizontally) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setCenterHorizontally( sal_Bool centerHorizontally)
 {
     try
     {
@@ -575,7 +574,7 @@ void SAL_CALL ScVbaPageSetup::setCenterHorizontally( sal_Bool centerHorizontally
     }
 }
 
-sal_Bool SAL_CALL ScVbaPageSetup::getPrintHeadings() throw (css::uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL ScVbaPageSetup::getPrintHeadings()
 {
     bool printHeadings = false;
     try
@@ -589,7 +588,7 @@ sal_Bool SAL_CALL ScVbaPageSetup::getPrintHeadings() throw (css::uno::RuntimeExc
     return printHeadings;
 }
 
-void SAL_CALL ScVbaPageSetup::setPrintHeadings( sal_Bool printHeadings) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setPrintHeadings( sal_Bool printHeadings)
 {
     try
     {
@@ -600,32 +599,32 @@ void SAL_CALL ScVbaPageSetup::setPrintHeadings( sal_Bool printHeadings) throw (c
     }
 }
 
-sal_Bool SAL_CALL ScVbaPageSetup::getPrintGridlines() throw (uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL ScVbaPageSetup::getPrintGridlines()
 {
     return false;
 }
 
-void SAL_CALL ScVbaPageSetup::setPrintGridlines( sal_Bool /*_printgridlines*/ ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setPrintGridlines( sal_Bool /*_printgridlines*/ )
 {
 }
 
-OUString SAL_CALL ScVbaPageSetup::getPrintTitleRows() throw (uno::RuntimeException, std::exception)
+OUString SAL_CALL ScVbaPageSetup::getPrintTitleRows()
 {
     return OUString();
 }
-void SAL_CALL ScVbaPageSetup::setPrintTitleRows( const OUString& /*_printtitlerows*/ ) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setPrintTitleRows( const OUString& /*_printtitlerows*/ )
 {
 }
-OUString SAL_CALL ScVbaPageSetup::getPrintTitleColumns() throw (uno::RuntimeException, std::exception)
+OUString SAL_CALL ScVbaPageSetup::getPrintTitleColumns()
 {
     return OUString();
 }
 
-void SAL_CALL ScVbaPageSetup::setPrintTitleColumns( const OUString& /*_printtitlecolumns*/ ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setPrintTitleColumns( const OUString& /*_printtitlecolumns*/ )
 {
 }
 
-sal_Int32 SAL_CALL ScVbaPageSetup::getPaperSize() throw (uno::RuntimeException, std::exception)
+sal_Int32 SAL_CALL ScVbaPageSetup::getPaperSize()
 {
     awt::Size aSize; // current papersize
     mxPageProps->getPropertyValue( "Size" ) >>= aSize;
@@ -638,7 +637,7 @@ sal_Int32 SAL_CALL ScVbaPageSetup::getPaperSize() throw (uno::RuntimeException,
     return nPaperSizeIndex;
 }
 
-void SAL_CALL ScVbaPageSetup::setPaperSize( sal_Int32 papersize ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaPageSetup::setPaperSize( sal_Int32 papersize )
 {
     if ( papersize != excel::XlPaperSize::xlPaperUser )
     {
