@@ -17,8 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "dbfunc.hxx"
-#include "scitems.hxx"
+#include <dbfunc.hxx>
+#include <scitems.hxx>
 #include <sfx2/bindings.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/msgbox.hxx>
@@ -36,43 +36,45 @@
 #include <com/sun/star/sheet/XDimensionsSupplier.hpp>
 #include <com/sun/star/sheet/XDrillDownDataSupplier.hpp>
 
-#include "global.hxx"
-#include "globstr.hrc"
-#include "sc.hrc"
-#include "undotab.hxx"
-#include "undodat.hxx"
-#include "dbdata.hxx"
-#include "rangenam.hxx"
-#include "rangeutl.hxx"
-#include "docsh.hxx"
-#include "olinetab.hxx"
-#include "consoli.hxx"
-#include "olinefun.hxx"
-#include "dpobject.hxx"
-#include "dpsave.hxx"
-#include "dpdimsave.hxx"
-#include "dbdocfun.hxx"
-#include "dpoutput.hxx"
-#include "dptabsrc.hxx"
-#include "dpshttab.hxx"
-#include "dpsdbtab.hxx"
-#include "editable.hxx"
-#include "docpool.hxx"
-#include "patattr.hxx"
-#include "unonames.hxx"
-#include "formulacell.hxx"
-#include "userlist.hxx"
-#include "queryentry.hxx"
-#include "markdata.hxx"
-#include "stringutil.hxx"
-#include "tabvwsh.hxx"
-#include "generalfunction.hxx"
+#include <global.hxx>
+#include <globstr.hrc>
+#include <sc.hrc>
+#include <undotab.hxx>
+#include <undodat.hxx>
+#include <dbdata.hxx>
+#include <rangenam.hxx>
+#include <rangeutl.hxx>
+#include <docsh.hxx>
+#include <olinetab.hxx>
+#include <consoli.hxx>
+#include <olinefun.hxx>
+#include <dpobject.hxx>
+#include <dpsave.hxx>
+#include <dpdimsave.hxx>
+#include <dbdocfun.hxx>
+#include <dpoutput.hxx>
+#include <dptabsrc.hxx>
+#include <dpshttab.hxx>
+#include <dpsdbtab.hxx>
+#include <editable.hxx>
+#include <docpool.hxx>
+#include <patattr.hxx>
+#include <unonames.hxx>
+#include <formulacell.hxx>
+#include <userlist.hxx>
+#include <queryentry.hxx>
+#include <markdata.hxx>
+#include <stringutil.hxx>
+#include <tabvwsh.hxx>
+#include <generalfunction.hxx>
 
 #include <list>
 #include <memory>
 #include <unordered_set>
 #include <unordered_map>
 #include <vector>
+#include <set>
+#include <algorithm>
 
 using namespace com::sun::star;
 using ::com::sun::star::uno::Any;
@@ -82,7 +84,6 @@ using ::com::sun::star::uno::UNO_QUERY;
 using ::com::sun::star::beans::XPropertySet;
 using ::com::sun::star::container::XNameAccess;
 using ::com::sun::star::sheet::XDimensionsSupplier;
-using ::std::list;
 using ::std::vector;
 
 //          outliner
@@ -396,11 +397,11 @@ void ScDBFunc::DoSubTotals( const ScSubTotalParam& rParam, bool bRecord,
     if (rParam.bReplace)
         if (rDoc.TestRemoveSubTotals( nTab, rParam ))
         {
-            bOk = ( ScopedVclPtrInstance<MessBox>( GetViewData().GetDialogParent(), WinBits(WB_YES_NO | WB_DEF_YES),
-                // "StarCalc" "delete data?"
-                ScGlobal::GetRscString( STR_MSSG_DOSUBTOTALS_0 ),
-                ScGlobal::GetRscString( STR_MSSG_DOSUBTOTALS_1 ) )->Execute()
-                == RET_YES );
+            bOk = ScopedVclPtrInstance<MessBox>( GetViewData().GetDialogParent(), MessBoxStyle::YesNo | MessBoxStyle::DefaultYes, 0,
+                            // "StarCalc" "delete data?"
+                            ScGlobal::GetRscString( STR_MSSG_DOSUBTOTALS_0 ),
+                            ScGlobal::GetRscString( STR_MSSG_DOSUBTOTALS_1 ) )->Execute()
+                    == RET_YES;
         }
 
     if (bOk)
@@ -992,8 +993,7 @@ void ScDBFunc::DateGroupDataPilot( const ScDPNumGroupInfo& rInfo, sal_Int32 nPar
                     {
                         ScDPSaveDimension* pOldDimension = aData.GetDimensionByName( aBaseDimName );
                         pSaveDimension->SetOrientation( pOldDimension->GetOrientation() );
-                        long nPosition = 0;     //! before (immediate) base
-                        aData.SetPosition( pSaveDimension, nPosition );
+                        aData.SetPosition( pSaveDimension, 0 ); //! before (immediate) base
                     }
                 }
             }
@@ -1179,8 +1179,7 @@ void ScDBFunc::GroupDataPilot()
     {
         ScDPSaveDimension* pOldDimension = aData.GetDimensionByName( aDimName );
         pSaveDimension->SetOrientation( pOldDimension->GetOrientation() );
-        long nPosition = 0;     //! before (immediate) base
-        aData.SetPosition( pSaveDimension, nPosition );
+        aData.SetPosition( pSaveDimension, 0 ); //! before (immediate) base
     }
 
     // apply changes
@@ -1279,7 +1278,7 @@ static OUString lcl_replaceMemberNameInSubtotal(const OUString& rSubtotal, const
         if (c == ' ')
         {
             OUString aWord = aWordBuf.makeStringAndClear();
-            if (aWord.equals(rMemberName))
+            if (aWord == rMemberName)
                 aBuf.append('?');
             else
                 aBuf.append(aWord);
@@ -1304,7 +1303,7 @@ static OUString lcl_replaceMemberNameInSubtotal(const OUString& rSubtotal, const
     if (!aWordBuf.isEmpty())
     {
         OUString aWord = aWordBuf.makeStringAndClear();
-        if (aWord.equals(rMemberName))
+        if (aWord == rMemberName)
             aBuf.append('?');
         else
             aBuf.append(aWord);
@@ -1330,11 +1329,12 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
         return;
     }
 
-    sal_uInt16 nErrorId = 0;
+    const char* pErrorId = nullptr;
 
     pDPObj->BuildAllDimensionMembers();
     ScDPSaveData aData( *pDPObj->GetSaveData() );
     bool bChange = false;
+    bool bNeedReloadGroups = false;
 
     DataPilotFieldOrientation nOrient = DataPilotFieldOrientation_HIDDEN;
     long nField = pDPObj->GetHeaderDim( rPos, nOrient );
@@ -1361,7 +1361,7 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
                     bChange = true;
                 }
                 else
-                    nErrorId = STR_INVALIDNAME;
+                    pErrorId = STR_INVALIDNAME;
             }
         }
         else if (nOrient == DataPilotFieldOrientation_COLUMN || nOrient == DataPilotFieldOrientation_ROW)
@@ -1384,10 +1384,10 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
                         bChange = true;
                     }
                     else
-                        nErrorId = STR_INVALIDNAME;
+                        pErrorId = STR_INVALIDNAME;
                 }
                 else
-                    nErrorId = STR_INVALIDNAME;
+                    pErrorId = STR_INVALIDNAME;
             }
         }
     }
@@ -1410,10 +1410,10 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
                     bChange = true;
                 }
                 else
-                    nErrorId = STR_INVALIDNAME;
+                    pErrorId = STR_INVALIDNAME;
             }
             else
-                nErrorId = STR_INVALIDNAME;
+                pErrorId = STR_INVALIDNAME;
         }
     }
     else
@@ -1455,12 +1455,13 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
                             pSaveMember->SetName( rString );
 
                         bChange = true;
+                        bNeedReloadGroups = true;
                     }
                     else
-                        nErrorId = STR_INVALIDNAME;
+                        pErrorId = STR_INVALIDNAME;
                  }
             }
-            else if ((aPosData.Flags & MemberResultFlags::GRANDTOTAL))
+            else if (aPosData.Flags & MemberResultFlags::GRANDTOTAL)
             {
                 aData.SetGrandTotalName(rString);
                 bChange = true;
@@ -1474,7 +1475,7 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
                     // data dimension
                     do
                     {
-                        if ((aPosData.Flags & MemberResultFlags::SUBTOTAL))
+                        if (aPosData.Flags & MemberResultFlags::SUBTOTAL)
                             break;
 
                         ScDPSaveDimension* pDim = aData.GetDimensionByName(aPosData.MemberName);
@@ -1483,7 +1484,7 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
 
                         if (rString.isEmpty())
                         {
-                            nErrorId = STR_INVALIDNAME;
+                            pErrorId = STR_INVALIDNAME;
                             break;
                         }
 
@@ -1498,7 +1499,7 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
                             bChange = true;
                         }
                         else
-                            nErrorId = STR_INVALIDNAME;
+                            pErrorId = STR_INVALIDNAME;
                     }
                     while (false);
                 }
@@ -1515,7 +1516,7 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
                         if (!pMem)
                             break;
 
-                        if ((aPosData.Flags & MemberResultFlags::SUBTOTAL))
+                        if (aPosData.Flags & MemberResultFlags::SUBTOTAL)
                         {
                             // Change subtotal only when the table has one data dimension.
                             if (aData.GetDataDimensionCount() > 1)
@@ -1556,10 +1557,10 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
                                     bChange = true;
                                 }
                                 else
-                                    nErrorId = STR_INVALIDNAME;
+                                    pErrorId = STR_INVALIDNAME;
                             }
                             else
-                                nErrorId = STR_INVALIDNAME;
+                                pErrorId = STR_INVALIDNAME;
                         }
                     }
                     while (false);
@@ -1573,13 +1574,23 @@ void ScDBFunc::DataPilotInput( const ScAddress& rPos, const OUString& rString )
         // apply changes
         ScDBDocFunc aFunc( *GetViewData().GetDocShell() );
         pDPObj->SetSaveData( aData );
+        if (bNeedReloadGroups)
+        {
+            ScDPCollection* pDPs = pDoc->GetDPCollection();
+            if (pDPs)
+            {
+                std::set<ScDPObject*> aRefs;
+                // tdf#111305: Reload groups in cache after modifications.
+                pDPs->ReloadGroupsInCache(pDPObj, aRefs);
+            } // pDPs
+        } // bNeedReloadGroups
         aFunc.UpdatePivotTable(*pDPObj, true, false);
     }
     else
     {
-        if ( !nErrorId )
-            nErrorId = STR_ERR_DATAPILOT_INPUT;
-        ErrorMessage( nErrorId );
+        if (!pErrorId)
+            pErrorId = STR_ERR_DATAPILOT_INPUT;
+        ErrorMessage(pErrorId);
     }
 }
 
@@ -1608,7 +1619,7 @@ struct ScOUStringCollate
     }
 };
 
-void ScDBFunc::DataPilotSort(ScDPObject* pDPObj, long nDimIndex, bool bAscending, sal_uInt16* pUserListId)
+void ScDBFunc::DataPilotSort(ScDPObject* pDPObj, long nDimIndex, bool bAscending, const sal_uInt16* pUserListId)
 {
     if (!pDPObj)
         return;
@@ -1637,8 +1648,8 @@ void ScDBFunc::DataPilotSort(ScDPObject* pDPObj, long nDimIndex, bool bAscending
     {
         typedef ScDPSaveDimension::MemberList MemList;
         const MemList& rDimMembers = pSaveDim->GetMembers();
-        list<OUString> aMembers;
-        std::unordered_set<OUString, OUStringHash> aMemberSet;
+        vector<OUString> aMembers;
+        std::unordered_set<OUString> aMemberSet;
         size_t nMemberCount = 0;
         for (MemList::const_iterator itr = rDimMembers.begin(), itrEnd = rDimMembers.end();
               itr != itrEnd; ++itr)
@@ -1651,11 +1662,11 @@ void ScDBFunc::DataPilotSort(ScDPObject* pDPObj, long nDimIndex, bool bAscending
 
         // Sort the member list in ascending order.
         ScOUStringCollate aCollate( ScGlobal::GetCollator() );
-        aMembers.sort(aCollate);
+        std::stable_sort(aMembers.begin(), aMembers.end(), aCollate);
 
         // Collect and rank those custom sort strings that also exist in the member name list.
 
-        typedef std::unordered_map<OUString, sal_uInt16, OUStringHash> UserSortMap;
+        typedef std::unordered_map<OUString, sal_uInt16> UserSortMap;
         UserSortMap aSubStrs;
         sal_uInt16 nSubCount = 0;
         if (pUserListId)
@@ -1679,7 +1690,7 @@ void ScDBFunc::DataPilotSort(ScDPObject* pDPObj, long nDimIndex, bool bAscending
                     // This string doesn't exist in the member name set.  Don't add this.
                     continue;
 
-                aSubStrs.insert(UserSortMap::value_type(aSub, nSubCount++));
+                aSubStrs.emplace(aSub, nSubCount++);
             }
         }
 
@@ -1687,12 +1698,10 @@ void ScDBFunc::DataPilotSort(ScDPObject* pDPObj, long nDimIndex, bool bAscending
 
         vector<OUString> aRankedNames(nMemberCount);
         sal_uInt16 nCurStrId = 0;
-        for (list<OUString>::const_iterator itr = aMembers.begin(), itrEnd = aMembers.end();
-              itr != itrEnd; ++itr)
+        for (auto const& aMemberName : aMembers)
         {
-            OUString aName = *itr;
             sal_uInt16 nRank = 0;
-            UserSortMap::const_iterator itrSub = aSubStrs.find(aName);
+            UserSortMap::const_iterator itrSub = aSubStrs.find(aMemberName);
             if (itrSub == aSubStrs.end())
                 nRank = nSubCount + nCurStrId++;
             else
@@ -1701,15 +1710,13 @@ void ScDBFunc::DataPilotSort(ScDPObject* pDPObj, long nDimIndex, bool bAscending
             if (!bAscending)
                 nRank = static_cast< sal_uInt16 >( nMemberCount - nRank - 1 );
 
-            aRankedNames[nRank] = aName;
+            aRankedNames[nRank] = aMemberName;
         }
 
         // Re-order ScDPSaveMember instances with the new ranks.
-
-        for (vector<OUString>::const_iterator itr = aRankedNames.begin(), itrEnd = aRankedNames.end();
-              itr != itrEnd; ++itr)
+        for (auto const& aRankedName : aRankedNames)
         {
-            const ScDPSaveMember* pOldMem = pSaveDim->GetExistingMemberByName(*itr);
+            const ScDPSaveMember* pOldMem = pSaveDim->GetExistingMemberByName(aRankedName);
             if (!pOldMem)
                 // All members are supposed to be present.
                 continue;
@@ -1756,7 +1763,7 @@ bool ScDBFunc::DataPilotMove( const ScRange& rSource, const ScAddress& rDest )
         bool bValid = ( aDestData.Dimension >= 0 );        // dropping onto a field
 
         // look through the source range
-        std::unordered_set< OUString, OUStringHash > aMembersSet;   // for lookup
+        std::unordered_set< OUString > aMembersSet;   // for lookup
         std::vector< OUString > aMembersVector;  // members in original order, for inserting
         aMembersVector.reserve( std::max( static_cast<SCSIZE>( rSource.aEnd.Col() - rSource.aStart.Col() + 1 ),
                                           static_cast<SCSIZE>( rSource.aEnd.Row() - rSource.aStart.Row() + 1 ) ) );
@@ -1991,7 +1998,7 @@ void ScDBFunc::ShowDataPilotSourceData( ScDPObject& rDPObj, const Sequence<sheet
 
     SCTAB nNewTab = GetViewData().GetTabNo();
 
-    std::unique_ptr<ScDocument> pInsDoc(new ScDocument(SCDOCMODE_CLIP));
+    ScDocumentUniquePtr pInsDoc(new ScDocument(SCDOCMODE_CLIP));
     pInsDoc->ResetClip( pDoc, nNewTab );
     for (SCROW nRow = 0; nRow < nRowSize; ++nRow)
     {
@@ -2151,12 +2158,12 @@ void ScDBFunc::RepeatDB( bool bRecord )
 
         if (bSort)
         {
-            pDBData->GetSortParam( aSortParam );            // range may have chaged
+            pDBData->GetSortParam( aSortParam );            // range may have changed
             Sort( aSortParam, false, false);
         }
         if (bQuery)
         {
-            pDBData->GetQueryParam( aQueryParam );          // range may have chaged
+            pDBData->GetQueryParam( aQueryParam );          // range may have changed
             ScRange aAdvSource;
             if (pDBData->GetAdvancedQuerySource(aAdvSource))
             {
@@ -2172,7 +2179,7 @@ void ScDBFunc::RepeatDB( bool bRecord )
         }
         if (bSubTotal)
         {
-            pDBData->GetSubTotalParam( aSubTotalParam );    // range may have chaged
+            pDBData->GetSubTotalParam( aSubTotalParam );    // range may have changed
             aSubTotalParam.bRemoveOnly = false;
             DoSubTotals( aSubTotalParam, false );
         }
