@@ -21,11 +21,13 @@
 #include <vcl/taskpanelist.hxx>
 #include <vcl/settings.hxx>
 
-#include "olinewin.hxx"
-#include "olinetab.hxx"
-#include "document.hxx"
-#include "dbfunc.hxx"
-#include "sc.hrc"
+#include <olinewin.hxx>
+#include <olinetab.hxx>
+#include <document.hxx>
+#include <dbfunc.hxx>
+#include <strings.hrc>
+#include <scresid.hxx>
+#include <bitmaps.hlst>
 
 const long SC_OL_BITMAPSIZE                 = 12;
 const long SC_OL_POSOFFSET                  = 2;
@@ -33,11 +35,6 @@ const long SC_OL_POSOFFSET                  = 2;
 const size_t SC_OL_NOLEVEL                  = static_cast< size_t >( -1 );
 const size_t SC_OL_HEADERENTRY              = static_cast< size_t >( -1 );
 
-const sal_uInt16 SC_OL_IMAGE_PLUS               = 9;
-const sal_uInt16 SC_OL_IMAGE_MINUS              = SC_OL_IMAGE_PLUS + 1;
-const sal_uInt16 SC_OL_IMAGE_NOTPRESSED         = SC_OL_IMAGE_MINUS + 1;
-const sal_uInt16 SC_OL_IMAGE_PRESSED            = SC_OL_IMAGE_NOTPRESSED + 1;
-
 ScOutlineWindow::ScOutlineWindow( vcl::Window* pParent, ScOutlineMode eMode, ScViewData* pViewData, ScSplitPos eWhich ) :
     Window( pParent ),
     mrViewData( *pViewData ),
@@ -45,7 +42,6 @@ ScOutlineWindow::ScOutlineWindow( vcl::Window* pParent, ScOutlineMode eMode, ScV
     mbHoriz( eMode == SC_OUTLINE_HOR ),
     mbMirrorEntries( false ),           // updated in SetHeaderSize
     mbMirrorLevels( false ),            // updated in SetHeaderSize
-    mpSymbols( nullptr ),
     maLineColor( COL_BLACK ),
     mnHeaderSize( 0 ),
     mnHeaderPos( 0 ),
@@ -141,7 +137,7 @@ void ScOutlineWindow::ScrollPixel( long nDiff )
 
 void ScOutlineWindow::ScrollRel( long nEntryDiff, long nEntryStart, long nEntryEnd )
 {
-    Rectangle aRect( GetRectangle( 0, nEntryStart, GetOutputSizeLevel() - 1, nEntryEnd ) );
+    tools::Rectangle aRect( GetRectangle( 0, nEntryStart, GetOutputSizeLevel() - 1, nEntryEnd ) );
     if ( mbHoriz )
         Scroll( nEntryDiff, 0, aRect );
     else
@@ -155,7 +151,6 @@ void ScOutlineWindow::InitSettings()
     const StyleSettings& rStyleSettings = GetSettings().GetStyleSettings();
     SetBackground( rStyleSettings.GetFaceColor() );
     maLineColor = rStyleSettings.GetButtonTextColor();
-    mpSymbols = ScGlobal::GetOutlineSymbols();
     Invalidate();
 }
 
@@ -216,10 +211,10 @@ Point ScOutlineWindow::GetPoint( long nLevelPos, long nEntryPos ) const
     return mbHoriz ? Point( nEntryPos, nLevelPos ) : Point( nLevelPos, nEntryPos );
 }
 
-Rectangle ScOutlineWindow::GetRectangle(
+tools::Rectangle ScOutlineWindow::GetRectangle(
         long nLevelStart, long nEntryStart, long nLevelEnd, long nEntryEnd ) const
 {
-    return Rectangle( GetPoint( nLevelStart, nEntryStart ), GetPoint( nLevelEnd, nEntryEnd ) );
+    return tools::Rectangle( GetPoint( nLevelStart, nEntryStart ), GetPoint( nLevelEnd, nEntryEnd ) );
 }
 
 long ScOutlineWindow::GetOutputSizeLevel() const
@@ -293,7 +288,7 @@ bool ScOutlineWindow::GetEntryPos(
                 (rnStartPos - ( SC_OL_BITMAPSIZE / 2 ) * nEntriesSign) :
                 rnStartPos + nEntriesSign;
     long nCenter = (rnStartPos + rnEndPos - SC_OL_BITMAPSIZE * nEntriesSign +
-                        ( mbMirrorEntries ? 1 : 0 )) / 2L;
+                        ( mbMirrorEntries ? 1 : 0 )) / 2;
     rnImagePos = mbMirrorEntries ? std::max( rnImagePos, nCenter ) : std::min( rnImagePos, nCenter );
 
     // --- refinements ---
@@ -516,7 +511,7 @@ void ScOutlineWindow::DataChanged( const DataChangedEvent& rDCEvt )
 
 void ScOutlineWindow::SetEntryAreaClipRegion()
 {
-    SetClipRegion( vcl::Region(Rectangle(
+    SetClipRegion( vcl::Region(tools::Rectangle(
         GetPoint( 0, mnMainFirstPos ),
         GetPoint( GetOutputSizeLevel() - 1, mnMainLastPos ))));
 }
@@ -533,14 +528,21 @@ void ScOutlineWindow::DrawRectRel(
     DrawRect( GetRectangle( nLevelStart, nEntryStart, nLevelEnd, nEntryEnd ) );
 }
 
-void ScOutlineWindow::DrawImageRel( long nLevelPos, long nEntryPos, sal_uInt16 nId )
+namespace
 {
-    OSL_ENSURE( mpSymbols, "ScOutlineWindow::DrawImageRel - no images" );
-    const Image& rImage = mpSymbols->GetImage( nId );
+    Image GetImage(const OUString& rId)
+    {
+        return Image(BitmapEx(rId));
+    }
+}
+
+void ScOutlineWindow::DrawImageRel(long nLevelPos, long nEntryPos, const OUString& rId)
+{
+    const Image& rImage = GetImage(rId);
     SetLineColor();
     SetFillColor( GetBackground().GetColor() );
     Point aPos( GetPoint( nLevelPos, nEntryPos ) );
-    DrawRect( Rectangle( aPos, rImage.GetSizePixel() ) );
+    DrawRect( tools::Rectangle( aPos, rImage.GetSizePixel() ) );
     DrawImage( aPos, rImage );
 }
 
@@ -549,12 +551,11 @@ void ScOutlineWindow::DrawBorderRel( size_t nLevel, size_t nEntry, bool bPressed
     Point aPos;
     if ( GetImagePos( nLevel, nEntry, aPos ) )
     {
-        OSL_ENSURE( mpSymbols, "ScOutlineWindow::DrawBorderRel - no images" );
-        sal_uInt16 nId = bPressed ? SC_OL_IMAGE_PRESSED : SC_OL_IMAGE_NOTPRESSED;
+        OUString sId = bPressed ? OUString(RID_BMP_PRESSED) : OUString(RID_BMP_NOTPRESSED);
         bool bClip = (nEntry != SC_OL_HEADERENTRY);
         if ( bClip )
             SetEntryAreaClipRegion();
-        DrawImage( aPos, mpSymbols->GetImage( nId ) );
+        DrawImage(aPos, GetImage(sId));
         if ( bClip )
             SetClipRegion();
     }
@@ -574,11 +575,11 @@ void ScOutlineWindow::ShowFocus()
             if ( GetImagePos( mnFocusLevel, mnFocusEntry, aPos ) )
             {
                 aPos += Point( 1, 1 );
-                maFocusRect = Rectangle( aPos, Size( SC_OL_BITMAPSIZE - 2, SC_OL_BITMAPSIZE - 2 ) );
+                maFocusRect = tools::Rectangle( aPos, Size( SC_OL_BITMAPSIZE - 2, SC_OL_BITMAPSIZE - 2 ) );
                 bool bClip = (mnFocusEntry != SC_OL_HEADERENTRY);
                 if ( bClip )
                     SetEntryAreaClipRegion();
-                InvertTracking( maFocusRect, SHOWTRACK_SMALL | SHOWTRACK_WINDOW );
+                InvertTracking( maFocusRect, ShowTrackFlags::Small | ShowTrackFlags::TrackWindow );
                 if ( bClip )
                     SetClipRegion();
             }
@@ -593,14 +594,26 @@ void ScOutlineWindow::HideFocus()
         bool bClip = (mnFocusEntry != SC_OL_HEADERENTRY);
         if ( bClip )
             SetEntryAreaClipRegion();
-        InvertTracking( maFocusRect, SHOWTRACK_SMALL | SHOWTRACK_WINDOW );
+        InvertTracking( maFocusRect, ShowTrackFlags::Small | ShowTrackFlags::TrackWindow );
         if ( bClip )
             SetClipRegion();
         maFocusRect.SetEmpty();
     }
 }
 
-void ScOutlineWindow::Paint( vcl::RenderContext& /*rRenderContext*/, const Rectangle& /* rRect */ )
+static const OUStringLiteral aLevelBmps[]=
+{
+    RID_BMP_LEVEL1,
+    RID_BMP_LEVEL2,
+    RID_BMP_LEVEL3,
+    RID_BMP_LEVEL4,
+    RID_BMP_LEVEL5,
+    RID_BMP_LEVEL6,
+    RID_BMP_LEVEL7,
+    RID_BMP_LEVEL8
+};
+
+void ScOutlineWindow::Paint( vcl::RenderContext& /*rRenderContext*/, const tools::Rectangle& /* rRect */ )
 {
     long nEntriesSign = mbMirrorEntries ? -1 : 1;
     long nLevelsSign  = mbMirrorLevels  ? -1 : 1;
@@ -624,7 +637,7 @@ void ScOutlineWindow::Paint( vcl::RenderContext& /*rRenderContext*/, const Recta
     {
         long nEntryPos = GetHeaderEntryPos();
         for ( size_t nLevel = 0; nLevel < nLevelCount; ++nLevel )
-            DrawImageRel( GetLevelPos( nLevel ), nEntryPos, static_cast< sal_uInt16 >( nLevel + 1 ) );
+            DrawImageRel(GetLevelPos(nLevel), nEntryPos, aLevelBmps[nLevel]);
 
         SetLineColor( maLineColor );
         long nLinePos = mnHeaderPos + (mbMirrorEntries ? 0 : (mnHeaderSize - 1));
@@ -696,8 +709,8 @@ void ScOutlineWindow::Paint( vcl::RenderContext& /*rRenderContext*/, const Recta
             // draw, if not hidden by higher levels
             if ( bDraw )
             {
-                sal_uInt16 nImageId = pEntry->IsHidden() ? SC_OL_IMAGE_PLUS : SC_OL_IMAGE_MINUS;
-                DrawImageRel( nLevelPos, nImagePos, nImageId );
+                OUString sImageId = pEntry->IsHidden() ? OUString(RID_BMP_PLUS) : OUString(RID_BMP_MINUS);
+                DrawImageRel(nLevelPos, nImagePos, sImageId);
             }
         }
     }
@@ -838,7 +851,7 @@ bool ScOutlineWindow::ImplMoveFocusByLevel( bool bForward )
     return bWrapped;
 }
 
-bool ScOutlineWindow::ImplMoveFocusByTabOrder( bool bForward, bool bFindVisible )
+bool ScOutlineWindow::ImplMoveFocusByTabOrder( bool bForward )
 {
     bool bRet = false;
     size_t nOldLevel = mnFocusLevel;
@@ -858,7 +871,7 @@ bool ScOutlineWindow::ImplMoveFocusByTabOrder( bool bForward, bool bFindVisible
         if ( bForward && bWrapInLevel )
             bRet |= ImplMoveFocusByLevel( bForward );
     }
-    while ( bFindVisible && !IsFocusButtonVisible() && ((nOldLevel != mnFocusLevel) || (nOldEntry != mnFocusEntry)) );
+    while ( !IsFocusButtonVisible() && ((nOldLevel != mnFocusLevel) || (nOldEntry != mnFocusEntry)) );
 
     return bRet;
 }
@@ -870,7 +883,7 @@ void ScOutlineWindow::ImplMoveFocusToVisible( bool bForward )
         ImplMoveFocusByEntry( bForward, true );
     // then try to find any other entry
     if ( !IsFocusButtonVisible() )
-        ImplMoveFocusByTabOrder( bForward, true );
+        ImplMoveFocusByTabOrder( bForward );
 }
 
 void ScOutlineWindow::MoveFocusByEntry( bool bForward )
@@ -890,7 +903,7 @@ void ScOutlineWindow::MoveFocusByLevel( bool bForward )
 void ScOutlineWindow::MoveFocusByTabOrder( bool bForward )
 {
     HideFocus();
-    ImplMoveFocusByTabOrder( bForward, true );
+    ImplMoveFocusByTabOrder( bForward );
     ShowFocus();
 }
 
