@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/eeitem.hxx>
 
 #include <svtools/colorcfg.hxx>
@@ -32,45 +32,44 @@
 #include <tools/multisel.hxx>
 #include <vcl/waitobj.hxx>
 #include <vcl/settings.hxx>
+#include <o3tl/deleter.hxx>
 
-#include "preview.hxx"
-#include "prevwsh.hxx"
-#include "prevloc.hxx"
-#include "docsh.hxx"
-#include "docfunc.hxx"
-#include "printfun.hxx"
-#include "printopt.hxx"
-#include "stlpool.hxx"
-#include "undostyl.hxx"
-#include "drwlayer.hxx"
-#include "scmod.hxx"
-#include "markdata.hxx"
-#include "globstr.hrc"
-#include "sc.hrc"
-#include "AccessibleDocumentPagePreview.hxx"
+#include <preview.hxx>
+#include <prevwsh.hxx>
+#include <prevloc.hxx>
+#include <docsh.hxx>
+#include <docfunc.hxx>
+#include <printfun.hxx>
+#include <printopt.hxx>
+#include <stlpool.hxx>
+#include <undostyl.hxx>
+#include <drwlayer.hxx>
+#include <scmod.hxx>
+#include <markdata.hxx>
+#include <globstr.hrc>
+#include <sc.hrc>
+#include <AccessibleDocumentPagePreview.hxx>
 #include <vcl/lineinfo.hxx>
 #include <svx/algitem.hxx>
 #include <editeng/lrspitem.hxx>
 #include <editeng/ulspitem.hxx>
 #include <editeng/colritem.hxx>
 #include <editeng/fhgtitem.hxx>
-#include "attrib.hxx"
-#include "pagepar.hxx"
+#include <attrib.hxx>
+#include <pagepar.hxx>
 #include <com/sun/star/accessibility/XAccessible.hpp>
-#include "AccessibilityHints.hxx"
+#include <AccessibilityHints.hxx>
 #include <vcl/svapp.hxx>
-#include "viewutil.hxx"
+#include <viewutil.hxx>
 #include <columnspanset.hxx>
 #include <docpool.hxx>
 #include <patattr.hxx>
 
 #include <memory>
 
-// STATIC DATA -----------------------------------------------------------
-
 #define SC_PREVIEW_SHADOWSIZE   2
 
-static long lcl_GetDisplayStart( SCTAB nTab, ScDocument* pDoc, std::vector<long>& nPages )
+static long lcl_GetDisplayStart( SCTAB nTab, const ScDocument* pDoc, std::vector<long>& nPages )
 {
     long nDisplayStart = 0;
     for (SCTAB i=0; i<nTab; i++)
@@ -129,16 +128,12 @@ ScPreview::ScPreview( vcl::Window* pParent, ScDocShell* pDocSh, ScPreviewShell*
     nHeaderHeight ( 0 ),
     nFooterHeight ( 0 )
 {
-    SetOutDevViewType( OUTDEV_VIEWTYPE_PRINTPREVIEW );
+    SetOutDevViewType( OutDevViewType::PrintPreview );
     SetBackground();
 
     SetHelpId( HID_SC_WIN_PREVIEW );
-    SetUniqueId( HID_SC_WIN_PREVIEW );
 
     SetDigitLanguage( SC_MOD()->GetOptDigitLanguage() );
-
-    for (SCCOL i=0; i<=MAXCOL; i++)
-        nRight[i] = 0;                  // initialized with actual positions when markers are drawn
 }
 
 ScPreview::~ScPreview()
@@ -227,6 +222,12 @@ void ScPreview::CalcPages()
     ScDocument& rDoc = pDocShell->GetDocument();
     nTabCount = rDoc.GetTableCount();
 
+    if (maSelectedTabs.empty())
+    {
+        SCTAB nCurrentTab = ScDocShell::GetCurTab();
+        maSelectedTabs.insert(nCurrentTab);
+    }
+
     SCTAB nStart = nTabsTested;
     if (!bValid)
     {
@@ -246,18 +247,18 @@ void ScPreview::CalcPages()
     while (nStart > static_cast<SCTAB>(nPages.size()))
         nPages.push_back(0);
     while (nStart > static_cast<SCTAB>(nFirstAttr.size()))
-        nFirstAttr.push_back(0);
+        nFirstAttr.push_back(1);
 
     for (SCTAB i=nStart; i<nTabCount; i++)
     {
         if ( i == static_cast<SCTAB>(nPages.size()))
             nPages.push_back(0);
         if ( i == static_cast<SCTAB>(nFirstAttr.size()))
-            nFirstAttr.push_back(0);
+            nFirstAttr.push_back(1);
         if (!aOptions.GetAllSheets() && maSelectedTabs.count(i) == 0)
         {
             nPages[i] = 0;
-            nFirstAttr[i] = 0;
+            nFirstAttr[i] = 1;
             continue;
         }
 
@@ -346,12 +347,12 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
     {
         CalcPages();
         RecalcPages();
-        UpdateDrawView();       // Spreedsheet eventually changes
+        UpdateDrawView();       // Spreadsheet eventually changes
     }
 
     Fraction aPreviewZoom( nZoom, 100 );
     Fraction aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
-    MapMode aMMMode( MAP_100TH_MM, Point(), aHorPrevZoom, aPreviewZoom );
+    MapMode aMMMode( MapUnit::Map100thMM, Point(), aHorPrevZoom, aPreviewZoom );
 
     bool bDoPrint = ( pFillLocation == nullptr );
     bool bValidPage = ( nPageNo < nTotalPages );
@@ -368,9 +369,9 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
 
         Size aWinSize = GetOutputSize();
         if ( aOffset.X() < 0 )
-            DrawRect(Rectangle( 0, 0, -aOffset.X(), aWinSize.Height() ));
+            DrawRect(tools::Rectangle( 0, 0, -aOffset.X(), aWinSize.Height() ));
         if ( aOffset.Y() < 0 )
-            DrawRect(Rectangle( 0, 0, aWinSize.Width(), -aOffset.Y() ));
+            DrawRect(tools::Rectangle( 0, 0, aWinSize.Width(), -aOffset.Y() ));
     }
 
     long   nLeftMargin = 0;
@@ -388,11 +389,11 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
     {
         ScPrintOptions aOptions = pScMod->GetPrintOptions();
 
-        ScPrintFunc* pPrintFunc;
+        std::unique_ptr<ScPrintFunc, o3tl::default_delete<ScPrintFunc>> pPrintFunc;
         if (bStateValid)
-            pPrintFunc = new ScPrintFunc( this, pDocShell, aState, &aOptions );
+            pPrintFunc.reset(new ScPrintFunc(this, pDocShell, aState, &aOptions));
         else
-            pPrintFunc = new ScPrintFunc( this, pDocShell, nTab, nFirstAttr[nTab], nTotalPages, nullptr, &aOptions );
+            pPrintFunc.reset(new ScPrintFunc(this, pDocShell, nTab, nFirstAttr[nTab], nTotalPages, nullptr, &aOptions));
 
         pPrintFunc->SetOffset(aOffset);
         pPrintFunc->SetManualZoom(nZoom);
@@ -426,10 +427,11 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
 
         if ( bDoPrint && bPageMargin && pLocationData )     // don't make use of pLocationData while filling it
         {
-            Rectangle aPixRect;
-            Rectangle aRectCellPosition;
-            Rectangle aRectPosition;
+            tools::Rectangle aPixRect;
+            tools::Rectangle aRectCellPosition;
+            tools::Rectangle aRectPosition;
             pLocationData->GetMainCellRange( aPageArea, aPixRect );
+            mvRight.resize(aPageArea.aEnd.Col()+1);
             if( !bLayoutRTL )
             {
                 pLocationData->GetCellPosition( aPageArea.aStart, aRectPosition );
@@ -437,7 +439,7 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
                 for( SCCOL i = aPageArea.aStart.Col(); i <= aPageArea.aEnd.Col(); i++ )
                 {
                     pLocationData->GetCellPosition( ScAddress( i,aPageArea.aStart.Row(),aPageArea.aStart.Tab()),aRectCellPosition );
-                    nRight[i] = aRectCellPosition.Right();
+                    mvRight[i] = aRectCellPosition.Right();
                 }
             }
             else
@@ -446,11 +448,11 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
                 nLeftPosition = aRectPosition.Right()+1;
 
                 pLocationData->GetCellPosition( aPageArea.aStart,aRectCellPosition );
-                nRight[ aPageArea.aEnd.Col() ] = aRectCellPosition.Left();
+                mvRight[ aPageArea.aEnd.Col() ] = aRectCellPosition.Left();
                 for( SCCOL i = aPageArea.aEnd.Col(); i > aPageArea.aStart.Col(); i-- )
                 {
                     pLocationData->GetCellPosition( ScAddress( i,aPageArea.aEnd.Row(),aPageArea.aEnd.Tab()),aRectCellPosition );
-                    nRight[ i-1 ] = nRight[ i ] + aRectCellPosition.Right() - aRectCellPosition.Left() + 1;
+                    mvRight[ i-1 ] = mvRight[ i ] + aRectCellPosition.Right() - aRectCellPosition.Left() + 1;
                 }
             }
         }
@@ -475,7 +477,6 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
             aState.nDocPages = nTotalPages;
             bStateValid = true;
         }
-        delete pPrintFunc;
     }
 
     if ( bDoPrint )
@@ -500,11 +501,10 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
             // Draw background first.
             SetLineColor();
             SetFillColor(aBackColor);
-            DrawRect(Rectangle(0, 0, aWinEnd.X(), aWinEnd.Y()));
+            DrawRect(tools::Rectangle(0, 0, aWinEnd.X(), aWinEnd.Y()));
 
             const ScPatternAttr& rDefPattern =
-                static_cast<const ScPatternAttr&>(
-                    rDoc.GetPool()->GetDefaultItem(ATTR_PATTERN));
+                    rDoc.GetPool()->GetDefaultItem(ATTR_PATTERN);
 
             std::unique_ptr<ScEditEngineDefaulter> pEditEng(
                 new ScEditEngineDefaulter(EditEngine::CreatePool(), true));
@@ -556,14 +556,14 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
                 DrawInvert( nPageEndY - nFooterHeight, PointerStyle::VSizeBar );
             }
 
-            SetMapMode( MapMode( MAP_PIXEL ) );
+            SetMapMode( MapMode( MapUnit::MapPixel ) );
             for( int i= aPageArea.aStart.Col(); i<= aPageArea.aEnd.Col(); i++ )
             {
                 Point aColumnTop = LogicToPixel( Point( 0, -aOffset.Y() ) ,aMMMode );
                 SetLineColor( COL_BLACK );
                 SetFillColor( COL_BLACK );
-                DrawRect( Rectangle( Point( nRight[i] - 2, aColumnTop.Y() ),Point( nRight[i] + 2 , 4 + aColumnTop.Y()) ));
-                DrawLine( Point( nRight[i], aColumnTop.Y() ), Point( nRight[i],  10 + aColumnTop.Y()) );
+                DrawRect( tools::Rectangle( Point( mvRight[i] - 2, aColumnTop.Y() ),Point( mvRight[i] + 2 , 4 + aColumnTop.Y()) ));
+                DrawLine( Point( mvRight[i], aColumnTop.Y() ), Point( mvRight[i],  10 + aColumnTop.Y()) );
             }
             SetMapMode( aMMMode );
         }
@@ -574,13 +574,13 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
             SetLineColor();
             SetFillColor(aBackColor);
             if (bRight)
-                DrawRect(Rectangle(nPageEndX,0, aWinEnd.X(),aWinEnd.Y()));
+                DrawRect(tools::Rectangle(nPageEndX,0, aWinEnd.X(),aWinEnd.Y()));
             if (bBottom)
             {
                 if (bRight)
-                    DrawRect(Rectangle(0,nPageEndY, nPageEndX,aWinEnd.Y()));    // Corner not duplicated
+                    DrawRect(tools::Rectangle(0,nPageEndY, nPageEndX,aWinEnd.Y()));    // Corner not duplicated
                 else
-                    DrawRect(Rectangle(0,nPageEndY, aWinEnd.X(),aWinEnd.Y()));
+                    DrawRect(tools::Rectangle(0,nPageEndY, aWinEnd.X(),aWinEnd.Y()));
             }
         }
 
@@ -595,7 +595,7 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
                 SetLineColor( aBorderColor );
                 SetFillColor();
 
-                Rectangle aPixel( LogicToPixel( Rectangle( -aOffset.X(), -aOffset.Y(), nPageEndX, nPageEndY ) ) );
+                tools::Rectangle aPixel( LogicToPixel( tools::Rectangle( -aOffset.X(), -aOffset.Y(), nPageEndX, nPageEndY ) ) );
                 --aPixel.Right();
                 --aPixel.Bottom();
                 DrawRect( PixelToLogic( aPixel ) );
@@ -606,15 +606,15 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
             SetLineColor();
             SetFillColor( aBorderColor );
 
-            Rectangle aPixel;
+            tools::Rectangle aPixel;
 
-            aPixel = LogicToPixel( Rectangle( nPageEndX, -aOffset.Y(), nPageEndX, nPageEndY ) );
+            aPixel = LogicToPixel( tools::Rectangle( nPageEndX, -aOffset.Y(), nPageEndX, nPageEndY ) );
             aPixel.Top() += SC_PREVIEW_SHADOWSIZE;
             aPixel.Right() += SC_PREVIEW_SHADOWSIZE - 1;
             aPixel.Bottom() += SC_PREVIEW_SHADOWSIZE - 1;
             DrawRect( PixelToLogic( aPixel ) );
 
-            aPixel = LogicToPixel( Rectangle( -aOffset.X(), nPageEndY, nPageEndX, nPageEndY ) );
+            aPixel = LogicToPixel( tools::Rectangle( -aOffset.X(), nPageEndY, nPageEndX, nPageEndY ) );
             aPixel.Left() += SC_PREVIEW_SHADOWSIZE;
             aPixel.Right() += SC_PREVIEW_SHADOWSIZE - 1;
             aPixel.Bottom() += SC_PREVIEW_SHADOWSIZE - 1;
@@ -623,7 +623,7 @@ void ScPreview::DoPrint( ScPreviewLocationData* pFillLocation )
     }
 }
 
-void ScPreview::Paint( vcl::RenderContext& /*rRenderContext*/, const Rectangle& /* rRect */ )
+void ScPreview::Paint( vcl::RenderContext& /*rRenderContext*/, const tools::Rectangle& /* rRect */ )
 {
     bool bWasInPaint = bInPaint;        // nested calls shouldn't be necessary, but allow for now
     bInPaint = true;
@@ -704,7 +704,7 @@ void ScPreview::DataChanged(bool bNewTime)
     }
 
     bValid = false;
-    InvalidateLocationData( SC_HINT_DATACHANGED );
+    InvalidateLocationData( SfxHintId::ScDataChanged );
     Invalidate();
 }
 
@@ -739,7 +739,7 @@ void ScPreview::SetZoom(sal_uInt16 nNewZoom)
 
         Fraction aPreviewZoom( nZoom, 100 );
         Fraction aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
-        MapMode aMMMode( MAP_100TH_MM, Point(), aHorPrevZoom, aPreviewZoom );
+        MapMode aMMMode( MapUnit::Map100thMM, Point(), aHorPrevZoom, aPreviewZoom );
         SetMapMode( aMMMode );
 
         bInSetZoom = true;              // don't scroll during SetYOffset in UpdateScrollBars
@@ -747,7 +747,7 @@ void ScPreview::SetZoom(sal_uInt16 nNewZoom)
         bInSetZoom = false;
 
         bStateValid = false;
-        InvalidateLocationData( SC_HINT_ACC_VISAREACHANGED );
+        InvalidateLocationData( SfxHintId::ScAccVisAreaChanged );
         DoInvalidate();
         Invalidate();
     }
@@ -758,7 +758,7 @@ void ScPreview::SetPageNo( long nPage )
     nPageNo = nPage;
     RecalcPages();
     UpdateDrawView();       // The table eventually changes
-    InvalidateLocationData( SC_HINT_DATACHANGED );
+    InvalidateLocationData( SfxHintId::ScDataChanged );
     Invalidate();
 }
 
@@ -788,15 +788,15 @@ long ScPreview::GetFirstPage(SCTAB nTabP)
     return nPage;
 }
 
-static Size lcl_GetDocPageSize( ScDocument* pDoc, SCTAB nTab )
+static Size lcl_GetDocPageSize( const ScDocument* pDoc, SCTAB nTab )
 {
     OUString aName = pDoc->GetPageStyle( nTab );
     ScStyleSheetPool* pStylePool = pDoc->GetStyleSheetPool();
-    SfxStyleSheetBase* pStyleSheet = pStylePool->Find( aName, SFX_STYLE_FAMILY_PAGE );
+    SfxStyleSheetBase* pStyleSheet = pStylePool->Find( aName, SfxStyleFamily::Page );
     if ( pStyleSheet )
     {
         SfxItemSet& rStyleSet = pStyleSheet->GetItemSet();
-        return static_cast<const SvxSizeItem&>( rStyleSet.Get(ATTR_PAGE_SIZE)).GetSize();
+        return rStyleSet.Get(ATTR_PAGE_SIZE).GetSize();
     }
     else
     {
@@ -814,7 +814,7 @@ sal_uInt16 ScPreview::GetOptimalZoom(bool bWidthOnly)
     //  desired margin is 0.25cm in default MapMode (like Writer),
     //  but some additional margin is introduced by integer scale values
     //  -> add only 0.10cm, so there is some margin in all cases.
-    Size aMarginSize( LogicToPixel( Size( 100, 100 ), MAP_100TH_MM ) );
+    Size aMarginSize( LogicToPixel(Size(100, 100), MapMode(MapUnit::Map100thMM)) );
     aWinSize.Width()  -= 2 * aMarginSize.Width();
     aWinSize.Height() -= 2 * aMarginSize.Height();
 
@@ -850,7 +850,8 @@ void ScPreview::SetXOffset( long nX )
         aOffset.X() = nX;
         if (nDif && !bInSetZoom)
         {
-            MapMode aOldMode = GetMapMode(); SetMapMode(MAP_PIXEL);
+            MapMode aOldMode = GetMapMode();
+            SetMapMode(MapMode(MapUnit::MapPixel));
             Scroll( nDif, 0 );
             SetMapMode(aOldMode);
         }
@@ -861,7 +862,7 @@ void ScPreview::SetXOffset( long nX )
         if (!bInSetZoom)
             Invalidate();
     }
-    InvalidateLocationData( SC_HINT_ACC_VISAREACHANGED );
+    InvalidateLocationData( SfxHintId::ScAccVisAreaChanged );
     Invalidate();
 }
 
@@ -876,7 +877,8 @@ void ScPreview::SetYOffset( long nY )
         aOffset.Y() = nY;
         if (nDif && !bInSetZoom)
         {
-            MapMode aOldMode = GetMapMode(); SetMapMode(MAP_PIXEL);
+            MapMode aOldMode = GetMapMode();
+            SetMapMode(MapMode(MapUnit::MapPixel));
             Scroll( 0, nDif );
             SetMapMode(aOldMode);
         }
@@ -887,7 +889,7 @@ void ScPreview::SetYOffset( long nY )
         if (!bInSetZoom)
             Invalidate();
     }
-    InvalidateLocationData( SC_HINT_ACC_VISAREACHANGED );
+    InvalidateLocationData( SfxHintId::ScAccVisAreaChanged );
     Invalidate();
 }
 
@@ -926,7 +928,7 @@ void ScPreview::StaticInvalidate()
     rBindings.Invalidate(SID_ATTR_ZOOMSLIDER);
 }
 
-IMPL_STATIC_LINK_NOARG_TYPED( ScPreview, InvalidateHdl, void*, void )
+IMPL_STATIC_LINK_NOARG( ScPreview, InvalidateHdl, void*, void )
 {
     StaticInvalidate();
 }
@@ -956,7 +958,7 @@ void ScPreview::DataChanged( const DataChangedEvent& rDCEvt )
                 pViewShell->InvalidateBorder();     // calls OuterResizePixel
             }
             Invalidate();
-            InvalidateLocationData( SC_HINT_DATACHANGED );
+            InvalidateLocationData( SfxHintId::ScDataChanged );
         }
     }
 }
@@ -965,7 +967,7 @@ void ScPreview::MouseButtonDown( const MouseEvent& rMEvt )
 {
     Fraction  aPreviewZoom( nZoom, 100 );
     Fraction  aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
-    MapMode   aMMMode( MAP_100TH_MM, Point(), aHorPrevZoom, aPreviewZoom );
+    MapMode   aMMMode( MapUnit::Map100thMM, Point(), aHorPrevZoom, aPreviewZoom );
 
     aButtonDownChangePoint = PixelToLogic( rMEvt.GetPosPixel(),aMMMode );
     aButtonDownPt = PixelToLogic( rMEvt.GetPosPixel(),aMMMode );
@@ -1024,7 +1026,7 @@ void ScPreview::MouseButtonDown( const MouseEvent& rMEvt )
         SCCOL i = 0;
         for( i = aPageArea.aStart.Col(); i<= aPageArea.aEnd.Col(); i++ )
         {
-            if( aNowPt.X() < nRight[i] + 2 && aNowPt.X() > nRight[i] - 2 )
+            if( aNowPt.X() < mvRight[i] + 2 && aNowPt.X() > mvRight[i] - 2 )
             {
                 nColNumberButttonDown = i;
                 break;
@@ -1037,7 +1039,7 @@ void ScPreview::MouseButtonDown( const MouseEvent& rMEvt )
         if( nColNumberButttonDown == aPageArea.aStart.Col() )
             DrawInvert( PixelToLogic( Point( nLeftPosition, 0 ),aMMMode ).X() ,PointerStyle::HSplit );
         else
-            DrawInvert( PixelToLogic( Point( nRight[ nColNumberButttonDown-1 ], 0 ),aMMMode ).X() ,PointerStyle::HSplit );
+            DrawInvert( PixelToLogic( Point( mvRight[ nColNumberButttonDown-1 ], 0 ),aMMMode ).X() ,PointerStyle::HSplit );
 
         DrawInvert( aButtonDownChangePoint.X(), PointerStyle::HSplit );
         bColRulerMove = true;
@@ -1048,12 +1050,12 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 {
         Fraction  aPreviewZoom( nZoom, 100 );
         Fraction  aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
-        MapMode   aMMMode( MAP_100TH_MM, Point(), aHorPrevZoom, aPreviewZoom );
+        MapMode   aMMMode( MapUnit::Map100thMM, Point(), aHorPrevZoom, aPreviewZoom );
 
         aButtonUpPt = PixelToLogic( rMEvt.GetPosPixel(),aMMMode );
 
-        long  nWidth = (long) lcl_GetDocPageSize(&pDocShell->GetDocument(), nTab).Width();
-        long  nHeight = (long) lcl_GetDocPageSize(&pDocShell->GetDocument(), nTab).Height();
+        long  nWidth = lcl_GetDocPageSize(&pDocShell->GetDocument(), nTab).Width();
+        long  nHeight = lcl_GetDocPageSize(&pDocShell->GetDocument(), nTab).Height();
 
         if( rMEvt.IsLeft() && GetPointer() == PointerStyle::HSizeBar )
         {
@@ -1063,7 +1065,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
             OUString aOldName = rDoc.GetPageStyle( nTab );
             bool bUndo = rDoc.IsUndoEnabled();
             ScStyleSheetPool* pStylePool = rDoc.GetStyleSheetPool();
-            SfxStyleSheetBase* pStyleSheet = pStylePool->Find( aOldName, SFX_STYLE_FAMILY_PAGE );
+            SfxStyleSheetBase* pStyleSheet = pStylePool->Find( aOldName, SfxStyleFamily::Page );
 
             if ( pStyleSheet )
             {
@@ -1074,22 +1076,22 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 
                 SfxItemSet&  rStyleSet = pStyleSheet->GetItemSet();
 
-                SvxLRSpaceItem aLRItem = static_cast<const SvxLRSpaceItem&>( rStyleSet.Get( ATTR_LRSPACE ) );
+                SvxLRSpaceItem aLRItem = rStyleSet.Get( ATTR_LRSPACE );
 
                 if(( bLeftRulerChange || bRightRulerChange ) && ( aButtonUpPt.X() <= ( 0 - aOffset.X() ) || aButtonUpPt.X() > nWidth * HMM_PER_TWIPS - aOffset.X() ) )
                 {
                     bMoveRulerAction = false;
-                    Invalidate(Rectangle(0, 0, 10000, 10000));
+                    Invalidate(tools::Rectangle(0, 0, 10000, 10000));
                 }
                 else if( bLeftRulerChange && ( aButtonUpPt.X() / HMM_PER_TWIPS > nWidth - aLRItem.GetRight() - aOffset.X() / HMM_PER_TWIPS ) )
                 {
                     bMoveRulerAction = false;
-                    Invalidate(Rectangle(0, 0, 10000, 10000));
+                    Invalidate(tools::Rectangle(0, 0, 10000, 10000));
                 }
                 else if( bRightRulerChange && ( aButtonUpPt.X() / HMM_PER_TWIPS < aLRItem.GetLeft() - aOffset.X() / HMM_PER_TWIPS ) )
                 {
                     bMoveRulerAction = false;
-                    Invalidate(Rectangle(0, 0, 10000, 10000));
+                    Invalidate(tools::Rectangle(0, 0, 10000, 10000));
                 }
                 else if( aButtonDownPt.X() == aButtonUpPt.X() )
                 {
@@ -1117,7 +1119,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                     if( bUndo )
                     {
                         pDocShell->GetUndoManager()->AddUndoAction(
-                            new ScUndoModifyStyle( pDocShell, SFX_STYLE_FAMILY_PAGE,
+                            new ScUndoModifyStyle( pDocShell, SfxStyleFamily::Page,
                             aOldData, aNewData ) );
                     }
 
@@ -1127,7 +1129,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                         aPrintFunc.UpdatePages();
                     }
 
-                    Rectangle aRect(0,0,10000,10000);
+                    tools::Rectangle aRect(0,0,10000,10000);
                     Invalidate(aRect);
                     aModificator.SetDocumentModified();
                     bLeftRulerChange = false;
@@ -1146,7 +1148,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
             if( ( bTopRulerChange || bBottomRulerChange || bHeaderRulerChange || bFooterRulerChange ) && ( aButtonUpPt.Y() <= ( 0 - aOffset.Y() ) || aButtonUpPt.Y() > nHeight * HMM_PER_TWIPS -aOffset.Y() ) )
             {
                 bMoveRulerAction = false;
-                Invalidate(Rectangle(0, 0, 10000, 10000));
+                Invalidate(tools::Rectangle(0, 0, 10000, 10000));
             }
             else if( aButtonDownPt.Y() == aButtonUpPt.Y() )
             {
@@ -1158,7 +1160,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                 ScDocument& rDoc = pDocShell->GetDocument();
                 bool bUndo = rDoc.IsUndoEnabled();
                 ScStyleSheetPool* pStylePool = rDoc.GetStyleSheetPool();
-                SfxStyleSheetBase* pStyleSheet = pStylePool->Find( rDoc.GetPageStyle( nTab ), SFX_STYLE_FAMILY_PAGE );
+                SfxStyleSheetBase* pStyleSheet = pStylePool->Find( rDoc.GetPageStyle( nTab ), SfxStyleFamily::Page );
                 OSL_ENSURE( pStyleSheet, "PageStyle not found" );
                 if ( pStyleSheet )
                 {
@@ -1169,7 +1171,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 
                     SfxItemSet& rStyleSet = pStyleSheet->GetItemSet();
 
-                    SvxULSpaceItem aULItem = static_cast<const SvxULSpaceItem&>( rStyleSet.Get( ATTR_ULSPACE ) );
+                    SvxULSpaceItem aULItem = rStyleSet.Get( ATTR_ULSPACE );
 
                     if( bTopRulerMove && bTopRulerChange )
                     {
@@ -1188,11 +1190,11 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                         const SfxPoolItem* pItem = nullptr;
                         if ( rStyleSet.GetItemState( ATTR_PAGE_HEADERSET, false, &pItem ) == SfxItemState::SET )
                         {
-                            const SfxItemSet& pHeaderSet = static_cast<const SvxSetItem*>(pItem)->GetItemSet();
-                            Size  aHeaderSize = static_cast<const SvxSizeItem&>(pHeaderSet.Get(ATTR_PAGE_SIZE)).GetSize();
+                            const SfxItemSet& rHeaderSet = static_cast<const SvxSetItem*>(pItem)->GetItemSet();
+                            Size  aHeaderSize = rHeaderSet.Get(ATTR_PAGE_SIZE).GetSize();
                             aHeaderSize.Height() = (long)( aButtonUpPt.Y() / HMM_PER_TWIPS + aOffset.Y() / HMM_PER_TWIPS - aULItem.GetUpper());
                             aHeaderSize.Height() = aHeaderSize.Height() * 100 / mnScale;
-                            SvxSetItem  aNewHeader( static_cast<const SvxSetItem&>(rStyleSet.Get(ATTR_PAGE_HEADERSET)) );
+                            SvxSetItem  aNewHeader( rStyleSet.Get(ATTR_PAGE_HEADERSET) );
                             aNewHeader.GetItemSet().Put( SvxSizeItem( ATTR_PAGE_SIZE, aHeaderSize ) );
                             rStyleSet.Put( aNewHeader );
                             pDocShell->SetModified();
@@ -1203,11 +1205,11 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                         const SfxPoolItem* pItem = nullptr;
                         if( rStyleSet.GetItemState( ATTR_PAGE_FOOTERSET, false, &pItem ) == SfxItemState::SET )
                         {
-                            const SfxItemSet& pFooterSet = static_cast<const SvxSetItem*>(pItem)->GetItemSet();
-                            Size aFooterSize = static_cast<const SvxSizeItem&>(pFooterSet.Get(ATTR_PAGE_SIZE)).GetSize();
+                            const SfxItemSet& rFooterSet = static_cast<const SvxSetItem*>(pItem)->GetItemSet();
+                            Size aFooterSize = rFooterSet.Get(ATTR_PAGE_SIZE).GetSize();
                             aFooterSize.Height() = (long)( nHeight - aButtonUpPt.Y() / HMM_PER_TWIPS - aOffset.Y() / HMM_PER_TWIPS - aULItem.GetLower() );
                             aFooterSize.Height() = aFooterSize.Height() * 100 / mnScale;
-                            SvxSetItem  aNewFooter( static_cast<const SvxSetItem&>(rStyleSet.Get(ATTR_PAGE_FOOTERSET)) );
+                            SvxSetItem  aNewFooter( rStyleSet.Get(ATTR_PAGE_FOOTERSET) );
                             aNewFooter.GetItemSet().Put( SvxSizeItem( ATTR_PAGE_SIZE, aFooterSize ) );
                             rStyleSet.Put( aNewFooter );
                             pDocShell->SetModified();
@@ -1219,7 +1221,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                     if( bUndo )
                     {
                         pDocShell->GetUndoManager()->AddUndoAction(
-                            new ScUndoModifyStyle( pDocShell, SFX_STYLE_FAMILY_PAGE,
+                            new ScUndoModifyStyle( pDocShell, SfxStyleFamily::Page,
                             aOldData, aNewData ) );
                     }
 
@@ -1229,7 +1231,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                         aPrintFunc.UpdatePages();
                     }
 
-                    Rectangle aRect(0, 0, 10000, 10000);
+                    tools::Rectangle aRect(0, 0, 10000, 10000);
                     Invalidate(aRect);
                     aModificator.SetDocumentModified();
                     bTopRulerChange = false;
@@ -1255,7 +1257,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                 if( nColNumberButttonDown == aPageArea.aStart.Col() )
                     DrawInvert( PixelToLogic( Point( nLeftPosition, 0 ),aMMMode ).X() ,PointerStyle::HSplit );
                 else
-                    DrawInvert( PixelToLogic( Point( nRight[ nColNumberButttonDown-1 ], 0 ),aMMMode ).X() ,PointerStyle::HSplit );
+                    DrawInvert( PixelToLogic( Point( mvRight[ nColNumberButttonDown-1 ], 0 ),aMMMode ).X() ,PointerStyle::HSplit );
                 DrawInvert( aButtonUpPt.X(), PointerStyle::HSplit );
             }
             if( bMoveRulerAction )
@@ -1265,13 +1267,13 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
 
                 if( !bLayoutRTL )
                 {
-                    nNewColWidth = (long) ( PixelToLogic( Point( rMEvt.GetPosPixel().X() - nRight[ nColNumberButttonDown ], 0), aMMMode ).X() / HMM_PER_TWIPS ) * 100 / mnScale;
+                    nNewColWidth = (long) ( PixelToLogic( Point( rMEvt.GetPosPixel().X() - mvRight[ nColNumberButttonDown ], 0), aMMMode ).X() / HMM_PER_TWIPS ) * 100 / mnScale;
                     nNewColWidth += pDocShell->GetDocument().GetColWidth( nColNumberButttonDown, nTab );
                 }
                 else
                 {
 
-                    nNewColWidth = (long) ( PixelToLogic( Point( nRight[ nColNumberButttonDown ] - rMEvt.GetPosPixel().X(), 0), aMMMode ).X() / HMM_PER_TWIPS ) * 100 / mnScale;
+                    nNewColWidth = (long) ( PixelToLogic( Point( mvRight[ nColNumberButttonDown ] - rMEvt.GetPosPixel().X(), 0), aMMMode ).X() / HMM_PER_TWIPS ) * 100 / mnScale;
                     nNewColWidth += pDocShell->GetDocument().GetColWidth( nColNumberButttonDown, nTab );
                 }
 
@@ -1286,7 +1288,7 @@ void ScPreview::MouseButtonUp( const MouseEvent& rMEvt )
                     ScPrintFunc aPrintFunc( this, pDocShell, nTab );
                     aPrintFunc.UpdatePages();
                 }
-                Rectangle aRect(0, 0, 10000, 10000);
+                tools::Rectangle aRect(0, 0, 10000, 10000);
                 Invalidate(aRect);
             }
             bColRulerMove = false;
@@ -1298,7 +1300,7 @@ void ScPreview::MouseMove( const MouseEvent& rMEvt )
 {
     Fraction aPreviewZoom( nZoom, 100 );
     Fraction aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
-    MapMode  aMMMode( MAP_100TH_MM, Point(), aHorPrevZoom, aPreviewZoom );
+    MapMode  aMMMode( MapUnit::Map100thMM, Point(), aHorPrevZoom, aPreviewZoom );
     Point    aMouseMovePoint = PixelToLogic( rMEvt.GetPosPixel(), aMMMode );
 
     long    nLeftMargin = 0;
@@ -1306,8 +1308,8 @@ void ScPreview::MouseMove( const MouseEvent& rMEvt )
     long    nTopMargin = 0;
     long    nBottomMargin = 0;
 
-    long    nWidth = (long) lcl_GetDocPageSize(&pDocShell->GetDocument(), nTab).Width();
-    long    nHeight = (long) lcl_GetDocPageSize(&pDocShell->GetDocument(), nTab).Height();
+    long    nWidth = lcl_GetDocPageSize(&pDocShell->GetDocument(), nTab).Width();
+    long    nHeight = lcl_GetDocPageSize(&pDocShell->GetDocument(), nTab).Height();
 
     if ( nPageNo < nTotalPages )
     {
@@ -1355,7 +1357,8 @@ void ScPreview::MouseMove( const MouseEvent& rMEvt )
     {
         Point   aColumnTop = LogicToPixel( Point( 0, -aOffset.Y() ) ,aMMMode );
         Point   aColumnBottom = LogicToPixel( Point( 0, (long)( nHeight * HMM_PER_TWIPS - aOffset.Y()) ), aMMMode );
-        if( aPixPt.X() < ( nRight[i] + 2 ) && ( aPixPt.X() > ( nRight[i] - 2 ) ) && ( aPixPt.X() < aRightTop.X() ) && ( aPixPt.X() > aLeftTop.X() )
+        long nRight = i < static_cast<SCCOL>(mvRight.size()) ? mvRight[i] : 0;
+        if( aPixPt.X() < ( nRight + 2 ) && ( aPixPt.X() > ( nRight - 2 ) ) && ( aPixPt.X() < aRightTop.X() ) && ( aPixPt.X() > aLeftTop.X() )
             && ( aPixPt.Y() > aColumnTop.Y() ) && ( aPixPt.Y() < aColumnBottom.Y() ) && !bLeftRulerMove && !bRightRulerMove
             && !bTopRulerMove && !bBottomRulerMove && !bHeaderRulerMove && !bFooterRulerMove )
         {
@@ -1493,24 +1496,24 @@ void ScPreview::MouseMove( const MouseEvent& rMEvt )
     }
 }
 
-void ScPreview::InvalidateLocationData(sal_uLong nId)
+void ScPreview::InvalidateLocationData(SfxHintId nId)
 {
     bLocationValid = false;
     if (pViewShell->HasAccessibilityObjects())
-        pViewShell->BroadcastAccessibility( SfxSimpleHint( nId ) );
+        pViewShell->BroadcastAccessibility( SfxHint( nId ) );
 }
 
 void ScPreview::GetFocus()
 {
     Window::GetFocus();
     if (pViewShell && pViewShell->HasAccessibilityObjects())
-        pViewShell->BroadcastAccessibility( ScAccWinFocusGotHint(GetAccessible()) );
+        pViewShell->BroadcastAccessibility( ScAccWinFocusGotHint() );
 }
 
 void ScPreview::LoseFocus()
 {
     if (pViewShell && pViewShell->HasAccessibilityObjects())
-        pViewShell->BroadcastAccessibility( ScAccWinFocusLostHint(GetAccessible()) );
+        pViewShell->BroadcastAccessibility( ScAccWinFocusLostHint() );
     Window::LoseFocus();
 }
 
@@ -1535,7 +1538,7 @@ void ScPreview::DragMove( long nDragMovePos, PointerStyle nFlags )
 {
     Fraction aPreviewZoom( nZoom, 100 );
     Fraction aHorPrevZoom( (long)( 100 * nZoom / pDocShell->GetOutputFactor() ), 10000 );
-    MapMode  aMMMode( MAP_100TH_MM, Point(), aHorPrevZoom, aPreviewZoom );
+    MapMode  aMMMode( MapUnit::Map100thMM, Point(), aHorPrevZoom, aPreviewZoom );
     SetMapMode( aMMMode );
     long  nPos = nDragMovePos;
     if( nFlags == PointerStyle::HSizeBar || nFlags == PointerStyle::HSplit )
@@ -1560,16 +1563,16 @@ void ScPreview::DragMove( long nDragMovePos, PointerStyle nFlags )
 
 void ScPreview::DrawInvert( long nDragPos, PointerStyle nFlags )
 {
-    long  nHeight = (long) lcl_GetDocPageSize( &pDocShell->GetDocument(), nTab ).Height();
-    long  nWidth = (long) lcl_GetDocPageSize( &pDocShell->GetDocument(), nTab ).Width();
+    long  nHeight = lcl_GetDocPageSize( &pDocShell->GetDocument(), nTab ).Height();
+    long  nWidth = lcl_GetDocPageSize( &pDocShell->GetDocument(), nTab ).Width();
     if( nFlags == PointerStyle::HSizeBar || nFlags == PointerStyle::HSplit )
     {
-        Rectangle aRect( nDragPos, -aOffset.Y(), nDragPos + 1,(long)( ( nHeight * HMM_PER_TWIPS ) - aOffset.Y()));
+        tools::Rectangle aRect( nDragPos, -aOffset.Y(), nDragPos + 1,(long)( ( nHeight * HMM_PER_TWIPS ) - aOffset.Y()));
         Invert( aRect, InvertFlags::N50 );
     }
     else if( nFlags == PointerStyle::VSizeBar )
     {
-        Rectangle aRect( -aOffset.X(), nDragPos,(long)( ( nWidth * HMM_PER_TWIPS ) - aOffset.X() ), nDragPos + 1 );
+        tools::Rectangle aRect( -aOffset.X(), nDragPos,(long)( ( nWidth * HMM_PER_TWIPS ) - aOffset.X() ), nDragPos + 1 );
         Invert( aRect, InvertFlags::N50 );
     }
 }
