@@ -21,7 +21,7 @@
 
 #include <memory>
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <sfx2/request.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/viewfrm.hxx>
@@ -34,22 +34,24 @@
 #include <svx/svxdlg.hxx>
 #include <editeng/colritem.hxx>
 
-#include "tabvwsh.hxx"
-#include "sc.hrc"
-#include "docsh.hxx"
-#include "document.hxx"
-#include "shtabdlg.hxx"
-#include "scresid.hxx"
-#include "globstr.hrc"
-#include "docfunc.hxx"
-#include "eventuno.hxx"
+#include <tabvwsh.hxx>
+#include <sc.hrc>
+#include <docsh.hxx>
+#include <document.hxx>
+#include <shtabdlg.hxx>
+#include <scresid.hxx>
+#include <globstr.hrc>
+#include <strings.hrc>
+#include <docfunc.hxx>
+#include <eventuno.hxx>
+#include <dpobject.hxx>
+#include <dpshttab.hxx>
 
-#include "scabstdlg.hxx"
+#include <scabstdlg.hxx>
 
-#include "tabbgcolor.hxx"
-#include "tabbgcolordlg.hxx"
-#include "sccommands.h"
-#include "markdata.hxx"
+#include <tabbgcolor.hxx>
+#include <tabbgcolordlg.hxx>
+#include <markdata.hxx>
 
 #include <vector>
 
@@ -132,7 +134,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                    std::unique_ptr<AbstractScShowTabDlg> pDlg(pFact->CreateScShowTabDlg(GetDialogParent()));
+                    ScopedVclPtr<AbstractScShowTabDlg> pDlg(pFact->CreateScShowTabDlg(GetDialogParent()));
                     OSL_ENSURE(pDlg, "Dialog create fail!");
 
                     OUString aTabName;
@@ -149,10 +151,10 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
                     if ( pDlg->Execute() == RET_OK )
                     {
-                        const sal_Int32 nCount = pDlg->GetSelectEntryCount();
+                        const sal_Int32 nCount = pDlg->GetSelectedEntryCount();
                         for (sal_Int32 nPos=0; nPos<nCount; ++nPos)
                         {
-                            aName = pDlg->GetSelectEntry(nPos);
+                            aName = pDlg->GetSelectedEntry(nPos);
                             rReq.AppendItem( SfxStringItem( FID_TABLE_SHOW, aName ) );
                             rNames.push_back(aName);
                         }
@@ -178,17 +180,25 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     bool bOk = false;
                     const SfxPoolItem*  pTabItem;
                     const SfxPoolItem*  pNameItem;
-                    OUString            aName;
 
                     if ( pReqArgs->HasItem( FN_PARAM_1, &pTabItem ) &&
                          pReqArgs->HasItem( nSlot, &pNameItem ) )
                     {
-                        // sheet number from basic: 1-based
+                        OUString aName = static_cast<const SfxStringItem*>(pNameItem)->GetValue();
+                        pDoc->CreateValidTabName(aName);
 
-                        aName = static_cast<const SfxStringItem*>(pNameItem)->GetValue();
-                        nTabNr = static_cast<const SfxUInt16Item*>(pTabItem)->GetValue() - 1;
-                        if ( nTabNr < nTabCount )
-                            bOk = InsertTable( aName, nTabNr );
+                        // sheet number from basic: 1-based
+                        // 0 is special, means adding at the end
+                        nTabNr = static_cast<const SfxUInt16Item*>(pTabItem)->GetValue();
+                        if (nTabNr == 0)
+                            nTabNr = nTabCount;
+                        else
+                            --nTabNr;
+
+                        if (nTabNr > nTabCount)
+                            nTabNr = nTabCount;
+
+                        bOk = InsertTable(aName, nTabNr);
                     }
 
                     if (bOk)
@@ -200,7 +210,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                    std::unique_ptr<AbstractScInsertTableDlg> pDlg(pFact->CreateScInsertTableDlg(GetDialogParent(), rViewData,
+                    ScopedVclPtr<AbstractScInsertTableDlg> pDlg(pFact->CreateScInsertTableDlg(GetDialogParent(), rViewData,
                         nTabSelCount, nSlot == FID_INS_TABLE_EXT));
                     OSL_ENSURE(pDlg, "Dialog create fail!");
                     if ( RET_OK == pDlg->Execute() )
@@ -325,8 +335,14 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     OUString      aName;
 
                     if( pReqArgs->HasItem( FN_PARAM_1, &pItem ) )
+                    {
                         nTabNr = static_cast<const SfxUInt16Item*>(pItem)->GetValue();
 
+                        // inserting is 1-based, let's be consistent
+                        if (nTabNr > 0)
+                            --nTabNr;
+                    }
+
                     if( pReqArgs->HasItem( nSlot, &pItem ) )
                         aName = static_cast<const SfxStringItem*>(pItem)->GetValue();
 
@@ -357,13 +373,13 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     switch ( nSlot )
                     {
                         case FID_TAB_APPEND:
-                            aDlgTitle = OUString(ScResId(SCSTR_APDTABLE));
+                            aDlgTitle = ScResId(SCSTR_APDTABLE);
                             pDoc->CreateValidTabName( aName );
                             pHelpId = HID_SC_APPEND_NAME;
                             break;
 
                         case FID_TAB_RENAME:
-                            aDlgTitle = OUString(ScResId(SCSTR_RENAMETAB));
+                            aDlgTitle = ScResId(SCSTR_RENAMETAB);
                             pDoc->GetName( rViewData.GetTabNo(), aName );
                             pHelpId = HID_SC_RENAME_NAME;
                             break;
@@ -372,8 +388,8 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                    std::unique_ptr<AbstractScStringInputDlg> pDlg(pFact->CreateScStringInputDlg(
-                        GetDialogParent(), aDlgTitle, OUString(ScResId(SCSTR_NAME)),
+                    ScopedVclPtr<AbstractScStringInputDlg> pDlg(pFact->CreateScStringInputDlg(
+                        GetDialogParent(), aDlgTitle, ScResId(SCSTR_NAME),
                         aName, GetStaticInterface()->GetSlot(nSlot)->GetCommand(),
                         pHelpId));
 
@@ -412,7 +428,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                                 }
                                 else
                                 {
-                                    nRet = ScopedVclPtr<MessageDialog>::Create(GetDialogParent(),
+                                    nRet = ScopedVclPtrInstance<MessageDialog>(GetDialogParent(),
                                                      aErrMsg
                                                    )->Execute();
                                 }
@@ -466,7 +482,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                             {
                                 pScSh->GetTitle();
 
-                                if (aDocName.equals(pScSh->GetTitle()))
+                                if (aDocName == pScSh->GetTitle())
                                 {
                                     nDoc = i;
                                     ScDocument& rDestDoc = pScSh->GetDocument();
@@ -497,7 +513,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                    std::unique_ptr<AbstractScMoveTableDlg> pDlg(pFact->CreateScMoveTableDlg(GetDialogParent(),
+                    ScopedVclPtr<AbstractScMoveTableDlg> pDlg(pFact->CreateScMoveTableDlg(GetDialogParent(),
                         aDefaultName));
                     OSL_ENSURE(pDlg, "Dialog create fail!");
 
@@ -560,37 +576,99 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
         case FID_DELETE_TABLE:
             {
-                //  unnecessary parameter ->  method depends on table
+                bool bHasIndex = (pReqArgs != nullptr);
 
-                bool bDoIt = rReq.IsAPI();
-                if( !bDoIt )
+                // allow removing via the Index/FID_DELETE_TABLE parameter
+                SCTAB nTabNr = nCurrentTab;
+                if (bHasIndex)
                 {
-                    //  source isn't basic -> ask again
-
-                        bDoIt = ( RET_YES ==
-                                  ScopedVclPtr<QueryBox>::Create( GetDialogParent(),
-                                            WinBits( WB_YES_NO | WB_DEF_YES ),
-                                            ScGlobal::GetRscString(STR_QUERY_DELTAB)
-                                      )->Execute() );
-                }
-                if( bDoIt )
-                {
-                    SCTAB nNewTab   = nCurrentTab;
-                    SCTAB nFirstTab=0;
-                    bool   bTabFlag=false;
-                    ScMarkData& rMark = rViewData.GetMarkData();
-                    std::vector<SCTAB> TheTabs;
-                    for(SCTAB i=0;i<nTabCount;i++)
+                    const SfxPoolItem* pItem;
+                    if (pReqArgs->HasItem(FID_DELETE_TABLE, &pItem))
                     {
-                        if(rMark.GetTableSelect(i) &&!pDoc->IsTabProtected(i))
+                        nTabNr = static_cast<const SfxUInt16Item*>(pItem)->GetValue();
+
+                        // inserting is 1-based, let's be consistent
+                        if (nTabNr > 0)
+                            --nTabNr;
+                    }
+                }
+
+                bool bDoIt = bHasIndex;
+                if (!bDoIt)
+                {
+                    bool bTabWithPivotTable = false;
+                    if (pDoc->HasPivotTable())
+                    {
+                        const ScDPCollection* pDPs = pDoc->GetDPCollection();
+                        if (pDPs)
                         {
-                            TheTabs.push_back(i);
-                            bTabFlag=true;
-                            if(nNewTab==i) nNewTab++;
+                            const ScMarkData::MarkedTabsType& rSelectedTabs = rViewData.GetMarkData().GetSelectedTabs();
+                            for (ScMarkData::MarkedTabsType::const_iterator iterator = rSelectedTabs.begin();
+                                    iterator != rSelectedTabs.end() && !bTabWithPivotTable; ++iterator )
+                            {
+                                const SCTAB nSelTab = *iterator;
+                                const size_t nCount = pDPs->GetCount();
+                                for (size_t i = 0; i < nCount; ++i)
+                                {
+                                    const ScDPObject& rDPObj = (*pDPs)[i];
+                                    const ScSheetSourceDesc* pSheetSourceDesc = rDPObj.GetSheetDesc();
+                                    if (pSheetSourceDesc && pSheetSourceDesc->GetSourceRange().aStart.Tab() == nSelTab)
+                                        bTabWithPivotTable = true;
+                                }
+                            }
                         }
-                        if(!bTabFlag) nFirstTab=i;
+                    }
+
+                    if (bTabWithPivotTable)
+                    {
+                        // Hard warning as there is potential of data loss on deletion
+                        bDoIt = ( RET_YES ==
+                                ScopedVclPtrInstance<QueryBox>( GetDialogParent(),
+                                            MessBoxStyle::YesNo | MessBoxStyle::DefaultNo,
+                                            ScGlobal::GetRscString(STR_QUERY_PIVOTTABLE_DELTAB))->Execute() );
+                    }
+                    else
+                    {
+                        // no parameter given, ask for confirmation
+                        bDoIt = ( RET_YES ==
+                                ScopedVclPtrInstance<QueryBox>( GetDialogParent(),
+                                            MessBoxStyle::YesNo | MessBoxStyle::DefaultYes,
+                                            ScGlobal::GetRscString(STR_QUERY_DELTAB))->Execute() );
+                    }
+                }
+
+                if (bDoIt)
+                {
+                    SCTAB nNewTab = nCurrentTab;
+                    std::vector<SCTAB> TheTabs;
+
+                    if (bHasIndex)
+                    {
+                        // sheet no. provided by the parameter
+                        TheTabs.push_back(nTabNr);
+                        if (nNewTab > nTabNr && nNewTab > 0)
+                            --nNewTab;
+                    }
+                    else
+                    {
+                        SCTAB nFirstTab = 0;
+                        bool bTabFlag = false;
+                        ScMarkData& rMark = rViewData.GetMarkData();
+                        for (SCTAB i = 0; i < nTabCount; i++)
+                        {
+                            if (rMark.GetTableSelect(i) && !pDoc->IsTabProtected(i))
+                            {
+                                TheTabs.push_back(i);
+                                bTabFlag = true;
+                                if (nNewTab == i && i+1 < nTabCount)
+                                    nNewTab++;
+                            }
+                            if (!bTabFlag)
+                                nFirstTab = i;
+                        }
+                        if (nNewTab >= nTabCount - static_cast<SCTAB>(TheTabs.size()))
+                            nNewTab = nFirstTab;
                     }
-                    if(nNewTab>=nTabCount) nNewTab=nFirstTab;
 
                     rViewData.SetTabNo(nNewTab);
                     DeleteTables(TheTabs);
@@ -613,16 +691,16 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
 
                     ::svl::IUndoManager* pUndoManager = pDocSh->GetUndoManager();
                     OUString aUndo = ScGlobal::GetRscString( STR_UNDO_TAB_RTL );
-                    pUndoManager->EnterListAction( aUndo, aUndo );
+                    pUndoManager->EnterListAction( aUndo, aUndo, 0, rViewData.GetViewShell()->GetViewShellId() );
 
                     ScMarkData::const_iterator itr = rMark.begin(), itrEnd = rMark.end();
                     for (; itr != itrEnd; ++itr)
-                        rFunc.SetLayoutRTL( *itr, bSet, false );
+                        rFunc.SetLayoutRTL( *itr, bSet );
 
                     pUndoManager->LeaveListAction();
                 }
                 else
-                    rFunc.SetLayoutRTL( nCurrentTab, bSet, false );
+                    rFunc.SetLayoutRTL( nCurrentTab, bSet );
             }
             break;
 
@@ -656,8 +734,6 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     bool                bDone = false;
                     const SfxPoolItem*  pItem;
                     Color               aColor;
-                    if( pReqArgs->HasItem( FN_PARAM_1, &pItem ) )
-                        nTabNr = static_cast<const SfxUInt16Item*>(pItem)->GetValue();
 
                     if( pReqArgs->HasItem( nSlot, &pItem ) )
                         aColor = static_cast<const SvxColorItem*>(pItem)->GetValue();
@@ -696,12 +772,11 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     aTabBgColor = pDoc->GetTabBgColor( nCurrentTab );
                     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
-                    std::unique_ptr<AbstractScTabBgColorDlg> pDlg(pFact->CreateScTabBgColorDlg(
+                    ScopedVclPtr<AbstractScTabBgColorDlg> pDlg(pFact->CreateScTabBgColorDlg(
                                                                 GetDialogParent(),
-                                                                OUString(ScResId(SCSTR_SET_TAB_BG_COLOR)),
-                                                                OUString(ScResId(SCSTR_NO_TAB_BG_COLOR)),
-                                                                aTabBgColor,
-                                                                CMD_FID_TAB_SET_TAB_BG_COLOR));
+                                                                ScResId(SCSTR_SET_TAB_BG_COLOR),
+                                                                ScResId(SCSTR_NO_TAB_BG_COLOR),
+                                                                aTabBgColor));
                     while ( !bDone && nRet == RET_OK )
                     {
                         nRet = pDlg->Execute();
@@ -757,7 +832,7 @@ void ScTabViewShell::ExecuteTable( SfxRequest& rReq )
                     SvxAbstractDialogFactory* pDlgFactory = SvxAbstractDialogFactory::Create();
                     if (pDlgFactory)
                     {
-                        std::unique_ptr<VclAbstractDialog> pDialog( pDlgFactory->CreateSvxMacroAssignDlg(
+                        ScopedVclPtr<VclAbstractDialog> pDialog( pDlgFactory->CreateSvxMacroAssignDlg(
                             GetDialogParent(), xFrame, false, xEvents, 0 ) );
                         if ( pDialog.get() && pDialog->Execute() == RET_OK )
                         {
