@@ -28,32 +28,31 @@
 #include <svx/svdundo.hxx>
 #include <svx/xbtmpit.hxx>
 #include <svx/xoutbmp.hxx>
+#include <svtools/embedhlp.hxx>
 #include <sfx2/objsh.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <com/sun/star/embed/Aspects.hpp>
 
-#include "document.hxx"
-#include "viewfunc.hxx"
-#include "tabvwsh.hxx"
-#include "drawview.hxx"
-#include "scmod.hxx"
-#include "drwlayer.hxx"
-#include "drwtrans.hxx"
-#include "globstr.hrc"
-#include "chartlis.hxx"
-#include "docuno.hxx"
-#include "docsh.hxx"
-#include "convuno.hxx"
-#include "dragdata.hxx"
+#include <document.hxx>
+#include <viewfunc.hxx>
+#include <tabvwsh.hxx>
+#include <drawview.hxx>
+#include <scmod.hxx>
+#include <drwlayer.hxx>
+#include <drwtrans.hxx>
+#include <globstr.hrc>
+#include <chartlis.hxx>
+#include <docuno.hxx>
+#include <docsh.hxx>
+#include <convuno.hxx>
+#include <dragdata.hxx>
+#include <gridwin.hxx>
 
-extern Point aDragStartDiff;
-
-sal_Bool bPasteIsMove = false;
+bool bPasteIsMove = false;
 
 using namespace com::sun::star;
 
-
 static void lcl_AdjustInsertPos( ScViewData* pData, Point& rPos, Size& rSize )
 {
     SdrPage* pPage = pData->GetScDrawView()->GetModel()->GetPage( static_cast<sal_uInt16>(pData->GetTabNo()) );
@@ -73,7 +72,7 @@ static void lcl_AdjustInsertPos( ScViewData* pData, Point& rPos, Size& rSize )
 }
 
 void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
-                            bool bGroup, const OUString& rSrcShellID, const OUString& rDestShellID )
+        bool bGroup, const OUString& rSrcShellID, const OUString& rDestShellID )
 {
     bool bSameDocClipboard = rSrcShellID == rDestShellID;
 
@@ -83,16 +82,16 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
     // MapMode at Outliner-RefDevice has to be right (as in FuText::MakeOutliner)
     //! merge with FuText::MakeOutliner?
     MapMode aOldMapMode;
-    OutputDevice* pRef = GetViewData()->GetDocument()->GetDrawLayer()->GetRefDevice();
+    OutputDevice* pRef = GetViewData().GetDocument()->GetDrawLayer()->GetRefDevice();
     if (pRef)
     {
         aOldMapMode = pRef->GetMapMode();
-        pRef->SetMapMode( MapMode(MAP_100TH_MM) );
+        pRef->SetMapMode( MapMode(MapUnit::Map100thMM) );
     }
 
-    sal_Bool bNegativePage = GetViewData()->GetDocument()->IsNegativePage( GetViewData()->GetTabNo() );
+    bool bNegativePage = GetViewData().GetDocument()->IsNegativePage( GetViewData().GetTabNo() );
 
-    SdrView* pDragEditView = NULL;
+    SdrView* pDragEditView = nullptr;
     ScModule* pScMod = SC_MOD();
     const ScDragData& rData = pScMod->GetDragData();
     ScDrawTransferObj* pDrawTrans = rData.pDrawTransfer;
@@ -116,7 +115,7 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
     if (bGroup)
         pScDrawView->BegUndo( ScGlobal::GetRscString( STR_UNDO_PASTE ) );
 
-    sal_Bool bSameDoc = ( pDragEditView && pDragEditView->GetModel() == pScDrawView->GetModel() );
+    bool bSameDoc = ( pDragEditView && pDragEditView->GetModel() == pScDrawView->GetModel() );
     if (bSameDoc)
     {
             // copy locally - incl. charts
@@ -132,12 +131,12 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
                 pDragEditView->GetSdrPageView()->GetPage() )
         {
             if ( nDiffX != 0 || nDiffY != 0 )
-                pDragEditView->MoveAllMarked(Size(nDiffX,nDiffY), false);
+                pDragEditView->MoveAllMarked(Size(nDiffX,nDiffY));
         }
         else
         {
             SdrModel* pDrawModel = pDragEditView->GetModel();
-            SCTAB nTab = GetViewData()->GetTabNo();
+            SCTAB nTab = GetViewData().GetTabNo();
             SdrPage* pDestPage = pDrawModel->GetPage( static_cast< sal_uInt16 >( nTab ) );
             OSL_ENSURE(pDestPage,"who is this, Page?");
 
@@ -149,38 +148,39 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
 
             SdrMarkList aMark = pDragEditView->GetMarkedObjectList();
             aMark.ForceSort();
-            sal_uLong nMarkAnz=aMark.GetMarkCount();
-            for (sal_uLong nm=0; nm<nMarkAnz; nm++) {
+            const size_t nMarkCnt=aMark.GetMarkCount();
+            for (size_t nm=0; nm<nMarkCnt; ++nm) {
                 const SdrMark* pM=aMark.GetMark(nm);
                 const SdrObject* pObj=pM->GetMarkedSdrObj();
 
-                SdrObject* pNeuObj=pObj->Clone();
+                SdrObject* pNewObj=pObj->Clone();
 
-                if (pNeuObj!=NULL)
+                if (pNewObj!=nullptr)
                 {
-                    pNeuObj->SetModel(pDrawModel);
-                    pNeuObj->SetPage(pDestPage);
+                    pNewObj->SetModel(pDrawModel);
+                    pNewObj->SetPage(pDestPage);
 
                     //  copy graphics within the same model - always needs new name
-                    if ( pNeuObj->ISA(SdrGrafObj) && !bPasteIsMove )
-                        pNeuObj->SetName(((ScDrawLayer*)pDrawModel)->GetNewGraphicName());
+                    if ( dynamic_cast<const SdrGrafObj*>( pNewObj) !=  nullptr && !bPasteIsMove )
+                        pNewObj->SetName(static_cast<ScDrawLayer*>(pDrawModel)->GetNewGraphicName());
 
                     if (nDiffX!=0 || nDiffY!=0)
-                        pNeuObj->NbcMove(Size(nDiffX,nDiffY));
-                    pDestPage->InsertObject( pNeuObj );
-                    pScDrawView->AddUndo(new SdrUndoInsertObj( *pNeuObj ));
+                        pNewObj->NbcMove(Size(nDiffX,nDiffY));
+                    if (pDestPage)
+                        pDestPage->InsertObject( pNewObj );
+                    pScDrawView->AddUndo(new SdrUndoInsertObj( *pNewObj ));
 
-                    if (ScDrawLayer::IsCellAnchored(*pNeuObj))
-                        ScDrawLayer::SetCellAnchoredFromPosition(*pNeuObj, *GetViewData()->GetDocument(), nTab);
+                    if (ScDrawLayer::IsCellAnchored(*pNewObj))
+                        ScDrawLayer::SetCellAnchoredFromPosition(*pNewObj, *GetViewData().GetDocument(), nTab);
                 }
             }
 
             if (bPasteIsMove)
                 pDragEditView->DeleteMarked();
 
-            ScDocument* pDocument = GetViewData()->GetDocument();
-            ScDocShell* pDocShell = GetViewData()->GetDocShell();
-            ScModelObj* pModelObj = ( pDocShell ? ScModelObj::getImplementation( pDocShell->GetModel() ) : NULL );
+            ScDocument* pDocument = GetViewData().GetDocument();
+            ScDocShell* pDocShell = GetViewData().GetDocShell();
+            ScModelObj* pModelObj = ( pDocShell ? ScModelObj::getImplementation( pDocShell->GetModel() ) : nullptr );
             if ( pDocument && pDestPage && pModelObj && pDrawTrans )
             {
                 const ScRangeListVector& rProtectedChartRangesVector( pDrawTrans->GetProtectedChartRangesVector() );
@@ -197,18 +197,18 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
         SdrPageView* pPv = aView.ShowSdrPage(aView.GetModel()->GetPage(0));
         aView.MarkAllObj(pPv);
         Size aSize = aView.GetAllMarkedRect().GetSize();
-        lcl_AdjustInsertPos( GetViewData(), aPos, aSize );
+        lcl_AdjustInsertPos( &GetViewData(), aPos, aSize );
 
         // don't change marking if OLE object is active
         // (at Drop from OLE object it would be deactivated in the middle of ExecuteDrag!)
 
-        sal_uLong nOptions = 0;
-        SfxInPlaceClient* pClient = GetViewData()->GetViewShell()->GetIPClient();
+        SdrInsertFlags nOptions = SdrInsertFlags::NONE;
+        SfxInPlaceClient* pClient = GetViewData().GetViewShell()->GetIPClient();
         if ( pClient && pClient->IsObjectInPlaceActive() )
-            nOptions |= SDRINSERT_DONTMARK;
+            nOptions |= SdrInsertFlags::DONTMARK;
 
         ::std::vector< OUString > aExcludedChartNames;
-        SCTAB nTab = GetViewData()->GetTabNo();
+        SCTAB nTab = GetViewData().GetTabNo();
         SdrPage* pPage = pScDrawView->GetModel()->GetPage( static_cast< sal_uInt16 >( nTab ) );
         OSL_ENSURE( pPage, "Page?" );
         if ( pPage )
@@ -219,38 +219,38 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
         // #89247# Set flag for ScDocument::UpdateChartListeners() which is
         // called during paste.
         if ( !bSameDocClipboard )
-            GetViewData()->GetDocument()->SetPastingDrawFromOtherDoc( sal_True );
+            GetViewData().GetDocument()->SetPastingDrawFromOtherDoc( true );
 
-        pScDrawView->Paste(*pModel, aPos, NULL, nOptions, rSrcShellID, rDestShellID);
+        pScDrawView->Paste(*pModel, aPos, nullptr, nOptions);
 
         if ( !bSameDocClipboard )
-            GetViewData()->GetDocument()->SetPastingDrawFromOtherDoc( false );
+            GetViewData().GetDocument()->SetPastingDrawFromOtherDoc( false );
 
         // Paste puts all objects on the active (front) layer
         // controls must be on SC_LAYER_CONTROLS
         if (pPage)
         {
-            SdrObjListIter aIter( *pPage, IM_DEEPNOGROUPS );
+            SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
             SdrObject* pObject = aIter.Next();
             while (pObject)
             {
-                if ( pObject->ISA(SdrUnoObj) && pObject->GetLayer() != SC_LAYER_CONTROLS )
+                if ( dynamic_cast<const SdrUnoObj*>( pObject) !=  nullptr && pObject->GetLayer() != SC_LAYER_CONTROLS )
                     pObject->NbcSetLayer(SC_LAYER_CONTROLS);
 
                 if (ScDrawLayer::IsCellAnchored(*pObject))
-                    ScDrawLayer::SetCellAnchoredFromPosition(*pObject, *GetViewData()->GetDocument(), nTab);
+                    ScDrawLayer::SetCellAnchoredFromPosition(*pObject, *GetViewData().GetDocument(), nTab);
 
                 pObject = aIter.Next();
             }
         }
 
         // all graphics objects must have names
-        GetViewData()->GetDocument()->EnsureGraphicNames();
+        GetViewData().GetDocument()->EnsureGraphicNames();
 
-        ScDocument* pDocument = GetViewData()->GetDocument();
-        ScDocShell* pDocShell = GetViewData()->GetDocShell();
-        ScModelObj* pModelObj = ( pDocShell ? ScModelObj::getImplementation( pDocShell->GetModel() ) : NULL );
-        ScDrawTransferObj* pTransferObj = ScDrawTransferObj::GetOwnClipboard( NULL );
+        ScDocument* pDocument = GetViewData().GetDocument();
+        ScDocShell* pDocShell = GetViewData().GetDocShell();
+        ScModelObj* pModelObj = ( pDocShell ? ScModelObj::getImplementation( pDocShell->GetModel() ) : nullptr );
+        ScDrawTransferObj* pTransferObj = ScDrawTransferObj::GetOwnClipboard();
         if ( pDocument && pPage && pModelObj && ( pTransferObj || pDrawTrans ) )
         {
             const ScRangeListVector& rProtectedChartRangesVector(
@@ -269,7 +269,7 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
     if (pRef)
         pRef->SetMapMode( aOldMapMode );
 
-    // GetViewData()->GetViewShell()->SetDrawShell( sal_True );
+    // GetViewData().GetViewShell()->SetDrawShell( true );
     // It is not sufficient to just set the DrawShell if we pasted, for
     // example, a chart.  SetDrawShellOrSub() would only work for D&D in the
     // same document but not if inserting from the clipboard, therefore
@@ -278,7 +278,7 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
 
 }
 
-sal_Bool ScViewFunc::PasteObject( const Point& rPos, const uno::Reference < embed::XEmbeddedObject >& xObj,
+bool ScViewFunc::PasteObject( const Point& rPos, const uno::Reference < embed::XEmbeddedObject >& xObj,
                                 const Size* pDescSize, const Graphic* pReplGraph, const OUString& aMediaType, sal_Int64 nAspect )
 {
     MakeDrawLayer();
@@ -286,7 +286,7 @@ sal_Bool ScViewFunc::PasteObject( const Point& rPos, const uno::Reference < embe
     {
         OUString aName;
         //TODO/MBA: is that OK?
-        comphelper::EmbeddedObjectContainer& aCnt = GetViewData()->GetViewShell()->GetObjectShell()->GetEmbeddedObjectContainer();
+        comphelper::EmbeddedObjectContainer& aCnt = GetViewData().GetViewShell()->GetObjectShell()->GetEmbeddedObjectContainer();
         if ( !aCnt.HasEmbeddedObject( xObj ) )
             aCnt.InsertEmbeddedObject( xObj, aName );
         else
@@ -299,19 +299,19 @@ sal_Bool ScViewFunc::PasteObject( const Point& rPos, const uno::Reference < embe
         Size aSize;
         if ( nAspect == embed::Aspects::MSOLE_ICON )
         {
-            MapMode aMapMode( MAP_100TH_MM );
+            MapMode aMapMode( MapUnit::Map100thMM );
             aSize = aObjRef.GetSize( &aMapMode );
         }
         else
         {
             // working with visual area can switch object to running state
             MapUnit aMapObj = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( nAspect ) );
-            MapUnit aMap100 = MAP_100TH_MM;
+            MapUnit aMap100 = MapUnit::Map100thMM;
 
             if ( pDescSize && pDescSize->Width() && pDescSize->Height() )
             {
                 // use size from object descriptor if given
-                aSize = OutputDevice::LogicToLogic( *pDescSize, aMap100, aMapObj );
+                aSize = OutputDevice::LogicToLogic(*pDescSize, MapMode(aMap100), MapMode(aMapObj));
                 awt::Size aSz;
                 aSz.Width = aSize.Width();
                 aSz.Height = aSize.Height();
@@ -329,14 +329,14 @@ sal_Bool ScViewFunc::PasteObject( const Point& rPos, const uno::Reference < embe
             }
 
             aSize = Size( aSz.Width, aSz.Height );
-            aSize = OutputDevice::LogicToLogic( aSize, aMapObj, aMap100 );  // for SdrOle2Obj
+            aSize = OutputDevice::LogicToLogic(aSize, MapMode(aMapObj), MapMode(aMap100)); // for SdrOle2Obj
 
             if( aSize.Height() == 0 || aSize.Width() == 0 )
             {
                 OSL_FAIL("SvObjectDescriptor::GetSize == 0");
                 aSize.Width() = 5000;
                 aSize.Height() = 5000;
-                aSize = OutputDevice::LogicToLogic( aSize, aMap100, aMapObj );
+                aSize = OutputDevice::LogicToLogic(aSize, MapMode(aMap100), MapMode(aMapObj));
                 aSz.Width = aSize.Width();
                 aSz.Height = aSize.Height();
                 xObj->setVisualAreaSize( nAspect, aSz );
@@ -345,48 +345,75 @@ sal_Bool ScViewFunc::PasteObject( const Point& rPos, const uno::Reference < embe
 
         // don't call AdjustInsertPos
         Point aInsPos = rPos;
-        if ( GetViewData()->GetDocument()->IsNegativePage( GetViewData()->GetTabNo() ) )
+        if ( GetViewData().GetDocument()->IsNegativePage( GetViewData().GetTabNo() ) )
             aInsPos.X() -= aSize.Width();
-        Rectangle aRect( aInsPos, aSize );
+        tools::Rectangle aRect( aInsPos, aSize );
 
         ScDrawView* pDrView = GetScDrawView();
         SdrOle2Obj* pSdrObj = new SdrOle2Obj( aObjRef, aName, aRect );
 
         SdrPageView* pPV = pDrView->GetSdrPageView();
         pDrView->InsertObjectSafe( pSdrObj, *pPV );             // don't mark if OLE
-        GetViewData()->GetViewShell()->SetDrawShell( sal_True );
-        return sal_True;
+        GetViewData().GetViewShell()->SetDrawShell( true );
+        return true;
     }
     else
         return false;
 }
 
-sal_Bool ScViewFunc::PasteBitmapEx( const Point& rPos, const BitmapEx& rBmpEx )
+bool ScViewFunc::PasteBitmapEx( const Point& rPos, const BitmapEx& rBmpEx )
 {
-    OUString aEmpty;
     Graphic aGraphic(rBmpEx);
-    return PasteGraphic( rPos, aGraphic, aEmpty, aEmpty );
+    return PasteGraphic( rPos, aGraphic, "", "" );
 }
 
-sal_Bool ScViewFunc::PasteMetaFile( const Point& rPos, const GDIMetaFile& rMtf )
+bool ScViewFunc::PasteMetaFile( const Point& rPos, const GDIMetaFile& rMtf )
 {
-    OUString aEmpty;
     Graphic aGraphic(rMtf);
-    return PasteGraphic( rPos, aGraphic, aEmpty, aEmpty );
+    return PasteGraphic( rPos, aGraphic, "", "" );
 }
 
-sal_Bool ScViewFunc::PasteGraphic( const Point& rPos, const Graphic& rGraphic,
+bool ScViewFunc::PasteGraphic( const Point& rPos, const Graphic& rGraphic,
                                 const OUString& rFile, const OUString& rFilter )
 {
     MakeDrawLayer();
     ScDrawView* pScDrawView = GetScDrawView();
 
-    Point aPos( rPos );
-    Window* pWin = GetActiveWin();
-    MapMode aSourceMap = rGraphic.GetPrefMapMode();
-    MapMode aDestMap( MAP_100TH_MM );
+    if (!pScDrawView)
+        return false;
 
-    if (aSourceMap.GetMapUnit() == MAP_PIXEL)
+    // #i123922# check if the drop was over an existing object; if yes, evtl. replace
+    // the graphic for a SdrGraphObj (including link state updates) or adapt the fill
+    // style for other objects
+    SdrPageView* pPageView = pScDrawView->GetSdrPageView();
+    if (pPageView)
+    {
+        SdrObject* pPickObj = pScDrawView->PickObj(rPos, pScDrawView->getHitTolLog(), pPageView);
+        if (pPickObj)
+        {
+            const OUString aBeginUndo(ScGlobal::GetRscString(STR_UNDO_DRAGDROP));
+            SdrObject* pResult = pScDrawView->ApplyGraphicToObject(
+                *pPickObj,
+                rGraphic,
+                aBeginUndo,
+                rFile,
+                rFilter);
+
+            if (pResult)
+            {
+                // we are done; mark the modified/new object
+                pScDrawView->MarkObj(pResult, pScDrawView->GetSdrPageView());
+                return true;
+            }
+        }
+    }
+
+    Point aPos( rPos );
+    vcl::Window* pWin = GetActiveWin();
+    MapMode aSourceMap = rGraphic.GetPrefMapMode();
+    MapMode aDestMap( MapUnit::Map100thMM );
+
+    if (aSourceMap.GetMapUnit() == MapUnit::MapPixel)
     {
         // consider pixel correction, so bitmap fits to screen
         Fraction aScaleX, aScaleY;
@@ -397,17 +424,16 @@ sal_Bool ScViewFunc::PasteGraphic( const Point& rPos, const Graphic& rGraphic,
 
     Size aSize = pWin->LogicToLogic( rGraphic.GetPrefSize(), &aSourceMap, &aDestMap );
 
-    if ( GetViewData()->GetDocument()->IsNegativePage( GetViewData()->GetTabNo() ) )
+    if ( GetViewData().GetDocument()->IsNegativePage( GetViewData().GetTabNo() ) )
         aPos.X() -= aSize.Width();
 
-    GetViewData()->GetViewShell()->SetDrawShell( sal_True );
-
-    Rectangle aRect(aPos, aSize);
+    GetViewData().GetViewShell()->SetDrawShell( true );
+    tools::Rectangle aRect(aPos, aSize);
     SdrGrafObj* pGrafObj = new SdrGrafObj(rGraphic, aRect);
 
     // path was the name of the graphic in history
 
-    ScDrawLayer* pLayer = (ScDrawLayer*) pScDrawView->GetModel();
+    ScDrawLayer* pLayer = static_cast<ScDrawLayer*>( pScDrawView->GetModel() );
     OUString aName = pLayer->GetNewGraphicName();                 // "Graphics"
     pGrafObj->SetName(aName);
 
@@ -420,53 +446,7 @@ sal_Bool ScViewFunc::PasteGraphic( const Point& rPos, const Graphic& rGraphic,
     if (!rFile.isEmpty())
         pGrafObj->SetGraphicLink( rFile, ""/*TODO?*/, rFilter );
 
-    return sal_True;
+    return true;
 }
 
-sal_Bool ScViewFunc::ApplyGraphicToObject( SdrObject* pPickObj, const Graphic& rGraphic )
-{
-    sal_Bool bRet = false;
-
-    ScDrawView* pScDrawView = GetScDrawView();
-    if ( pScDrawView && pPickObj )
-    {
-        /**********************************************************************
-        * New attributes for object
-        **********************************************************************/
-        SdrPageView* pPV = pScDrawView->GetSdrPageView();
-        if (pPickObj->ISA(SdrGrafObj))
-        {
-            /******************************************************************
-            * Graphic object gets a new graphic
-            ******************************************************************/
-            SdrGrafObj* pNewGrafObj = (SdrGrafObj*) pPickObj->Clone();
-            pNewGrafObj->SetGraphic(rGraphic);
-
-            pScDrawView->BegUndo(ScGlobal::GetRscString(STR_UNDO_DRAGDROP));
-            pScDrawView->ReplaceObjectAtView(pPickObj, *pPV, pNewGrafObj);
-            pScDrawView->EndUndo();
-
-            bRet = sal_True;
-        }
-        else if (pPickObj->IsClosedObj() && !pPickObj->ISA(SdrOle2Obj))
-        {
-            /******************************************************************
-            * Object gets filled with the graphic
-            ******************************************************************/
-            pScDrawView->AddUndo(new SdrUndoAttrObj(*pPickObj));
-
-            SfxItemSet aSet( pScDrawView->GetModel()->GetItemPool(),
-                                XATTR_FILLSTYLE, XATTR_FILLBITMAP );
-            aSet.Put(XFillStyleItem(XFILL_BITMAP));
-            aSet.Put(XFillBitmapItem(OUString(), rGraphic));
-
-            pPickObj->SetMergedItemSetAndBroadcast(aSet);
-
-            bRet = sal_True;
-        }
-    }
-    return bRet;
-}
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
