@@ -22,7 +22,7 @@
 #include <cppuhelper/implementationentry.hxx>
 #include <cppuhelper/factory.hxx>
 #include <cppuhelper/exc_hlp.hxx>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <unotools/mediadescriptor.hxx>
 
@@ -32,6 +32,7 @@
 
 #include <com/sun/star/script/provider/theMasterScriptProviderFactory.hpp>
 #include <com/sun/star/script/browse/BrowseNodeFactoryViewTypes.hpp>
+#include <com/sun/star/script/browse/BrowseNodeTypes.hpp>
 #include <com/sun/star/document/XScriptInvocationContext.hpp>
 
 #include <tools/diagnose_ex.h>
@@ -43,6 +44,8 @@
 
 #include <vector>
 #include <algorithm>
+#include <memory>
+
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::script;
@@ -51,55 +54,46 @@ using namespace ::sf_misc;
 namespace browsenodefactory
 {
 class BrowseNodeAggregator :
-    public ::cppu::WeakImplHelper1< browse::XBrowseNode >
+    public ::cppu::WeakImplHelper< browse::XBrowseNode >
 {
 private:
     OUString m_Name;
-    Sequence< Reference< browse::XBrowseNode > > m_Nodes;
+    std::vector< Reference< browse::XBrowseNode > > m_Nodes;
 
 public:
 
-    BrowseNodeAggregator( const Reference< browse::XBrowseNode >& node )
+    explicit BrowseNodeAggregator( const Reference< browse::XBrowseNode >& node )
     {
         m_Name = node->getName();
-        m_Nodes.realloc( 1 );
+        m_Nodes.resize( 1 );
         m_Nodes[ 0 ] = node;
     }
 
-    virtual ~BrowseNodeAggregator()
-    {
-    }
-
     void addBrowseNode( const Reference< browse::XBrowseNode>& node )
     {
-        sal_Int32 index = m_Nodes.getLength();
-
-        m_Nodes.realloc( index + 1 );
-        m_Nodes[ index ] = node;
+        m_Nodes.push_back( node );
     }
 
     virtual OUString
-    SAL_CALL getName()
-            throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    SAL_CALL getName() override
     {
         return m_Name;
     }
 
     virtual Sequence< Reference< browse::XBrowseNode > > SAL_CALL
-    getChildNodes()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    getChildNodes() override
     {
         std::vector<  Sequence< Reference < browse::XBrowseNode > > > seqs;
-        seqs.reserve( m_Nodes.getLength() );
+        seqs.reserve( m_Nodes.size() );
 
         sal_Int32 numChildren = 0;
 
-        for ( sal_Int32 i = 0; i < m_Nodes.getLength(); i++ )
+        for (Reference<XBrowseNode> & xNode : m_Nodes)
         {
             Sequence< Reference < browse::XBrowseNode > > children;
             try
             {
-                children = m_Nodes[ i ]->getChildNodes();
+                children = xNode->getChildNodes();
                 seqs.push_back( children );
                 numChildren += children.getLength();
             }
@@ -126,18 +120,17 @@ public:
     }
 
     virtual sal_Bool SAL_CALL
-    hasChildNodes()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    hasChildNodes() override
     {
-        if ( m_Nodes.getLength() != 0 )
+        if ( !m_Nodes.empty() )
         {
-            for ( sal_Int32 i = 0 ; i < m_Nodes.getLength(); i++ )
+            for (Reference<XBrowseNode> & xNode : m_Nodes)
             {
                 try
                 {
-                    if ( m_Nodes[ i ]->hasChildNodes() )
+                    if ( xNode->hasChildNodes() )
                     {
-                        return sal_True;
+                        return true;
                     }
                 }
                 catch ( Exception& )
@@ -148,20 +141,16 @@ public:
             }
         }
 
-        return sal_False;
+        return false;
     }
 
-    virtual sal_Int16 SAL_CALL getType()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual sal_Int16 SAL_CALL getType() override
     {
         return browse::BrowseNodeTypes::CONTAINER;
     }
 };
 
-//typedef std::map< OUString, Reference< browse::XBrowseNode > >
-typedef std::unordered_map< OUString, Reference< browse::XBrowseNode >,
-    OUStringHash, ::std::equal_to< OUString > >
-        BrowseNodeAggregatorHash;
+typedef std::unordered_map< OUString, Reference< browse::XBrowseNode > >  BrowseNodeAggregatorHash;
 typedef std::vector< OUString > vString;
 
 struct alphaSort
@@ -172,46 +161,35 @@ struct alphaSort
     }
 };
 class LocationBrowseNode :
-    public ::cppu::WeakImplHelper1< browse::XBrowseNode >
+    public ::cppu::WeakImplHelper< browse::XBrowseNode >
 {
 private:
-    BrowseNodeAggregatorHash* m_hBNA;
+    std::unique_ptr<BrowseNodeAggregatorHash> m_hBNA;
     vString m_vStr;
     OUString m_sNodeName;
     Reference< browse::XBrowseNode > m_origNode;
 
 public:
 
-    LocationBrowseNode( const Reference< browse::XBrowseNode >& node )
+    explicit LocationBrowseNode( const Reference< browse::XBrowseNode >& node )
     {
         m_sNodeName = node->getName();
-        m_hBNA = NULL;
+        m_hBNA = nullptr;
         m_origNode.set( node );
     }
 
-    virtual ~LocationBrowseNode()
-    {
-        if (m_hBNA)
-        {
-            delete m_hBNA;
-        }
-    }
-
 
     // XBrowseNode
 
-
-    virtual OUString SAL_CALL getName()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual OUString SAL_CALL getName() override
     {
         return m_sNodeName;
     }
 
     virtual Sequence< Reference< browse::XBrowseNode > > SAL_CALL
-    getChildNodes()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    getChildNodes() override
     {
-        if ( m_hBNA == NULL )
+        if ( m_hBNA == nullptr )
         {
             loadChildNodes();
         }
@@ -229,14 +207,12 @@ public:
         return children;
     }
 
-    virtual sal_Bool SAL_CALL hasChildNodes()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual sal_Bool SAL_CALL hasChildNodes() override
     {
-        return sal_True;
+        return true;
     }
 
-    virtual sal_Int16 SAL_CALL getType()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual sal_Int16 SAL_CALL getType() override
     {
         return browse::BrowseNodeTypes::CONTAINER;
     }
@@ -245,7 +221,7 @@ private:
 
     void loadChildNodes()
     {
-        m_hBNA = new BrowseNodeAggregatorHash();
+        m_hBNA.reset( new BrowseNodeAggregatorHash );
 
         Sequence< Reference< browse::XBrowseNode > > langNodes =
             m_origNode->getChildNodes();
@@ -286,7 +262,7 @@ private:
                 }
             }
         }
-        // sort children alpahbetically
+        // sort children alphabetically
         ::std::sort( m_vStr.begin(), m_vStr.end(), alphaSort() );
     }
 };
@@ -294,7 +270,7 @@ private:
 namespace
 {
 
-Sequence< Reference< browse::XBrowseNode > > getAllBrowseNodes( const Reference< XComponentContext >& xCtx )
+std::vector< Reference< browse::XBrowseNode > > getAllBrowseNodes( const Reference< XComponentContext >& xCtx )
 {
     Sequence< OUString > openDocs =
         MiscUtils::allOpenTDocUrls( xCtx );
@@ -303,21 +279,19 @@ Sequence< Reference< browse::XBrowseNode > > getAllBrowseNodes( const Reference<
     sal_Int32 initialSize = openDocs.getLength() + 2;
     sal_Int32 mspIndex = 0;
 
-    Sequence < Reference < browse::XBrowseNode > > locnBNs( initialSize );
+    std::vector< Reference < browse::XBrowseNode > > locnBNs( initialSize );
     try
     {
         xFac = provider::theMasterScriptProviderFactory::get( xCtx );
 
-        locnBNs[ mspIndex++ ] = Reference< browse::XBrowseNode >( xFac->createScriptProvider( makeAny( OUString("user") ) ), UNO_QUERY_THROW );
-        locnBNs[ mspIndex++ ] = Reference< browse::XBrowseNode >( xFac->createScriptProvider( makeAny( OUString("share") ) ), UNO_QUERY_THROW );
+        locnBNs[ mspIndex++ ].set( xFac->createScriptProvider( makeAny( OUString("user") ) ), UNO_QUERY_THROW );
+        locnBNs[ mspIndex++ ].set( xFac->createScriptProvider( makeAny( OUString("share") ) ), UNO_QUERY_THROW );
     }
     // TODO proper exception handling, should throw
     catch( const Exception& e )
     {
-        (void)e;
-        OSL_TRACE("Caught Exception %s",
-            OUStringToOString( e.Message , RTL_TEXTENCODING_ASCII_US ).pData->buffer );
-        locnBNs.realloc( mspIndex );
+        SAL_WARN("scripting", "Caught " << e );
+        locnBNs.resize( mspIndex );
         return locnBNs;
     }
 
@@ -339,8 +313,7 @@ Sequence< Reference< browse::XBrowseNode > > getAllBrowseNodes( const Reference<
                 {
                     Reference< document::XEmbeddedScripts > xScripts( model, UNO_QUERY );
                     if ( xScripts.is() )
-                        locnBNs[ mspIndex++ ] = Reference< browse::XBrowseNode >(
-                            xFac->createScriptProvider( makeAny( model ) ), UNO_QUERY_THROW );
+                        locnBNs[ mspIndex++ ].set( xFac->createScriptProvider( makeAny( model ) ), UNO_QUERY_THROW );
                 }
             }
         }
@@ -351,7 +324,7 @@ Sequence< Reference< browse::XBrowseNode > > getAllBrowseNodes( const Reference<
 
     }
 
-    Sequence < Reference < browse::XBrowseNode > > locnBNs_Return( mspIndex );
+    std::vector< Reference < browse::XBrowseNode > > locnBNs_Return( mspIndex );
     for ( sal_Int32 j = 0; j < mspIndex; j++ )
         locnBNs_Return[j] = locnBNs[j];
 
@@ -370,7 +343,7 @@ struct alphaSortForBNodes
     }
 };
 
-typedef ::cppu::WeakImplHelper1< browse::XBrowseNode > t_BrowseNodeBase;
+typedef ::cppu::WeakImplHelper< browse::XBrowseNode > t_BrowseNodeBase;
 class DefaultBrowseNode :
     public t_BrowseNodeBase
 {
@@ -418,7 +391,7 @@ public:
         }
     }
 
-    virtual ~DefaultBrowseNode()
+    virtual ~DefaultBrowseNode() override
     {
         if ( m_xAggProxy.is() )
         {
@@ -427,12 +400,11 @@ public:
     }
 
     virtual Sequence< Reference< browse::XBrowseNode > > SAL_CALL
-                getChildNodes()
-    throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+                getChildNodes() override
     {
         if ( hasChildNodes() )
         {
-            vXBrowseNodes m_vNodes;
+            vXBrowseNodes aVNodes;
             Sequence < Reference< browse::XBrowseNode > > nodes =
                 m_xWrappedBrowseNode->getChildNodes();
             for ( sal_Int32 i=0; i<nodes.getLength(); i++ )
@@ -440,13 +412,13 @@ public:
                 Reference< browse::XBrowseNode > xBrowseNode = nodes[ i ];
                 OSL_ENSURE( xBrowseNode.is(), "DefaultBrowseNode::getChildNodes(): Invalid BrowseNode" );
                 if( xBrowseNode.is() )
-                    m_vNodes.push_back( new DefaultBrowseNode( m_xCtx, xBrowseNode ) );
+                    aVNodes.push_back( new DefaultBrowseNode( m_xCtx, xBrowseNode ) );
             }
 
-            ::std::sort( m_vNodes.begin(), m_vNodes.end(), alphaSortForBNodes() );
-            Sequence < Reference< browse::XBrowseNode > > children( m_vNodes.size() );
-            vXBrowseNodes::const_iterator it = m_vNodes.begin();
-            for ( sal_Int32 i=0; it != m_vNodes.end() && i<children.getLength(); i++, ++it )
+            ::std::sort( aVNodes.begin(), aVNodes.end(), alphaSortForBNodes() );
+            Sequence < Reference< browse::XBrowseNode > > children( aVNodes.size() );
+            vXBrowseNodes::const_iterator it = aVNodes.begin();
+            for ( sal_Int32 i=0; it != aVNodes.end() && i<children.getLength(); i++, ++it )
             {
                 children[ i ].set( *it );
             }
@@ -461,29 +433,25 @@ public:
         }
     }
 
-    virtual sal_Int16 SAL_CALL getType()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual sal_Int16 SAL_CALL getType() override
     {
         return m_xWrappedBrowseNode->getType();
     }
 
     virtual OUString
-    SAL_CALL getName()
-    throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    SAL_CALL getName() override
     {
         return m_xWrappedBrowseNode->getName();
     }
 
     virtual sal_Bool SAL_CALL
-    hasChildNodes()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    hasChildNodes() override
     {
         return m_xWrappedBrowseNode->hasChildNodes();
     }
 
     // XInterface
-    virtual Any SAL_CALL queryInterface( const Type& aType )
-        throw ( com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual Any SAL_CALL queryInterface( const Type& aType ) override
     {
         Any aRet = t_BrowseNodeBase::queryInterface( aType );
         if ( aRet.hasValue() )
@@ -500,36 +468,20 @@ public:
         }
     }
 
-    virtual void SAL_CALL acquire()
-        throw () SAL_OVERRIDE
-
-    {
-        osl_atomic_increment( &m_refCount );
-    }
-    virtual void SAL_CALL release()
-        throw () SAL_OVERRIDE
-    {
-        if ( osl_atomic_decrement( &m_refCount ) == 0 )
-        {
-            delete this;
-        }
-    }
     // XTypeProvider (implemnented by base, but needs to be overridden for
     //                delegating to aggregate)
-    virtual Sequence< Type > SAL_CALL getTypes()
-        throw ( com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual Sequence< Type > SAL_CALL getTypes() override
     {
         return m_xWrappedTypeProv->getTypes();
     }
-    virtual Sequence< sal_Int8 > SAL_CALL getImplementationId()
-        throw ( com::sun::star::uno::RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual Sequence< sal_Int8 > SAL_CALL getImplementationId() override
     {
         return css::uno::Sequence<sal_Int8>();
     }
 };
 
 class DefaultRootBrowseNode :
-    public ::cppu::WeakImplHelper1< browse::XBrowseNode >
+    public ::cppu::WeakImplHelper< browse::XBrowseNode >
 {
 
 private:
@@ -537,25 +489,20 @@ private:
     OUString m_Name;
 
 public:
-    DefaultRootBrowseNode( const Reference< XComponentContext >& xCtx )
+    explicit DefaultRootBrowseNode( const Reference< XComponentContext >& xCtx )
     {
-        Sequence < Reference< browse::XBrowseNode > > nodes =
+        std::vector< Reference< browse::XBrowseNode > > nodes =
             getAllBrowseNodes( xCtx );
 
-        for ( sal_Int32 i=0; i<nodes.getLength(); i++ )
+        for (Reference< browse::XBrowseNode > & xNode : nodes)
         {
-            m_vNodes.push_back( new DefaultBrowseNode( xCtx, nodes[ i ] ) );
+            m_vNodes.push_back( new DefaultBrowseNode( xCtx, xNode ) );
         }
         m_Name = "Root";
     }
 
-    virtual ~DefaultRootBrowseNode()
-    {
-    }
-
     virtual Sequence< Reference< browse::XBrowseNode > > SAL_CALL
-                getChildNodes()
-    throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+                getChildNodes() override
     {
         // no need to sort user, share, doc1...docN
         //::std::sort( m_vNodes.begin(), m_vNodes.end(), alphaSortForBNodes() );
@@ -568,25 +515,22 @@ public:
         return children;
     }
 
-    virtual sal_Int16 SAL_CALL getType()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual sal_Int16 SAL_CALL getType() override
     {
         return browse::BrowseNodeTypes::ROOT;
     }
 
     virtual OUString
-    SAL_CALL getName()
-    throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    SAL_CALL getName() override
     {
         return m_Name;
     }
 
     virtual sal_Bool SAL_CALL
-    hasChildNodes()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    hasChildNodes() override
     {
         bool result = true;
-        if ( !m_vNodes.size() )
+        if ( m_vNodes.empty() )
         {
             result = false;
         }
@@ -596,38 +540,32 @@ public:
 
 
 class SelectorBrowseNode :
-    public ::cppu::WeakImplHelper1< browse::XBrowseNode >
+    public ::cppu::WeakImplHelper< browse::XBrowseNode >
 {
 private:
     Reference< XComponentContext > m_xComponentContext;
 
 public:
-    SelectorBrowseNode( const Reference< XComponentContext >& xContext )
+    explicit SelectorBrowseNode( const Reference< XComponentContext >& xContext )
       : m_xComponentContext( xContext )
     {
     }
 
-    virtual ~SelectorBrowseNode()
-    {
-    }
-
-    virtual OUString SAL_CALL getName()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual OUString SAL_CALL getName() override
     {
         return OUString("Root");
     }
 
     virtual Sequence< Reference< browse::XBrowseNode > > SAL_CALL
-    getChildNodes()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    getChildNodes() override
     {
 
-        Sequence < Reference < browse::XBrowseNode > > locnBNs = getAllBrowseNodes( m_xComponentContext );
+        std::vector< Reference < browse::XBrowseNode > > locnBNs = getAllBrowseNodes( m_xComponentContext );
 
         Sequence<  Reference< browse::XBrowseNode > > children(
-            locnBNs.getLength() );
+            locnBNs.size() );
 
-        for ( sal_Int32 j = 0; j < locnBNs.getLength(); j++ )
+        for ( size_t j = 0; j < locnBNs.size(); j++ )
         {
             children[j] = new LocationBrowseNode( locnBNs[j] );
         }
@@ -635,14 +573,12 @@ public:
         return children;
     }
 
-    virtual sal_Bool SAL_CALL hasChildNodes()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual sal_Bool SAL_CALL hasChildNodes() override
     {
-        return sal_True; // will always be user and share
+        return true; // will always be user and share
     }
 
-    virtual sal_Int16 SAL_CALL getType()
-        throw ( RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual sal_Int16 SAL_CALL getType() override
     {
         return browse::BrowseNodeTypes::CONTAINER;
     }
@@ -659,7 +595,6 @@ BrowseNodeFactoryImpl::~BrowseNodeFactoryImpl()
 }
 
 
-
 // Implementation of XBrowseNodeFactory
 
 
@@ -669,12 +604,11 @@ BrowseNodeFactoryImpl::~BrowseNodeFactoryImpl()
  */
 Reference< browse::XBrowseNode > SAL_CALL
 BrowseNodeFactoryImpl::createView( sal_Int16 viewType )
-    throw (RuntimeException, std::exception)
 {
     switch( viewType )
     {
         case browse::BrowseNodeFactoryViewTypes::MACROSELECTOR:
-            return getSelectorHierarchy();
+            return new SelectorBrowseNode( m_xComponentContext );
         case browse::BrowseNodeFactoryViewTypes::MACROORGANIZER:
             return getOrganizerHierarchy();
         default:
@@ -682,20 +616,8 @@ BrowseNodeFactoryImpl::createView( sal_Int16 viewType )
     }
 }
 
-Reference< browse::XBrowseNode >
-BrowseNodeFactoryImpl::getSelectorHierarchy()
-    throw (RuntimeException)
-{
-    /*if ( !m_xSelectorBrowseNode.is() )
-    {
-        m_xSelectorBrowseNode = new SelectorBrowseNode( m_xComponentContext );
-    }*/
-    return new SelectorBrowseNode( m_xComponentContext );
-}
-
 Reference< browse::XBrowseNode >
 BrowseNodeFactoryImpl::getOrganizerHierarchy()
-    throw (RuntimeException)
 {
     Reference< browse::XBrowseNode > xRet = new  DefaultRootBrowseNode( m_xComponentContext );
     return xRet;
@@ -704,7 +626,6 @@ BrowseNodeFactoryImpl::getOrganizerHierarchy()
 // Helper methods
 
 
-
 // Namespace global methods for setting up BrowseNodeFactory service
 
 
@@ -737,20 +658,17 @@ bnf_create( Reference< XComponentContext > const & xComponentContext )
 
 OUString SAL_CALL
 BrowseNodeFactoryImpl::getImplementationName()
-    throw (RuntimeException, std::exception)
 {
     return bnf_getImplementationName();
 }
 
 Sequence< OUString > SAL_CALL
 BrowseNodeFactoryImpl::getSupportedServiceNames()
-    throw (RuntimeException, std::exception)
 {
     return bnf_getSupportedServiceNames();
 }
 
 sal_Bool BrowseNodeFactoryImpl::supportsService(OUString const & serviceName )
-    throw (RuntimeException, std::exception)
 {
     return cppu::supportsService(this, serviceName);
 }
