@@ -21,15 +21,14 @@
 
 #include <com/sun/star/style/XStyle.hpp>
 #include <com/sun/star/drawing/LineStyle.hpp>
-#include <com/sun/star/container/XNameAccess.hpp>
 #include <i18nlangtag/mslangid.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/dispatch.hxx>
-#include "Outliner.hxx"
+#include <Outliner.hxx>
 #include <comphelper/processfactory.hxx>
 #include <editeng/outliner.hxx>
 
-#include "../ui/inc/DrawDocShell.hxx"
+#include <DrawDocShell.hxx>
 #include <editeng/eeitem.hxx>
 
 #include <vcl/settings.hxx>
@@ -44,7 +43,7 @@
 #include <editeng/lspcitem.hxx>
 #include <editeng/adjustitem.hxx>
 #include <editeng/numdef.hxx>
-#include <svx/dialogs.hrc>
+#include <svx/strings.hrc>
 #include <svx/dialmgr.hxx>
 #include <editeng/bulletitem.hxx>
 #include <svx/xtable.hxx>
@@ -85,31 +84,30 @@
 #include <svx/svditer.hxx>
 #include <svx/svdogrp.hxx>
 #include <svx/svdlayer.hxx>
-#include <tools/shl.hxx>
 #include <editeng/numitem.hxx>
 #include <editeng/editeng.hxx>
 #include <editeng/unolingu.hxx>
 #include <com/sun/star/linguistic2/XHyphenator.hpp>
-#include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <svl/itempool.hxx>
 #include <editeng/outlobj.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <editeng/langitem.hxx>
 #include <editeng/frmdiritem.hxx>
 
-#include "sdresid.hxx"
-#include "drawdoc.hxx"
-#include "sdpage.hxx"
-#include "glob.hrc"
-#include "glob.hxx"
-#include "stlpool.hxx"
-#include "helpids.h"
-#include "sdiocmpt.hxx"
-#include "shapelist.hxx"
+#include <sdresid.hxx>
+#include <drawdoc.hxx>
+#include <sdpage.hxx>
+#include <strings.hrc>
+#include <glob.hxx>
+#include <stlpool.hxx>
+#include <helpids.h>
+#include <sdiocmpt.hxx>
+#include <shapelist.hxx>
 #include <basegfx/point/b2dpoint.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 #include <svl/itemset.hxx>
-#include "app.hrc"
+#include <app.hrc>
+#include <strings.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -129,7 +127,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     SdStyleSheetPool*       pSSPool = static_cast<SdStyleSheetPool*>(GetStyleSheetPool());
     SfxStyleSheetBase*      pSheet = nullptr;
     OUString                aHelpFile;
-    OUString                aStdName(SD_RESSTR(STR_STANDARD_STYLESHEET_NAME));
+    OUString                aStdName(SdResId(STR_STANDARD_STYLESHEET_NAME));
 
     // Default style
 
@@ -139,7 +137,6 @@ void SdDrawDocument::CreateLayoutTemplates()
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetHelpId( aHelpFile, HID_STANDARD_STYLESHEET_NAME );
     SfxItemSet& rISet = pSheet->GetItemSet();
-    SfxItemPool* pPool = rISet.GetPool();
 
     ::basegfx::B2DPolyPolygon aNullPolyPolygon;
     Color    aNullCol(RGB_Color(COL_DEFAULT_SHAPE_STROKE));
@@ -154,9 +151,9 @@ void SdDrawDocument::CreateLayoutTemplates()
     rISet.Put(XLineStyleItem(drawing::LineStyle_SOLID));
     rISet.Put(XLineColorItem(OUString(), RGB_Color(COL_DEFAULT_SHAPE_STROKE)));
     rISet.Put(XLineWidthItem(0));
-    rISet.Put(XLineDashItem(pPool,aNullDash));
-    rISet.Put(XLineStartItem(pPool,aNullPolyPolygon));
-    rISet.Put(XLineEndItem(pPool,aNullPolyPolygon));
+    rISet.Put(XLineDashItem(aNullDash));
+    rISet.Put(XLineStartItem(aNullPolyPolygon));
+    rISet.Put(XLineEndItem(aNullPolyPolygon));
     rISet.Put(XLineStartWidthItem(200));
     rISet.Put(XLineEndWidthItem(200));
     rISet.Put(XLineStartCenterItem());
@@ -168,12 +165,12 @@ void SdDrawDocument::CreateLayoutTemplates()
     rISet.Put(XFillColorItem(OUString(), RGB_Color(COL_DEFAULT_SHAPE_FILLING)));
 
     rISet.Put( XFillGradientItem( aNullGrad) );
-    rISet.Put(XFillHatchItem(pPool,aNullHatch));
+    rISet.Put(XFillHatchItem(aNullHatch));
     Size    aNullSize( 32, 32 );
     Color   aNullColor( COL_WHITE );
     Bitmap  aNullBmp( aNullSize, 8 );
     aNullBmp.Erase( aNullColor );
-    rISet.Put(XFillBitmapItem(pPool, Graphic(aNullBmp)));
+    rISet.Put(XFillBitmapItem(Graphic(aNullBmp)));
 
                     // Shadow attributes (Drawing Engine)
     rISet.Put(makeSdrShadowItem(false));
@@ -215,9 +212,9 @@ void SdDrawDocument::CreateLayoutTemplates()
     rISet.Put(SvxUnderlineItem(LINESTYLE_NONE, EE_CHAR_UNDERLINE));
     rISet.Put(SvxOverlineItem(LINESTYLE_NONE, EE_CHAR_OVERLINE));
     rISet.Put(SvxCrossedOutItem(STRIKEOUT_NONE, EE_CHAR_STRIKEOUT ));
-    rISet.Put(SvxCaseMapItem(SVX_CASEMAP_NOT_MAPPED, EE_CHAR_CASEMAP ));
+    rISet.Put(SvxCaseMapItem(SvxCaseMap::NotMapped, EE_CHAR_CASEMAP ));
     rISet.Put(SvxEmphasisMarkItem(FontEmphasisMark::NONE, EE_CHAR_EMPHASISMARK));
-    rISet.Put(SvxCharReliefItem(RELIEF_NONE, EE_CHAR_RELIEF));
+    rISet.Put(SvxCharReliefItem(FontRelief::NONE, EE_CHAR_RELIEF));
     rISet.Put(SvxColorItem(Color(COL_AUTO), EE_CHAR_COLOR ));
 
     // Paragraph attributes (Edit Engine)
@@ -256,7 +253,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     SfxItemSet* pISet = nullptr;
 
     // Object with arrowhead
-    aName = SD_RESSTR(STR_POOLSHEET_OBJWITHARROW);
+    aName = SdResId(STR_POOLSHEET_OBJWITHARROW);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_OBJWITHARROW );
@@ -271,14 +268,14 @@ void SdDrawDocument::CreateLayoutTemplates()
     aArrow.append(::basegfx::B2DPoint(0.0, 30.0));
     aArrow.append(::basegfx::B2DPoint(20.0, 30.0));
     aArrow.setClosed(true);
-    pISet->Put(XLineStartItem(SVX_RESSTR(RID_SVXSTR_ARROW),::basegfx::B2DPolyPolygon(aArrow)));
+    pISet->Put(XLineStartItem(SvxResId(RID_SVXSTR_ARROW),::basegfx::B2DPolyPolygon(aArrow)));
 
     pISet->Put(XLineStartWidthItem(700));
     pISet->Put(XLineEndWidthItem(300));
     pISet->Put(XLineStartCenterItem(true));
 
     // Object with Shadow
-    aName = SD_RESSTR(STR_POOLSHEET_OBJWITHSHADOW);
+    aName = SdResId(STR_POOLSHEET_OBJWITHSHADOW);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_OBJWITHSHADOW );
@@ -289,8 +286,8 @@ void SdDrawDocument::CreateLayoutTemplates()
     pISet->Put(makeSdrShadowXDistItem(200));        // 3 mm shadow distance
     pISet->Put(makeSdrShadowYDistItem(200));
 
-    // Object without fillung
-    aName = SD_RESSTR(STR_POOLSHEET_OBJWITHOUTFILL);
+    // Object without filling
+    aName = SdResId(STR_POOLSHEET_OBJWITHOUTFILL);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_OBJWITHOUTFILL );
@@ -301,7 +298,7 @@ void SdDrawDocument::CreateLayoutTemplates()
 
     // Object no fill no line
 
-    aName = SD_RESSTR(STR_POOLSHEET_OBJNOLINENOFILL);
+    aName = SdResId(STR_POOLSHEET_OBJNOLINENOFILL);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_OBJNOLINENOFILL );
@@ -312,7 +309,7 @@ void SdDrawDocument::CreateLayoutTemplates()
 
     // Text
 
-    aName = SD_RESSTR(STR_POOLSHEET_TEXT);
+    aName = SdResId(STR_POOLSHEET_TEXT);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TEXT );
@@ -322,7 +319,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
     // Text body
-    aName = SD_RESSTR(STR_POOLSHEET_TEXTBODY);
+    aName = SdResId(STR_POOLSHEET_TEXTBODY);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TEXTBODY );
@@ -334,7 +331,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pISet->Put(SvxFontHeightItem(564, 100, EE_CHAR_FONTHEIGHT));        // 16 pt
 
     // Text body, justified
-    aName = SD_RESSTR(STR_POOLSHEET_TEXTBODY_JUSTIFY);
+    aName = SdResId(STR_POOLSHEET_TEXTBODY_JUSTIFY);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TEXTBODY_JUSTIFY );
@@ -343,10 +340,10 @@ void SdDrawDocument::CreateLayoutTemplates()
     pISet->Put(XLineStyleItem(drawing::LineStyle_NONE));
     pISet->Put(XFillStyleItem(drawing::FillStyle_NONE));
 
-    pISet->Put(SvxAdjustItem(SVX_ADJUST_BLOCK, EE_PARA_JUST ));
+    pISet->Put(SvxAdjustItem(SvxAdjust::Block, EE_PARA_JUST ));
 
     // Text body, indented
-    aName = SD_RESSTR(STR_POOLSHEET_TEXTBODY_INDENT);
+    aName = SdResId(STR_POOLSHEET_TEXTBODY_INDENT);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TEXTBODY_INDENT );
@@ -361,7 +358,7 @@ void SdDrawDocument::CreateLayoutTemplates()
 
     // Title
 
-    aName = SD_RESSTR(STR_POOLSHEET_TITLE);
+    aName = SdResId(STR_POOLSHEET_TITLE);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TITLE );
@@ -373,7 +370,7 @@ void SdDrawDocument::CreateLayoutTemplates()
     pISet->Put(SvxFontHeightItem(1551, 100, EE_CHAR_FONTHEIGHT ));      // 44 pt
 
     // Title1
-    aName = SD_RESSTR(STR_POOLSHEET_TITLE1);
+    aName = SdResId(STR_POOLSHEET_TITLE1);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TITLE1 );
@@ -390,11 +387,11 @@ void SdDrawDocument::CreateLayoutTemplates()
 
     pISet->Put(SvxFontHeightItem(846, 100, EE_CHAR_FONTHEIGHT ));       // 24 pt
 
-    pISet->Put(SvxAdjustItem(SVX_ADJUST_CENTER, EE_PARA_JUST ));
+    pISet->Put(SvxAdjustItem(SvxAdjust::Center, EE_PARA_JUST ));
 
     // Title2
 
-    aName = SD_RESSTR(STR_POOLSHEET_TITLE2);
+    aName = SdResId(STR_POOLSHEET_TITLE2);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_TITLE2 );
@@ -419,11 +416,11 @@ void SdDrawDocument::CreateLayoutTemplates()
 
     pISet->Put(SvxULSpaceItem(100, 100, EE_PARA_ULSPACE ));      // Paragraph margin above/below: 1 mm
 
-    pISet->Put(SvxAdjustItem(SVX_ADJUST_CENTER, EE_PARA_JUST ));
+    pISet->Put(SvxAdjustItem(SvxAdjust::Center, EE_PARA_JUST ));
 
     // Headline
 
-    aName = SD_RESSTR(STR_POOLSHEET_HEADLINE);
+    aName = SdResId(STR_POOLSHEET_HEADLINE);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_HEADLINE );
@@ -438,7 +435,7 @@ void SdDrawDocument::CreateLayoutTemplates()
                                                 // Paragraph margin below: 2,1 mm
 
     // Headline1
-    aName = SD_RESSTR(STR_POOLSHEET_HEADLINE1);
+    aName = SdResId(STR_POOLSHEET_HEADLINE1);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_HEADLINE1 );
@@ -455,7 +452,7 @@ void SdDrawDocument::CreateLayoutTemplates()
                                                 // Paragraph margin below: 2,1 mm
 
     // Headline2
-    aName = SD_RESSTR(STR_POOLSHEET_HEADLINE2);
+    aName = SdResId(STR_POOLSHEET_HEADLINE2);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_HEADLINE2 );
@@ -473,7 +470,7 @@ void SdDrawDocument::CreateLayoutTemplates()
                                                 // Paragraph margin below: 2,1 mm
 
     // Measurements
-    aName = SD_RESSTR(STR_POOLSHEET_MEASURE);
+    aName = SdResId(STR_POOLSHEET_MEASURE);
     pSheet = &(pSSPool->Make(aName, SD_STYLE_FAMILY_GRAPHICS, nMask));
     pSheet->SetParent(aStdName);
     pSheet->SetHelpId( aHelpFile, HID_POOLSHEET_MEASURE );
@@ -484,15 +481,15 @@ void SdDrawDocument::CreateLayoutTemplates()
 
     pISet->Put(SvxFontHeightItem(423, 100, EE_CHAR_FONTHEIGHT ));         // 12 pt
 
-    pISet->Put(XLineStartItem(SVX_RESSTR(RID_SVXSTR_ARROW),::basegfx::B2DPolyPolygon(aArrow)));
+    pISet->Put(XLineStartItem(SvxResId(RID_SVXSTR_ARROW),::basegfx::B2DPolyPolygon(aArrow)));
     pISet->Put(XLineStartWidthItem(200));
-    pISet->Put(XLineEndItem(SVX_RESSTR(RID_SVXSTR_ARROW),::basegfx::B2DPolyPolygon(aArrow)));
+    pISet->Put(XLineEndItem(SvxResId(RID_SVXSTR_ARROW),::basegfx::B2DPolyPolygon(aArrow)));
     pISet->Put(XLineEndWidthItem(200));
     pISet->Put(XLineStyleItem(drawing::LineStyle_SOLID));
     pISet->Put(SdrYesNoItem(SDRATTR_MEASURESHOWUNIT, true));
 
     // Generate presentation templates for default layout.
-    OUString aPrefix = SD_RESSTR(STR_LAYOUT_DEFAULT_NAME);
+    OUString aPrefix = SdResId(STR_LAYOUT_DEFAULT_NAME);
     pSSPool->CreateLayoutStyleSheets(aPrefix);
 }
 
@@ -536,18 +533,15 @@ void SdDrawDocument::CreateDefaultCellStyles()
 {
     SdStyleSheetPool*       pSSPool = static_cast< SdStyleSheetPool* >(GetStyleSheetPool());
     SfxStyleSheetBase*      pSheet = nullptr;
-    OUString                aHelpFile;
 
     Reference< XNameContainer > xTableFamily( pSSPool->getByName( "table" ), UNO_QUERY );
 
     // ---- Default -----------------------------------------------
 
-    sal_uInt16 nMask = SFXSTYLEBIT_AUTO;
-
     OUString aDefaultCellStyleName( "default" );
 
-    pSheet = &(pSSPool->Make(aDefaultCellStyleName, SD_STYLE_FAMILY_CELL, nMask));
-    pSheet->SetHelpId( aHelpFile, HID_SD_CELL_STYLE_DEFAULT );
+    pSheet = &(pSSPool->Make(aDefaultCellStyleName, SD_STYLE_FAMILY_CELL, SFXSTYLEBIT_AUTO));
+    pSheet->SetHelpId( OUString(), HID_SD_CELL_STYLE_DEFAULT );
     SfxItemSet& rISet = pSheet->GetItemSet();
 
     Color    aNullCol(RGB_Color(COL_BLACK));
@@ -599,7 +593,7 @@ void SdDrawDocument::CreateDefaultCellStyles()
 
     Color aWhite( COL_WHITE );
     ::editeng::SvxBorderLine aBorderLine(
-            &aWhite, 1, table::BorderLineStyle::SOLID);
+            &aWhite, 1, SvxBorderLineStyle::SOLID);
 
     SvxBoxItem aBoxItem( SDRATTR_TABLE_BORDER );
     aBoxItem.SetLine( &aBorderLine, SvxBoxItemLine::TOP );
@@ -699,7 +693,7 @@ void SdDrawDocument::CreateDefaultCellStyles()
 }
 
 // Number of pages that reference a master page
-sal_uInt16 SdDrawDocument::GetMasterPageUserCount(SdrPage* pMaster) const
+sal_uInt16 SdDrawDocument::GetMasterPageUserCount(SdrPage const * pMaster) const
 {
     sal_uInt16 nResult = 0;
     sal_uInt16 nPage;
@@ -744,7 +738,7 @@ void SdDrawDocument::StartOnlineSpelling(bool bForceSpelling)
     {
         StopOnlineSpelling();
 
-        ::sd::Outliner* pOutl = GetInternalOutliner();
+        SdOutliner* pOutl = GetInternalOutliner();
 
         Reference< XSpellChecker1 > xSpellChecker( LinguMgr::GetSpellChecker() );
         if ( xSpellChecker.is() )
@@ -773,16 +767,16 @@ void SdDrawDocument::StartOnlineSpelling(bool bForceSpelling)
 
         mpOnlineSpellingList->seekShape(0);
         mpOnlineSpellingIdle = new Idle("OnlineSpelling");
-        mpOnlineSpellingIdle->SetIdleHdl( LINK(this, SdDrawDocument, OnlineSpellingHdl) );
-        mpOnlineSpellingIdle->SetPriority(SchedulerPriority::LOWEST);
+        mpOnlineSpellingIdle->SetInvokeHandler( LINK(this, SdDrawDocument, OnlineSpellingHdl) );
+        mpOnlineSpellingIdle->SetPriority(TaskPriority::LOWEST);
         mpOnlineSpellingIdle->Start();
     }
 }
 
 // Fill OnlineSpelling list
-void SdDrawDocument::FillOnlineSpellingList(SdPage* pPage)
+void SdDrawDocument::FillOnlineSpellingList(SdPage const * pPage)
 {
-    SdrObjListIter aIter(*pPage, IM_FLAT);
+    SdrObjListIter aIter(*pPage, SdrIterMode::Flat);
 
     while (aIter.IsMore())
     {
@@ -800,7 +794,7 @@ void SdDrawDocument::FillOnlineSpellingList(SdPage* pPage)
         {
             // Found a group object
             SdrObjListIter aGroupIter(*static_cast<SdrObjGroup*>(pObj)->GetSubList(),
-                                      IM_DEEPNOGROUPS);
+                                      SdrIterMode::DeepNoGroups);
 
             bool bSubTextObjFound = false;
 
@@ -822,7 +816,7 @@ void SdDrawDocument::FillOnlineSpellingList(SdPage* pPage)
 }
 
 // OnlineSpelling in the background
-IMPL_LINK_NOARG_TYPED(SdDrawDocument, OnlineSpellingHdl, Idle *, void)
+IMPL_LINK_NOARG(SdDrawDocument, OnlineSpellingHdl, Timer *, void)
 {
     if (mpOnlineSpellingList!=nullptr
         && ( !mbOnlineSpell || mpOnlineSpellingList->hasMore()))
@@ -841,7 +835,7 @@ IMPL_LINK_NOARG_TYPED(SdDrawDocument, OnlineSpellingHdl, Idle *, void)
             {
                 // Found a group object
                 SdrObjListIter aGroupIter(*static_cast<SdrObjGroup*>(pObj)->GetSubList(),
-                                          IM_DEEPNOGROUPS);
+                                          SdrIterMode::DeepNoGroups);
 
 
                 while (aGroupIter.IsMore())
@@ -868,8 +862,7 @@ IMPL_LINK_NOARG_TYPED(SdDrawDocument, OnlineSpellingHdl, Idle *, void)
         // Stop search
         StopOnlineSpelling();
 
-        delete mpOnlineSearchItem;
-        mpOnlineSearchItem = nullptr;
+        mpOnlineSearchItem.reset();
     }
 }
 
@@ -879,14 +872,14 @@ void SdDrawDocument::SpellObject(SdrTextObj* pObj)
     if (pObj && pObj->GetOutlinerParaObject() /* && pObj != pView->GetTextEditObject() */)
     {
         mbHasOnlineSpellErrors = false;
-        ::sd::Outliner* pOutl = GetInternalOutliner();
+        SdOutliner* pOutl = GetInternalOutliner();
         pOutl->SetUpdateMode(true);
         Link<EditStatus&,void> aEvtHdl = pOutl->GetStatusEventHdl();
         pOutl->SetStatusEventHdl(LINK(this, SdDrawDocument, OnlineSpellEventHdl));
 
         OutlinerMode nOldOutlMode = pOutl->GetMode();
         OutlinerMode nOutlMode = OutlinerMode::TextObject;
-        if (pObj->GetObjInventor() == SdrInventor &&
+        if (pObj->GetObjInventor() == SdrInventor::Default &&
             pObj->GetObjIdentifier() == OBJ_OUTLINETEXT)
         {
             nOutlMode = OutlinerMode::OutlineObject;
@@ -928,7 +921,7 @@ void SdDrawDocument::SpellObject(SdrTextObj* pObj)
 }
 
 // Object was inserted into model
-void SdDrawDocument::InsertObject(SdrObject* pObj, SdPage* /*pPage*/)
+void SdDrawDocument::InsertObject(SdrObject* pObj)
 {
     if(mpOnlineSpellingList && pObj)
     {
@@ -941,7 +934,7 @@ void SdDrawDocument::InsertObject(SdrObject* pObj, SdPage* /*pPage*/)
 }
 
 // Object removed from model
-void SdDrawDocument::RemoveObject(SdrObject* pObj, SdPage* /*pPage*/)
+void SdDrawDocument::RemoveObject(SdrObject* pObj)
 {
     if(mpOnlineSpellingList && pObj)
     {
@@ -954,7 +947,7 @@ void SdDrawDocument::RemoveObject(SdrObject* pObj, SdPage* /*pPage*/)
 }
 
 // Callback for ExecuteSpellPopup()
-IMPL_LINK_TYPED(SdDrawDocument, OnlineSpellEventHdl, EditStatus&, rEditStat, void)
+IMPL_LINK(SdDrawDocument, OnlineSpellEventHdl, EditStatus&, rEditStat, void)
 {
     EditStatusFlags nStat = rEditStat.GetStatusWord();
     mbHasOnlineSpellErrors = bool(nStat & EditStatusFlags::WRONGWORDCHANGED);
@@ -963,10 +956,9 @@ IMPL_LINK_TYPED(SdDrawDocument, OnlineSpellEventHdl, EditStatus&, rEditStat, voi
 // Callback for ExecuteSpellPopup()
 
 // removed link and replaced with Imp method
-void SdDrawDocument::ImpOnlineSpellCallback(SpellCallbackInfo* pInfo, SdrObject* pObj, SdrOutliner* pOutl)
+void SdDrawDocument::ImpOnlineSpellCallback(SpellCallbackInfo const * pInfo, SdrObject* pObj, SdrOutliner const * pOutl)
 {
-    delete mpOnlineSearchItem;
-    mpOnlineSearchItem = nullptr;
+    mpOnlineSearchItem.reset();
 
     SpellCallbackCommand nCommand = pInfo->nCommand;
 
@@ -982,7 +974,7 @@ void SdDrawDocument::ImpOnlineSpellCallback(SpellCallbackInfo* pInfo, SdrObject*
             pObj->BroadcastObjectChange();
         }
 
-        mpOnlineSearchItem = new SvxSearchItem( SID_SEARCH_ITEM );
+        mpOnlineSearchItem.reset(new SvxSearchItem( SID_SEARCH_ITEM ) );
         mpOnlineSearchItem->SetSearchString(pInfo->aWord);
         StartOnlineSpelling();
     }
@@ -1009,23 +1001,23 @@ void SdDrawDocument::RestoreLayerNames()
 
             if (aLayerName == "LAYER_LAYOUT")
             {
-                pLayer->SetName(SD_RESSTR(STR_LAYER_LAYOUT));
+                pLayer->SetName(SdResId(STR_LAYER_LAYOUT));
             }
             else if (aLayerName == "LAYER_BCKGRND")
             {
-                pLayer->SetName(SD_RESSTR(STR_LAYER_BCKGRND));
+                pLayer->SetName(SdResId(STR_LAYER_BCKGRND));
             }
             else if (aLayerName == "LAYER_BACKGRNDOBJ")
             {
-                pLayer->SetName(SD_RESSTR(STR_LAYER_BCKGRNDOBJ));
+                pLayer->SetName(SdResId(STR_LAYER_BCKGRNDOBJ));
             }
             else if (aLayerName == "LAYER_CONTROLS")
             {
-                pLayer->SetName(SD_RESSTR(STR_LAYER_CONTROLS));
+                pLayer->SetName(SdResId(STR_LAYER_CONTROLS));
             }
             else if (aLayerName == "LAYER_MEASURELINES")
             {
-                pLayer->SetName(SD_RESSTR(STR_LAYER_MEASURELINES));
+                pLayer->SetName(SdResId(STR_LAYER_MEASURELINES));
             }
         }
     }
@@ -1039,19 +1031,19 @@ OUString SdDrawDocument::CreatePageNumValue(sal_uInt16 nNum) const
 
     switch (mePageNumType)
     {
-        case SVX_CHARS_UPPER_LETTER:
-            aPageNumValue += OUString( (sal_Unicode)(char)((nNum - 1) % 26 + 'A') );
+        case css::style::NumberingType::CHARS_UPPER_LETTER:
+            aPageNumValue += OUStringLiteral1( (nNum - 1) % 26 + 'A' );
             break;
-        case SVX_CHARS_LOWER_LETTER:
-            aPageNumValue += OUString( (sal_Unicode)(char)((nNum - 1) % 26 + 'a') );
+        case css::style::NumberingType::CHARS_LOWER_LETTER:
+            aPageNumValue += OUStringLiteral1( (nNum - 1) % 26 + 'a' );
             break;
-        case SVX_ROMAN_UPPER:
+        case css::style::NumberingType::ROMAN_UPPER:
             bUpper = true;
             SAL_FALLTHROUGH;
-        case SVX_ROMAN_LOWER:
+        case css::style::NumberingType::ROMAN_LOWER:
             aPageNumValue += SvxNumberFormat::CreateRomanString(nNum, bUpper);
             break;
-        case SVX_NUMBER_NONE:
+        case css::style::NumberingType::NUMBER_NONE:
             aPageNumValue = " ";
             break;
         default:
@@ -1103,7 +1095,7 @@ void SdDrawDocument::RenameLayoutTemplate(const OUString& rOldLayoutName, const
     // Now set the layout name of the drawing and the notes page, as well as
     // their master pages.
     OUString aPageLayoutName(rNewName);
-    aPageLayoutName += aSep + SD_RESSTR(STR_LAYOUT_OUTLINE);
+    aPageLayoutName += aSep + STR_LAYOUT_OUTLINE;
 
     // Inform all text objects on pages that use the renamed layout and set the
     // new name.
@@ -1121,7 +1113,7 @@ void SdDrawDocument::RenameLayoutTemplate(const OUString& rOldLayoutName, const
             {
                 SdrObject* pObj = pPage->GetObj(nObj);
 
-                if (pObj->GetObjInventor() == SdrInventor)
+                if (pObj->GetObjInventor() == SdrInventor::Default)
                 {
                     switch( pObj->GetObjIdentifier() )
                     {
@@ -1164,7 +1156,7 @@ void SdDrawDocument::RenameLayoutTemplate(const OUString& rOldLayoutName, const
             {
                 SdrObject* pObj = pPage->GetObj(nObj);
 
-                if (pObj->GetObjInventor() == SdrInventor)
+                if (pObj->GetObjInventor() == SdrInventor::Default)
                 {
                     switch(pObj->GetObjIdentifier())
                     {
@@ -1195,7 +1187,7 @@ void SdDrawDocument::RenameLayoutTemplate(const OUString& rOldLayoutName, const
 // Set outliner defaults (pool defaults)
 void SdDrawDocument::SetTextDefaults() const
 {
-    // BulletItem and BulletFont for Titel and Outline
+    // BulletItem and BulletFont for Title and Outline
     SvxBulletItem aBulletItem(EE_PARA_BULLET);
     vcl::Font aBulletFont( SdStyleSheetPool::GetBulletFont() );
     aBulletFont.SetFontSize(Size(0,846));       // 24 pt
@@ -1213,7 +1205,7 @@ void SdDrawDocument::SetTextDefaults() const
     aNumberFormat.SetBulletRelSize(45);
     aNumberFormat.SetBulletColor(Color(COL_AUTO));
     aNumberFormat.SetStart(1);
-    aNumberFormat.SetNumAdjust(SVX_ADJUST_LEFT);
+    aNumberFormat.SetNumAdjust(SvxAdjust::Left);
 
     SvxNumRule aNumRule( SvxNumRuleFlags::BULLET_REL_SIZE | SvxNumRuleFlags::BULLET_COLOR | SvxNumRuleFlags::CHAR_TEXT_DISTANCE, SVX_MAX_NUM, false);
 
@@ -1242,9 +1234,9 @@ css::text::WritingMode SdDrawDocument::GetDefaultWritingMode() const
     {
         switch( static_cast<const SvxFrameDirectionItem&>( *pItem ).GetValue() )
         {
-            case FRMDIR_HORI_LEFT_TOP: eRet = css::text::WritingMode_LR_TB; break;
-            case FRMDIR_HORI_RIGHT_TOP: eRet = css::text::WritingMode_RL_TB; break;
-            case FRMDIR_VERT_TOP_RIGHT: eRet = css::text::WritingMode_TB_RL; break;
+            case SvxFrameDirection::Horizontal_LR_TB: eRet = css::text::WritingMode_LR_TB; break;
+            case SvxFrameDirection::Horizontal_RL_TB: eRet = css::text::WritingMode_RL_TB; break;
+            case SvxFrameDirection::Vertical_RL_TB: eRet = css::text::WritingMode_TB_RL; break;
 
             default:
                 OSL_FAIL( "Frame direction not supported yet" );
@@ -1262,9 +1254,9 @@ void SdDrawDocument::SetDefaultWritingMode(css::text::WritingMode eMode )
         SvxFrameDirection nVal;
         switch( eMode )
         {
-        case css::text::WritingMode_LR_TB: nVal = FRMDIR_HORI_LEFT_TOP; break;
-        case css::text::WritingMode_RL_TB: nVal = FRMDIR_HORI_RIGHT_TOP; break;
-        case css::text::WritingMode_TB_RL: nVal = FRMDIR_VERT_TOP_RIGHT; break;
+        case css::text::WritingMode_LR_TB: nVal = SvxFrameDirection::Horizontal_LR_TB; break;
+        case css::text::WritingMode_RL_TB: nVal = SvxFrameDirection::Horizontal_RL_TB; break;
+        case css::text::WritingMode_TB_RL: nVal = SvxFrameDirection::Vertical_RL_TB; break;
         default:
             OSL_FAIL( "Frame direction not supported yet" );
             return;
@@ -1273,10 +1265,10 @@ void SdDrawDocument::SetDefaultWritingMode(css::text::WritingMode eMode )
         SvxFrameDirectionItem aModeItem( nVal, EE_PARA_WRITINGDIR );
         pItemPool->SetPoolDefaultItem( aModeItem );
 
-        SvxAdjustItem aAdjust( SVX_ADJUST_LEFT, EE_PARA_JUST );
+        SvxAdjustItem aAdjust( SvxAdjust::Left, EE_PARA_JUST );
 
         if( eMode == css::text::WritingMode_RL_TB )
-            aAdjust.SetEnumValue( SVX_ADJUST_RIGHT );
+            aAdjust.SetAdjust( SvxAdjust::Right );
 
         pItemPool->SetPoolDefaultItem( aAdjust );
 
