@@ -17,22 +17,22 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sfx2/viewsh.hxx>
 #include <undo/undomanager.hxx>
 
 using namespace sd;
 
-UndoManager::UndoManager( sal_uInt16 nMaxUndoActionCount /* = 20 */ )
-  : SdrUndoManager( nMaxUndoActionCount )
-  , mpLinkedUndoManager(NULL)
+UndoManager::UndoManager()
+  : mpLinkedUndoManager(nullptr)
 {
 }
 
-void UndoManager::EnterListAction(const OUString &rComment, const OUString& rRepeatComment, sal_uInt16 nId /* =0 */)
+void UndoManager::EnterListAction(const OUString &rComment, const OUString& rRepeatComment, sal_uInt16 nId, ViewShellId nViewShellId)
 {
     if( !IsDoing() )
     {
         ClearLinkedRedoActions();
-        SdrUndoManager::EnterListAction( rComment, rRepeatComment, nId );
+        SdrUndoManager::EnterListAction( rComment, rRepeatComment, nId, nViewShellId );
     }
 }
 
@@ -56,7 +56,7 @@ void UndoManager::SetLinkedUndoManager (::svl::IUndoManager* pLinkedUndoManager)
 
 void UndoManager::ClearLinkedRedoActions()
 {
-    if (mpLinkedUndoManager != NULL)
+    if (mpLinkedUndoManager != nullptr)
         mpLinkedUndoManager->ClearRedo();
 }
 
