@@ -17,24 +17,22 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <com/sun/star/util/XCloneable.hpp>
-#include <com/sun/star/animations/XAnimationNode.hpp>
-#include "CustomAnimationCloner.hxx"
+#include <sal/config.h>
 
-#include "undoanim.hxx"
-#include "glob.hrc"
-#include "sdpage.hxx"
-#include "sdresid.hxx"
-#include "CustomAnimationEffect.hxx"
-#include "drawdoc.hxx"
+#include <com/sun/star/animations/XAnimationNode.hpp>
+#include <CustomAnimationCloner.hxx>
+
+#include <undoanim.hxx>
+#include <strings.hrc>
+#include <sdpage.hxx>
+#include <sdresid.hxx>
+#include <CustomAnimationEffect.hxx>
+#include <drawdoc.hxx>
 
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::Exception;
-using ::com::sun::star::uno::UNO_QUERY_THROW;
-using ::com::sun::star::util::XCloneable;
 using namespace ::com::sun::star::animations;
 
-
 namespace sd
 {
 
@@ -107,7 +105,7 @@ void UndoAnimation::Redo()
 
 OUString UndoAnimation::GetComment() const
 {
-    return SdResId(STR_UNDO_ANIMATION).toString();
+    return SdResId(STR_UNDO_ANIMATION);
 }
 
 struct UndoAnimationPathImpl
@@ -117,13 +115,13 @@ struct UndoAnimationPathImpl
     OUString msUndoPath;
     OUString msRedoPath;
 
-    UndoAnimationPathImpl( SdPage* pThePage, const com::sun::star::uno::Reference< ::com::sun::star::animations::XAnimationNode >& xNode )
+    UndoAnimationPathImpl( SdPage* pThePage, const css::uno::Reference< css::animations::XAnimationNode >& xNode )
         : mpPage( pThePage )
         , mnEffectOffset( -1 )
     {
         if( mpPage && xNode.is() )
         {
-            boost::shared_ptr< sd::MainSequence > pMainSequence( mpPage->getMainSequence() );
+            std::shared_ptr< sd::MainSequence > pMainSequence( mpPage->getMainSequence() );
             if( pMainSequence.get() )
             {
                 CustomAnimationEffectPtr pEffect( pMainSequence->findEffect( xNode ) );
@@ -135,26 +133,23 @@ struct UndoAnimationPathImpl
             }
         }
     }
+    UndoAnimationPathImpl(const UndoAnimationPathImpl&) = delete;
+    UndoAnimationPathImpl& operator=(const UndoAnimationPathImpl&) = delete;
 
     CustomAnimationEffectPtr getEffect() const
     {
         CustomAnimationEffectPtr pEffect;
         if( mpPage && (mnEffectOffset >= 0) )
         {
-            boost::shared_ptr< sd::MainSequence > pMainSequence( mpPage->getMainSequence() );
+            std::shared_ptr< sd::MainSequence > pMainSequence( mpPage->getMainSequence() );
             if( pMainSequence.get() )
                 pEffect = pMainSequence->getEffectFromOffset( mnEffectOffset );
         }
         return pEffect;
     }
-
-    private:
-        UndoAnimationPathImpl( const UndoAnimationPathImpl& ); //not implemented
-        const UndoAnimationPathImpl& operator=( const UndoAnimationPathImpl& ); // not implemented
-
 };
 
-UndoAnimationPath::UndoAnimationPath( SdDrawDocument* pDoc, SdPage* pThePage, const com::sun::star::uno::Reference< ::com::sun::star::animations::XAnimationNode >& xNode )
+UndoAnimationPath::UndoAnimationPath( SdDrawDocument* pDoc, SdPage* pThePage, const css::uno::Reference< css::animations::XAnimationNode >& xNode )
 : SdrUndoAction( *pDoc )
 , mpImpl( new UndoAnimationPathImpl( pThePage, xNode ) )
 {
@@ -185,7 +180,7 @@ void UndoAnimationPath::Redo()
 
 OUString UndoAnimationPath::GetComment() const
 {
-    return SdResId(STR_UNDO_ANIMATION).toString();
+    return SdResId(STR_UNDO_ANIMATION);
 }
 
 struct UndoTransitionImpl
@@ -194,7 +189,7 @@ struct UndoTransitionImpl
 
     sal_Int16 mnNewTransitionType;
     sal_Int16 mnNewTransitionSubtype;
-    sal_Bool mbNewTransitionDirection;
+    bool mbNewTransitionDirection;
     sal_Int32 mnNewTransitionFadeColor;
     double mfNewTransitionDuration;
     OUString maNewSoundFile;
@@ -204,7 +199,7 @@ struct UndoTransitionImpl
 
     sal_Int16 mnOldTransitionType;
     sal_Int16 mnOldTransitionSubtype;
-    sal_Bool mbOldTransitionDirection;
+    bool mbOldTransitionDirection;
     sal_Int32 mnOldTransitionFadeColor;
     double mfOldTransitionDuration;
     OUString maOldSoundFile;
@@ -275,7 +270,7 @@ void UndoTransition::Redo()
 
 OUString UndoTransition::GetComment() const
 {
-    return SdResId(STR_UNDO_SLIDE_PARAMS).toString();
+    return SdResId(STR_UNDO_SLIDE_PARAMS);
 }
 
 }
