@@ -27,29 +27,25 @@
 #include <sfx2/progress.hxx>
 #include <svl/itemset.hxx>
 
-#include "../ui/inc/DrawDocShell.hxx"
-#include "../ui/inc/strings.hrc"
+#include <DrawDocShell.hxx>
+#include <strings.hrc>
 
-#include "sdresid.hxx"
-#include "pres.hxx"
-#include "drawdoc.hxx"
-#include "sdfilter.hxx"
+#include <sdresid.hxx>
+#include <pres.hxx>
+#include <drawdoc.hxx>
+#include <sdfilter.hxx>
 
-// - Namespaces -
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::task;
-using namespace ::com::sun::star::frame;
 
-// - SdFilter -
 
-SdFilter::SdFilter( SfxMedium& rMedium, ::sd::DrawDocShell& rDocShell, bool bShowProgress )
+SdFilter::SdFilter( SfxMedium& rMedium, ::sd::DrawDocShell& rDocShell )
 :   mxModel( rDocShell.GetModel() )
 ,   mrMedium( rMedium )
 ,   mrDocShell( rDocShell )
 ,   mrDocument( *rDocShell.GetDoc() )
-,   mbIsDraw( rDocShell.GetDocumentType() == DOCUMENT_TYPE_DRAW )
-,   mbShowProgress( bShowProgress )
+,   mbIsDraw( rDocShell.GetDocumentType() == DocumentType::Draw )
 {
 }
 
@@ -57,21 +53,20 @@ SdFilter::~SdFilter()
 {
 }
 
-OUString SdFilter::ImplGetFullLibraryName( const OUString& rLibraryName ) const
+OUString SdFilter::ImplGetFullLibraryName( const OUString& rLibraryName )
 {
-    OUString aTemp(SVLIBRARY("?"));
-    return aTemp.replaceFirst( "?", rLibraryName );
+    return OUString(SVLIBRARY("?")).replaceFirst( "?", rLibraryName );
 }
 
 #ifndef DISABLE_DYNLOADING
 extern "C" { static void SAL_CALL thisModule() {} }
 
-::osl::Module* SdFilter::OpenLibrary( const OUString& rLibraryName ) const
+::osl::Module* SdFilter::OpenLibrary( const OUString& rLibraryName )
 {
     std::unique_ptr< osl::Module > mod(new osl::Module);
     return mod->loadRelative(&thisModule, ImplGetFullLibraryName(rLibraryName),
                              SAL_LOADMODULE_GLOBAL | SAL_LOADMODULE_LAZY)
-        ? mod.release() : 0;
+        ? mod.release() : nullptr;
 }
 
 #endif
