@@ -46,12 +46,12 @@
 #include <svx/svddrgmt.hxx>
 
 #include "CustomAnimationPane.hxx"
-#include "View.hxx"
+#include <View.hxx>
 #include "motionpathtag.hxx"
-#include "sdpage.hxx"
-#include "ViewShell.hxx"
-#include "app.hrc"
-#include "Window.hxx"
+#include <sdpage.hxx>
+#include <ViewShell.hxx>
+#include <app.hrc>
+#include <Window.hxx>
 
 #include <svx/sdr/contact/viewcontact.hxx>
 #include <svx/sdr/overlay/overlayprimitive2dsequenceobject.hxx>
@@ -180,7 +180,7 @@ bool PathDragResize::EndSdrDrag(bool /*bCopy*/)
         if( pPathObj )
         {
             const Point aRef( DragStat().Ref1() );
-            basegfx::B2DHomMatrix aTrans(basegfx::tools::createTranslateB2DHomMatrix(-aRef.X(), -aRef.Y()));
+            basegfx::B2DHomMatrix aTrans(basegfx::utils::createTranslateB2DHomMatrix(-aRef.X(), -aRef.Y()));
             aTrans.scale(double(aXFact), double(aYFact));
             aTrans.translate(aRef.X(), aRef.Y());
             basegfx::B2DPolyPolygon aDragPoly(pPathObj->GetPathPoly());
@@ -275,7 +275,7 @@ void SdPathHdl::CreateB2dIAObject()
 
             if(pPageView)
             {
-                for(sal_uInt32 b(0L); b < pPageView->PageWindowCount(); b++)
+                for(sal_uInt32 b(0); b < pPageView->PageWindowCount(); b++)
                 {
                     const SdrPageWindow& rPageWindow = *pPageView->GetPageWindow(b);
 
@@ -367,13 +367,11 @@ MotionPathTag::~MotionPathTag()
 
 void MotionPathTag::updatePathAttributes()
 {
-    OUString aEmpty( "?" );
-
     ::basegfx::B2DPolygon aCandidate;
     if( mxPolyPoly.count() )
     {
         aCandidate = mxPolyPoly.getB2DPolygon(0);
-        ::basegfx::tools::checkClosed( aCandidate );
+        ::basegfx::utils::checkClosed( aCandidate );
     }
 
     if( !aCandidate.isClosed() )
@@ -383,7 +381,7 @@ void MotionPathTag::updatePathAttributes()
         aEndArrow.append(::basegfx::B2DPoint(0.0, 30.0));
         aEndArrow.append(::basegfx::B2DPoint(20.0, 30.0));
         aEndArrow.setClosed(true);
-        mpPathObj->SetMergedItem(XLineEndItem(aEmpty,::basegfx::B2DPolyPolygon(aEndArrow)));
+        mpPathObj->SetMergedItem(XLineEndItem("?",::basegfx::B2DPolyPolygon(aEndArrow)));
         mpPathObj->SetMergedItem(XLineEndWidthItem(400));
         mpPathObj->SetMergedItem(XLineEndCenterItem(true));
     }
@@ -596,7 +594,7 @@ bool MotionPathTag::OnTabHandles( const KeyEvent& rKEvt )
         const SdrHdlList& rHdlList = mrView.GetHdlList();
         bool bForward(!rKEvt.GetKeyCode().IsShift());
 
-        ((SdrHdlList&)rHdlList).TravelFocusHdl(bForward);
+        const_cast<SdrHdlList&>(rHdlList).TravelFocusHdl(bForward);
 
         // guarantee visibility of focused handle
         SdrHdl* pHdl = rHdlList.GetFocusHdl();
@@ -659,7 +657,7 @@ bool MotionPathTag::OnMarkHandle( const KeyEvent& rKEvt )
             }
 
             if(pNewOne)
-                ((SdrHdlList&)rHdlList).SetFocusHdl(pNewOne);
+                const_cast<SdrHdlList&>(rHdlList).SetFocusHdl(pNewOne);
         }
     }
 
@@ -683,7 +681,7 @@ bool MotionPathTag::OnMove( const KeyEvent& rKEvt )
     if(rKEvt.GetKeyCode().IsMod2())
     {
         OutputDevice* pOut = mrView.GetViewShell()->GetActiveWindow();
-        Size aLogicSizeOnePixel = (pOut) ? pOut->PixelToLogic(Size(1,1)) : Size(100, 100);
+        Size aLogicSizeOnePixel = pOut ? pOut->PixelToLogic(Size(1,1)) : Size(100, 100);
         nX *= aLogicSizeOnePixel.Width();
         nY *= aLogicSizeOnePixel.Height();
     }
@@ -730,7 +728,7 @@ bool MotionPathTag::OnMove( const KeyEvent& rKEvt )
 
                 // switch snapping off
                 if(!bWasNoSnap)
-                    ((SdrDragStat&)mrView.GetDragStat()).SetNoSnap();
+                    const_cast<SdrDragStat&>(mrView.GetDragStat()).SetNoSnap();
                 if(bWasSnapEnabled)
                     mrView.SetSnapEnabled(false);
 
@@ -739,7 +737,7 @@ bool MotionPathTag::OnMove( const KeyEvent& rKEvt )
 
                 // restore snap
                 if(!bWasNoSnap)
-                    ((SdrDragStat&)mrView.GetDragStat()).SetNoSnap(bWasNoSnap);
+                    const_cast<SdrDragStat&>(mrView.GetDragStat()).SetNoSnap(bWasNoSnap);
                 if(bWasSnapEnabled)
                     mrView.SetSnapEnabled(bWasSnapEnabled);
             }
@@ -878,7 +876,7 @@ void MotionPathTag::addCustomHandles( SdrHdlList& rHandlerList )
             aPos = mxOrigin->getPosition();
         if( (aPos.X != maOriginPos.X) || (aPos.Y != maOriginPos.Y) )
         {
-            const basegfx::B2DHomMatrix aTransform(basegfx::tools::createTranslateB2DHomMatrix(
+            const basegfx::B2DHomMatrix aTransform(basegfx::utils::createTranslateB2DHomMatrix(
                 aPos.X - maOriginPos.X, aPos.Y - maOriginPos.Y));
             mxPolyPoly.transform( aTransform );
             mpPathObj->SetPathPoly( mxPolyPoly );
@@ -922,8 +920,8 @@ void MotionPathTag::addCustomHandles( SdrHdlList& rHandlerList )
 
                     if( mrView.IsPlusHandlesAlwaysVisible() || bSelected )
                     {
-                        sal_uInt32 nPlusAnz=mpPathObj->GetPlusHdlCount(*pSmartHdl);
-                        for (sal_uInt32 nPlusNum=0; nPlusNum<nPlusAnz; nPlusNum++)
+                        sal_uInt32 nPlusHdlCnt=mpPathObj->GetPlusHdlCount(*pSmartHdl);
+                        for (sal_uInt32 nPlusNum=0; nPlusNum<nPlusHdlCnt; nPlusNum++)
                         {
                             SdrHdl* pPlusHdl = mpPathObj->GetPlusHdl(*pSmartHdl,nPlusNum);
                             if (pPlusHdl!=nullptr)
