@@ -17,8 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <com/sun/star/presentation/AnimationEffect.hpp>
-#include <com/sun/star/presentation/AnimationSpeed.hpp>
 #include <svx/xoutbmp.hxx>
 #include <time.h>
 #include <svl/eitem.hxx>
@@ -29,16 +27,16 @@
 #include <sfx2/progress.hxx>
 #include <vcl/msgbox.hxx>
 
-#include "anminfo.hxx"
-#include "animobjs.hxx"
-#include "app.hrc"
-#include "strings.hrc"
-#include "sdresid.hxx"
-#include "View.hxx"
-#include "drawdoc.hxx"
-#include "sdpage.hxx"
-#include "res_bmp.hrc"
-#include "ViewShell.hxx"
+#include <anminfo.hxx>
+#include <animobjs.hxx>
+#include <app.hrc>
+#include <strings.hrc>
+#include <sdresid.hxx>
+#include <View.hxx>
+#include <drawdoc.hxx>
+#include <sdpage.hxx>
+
+#include <ViewShell.hxx>
 
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
@@ -59,7 +57,7 @@ SdDisplay::SdDisplay(vcl::Window* pWin)
     : Control(pWin, 0)
     , aScale(1, 1)
 {
-    SetMapMode( MAP_PIXEL );
+    SetMapMode(MapMode(MapUnit::MapPixel));
     const StyleSettings& rStyles = Application::GetSettings().GetStyleSettings();
     SetBackground( Wallpaper( Color( rStyles.GetFieldColor() ) ) );
 }
@@ -68,7 +66,7 @@ SdDisplay::~SdDisplay()
 {
 }
 
-void SdDisplay::SetBitmapEx( BitmapEx* pBmpEx )
+void SdDisplay::SetBitmapEx( BitmapEx const * pBmpEx )
 {
     if( pBmpEx )
     {
@@ -82,7 +80,7 @@ void SdDisplay::SetBitmapEx( BitmapEx* pBmpEx )
     }
 }
 
-void SdDisplay::Paint( vcl::RenderContext& /*rRenderContext*/, const Rectangle& )
+void SdDisplay::Paint( vcl::RenderContext& /*rRenderContext*/, const ::tools::Rectangle& )
 {
     Point aPt;
     Size aSize = GetOutputSize();
@@ -105,7 +103,7 @@ void SdDisplay::SetScale( const Fraction& rFrac )
 
 Size SdDisplay::GetOptimalSize() const
 {
-    return LogicToPixel(Size(147, 87), MAP_APPFONT);
+    return LogicToPixel(Size(147, 87), MapMode(MapUnit::MapAppFont));
 }
 
 void SdDisplay::DataChanged( const DataChangedEvent& rDCEvt )
@@ -130,7 +128,6 @@ const size_t AnimationWindow::EMPTY_FRAMELIST = std::numeric_limits<size_t>::max
 AnimationWindow::AnimationWindow(SfxBindings* pInBindings, SfxChildWindow *pCW, vcl::Window* pParent)
     : SfxDockingWindow(pInBindings, pCW, pParent,
         "DockingAnimation", "modules/simpress/ui/dockinganimation.ui")
-    , pWin(pParent)
     , m_nCurrentFrame(EMPTY_FRAMELIST)
     , bMovie(false)
     , bAllObjects(false)
@@ -163,11 +160,8 @@ AnimationWindow::AnimationWindow(SfxBindings* pInBindings, SfxChildWindow *pCW,
     m_pCtlDisplay->set_vexpand(true);
     m_pCtlDisplay->Show();
 
-    //undo SfxDockingWindow HelpId clear hack
-    reverseUniqueHelpIdHack(*this);
-
     // create new document with page
-    pMyDoc = new SdDrawDocument(DOCUMENT_TYPE_IMPRESS, nullptr);
+    pMyDoc = new SdDrawDocument(DocumentType::Impress, nullptr);
     SdPage* pPage = pMyDoc->AllocSdPage(false);
     pMyDoc->InsertPage(pPage);
 
@@ -213,10 +207,10 @@ void AnimationWindow::dispose()
 {
     DELETEZ( pControllerItem );
 
-    for (size_t i = 0; i < m_FrameList.size(); ++i)
+    for (const std::pair<BitmapEx*, tools::Time*> & i : m_FrameList)
     {
-        delete m_FrameList[i].first;
-        delete m_FrameList[i].second;
+        delete i.first;
+        delete i.second;
     }
     m_FrameList.clear();
     m_nCurrentFrame = EMPTY_FRAMELIST;
@@ -243,22 +237,21 @@ void AnimationWindow::dispose()
     m_pFtAdjustment.clear();
     m_pLbAdjustment.clear();
     m_pBtnCreateGroup.clear();
-    pWin.clear();
     SfxDockingWindow::dispose();
 }
 
-IMPL_LINK_NOARG_TYPED(AnimationWindow, ClickFirstHdl, Button*, void)
+IMPL_LINK_NOARG(AnimationWindow, ClickFirstHdl, Button*, void)
 {
     m_nCurrentFrame = (m_FrameList.empty()) ? EMPTY_FRAMELIST : 0;
     UpdateControl();
 }
 
-IMPL_LINK_NOARG_TYPED(AnimationWindow, ClickStopHdl, Button*, void)
+IMPL_LINK_NOARG(AnimationWindow, ClickStopHdl, Button*, void)
 {
     bMovie = false;
 }
 
-IMPL_LINK_TYPED( AnimationWindow, ClickPlayHdl, Button *, p, void )
+IMPL_LINK( AnimationWindow, ClickPlayHdl, Button *, p, void )
 {
     ScopeLockGuard aGuard( maPlayLock );
 
@@ -296,7 +289,7 @@ IMPL_LINK_TYPED( AnimationWindow, ClickPlayHdl, Button *, p, void )
         bDisableCtrls = true;
         m_pBtnStop->Enable();
         m_pBtnStop->Update();
-        OUString aStr("Animator:"); // here we should think about something smart
+        OUString const aStr("Animator:"); // here we should think about something smart
         pProgress = new SfxProgress( nullptr, aStr, nFullTime );
     }
 
@@ -375,14 +368,14 @@ IMPL_LINK_TYPED( AnimationWindow, ClickPlayHdl, Button *, p, void )
     m_pBtnGetOneObject->Enable( bBtnGetOneObjectEnabled );
 }
 
-IMPL_LINK_NOARG_TYPED(AnimationWindow, ClickLastHdl, Button*, void)
+IMPL_LINK_NOARG(AnimationWindow, ClickLastHdl, Button*, void)
 {
     m_nCurrentFrame =
         (m_FrameList.empty()) ? EMPTY_FRAMELIST : m_FrameList.size() - 1 ;
     UpdateControl();
 }
 
-IMPL_LINK_TYPED( AnimationWindow, ClickRbtHdl, Button*, p, void )
+IMPL_LINK( AnimationWindow, ClickRbtHdl, Button*, p, void )
 {
     if (m_FrameList.empty() || p == m_pRbtGroup || m_pRbtGroup->IsChecked())
     {
@@ -404,20 +397,20 @@ IMPL_LINK_TYPED( AnimationWindow, ClickRbtHdl, Button*, p, void )
     }
 }
 
-IMPL_LINK_TYPED( AnimationWindow, ClickGetObjectHdl, Button*, pBtn, void )
+IMPL_LINK( AnimationWindow, ClickGetObjectHdl, Button*, pBtn, void )
 {
     bAllObjects = pBtn == m_pBtnGetAllObjects;
 
     // Code now in AddObj()
     SfxBoolItem aItem( SID_ANIMATOR_ADD, true );
 
-    GetBindings().GetDispatcher()->Execute(
-        SID_ANIMATOR_ADD, SfxCallMode::SLOT | SfxCallMode::RECORD, &aItem, 0L );
+    GetBindings().GetDispatcher()->ExecuteList(
+        SID_ANIMATOR_ADD, SfxCallMode::SLOT | SfxCallMode::RECORD, { &aItem });
 }
 
-IMPL_LINK_TYPED( AnimationWindow, ClickRemoveBitmapHdl, Button*, pBtn, void )
+IMPL_LINK( AnimationWindow, ClickRemoveBitmapHdl, Button*, pBtn, void )
 {
-    SdPage*     pPage = pMyDoc->GetSdPage(0, PK_STANDARD);
+    SdPage*     pPage = pMyDoc->GetSdPage(0, PageKind::Standard);
     SdrObject*  pObject;
 
     // tdf#95298 check m_nCurrentFrame for EMPTY_FRAMELIST to avoid out-of-bound array access
@@ -446,7 +439,7 @@ IMPL_LINK_TYPED( AnimationWindow, ClickRemoveBitmapHdl, Button*, pBtn, void )
     }
     else // delete everything
     {
-        ScopedVclPtrInstance< WarningBox > aWarnBox( this, WB_YES_NO, SD_RESSTR( STR_ASK_DELETE_ALL_PICTURES ) );
+        ScopedVclPtrInstance< WarningBox > aWarnBox( this, MessBoxStyle::YesNo, SdResId( STR_ASK_DELETE_ALL_PICTURES ) );
         short nReturn = aWarnBox->Execute();
 
         if( nReturn == RET_YES )
@@ -489,16 +482,16 @@ IMPL_LINK_TYPED( AnimationWindow, ClickRemoveBitmapHdl, Button*, pBtn, void )
     UpdateControl();
 }
 
-IMPL_LINK_NOARG_TYPED(AnimationWindow, ClickCreateGroupHdl, Button*, void)
+IMPL_LINK_NOARG(AnimationWindow, ClickCreateGroupHdl, Button*, void)
 {
     // Code now in CreatePresObj()
     SfxBoolItem aItem( SID_ANIMATOR_CREATE, true );
 
-    GetBindings().GetDispatcher()->Execute(
-        SID_ANIMATOR_CREATE, SfxCallMode::SLOT | SfxCallMode::RECORD, &aItem, 0L );
+    GetBindings().GetDispatcher()->ExecuteList(SID_ANIMATOR_CREATE,
+            SfxCallMode::SLOT | SfxCallMode::RECORD, { &aItem });
 }
 
-IMPL_LINK_NOARG_TYPED(AnimationWindow, ModifyBitmapHdl, Edit&, void)
+IMPL_LINK_NOARG(AnimationWindow, ModifyBitmapHdl, Edit&, void)
 {
     sal_uLong nBmp = static_cast<sal_uLong>(m_pNumFldBitmap->GetValue());
 
@@ -512,7 +505,7 @@ IMPL_LINK_NOARG_TYPED(AnimationWindow, ModifyBitmapHdl, Edit&, void)
     UpdateControl();
 }
 
-IMPL_LINK_NOARG_TYPED(AnimationWindow, ModifyTimeHdl, Edit&, void)
+IMPL_LINK_NOARG(AnimationWindow, ModifyTimeHdl, Edit&, void)
 {
     sal_uLong nPos = static_cast<sal_uLong>(m_pNumFldBitmap->GetValue() - 1);
 
@@ -528,17 +521,16 @@ void AnimationWindow::UpdateControl(bool const bDisableCtrls)
     {
         BitmapEx aBmp(*m_FrameList[m_nCurrentFrame].first);
 
-        SdPage* pPage = pMyDoc->GetSdPage(0, PK_STANDARD);
-        SdrObject *const pObject =
-            static_cast<SdrObject*>(pPage->GetObj(m_nCurrentFrame));
+        SdPage* pPage = pMyDoc->GetSdPage(0, PageKind::Standard);
+        SdrObject *const pObject = pPage->GetObj(m_nCurrentFrame);
         if( pObject )
         {
             ScopedVclPtrInstance< VirtualDevice > pVD;
-            Rectangle       aObjRect( pObject->GetCurrentBoundRect() );
+            ::tools::Rectangle       aObjRect( pObject->GetCurrentBoundRect() );
             Size            aObjSize( aObjRect.GetSize() );
             Point           aOrigin( Point( -aObjRect.Left(), -aObjRect.Top() ) );
             MapMode         aMap( pVD->GetMapMode() );
-            aMap.SetMapUnit( MAP_100TH_MM );
+            aMap.SetMapUnit( MapUnit::Map100thMM );
             aMap.SetOrigin( aOrigin );
             pVD->SetMapMode( aMap );
             pVD->SetOutputSize( aObjSize );
@@ -693,8 +685,9 @@ bool AnimationWindow::Close()
     {
         SfxBoolItem aItem( SID_ANIMATION_OBJECTS, false );
 
-        GetBindings().GetDispatcher()->Execute(
-            SID_ANIMATION_OBJECTS, SfxCallMode::ASYNCHRON | SfxCallMode::RECORD, &aItem, 0L );
+        GetBindings().GetDispatcher()->ExecuteList(
+            SID_ANIMATION_OBJECTS, SfxCallMode::ASYNCHRON | SfxCallMode::RECORD,
+            { &aItem });
 
         SfxDockingWindow::Close();
 
@@ -702,11 +695,6 @@ bool AnimationWindow::Close()
     }
 }
 
-void AnimationWindow::FillInfo( SfxChildWinInfo& rInfo ) const
-{
-    SfxDockingWindow::FillInfo( rInfo ) ;
-}
-
 void AnimationWindow::AddObj (::sd::View& rView )
 {
     // finish text entry mode to ensure that bitmap is identical with object
@@ -716,7 +704,7 @@ void AnimationWindow::AddObj (::sd::View& rView )
     // clone object(s) and insert the clone(s) into the list
     const SdrMarkList& rMarkList   = rView.GetMarkedObjectList();
     const size_t nMarkCount = rMarkList.GetMarkCount();
-    SdPage*            pPage       = pMyDoc->GetSdPage(0, PK_STANDARD);
+    SdPage*            pPage       = pMyDoc->GetSdPage(0, PageKind::Standard);
     const size_t nCloneCount = pPage->GetObjCount();
 
     if (nMarkCount > 0)
@@ -728,12 +716,12 @@ void AnimationWindow::AddObj (::sd::View& rView )
         {
             SdrMark*            pMark = rMarkList.GetMark(0);
             SdrObject*          pObject = pMark->GetMarkedSdrObj();
-            SdAnimationInfo*    pAnimInfo = rView.GetDoc().GetAnimationInfo( pObject );
-            sal_uInt32              nInv = pObject->GetObjInventor();
-            sal_uInt16              nId = pObject->GetObjIdentifier();
+            SdAnimationInfo*    pAnimInfo = SdDrawDocument::GetAnimationInfo( pObject );
+            SdrInventor         nInv = pObject->GetObjInventor();
+            sal_uInt16          nId = pObject->GetObjIdentifier();
 
             // Animated Bitmap (GIF)
-            if( nInv == SdrInventor && nId == OBJ_GRAF && static_cast<SdrGrafObj*>( pObject )->IsAnimated() )
+            if( nInv == SdrInventor::Default && nId == OBJ_GRAF && static_cast<SdrGrafObj*>( pObject )->IsAnimated() )
             {
                 const SdrGrafObj*   pGrafObj = static_cast<SdrGrafObj*>(pObject);
                 Graphic             aGraphic( pGrafObj->GetTransformedGraphic() );
@@ -756,7 +744,7 @@ void AnimationWindow::AddObj (::sd::View& rView )
                         // LoopCount
                         if( i == 0 )
                         {
-                            long nLoopCount = aAnimation.GetLoopCount();
+                            sal_uInt32 nLoopCount = aAnimation.GetLoopCount();
 
                             if( !nLoopCount ) // endless
                                 m_pLbLoopCount->SelectEntryPos( m_pLbLoopCount->GetEntryCount() - 1);
@@ -899,14 +887,14 @@ void AnimationWindow::CreateAnimObj (::sd::View& rView )
     DBG_ASSERT( pOutWin, "Window does not exist!" );
 
     // find window center
-    const MapMode       aMap100( MAP_100TH_MM );
+    const MapMode       aMap100( MapUnit::Map100thMM );
     Size                aMaxSizeLog;
     Size                aMaxSizePix;
     Size                aTemp( pOutWin->GetOutputSizePixel() );
     const Point         aWindowCenter( pOutWin->PixelToLogic( Point( aTemp.Width() >> 1, aTemp.Height() >> 1 ) ) );
     const OutputDevice* pDefDev = Application::GetDefaultDevice();
     const size_t nCount = m_FrameList.size();
-    BitmapAdjustment    eBA = (BitmapAdjustment) m_pLbAdjustment->GetSelectEntryPos();
+    BitmapAdjustment    eBA = (BitmapAdjustment) m_pLbAdjustment->GetSelectedEntryPos();
 
     // find biggest bitmap
     for (size_t i = 0; i < nCount; ++i)
@@ -916,7 +904,7 @@ void AnimationWindow::CreateAnimObj (::sd::View& rView )
         Size            aTmpSizeLog;
         const Size      aTmpSizePix( rBmpEx.GetSizePixel() );
 
-        if ( aGraphic.GetPrefMapMode().GetMapUnit() == MAP_PIXEL )
+        if ( aGraphic.GetPrefMapMode().GetMapUnit() == MapUnit::MapPixel )
             aTmpSizeLog = pDefDev->PixelToLogic( aGraphic.GetPrefSize(), aMap100 );
         else
             aTmpSizeLog = OutputDevice::LogicToLogic( aGraphic.GetPrefSize(), aGraphic.GetPrefMapMode(), aMap100 );
@@ -992,17 +980,17 @@ void AnimationWindow::CreateAnimObj (::sd::View& rView )
 
             // find LoopCount (number of passes)
             AnimationBitmap aAnimBmp;
-            long            nLoopCount = 0L;
-            sal_Int32          nPos = m_pLbLoopCount->GetSelectEntryPos();
+            sal_uInt32 nLoopCount = 0;
+            sal_Int32 nPos = m_pLbLoopCount->GetSelectedEntryPos();
 
             if( nPos != LISTBOX_ENTRY_NOTFOUND && nPos != m_pLbLoopCount->GetEntryCount() - 1 ) // endless
-                nLoopCount = (long) m_pLbLoopCount->GetSelectEntry().toInt32();
+                nLoopCount = m_pLbLoopCount->GetSelectedEntry().toUInt32();
 
             aAnimBmp.aBmpEx = *pBitmapEx;
             aAnimBmp.aPosPix = aPt;
             aAnimBmp.aSizePix = aBitmapSize;
             aAnimBmp.nWait = nTime;
-            aAnimBmp.eDisposal = DISPOSE_BACK;
+            aAnimBmp.eDisposal = Disposal::Back;
             aAnimBmp.bUserInput = false;
 
             aAnimation.Insert( aAnimBmp );
@@ -1013,7 +1001,7 @@ void AnimationWindow::CreateAnimObj (::sd::View& rView )
         SdrGrafObj* pGrafObj = new SdrGrafObj( Graphic( aAnimation ) );
         const Point aOrg( aWindowCenter.X() - ( aMaxSizeLog.Width() >> 1 ), aWindowCenter.Y() - ( aMaxSizeLog.Height() >> 1 ) );
 
-        pGrafObj->SetLogicRect( Rectangle( aOrg, aMaxSizeLog ) );
+        pGrafObj->SetLogicRect( ::tools::Rectangle( aOrg, aMaxSizeLog ) );
         rView.InsertObjectAtView( pGrafObj, *pPV, SdrInsertFlags::SETDEFLAYER);
     }
     else
@@ -1021,12 +1009,12 @@ void AnimationWindow::CreateAnimObj (::sd::View& rView )
         // calculate offset for the specified direction
         Size aOffset;
         SdrObject * pClone = nullptr;
-        SdPage* pPage = pMyDoc->GetSdPage(0, PK_STANDARD);
+        SdPage* pPage = pMyDoc->GetSdPage(0, PageKind::Standard);
 
         for (size_t i = 0; i < nCount; ++i)
         {
             pClone = pPage->GetObj(i);
-            Rectangle aRect( pClone->GetSnapRect() );
+            ::tools::Rectangle aRect( pClone->GetSnapRect() );
 
             switch( eBA )
             {
