@@ -21,10 +21,10 @@
 #include <svx/dialogs.hrc>
 #include <svx/drawitem.hxx>
 
-#include "sdresid.hxx"
-#include "dlgpage.hxx"
+#include <sdresid.hxx>
+#include <dlgpage.hxx>
 
-#include "DrawDocShell.hxx"
+#include <DrawDocShell.hxx>
 #include <svl/aeitem.hxx>
 #include <svx/flagsdef.hxx>
 #include <svx/svxdlg.hxx>
@@ -33,7 +33,7 @@
 /**
  * Constructor of tab dialog: appends pages to the dialog
  */
-SdPageDlg::SdPageDlg( SfxObjectShell* pDocSh, vcl::Window* pParent, const SfxItemSet* pAttr, bool bAreaPage ) :
+SdPageDlg::SdPageDlg( SfxObjectShell const * pDocSh, vcl::Window* pParent, const SfxItemSet* pAttr, bool bAreaPage ) :
         SfxTabDialog ( pParent
                       ,"DrawPageDialog"
                       ,"modules/sdraw/ui/drawpagedialog.ui"
@@ -46,6 +46,8 @@ SdPageDlg::SdPageDlg( SfxObjectShell* pDocSh, vcl::Window* pParent, const SfxIte
         ( mpDocShell->GetItem( SID_GRADIENT_LIST ) ) ) );
     SvxBitmapListItem aBitmapListItem(*static_cast<const SvxBitmapListItem*>(
         ( mpDocShell->GetItem( SID_BITMAP_LIST ) ) ) );
+    SvxPatternListItem aPatternListItem(*static_cast<const SvxPatternListItem*>(
+        ( mpDocShell->GetItem( SID_PATTERN_LIST ) ) ) );
     SvxHatchListItem aHatchListItem(*static_cast<const SvxHatchListItem*>(
         ( mpDocShell->GetItem( SID_HATCH_LIST ) ) ) );
 
@@ -53,15 +55,20 @@ SdPageDlg::SdPageDlg( SfxObjectShell* pDocSh, vcl::Window* pParent, const SfxIte
     mpGradientList = aGradientListItem.GetGradientList();
     mpHatchingList = aHatchListItem.GetHatchList();
     mpBitmapList = aBitmapListItem.GetBitmapList();
+    mpPatternList = aPatternListItem.GetPatternList();
 
     SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
     OSL_ENSURE(pFact, "Dialog creation failed!");
 
     mnPage = AddTabPage( "RID_SVXPAGE_PAGE", pFact->GetTabPageCreatorFunc( RID_SVXPAGE_PAGE ), nullptr );
     mnArea = AddTabPage( "RID_SVXPAGE_AREA", pFact->GetTabPageCreatorFunc( RID_SVXPAGE_AREA ), nullptr );
+    mnTransparence = AddTabPage( "RID_SVXPAGE_TRANSPARENCE", pFact->GetTabPageCreatorFunc( RID_SVXPAGE_TRANSPARENCE ), nullptr );
 
     if(!bAreaPage)  // I have to add the page before I remove it !
+    {
         RemoveTabPage( "RID_SVXPAGE_AREA" );
+        RemoveTabPage( "RID_SVXPAGE_TRANSPARENCE" );
+    }
 }
 
 void SdPageDlg::PageCreated(sal_uInt16 nId, SfxTabPage& rPage)
@@ -69,9 +76,9 @@ void SdPageDlg::PageCreated(sal_uInt16 nId, SfxTabPage& rPage)
     SfxAllItemSet aSet(*(GetInputSetImpl()->GetPool()));
     if (nId == mnPage)
     {
-        aSet.Put (SfxAllEnumItem((const sal_uInt16)SID_ENUM_PAGE_MODE, SVX_PAGE_MODE_PRESENTATION));
-        aSet.Put (SfxAllEnumItem((const sal_uInt16)SID_PAPER_START, PAPER_A0));
-        aSet.Put (SfxAllEnumItem((const sal_uInt16)SID_PAPER_END, PAPER_E));
+        aSet.Put (SfxAllEnumItem((sal_uInt16)SID_ENUM_PAGE_MODE, SVX_PAGE_MODE_PRESENTATION));
+        aSet.Put (SfxAllEnumItem((sal_uInt16)SID_PAPER_START, PAPER_A0));
+        aSet.Put (SfxAllEnumItem((sal_uInt16)SID_PAPER_END, PAPER_E));
         rPage.PageCreated(aSet);
     }
     else if (nId == mnArea)
@@ -80,11 +87,18 @@ void SdPageDlg::PageCreated(sal_uInt16 nId, SfxTabPage& rPage)
         aSet.Put (SvxGradientListItem(mpGradientList,SID_GRADIENT_LIST));
         aSet.Put (SvxHatchListItem(mpHatchingList,SID_HATCH_LIST));
         aSet.Put (SvxBitmapListItem(mpBitmapList,SID_BITMAP_LIST));
+        aSet.Put (SvxPatternListItem(mpPatternList,SID_PATTERN_LIST));
         aSet.Put (SfxUInt16Item(SID_PAGE_TYPE,0));
         aSet.Put (SfxUInt16Item(SID_DLG_TYPE,1));
         aSet.Put (SfxUInt16Item(SID_TABPAGE_POS,0));
         rPage.PageCreated(aSet);
     }
+    else if (nId == mnTransparence)
+    {
+        aSet.Put(SfxUInt16Item(SID_PAGE_TYPE,0));
+        aSet.Put(SfxUInt16Item(SID_DLG_TYPE,1));
+        rPage.PageCreated(aSet);
+    }
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
