@@ -24,8 +24,10 @@
 #include <svx/drawitem.hxx>
 #include <svl/intitem.hxx>
 #include <svx/ofaitem.hxx>
-#include <svx/svxgrahicitem.hxx>
+#include <svx/svdmark.hxx>
 #include <svx/svdmodel.hxx>
+#include <svx/svdview.hxx>
+#include <svx/svxgrahicitem.hxx>
 #include <svl/cjkoptions.hxx>
 
 #include <svx/dialogs.hrc>
@@ -35,11 +37,11 @@
 #include <svl/style.hxx>
 #include <svx/xtable.hxx>
 
-#include "DrawDocShell.hxx"
-#include "tabtempl.hxx"
-#include "sdresid.hxx"
-#include "dlg_char.hxx"
-#include "paragr.hxx"
+#include <DrawDocShell.hxx>
+#include <tabtempl.hxx>
+#include <sdresid.hxx>
+#include <dlg_char.hxx>
+#include <paragr.hxx>
 #include <svx/flagsdef.hxx>
 
 /**
@@ -48,7 +50,7 @@
 SdTabTemplateDlg::SdTabTemplateDlg( vcl::Window* pParent,
                                 const SfxObjectShell* pDocShell,
                                 SfxStyleSheetBase& rStyleBase,
-                                SdrModel* pModel,
+                                SdrModel const * pModel,
                                 SdrView* pView )
     : SfxStyleDialog(pParent, "TemplateDialog",
         "modules/simpress/ui/templatedialog.ui",
@@ -59,6 +61,7 @@ SdTabTemplateDlg::SdTabTemplateDlg( vcl::Window* pParent,
     , pGradientList(pModel->GetGradientList())
     , pHatchingList(pModel->GetHatchList())
     , pBitmapList(pModel->GetBitmapList())
+    , pPatternList(pModel->GetPatternList())
     , pDashList(pModel->GetDashList())
     , pLineEndList(pModel->GetLineEndList())
     , m_nLineId(0)
@@ -67,14 +70,10 @@ SdTabTemplateDlg::SdTabTemplateDlg( vcl::Window* pParent,
     , m_nTransparencyId(0)
     , m_nFontId(0)
     , m_nFontEffectId(0)
-    , m_nIndentsId(0)
+    , m_nBackgroundId(0)
     , m_nTextId(0)
-    , m_nAnimationId(0)
     , m_nDimensionId(0)
     , m_nConnectorId(0)
-    , m_nAlignId(0)
-    , m_nTabId(0)
-    , m_nAsianTypoId(0)
 {
     // fill Listbox and set Select-Handler
 
@@ -84,27 +83,19 @@ SdTabTemplateDlg::SdTabTemplateDlg( vcl::Window* pParent,
     m_nTransparencyId = AddTabPage("transparency", RID_SVXPAGE_TRANSPARENCE);
     m_nFontId = AddTabPage("font", RID_SVXPAGE_CHAR_NAME);
     m_nFontEffectId = AddTabPage("fonteffect", RID_SVXPAGE_CHAR_EFFECTS);
-    m_nIndentsId = AddTabPage("indents", RID_SVXPAGE_STD_PARAGRAPH);
+    m_nBackgroundId = AddTabPage("background", RID_SVXPAGE_BACKGROUND);
+    AddTabPage("indents", RID_SVXPAGE_STD_PARAGRAPH);
     m_nTextId = AddTabPage("text", RID_SVXPAGE_TEXTATTR);
-    m_nAnimationId = AddTabPage("animation", RID_SVXPAGE_TEXTANIMATION);
+    AddTabPage("animation", RID_SVXPAGE_TEXTANIMATION);
     m_nDimensionId = AddTabPage("dimensioning", RID_SVXPAGE_MEASURE);
     m_nConnectorId = AddTabPage("connector", RID_SVXPAGE_CONNECTION);
-    m_nAlignId = AddTabPage("alignment", RID_SVXPAGE_ALIGN_PARAGRAPH);
-    m_nTabId = AddTabPage("tabs", RID_SVXPAGE_TABULATOR);
+    AddTabPage("alignment", RID_SVXPAGE_ALIGN_PARAGRAPH);
+    AddTabPage("tabs", RID_SVXPAGE_TABULATOR);
     SvtCJKOptions aCJKOptions;
     if( aCJKOptions.IsAsianTypographyEnabled() )
-        m_nAsianTypoId = AddTabPage("asiantypo", RID_SVXPAGE_PARA_ASIAN);
+        AddTabPage("asiantypo", RID_SVXPAGE_PARA_ASIAN);
     else
         RemoveTabPage("asiantypo");
-
-    nDlgType = 1;
-    nPageType = 0;
-    nPos = 0;
-
-    nColorTableState = ChangeType::NONE;
-    nBitmapListState = ChangeType::NONE;
-    nGradientListState = ChangeType::NONE;
-    nHatchingListState = ChangeType::NONE;
 }
 
 void SdTabTemplateDlg::PageCreated( sal_uInt16 nId, SfxTabPage &rPage )
@@ -115,7 +106,7 @@ void SdTabTemplateDlg::PageCreated( sal_uInt16 nId, SfxTabPage &rPage )
         aSet.Put (SvxColorListItem(pColorList,SID_COLOR_TABLE));
         aSet.Put (SvxDashListItem(pDashList,SID_DASH_LIST));
         aSet.Put (SvxLineEndListItem(pLineEndList,SID_LINEEND_LIST));
-        aSet.Put (SfxUInt16Item(SID_DLG_TYPE,nDlgType));
+        aSet.Put (SfxUInt16Item(SID_DLG_TYPE,1));
         rPage.PageCreated(aSet);
     }
     else if (nId == m_nAreaId)
@@ -124,22 +115,23 @@ void SdTabTemplateDlg::PageCreated( sal_uInt16 nId, SfxTabPage &rPage )
         aSet.Put (SvxGradientListItem(pGradientList,SID_GRADIENT_LIST));
         aSet.Put (SvxHatchListItem(pHatchingList,SID_HATCH_LIST));
         aSet.Put (SvxBitmapListItem(pBitmapList,SID_BITMAP_LIST));
-        aSet.Put (SfxUInt16Item(SID_PAGE_TYPE,nPageType));
-        aSet.Put (SfxUInt16Item(SID_DLG_TYPE,nDlgType));
-        aSet.Put (SfxUInt16Item(SID_TABPAGE_POS,nPos));
+        aSet.Put (SfxUInt16Item(SID_PAGE_TYPE,0));
+        aSet.Put (SfxUInt16Item(SID_DLG_TYPE,1));
+        aSet.Put (SfxUInt16Item(SID_TABPAGE_POS,0));
+        aSet.Put (SvxPatternListItem(pPatternList,SID_PATTERN_LIST));
         rPage.PageCreated(aSet);
     }
     else if (nId == m_nShadowId)
     {
         aSet.Put (SvxColorListItem(pColorList,SID_COLOR_TABLE));
-        aSet.Put (SfxUInt16Item(SID_PAGE_TYPE,nPageType));
-        aSet.Put (SfxUInt16Item(SID_DLG_TYPE,nDlgType));
+        aSet.Put (SfxUInt16Item(SID_PAGE_TYPE,0));
+        aSet.Put (SfxUInt16Item(SID_DLG_TYPE,1));
         rPage.PageCreated(aSet);
     }
     else if (nId == m_nTransparencyId)
     {
-        aSet.Put (SfxUInt16Item(SID_PAGE_TYPE,nPageType));
-        aSet.Put (SfxUInt16Item(SID_DLG_TYPE,nDlgType));
+        aSet.Put (SfxUInt16Item(SID_PAGE_TYPE,0));
+        aSet.Put (SfxUInt16Item(SID_DLG_TYPE,1));
         rPage.PageCreated(aSet);
     }
     else if (nId == m_nFontId)
@@ -152,12 +144,15 @@ void SdTabTemplateDlg::PageCreated( sal_uInt16 nId, SfxTabPage &rPage )
     }
     else if (nId == m_nFontEffectId)
     {
-        aSet.Put (SfxUInt16Item(SID_DISABLE_CTL,DISABLE_CASEMAP));
+        rPage.PageCreated(aSet);
+    }
+    else if (nId == m_nBackgroundId)
+    {
+        aSet.Put(SfxUInt32Item(SID_FLAG_TYPE,static_cast<sal_uInt32>(SvxBackgroundTabFlags::SHOW_CHAR_BKGCOLOR)));
         rPage.PageCreated(aSet);
     }
     else if (nId == m_nTextId)
     {
-        aSet.Put(OfaPtrItem(SID_SVXTEXTATTRPAGE_VIEW,pSdrView));
         rPage.PageCreated(aSet);
     }
     else if (nId == m_nDimensionId)
