@@ -17,12 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "ChangeRequestQueue.hxx"
 
 namespace sd { namespace framework {
 
-ChangeRequestQueue::ChangeRequestQueue (void)
+ChangeRequestQueue::ChangeRequestQueue()
 {
 }
 
