@@ -17,16 +17,14 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
-#include "fuconrec.hxx"
+#include <fuconrec.hxx>
 #include <svx/svdpagv.hxx>
 
-
 #include <svx/svxids.hrc>
-#include <svx/dialogs.hrc>
+#include <svx/strings.hrc>
 #include <svx/dialmgr.hxx>
 
-#include "app.hrc"
+#include <app.hrc>
 #include <svl/aeitem.hxx>
 #include <svx/xlnstwit.hxx>
 #include <svx/xlnedwit.hxx>
@@ -48,26 +46,24 @@
 #include <svx/svdocapt.hxx>
 
 #include <svx/svdomeas.hxx>
-#include "ViewShell.hxx"
-#include "ViewShellBase.hxx"
-#include "ToolBarManager.hxx"
+#include <ViewShell.hxx>
+#include <ViewShellBase.hxx>
+#include <ToolBarManager.hxx>
 #include <editeng/writingmodeitem.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 
-#include "sdresid.hxx"
-#include "View.hxx"
-#include "sdpage.hxx"
-#include "Window.hxx"
-#include "stlpool.hxx"
-#include "drawdoc.hxx"
-#include "res_bmp.hrc"
-#include "glob.hrc"
+#include <sdresid.hxx>
+#include <View.hxx>
+#include <sdpage.hxx>
+#include <Window.hxx>
+#include <stlpool.hxx>
+#include <drawdoc.hxx>
+
+#include <strings.hrc>
 
 namespace sd {
 
-TYPEINIT1( FuConstructRectangle, FuConstruct );
-
 
 FuConstructRectangle::FuConstructRectangle (
     ViewShell*  pViewSh,
@@ -93,7 +89,7 @@ void FuConstructRectangle::DoExecute( SfxRequest& rReq )
     FuConstruct::DoExecute( rReq );
 
     mpViewShell->GetViewShellBase().GetToolBarManager()->SetToolBar(
-        ToolBarManager::TBG_FUNCTION,
+        ToolBarManager::ToolBarGroup::Function,
         ToolBarManager::msDrawingObjectToolBar);
 
     const SfxItemSet *pArgs = rReq.GetArgs ();
@@ -104,37 +100,37 @@ void FuConstructRectangle::DoExecute( SfxRequest& rReq )
         {
             case SID_DRAW_ELLIPSE :
             {
-                SFX_REQUEST_ARG (rReq, pCenterX, SfxUInt32Item, ID_VAL_CENTER_X, sal_False);
-                SFX_REQUEST_ARG (rReq, pCenterY, SfxUInt32Item, ID_VAL_CENTER_Y, sal_False);
-                SFX_REQUEST_ARG (rReq, pAxisX, SfxUInt32Item, ID_VAL_AXIS_X, sal_False);
-                SFX_REQUEST_ARG (rReq, pAxisY, SfxUInt32Item, ID_VAL_AXIS_Y, sal_False);
+                const SfxUInt32Item* pCenterX = rReq.GetArg<SfxUInt32Item>(ID_VAL_CENTER_X);
+                const SfxUInt32Item* pCenterY = rReq.GetArg<SfxUInt32Item>(ID_VAL_CENTER_Y);
+                const SfxUInt32Item* pAxisX = rReq.GetArg<SfxUInt32Item>(ID_VAL_AXIS_X);
+                const SfxUInt32Item* pAxisY = rReq.GetArg<SfxUInt32Item>(ID_VAL_AXIS_Y);
 
-                Rectangle   aNewRectangle (pCenterX->GetValue () - pAxisX->GetValue () / 2,
+                ::tools::Rectangle   aNewRectangle (pCenterX->GetValue () - pAxisX->GetValue () / 2,
                                            pCenterY->GetValue () - pAxisY->GetValue () / 2,
                                            pCenterX->GetValue () + pAxisX->GetValue () / 2,
                                            pCenterY->GetValue () + pAxisY->GetValue () / 2);
                 SdrCircObj  *pNewCircle = new SdrCircObj (OBJ_CIRC, aNewRectangle);
                 SdrPageView *pPV = mpView->GetSdrPageView();
 
-                mpView->InsertObjectAtView(pNewCircle, *pPV, SDRINSERT_SETDEFLAYER | SDRINSERT_SETDEFATTR);
+                mpView->InsertObjectAtView(pNewCircle, *pPV, SdrInsertFlags::SETDEFLAYER | SdrInsertFlags::SETDEFATTR);
             }
             break;
 
             case SID_DRAW_RECT :
             {
-                SFX_REQUEST_ARG (rReq, pMouseStartX, SfxUInt32Item, ID_VAL_MOUSESTART_X, sal_False);
-                SFX_REQUEST_ARG (rReq, pMouseStartY, SfxUInt32Item, ID_VAL_MOUSESTART_Y, sal_False);
-                SFX_REQUEST_ARG (rReq, pMouseEndX, SfxUInt32Item, ID_VAL_MOUSEEND_X, sal_False);
-                SFX_REQUEST_ARG (rReq, pMouseEndY, SfxUInt32Item, ID_VAL_MOUSEEND_Y, sal_False);
+                const SfxUInt32Item* pMouseStartX = rReq.GetArg<SfxUInt32Item>(ID_VAL_MOUSESTART_X);
+                const SfxUInt32Item* pMouseStartY = rReq.GetArg<SfxUInt32Item>(ID_VAL_MOUSESTART_Y);
+                const SfxUInt32Item* pMouseEndX = rReq.GetArg<SfxUInt32Item>(ID_VAL_MOUSEEND_X);
+                const SfxUInt32Item* pMouseEndY = rReq.GetArg<SfxUInt32Item>(ID_VAL_MOUSEEND_Y);
 
-                Rectangle   aNewRectangle (pMouseStartX->GetValue (),
+                ::tools::Rectangle   aNewRectangle (pMouseStartX->GetValue (),
                                            pMouseStartY->GetValue (),
                                            pMouseEndX->GetValue (),
                                            pMouseEndY->GetValue ());
                 SdrRectObj  *pNewRect = new SdrRectObj (aNewRectangle);
                 SdrPageView *pPV = mpView->GetSdrPageView();
 
-                mpView->InsertObjectAtView(pNewRect, *pPV, SDRINSERT_SETDEFLAYER | SDRINSERT_SETDEFATTR);
+                mpView->InsertObjectAtView(pNewRect, *pPV, SdrInsertFlags::SETDEFLAYER | SdrInsertFlags::SETDEFATTR);
             }
             break;
         }
@@ -180,10 +176,9 @@ void FuConstructRectangle::DoExecute( SfxRequest& rReq )
     }
 }
 
-
-sal_Bool FuConstructRectangle::MouseButtonDown(const MouseEvent& rMEvt)
+bool FuConstructRectangle::MouseButtonDown(const MouseEvent& rMEvt)
 {
-    sal_Bool bReturn = FuConstruct::MouseButtonDown(rMEvt);
+    bool bReturn = FuConstruct::MouseButtonDown(rMEvt);
 
     if ( rMEvt.IsLeft() && !mpView->IsAction() )
     {
@@ -196,11 +191,11 @@ sal_Bool FuConstructRectangle::MouseButtonDown(const MouseEvent& rMEvt)
         {
             Size aCaptionSize(846, 846);    // (4x2)cm
             bReturn = mpView->BegCreateCaptionObj(aPnt, aCaptionSize,
-                                                (OutputDevice*) NULL, nDrgLog);
+                                                nullptr, nDrgLog);
         }
         else
         {
-            mpView->BegCreateObj(aPnt, (OutputDevice*) NULL, nDrgLog);
+            mpView->BegCreateObj(aPnt, nullptr, nDrgLog);
         }
 
         SdrObject* pObj = mpView->GetCreateObj();
@@ -214,38 +209,31 @@ sal_Bool FuConstructRectangle::MouseButtonDown(const MouseEvent& rMEvt)
             pObj->SetMergedItemSet(aAttr);
 
             if( nSlotId == SID_DRAW_CAPTION_VERTICAL )
-                ( (SdrTextObj*) pObj)->SetVerticalWriting( sal_True );
+                static_cast<SdrTextObj*>(pObj)->SetVerticalWriting( true );
         }
     }
     return bReturn;
 }
 
-
-sal_Bool FuConstructRectangle::MouseMove(const MouseEvent& rMEvt)
+bool FuConstructRectangle::MouseButtonUp(const MouseEvent& rMEvt)
 {
-    return FuConstruct::MouseMove(rMEvt);
-}
-
-
-sal_Bool FuConstructRectangle::MouseButtonUp(const MouseEvent& rMEvt)
-{
-    sal_Bool bReturn(sal_False);
+    bool bReturn(false);
 
     if(mpView->IsCreateObj() && rMEvt.IsLeft())
     {
         SdrObject* pObj = mpView->GetCreateObj();
 
-        if(pObj && mpView->EndCreateObj(SDRCREATE_FORCEEND))
+        if(pObj && mpView->EndCreateObj(SdrCreateCmd::ForceEnd))
         {
             if(SID_DRAW_MEASURELINE == nSlotId)
             {
                 SdrLayerAdmin& rAdmin = mpDoc->GetLayerAdmin();
-                OUString aStr(SD_RESSTR(STR_LAYER_MEASURELINES));
-                pObj->SetLayer(rAdmin.GetLayerID(aStr, sal_False));
+                OUString aStr(SdResId(STR_LAYER_MEASURELINES));
+                pObj->SetLayer(rAdmin.GetLayerID(aStr));
             }
 
-            // init text position when vertica caption object is created
-            if(pObj->ISA(SdrCaptionObj) && SID_DRAW_CAPTION_VERTICAL == nSlotId)
+            // init text position when vertical caption object is created
+            if( dynamic_cast< const SdrCaptionObj *>( pObj ) !=  nullptr && SID_DRAW_CAPTION_VERTICAL == nSlotId)
             {
                 // draw text object, needs to be initialized when vertical text is used
                 SfxItemSet aSet(pObj->GetMergedItemSet());
@@ -255,35 +243,24 @@ sal_Bool FuConstructRectangle::MouseButtonUp(const MouseEvent& rMEvt)
 
                 // Correct the value of SDRATTR_TEXTDIRECTION to avoid SetItemSet
                 // calling SetVerticalWriting() again since this item may not yet
-                // be set at the object and thus may differ from verical state of
+                // be set at the object and thus may differ from vertical state of
                 // the object.
-                aSet.Put(SvxWritingModeItem(com::sun::star::text::WritingMode_TB_RL, SDRATTR_TEXTDIRECTION));
+                aSet.Put(SvxWritingModeItem(css::text::WritingMode_TB_RL, SDRATTR_TEXTDIRECTION));
                 pObj->SetMergedItemSet(aSet);
             }
 
-            bReturn = sal_True;
+            bReturn = true;
         }
     }
 
     bReturn = FuConstruct::MouseButtonUp (rMEvt) || bReturn;
 
     if (!bPermanent)
-        mpViewShell->GetViewFrame()->GetDispatcher()->Execute(SID_OBJECT_SELECT, SFX_CALLMODE_ASYNCHRON);
+        mpViewShell->GetViewFrame()->GetDispatcher()->Execute(SID_OBJECT_SELECT, SfxCallMode::ASYNCHRON);
 
     return bReturn;
 }
 
-/**
- * Process keyboard input
- * @returns sal_True if a KeyEvent is being processed, sal_False otherwise
- */
-sal_Bool FuConstructRectangle::KeyInput(const KeyEvent& rKEvt)
-{
-    sal_Bool bReturn = FuConstruct::KeyInput(rKEvt);
-    return(bReturn);
-}
-
-
 void FuConstructRectangle::Activate()
 {
     SdrObjKind aObjKind;
@@ -298,7 +275,7 @@ void FuConstructRectangle::Activate()
         case SID_LINE_ARROW_SQUARE:
         case SID_LINE_SQUARE_ARROW:
             mpView->SetGlueVisible();
-            // no break !
+            SAL_FALLTHROUGH;
         case SID_DRAW_LINE :
         case SID_DRAW_XLINE:
             aObjKind = OBJ_LINE;
@@ -385,7 +362,6 @@ void FuConstructRectangle::Activate()
     FuConstruct::Activate();
 }
 
-
 void FuConstructRectangle::Deactivate()
 {
     if( nSlotId == SID_TOOL_CONNECTOR               ||
@@ -424,12 +400,11 @@ void FuConstructRectangle::Deactivate()
         nSlotId == SID_LINE_ARROW_SQUARE            ||
         nSlotId == SID_LINE_SQUARE_ARROW )
     {
-        mpView->SetGlueVisible( sal_False );
+        mpView->SetGlueVisible( false );
     }
     FuConstruct::Deactivate();
 }
 
-
 /**
  * set attribute for the object to be created
  */
@@ -441,7 +416,7 @@ void FuConstructRectangle::SetAttributes(SfxItemSet& rAttr, SdrObject* pObj)
         nSlotId == SID_DRAW_SQUARE_ROUND_NOFILL)
     {
         // round corner
-        rAttr.Put(SdrEckenradiusItem(500));
+        rAttr.Put(makeSdrEckenradiusItem(500));
     }
     else if (nSlotId == SID_CONNECTOR_LINE              ||
              nSlotId == SID_CONNECTOR_LINE_ARROW_START  ||
@@ -452,7 +427,7 @@ void FuConstructRectangle::SetAttributes(SfxItemSet& rAttr, SdrObject* pObj)
              nSlotId == SID_CONNECTOR_LINE_CIRCLES)
     {
         // direct connector
-        rAttr.Put(SdrEdgeKindItem(SDREDGE_ONELINE));
+        rAttr.Put(SdrEdgeKindItem(SdrEdgeKind::OneLine));
     }
     else if (nSlotId == SID_CONNECTOR_LINES              ||
              nSlotId == SID_CONNECTOR_LINES_ARROW_START  ||
@@ -463,7 +438,7 @@ void FuConstructRectangle::SetAttributes(SfxItemSet& rAttr, SdrObject* pObj)
              nSlotId == SID_CONNECTOR_LINES_CIRCLES)
     {
         // line connector
-        rAttr.Put(SdrEdgeKindItem(SDREDGE_THREELINES));
+        rAttr.Put(SdrEdgeKindItem(SdrEdgeKind::ThreeLines));
     }
     else if (nSlotId == SID_CONNECTOR_CURVE              ||
              nSlotId == SID_CONNECTOR_CURVE_ARROW_START  ||
@@ -474,16 +449,16 @@ void FuConstructRectangle::SetAttributes(SfxItemSet& rAttr, SdrObject* pObj)
              nSlotId == SID_CONNECTOR_CURVE_CIRCLES)
     {
         // curve connector
-        rAttr.Put(SdrEdgeKindItem(SDREDGE_BEZIER));
+        rAttr.Put(SdrEdgeKindItem(SdrEdgeKind::Bezier));
     }
     else if ( nSlotId == SID_DRAW_CAPTION || nSlotId == SID_DRAW_CAPTION_VERTICAL )
     {
         // legend object
         Size aSize(pObj->GetLogicRect().GetSize());
-        rAttr.Put( SdrTextMinFrameHeightItem( aSize.Height() ) );
-        rAttr.Put( SdrTextMinFrameWidthItem( aSize.Width() ) );
-        rAttr.Put( SdrTextAutoGrowHeightItem( sal_True ) );
-        rAttr.Put( SdrTextAutoGrowWidthItem( sal_True ) );
+        rAttr.Put( makeSdrTextMinFrameHeightItem( aSize.Height() ) );
+        rAttr.Put( makeSdrTextMinFrameWidthItem( aSize.Width() ) );
+        rAttr.Put( makeSdrTextAutoGrowHeightItem( true ) );
+        rAttr.Put( makeSdrTextAutoGrowWidthItem( true ) );
 
         // Support full with for vertical caption objects, too
         if(SID_DRAW_CAPTION == nSlotId)
@@ -491,53 +466,52 @@ void FuConstructRectangle::SetAttributes(SfxItemSet& rAttr, SdrObject* pObj)
         else
             rAttr.Put( SdrTextVertAdjustItem( SDRTEXTVERTADJUST_BLOCK ) );
 
-        rAttr.Put( SvxAdjustItem( SVX_ADJUST_CENTER, EE_PARA_JUST ) );
-        rAttr.Put( SdrTextLeftDistItem( 100 ) );
-        rAttr.Put( SdrTextRightDistItem( 100 ) );
-        rAttr.Put( SdrTextUpperDistItem( 100 ) );
-        rAttr.Put( SdrTextLowerDistItem( 100 ) );
+        rAttr.Put( SvxAdjustItem( SvxAdjust::Center, EE_PARA_JUST ) );
+        rAttr.Put( makeSdrTextLeftDistItem( 100 ) );
+        rAttr.Put( makeSdrTextRightDistItem( 100 ) );
+        rAttr.Put( makeSdrTextUpperDistItem( 100 ) );
+        rAttr.Put( makeSdrTextLowerDistItem( 100 ) );
     }
     else if (nSlotId == SID_DRAW_MEASURELINE)
     {
         // dimension line
-        SdPage* pPage = (SdPage*) mpView->GetSdrPageView()->GetPage();
-        OUString aName(SD_RESSTR(STR_POOLSHEET_MEASURE));
-        SfxStyleSheet* pSheet = (SfxStyleSheet*) pPage->GetModel()->
+        SdPage* pPage = static_cast<SdPage*>( mpView->GetSdrPageView()->GetPage() );
+        OUString aName(SdResId(STR_POOLSHEET_MEASURE));
+        SfxStyleSheet* pSheet = static_cast<SfxStyleSheet*>( pPage->GetModel()->
                                      GetStyleSheetPool()->
-                                     Find(aName, SD_STYLE_FAMILY_GRAPHICS);
+                                     Find(aName, SD_STYLE_FAMILY_GRAPHICS));
         DBG_ASSERT(pSheet, "StyleSheet missing");
 
         if (pSheet)
         {
-            pObj->SetStyleSheet(pSheet, sal_False);
+            pObj->SetStyleSheet(pSheet, false);
         }
 
         SdrLayerAdmin& rAdmin = mpDoc->GetLayerAdmin();
-        OUString aStr(SD_RESSTR(STR_LAYER_MEASURELINES));
-        pObj->SetLayer(rAdmin.GetLayerID(aStr, sal_False));
+        OUString aStr(SdResId(STR_LAYER_MEASURELINES));
+        pObj->SetLayer(rAdmin.GetLayerID(aStr));
     }
     else if (nSlotId == OBJ_CUSTOMSHAPE )
     {
     }
 }
 
-
 /**
  * set line starts and ends for the object to be created
  */
-::basegfx::B2DPolyPolygon getPolygon( sal_uInt16 nResId, SdrModel* pDoc )
+::basegfx::B2DPolyPolygon getPolygon(const char* pResId, SdrModel const * pDoc)
 {
     ::basegfx::B2DPolyPolygon aRetval;
     XLineEndListRef pLineEndList = pDoc->GetLineEndList();
 
     if( pLineEndList.is() )
     {
-        OUString aArrowName( SVX_RES(nResId) );
+        OUString aArrowName(SvxResId(pResId));
         long nCount = pLineEndList->Count();
         long nIndex;
-        for( nIndex = 0L; nIndex < nCount; nIndex++ )
+        for( nIndex = 0; nIndex < nCount; nIndex++ )
         {
-            XLineEndEntry* pEntry = pLineEndList->GetLineEnd(nIndex);
+            const XLineEndEntry* pEntry = pLineEndList->GetLineEnd(nIndex);
             if( pEntry->GetName() == aArrowName )
             {
                 aRetval = pEntry->GetLineEnd();
@@ -549,7 +523,7 @@ void FuConstructRectangle::SetAttributes(SfxItemSet& rAttr, SdrObject* pObj)
     return aRetval;
 }
 
-void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
+void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject const * pObj)
 {
     if ( (pObj->GetObjIdentifier() == OBJ_EDGE &&
           nSlotId != SID_TOOL_CONNECTOR        &&
@@ -583,7 +557,7 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
         if( !aCircle.count() )
         {
             ::basegfx::B2DPolygon aNewCircle;
-            aNewCircle = ::basegfx::tools::createPolygonFromEllipse(::basegfx::B2DPoint(0.0, 0.0), 250.0, 250.0);
+            aNewCircle = ::basegfx::utils::createPolygonFromEllipse(::basegfx::B2DPoint(0.0, 0.0), 250.0, 250.0);
             aNewCircle.setClosed(true);
             aCircle.append(aNewCircle);
         }
@@ -610,9 +584,9 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
         long nWidth = 300; // (1/100th mm)
 
         // determine line width and calculate with it the line end width
-        if( aSet.GetItemState( XATTR_LINEWIDTH ) != SFX_ITEM_DONTCARE )
+        if( aSet.GetItemState( XATTR_LINEWIDTH ) != SfxItemState::DONTCARE )
         {
-            long nValue = ( ( const XLineWidthItem& ) aSet.Get( XATTR_LINEWIDTH ) ).GetValue();
+            long nValue = aSet.Get( XATTR_LINEWIDTH ).GetValue();
             if( nValue > 0 )
                 nWidth = nValue * 3;
         }
@@ -626,9 +600,9 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_LINE_ARROWS:
             {
                 // connector with arrow ends
-                rAttr.Put(XLineStartItem(SVX_RESSTR(RID_SVXSTR_ARROW), aArrow));
+                rAttr.Put(XLineStartItem(SvxResId(RID_SVXSTR_ARROW), aArrow));
                 rAttr.Put(XLineStartWidthItem(nWidth));
-                rAttr.Put(XLineEndItem(SVX_RESSTR(RID_SVXSTR_ARROW), aArrow));
+                rAttr.Put(XLineEndItem(SvxResId(RID_SVXSTR_ARROW), aArrow));
                 rAttr.Put(XLineEndWidthItem(nWidth));
             }
             break;
@@ -642,7 +616,7 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_LINE_ARROW_SQUARE:
             {
                 // connector with arrow start
-                rAttr.Put(XLineStartItem(SVX_RESSTR(RID_SVXSTR_ARROW), aArrow));
+                rAttr.Put(XLineStartItem(SvxResId(RID_SVXSTR_ARROW), aArrow));
                 rAttr.Put(XLineStartWidthItem(nWidth));
             }
             break;
@@ -656,7 +630,7 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_LINE_SQUARE_ARROW:
             {
                 // connector with arrow end
-                rAttr.Put(XLineEndItem(SVX_RESSTR(RID_SVXSTR_ARROW), aArrow));
+                rAttr.Put(XLineEndItem(SvxResId(RID_SVXSTR_ARROW), aArrow));
                 rAttr.Put(XLineEndWidthItem(nWidth));
             }
             break;
@@ -667,9 +641,9 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_CONNECTOR_CURVE_CIRCLES:
             {
                 // connector with circle ends
-                rAttr.Put(XLineStartItem(SVX_RESSTR(RID_SVXSTR_CIRCLE), aCircle));
+                rAttr.Put(XLineStartItem(SvxResId(RID_SVXSTR_CIRCLE), aCircle));
                 rAttr.Put(XLineStartWidthItem(nWidth));
-                rAttr.Put(XLineEndItem(SVX_RESSTR(RID_SVXSTR_CIRCLE), aCircle));
+                rAttr.Put(XLineEndItem(SvxResId(RID_SVXSTR_CIRCLE), aCircle));
                 rAttr.Put(XLineEndWidthItem(nWidth));
             }
             break;
@@ -680,7 +654,7 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_CONNECTOR_CURVE_CIRCLE_START:
             {
                 // connector with circle start
-                rAttr.Put(XLineStartItem(SVX_RESSTR(RID_SVXSTR_CIRCLE), aCircle));
+                rAttr.Put(XLineStartItem(SvxResId(RID_SVXSTR_CIRCLE), aCircle));
                 rAttr.Put(XLineStartWidthItem(nWidth));
             }
             break;
@@ -691,11 +665,11 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_CONNECTOR_CURVE_CIRCLE_END:
             {
                 // connector with circle ends
-                rAttr.Put(XLineEndItem(SVX_RESSTR(RID_SVXSTR_CIRCLE), aCircle));
+                rAttr.Put(XLineEndItem(SvxResId(RID_SVXSTR_CIRCLE), aCircle));
                 rAttr.Put(XLineEndWidthItem(nWidth));
             }
             break;
-        };
+        }
 
         // and again, for the still missing ends
         switch (nSlotId)
@@ -703,7 +677,7 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_LINE_ARROW_CIRCLE:
             {
                 // circle end
-                rAttr.Put(XLineEndItem(SVX_RESSTR(RID_SVXSTR_CIRCLE), aCircle));
+                rAttr.Put(XLineEndItem(SvxResId(RID_SVXSTR_CIRCLE), aCircle));
                 rAttr.Put(XLineEndWidthItem(nWidth));
             }
             break;
@@ -711,7 +685,7 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_LINE_CIRCLE_ARROW:
             {
                 // circle start
-                rAttr.Put(XLineStartItem(SVX_RESSTR(RID_SVXSTR_CIRCLE), aCircle));
+                rAttr.Put(XLineStartItem(SvxResId(RID_SVXSTR_CIRCLE), aCircle));
                 rAttr.Put(XLineStartWidthItem(nWidth));
             }
             break;
@@ -719,7 +693,7 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_LINE_ARROW_SQUARE:
             {
                 // square end
-                rAttr.Put(XLineEndItem(SVX_RESSTR(RID_SVXSTR_SQUARE), aSquare));
+                rAttr.Put(XLineEndItem(SvxResId(RID_SVXSTR_SQUARE), aSquare));
                 rAttr.Put(XLineEndWidthItem(nWidth));
             }
             break;
@@ -727,7 +701,7 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
             case SID_LINE_SQUARE_ARROW:
             {
                 // square start
-                rAttr.Put(XLineStartItem(SVX_RESSTR(RID_SVXSTR_SQUARE), aSquare));
+                rAttr.Put(XLineStartItem(SvxResId(RID_SVXSTR_SQUARE), aSquare));
                 rAttr.Put(XLineStartWidthItem(nWidth));
             }
             break;
@@ -735,7 +709,7 @@ void FuConstructRectangle::SetLineEnds(SfxItemSet& rAttr, SdrObject* pObj)
     }
 }
 
-SdrObject* FuConstructRectangle::CreateDefaultObject(const sal_uInt16 nID, const Rectangle& rRectangle)
+SdrObject* FuConstructRectangle::CreateDefaultObject(const sal_uInt16 nID, const ::tools::Rectangle& rRectangle)
 {
     DBG_ASSERT( (nID != SID_DRAW_FONTWORK) && (nID != SID_DRAW_FONTWORK_VERTICAL ), "FuConstRectangle::CreateDefaultObject can not create Fontwork shapes!" );
 
@@ -794,11 +768,11 @@ SdrObject* FuConstructRectangle::CreateDefaultObject(const sal_uInt16 nID, const
 
     SdrObject* pObj = SdrObjFactory::MakeNewObject(
         mpView->GetCurrentObjInventor(), mpView->GetCurrentObjIdentifier(),
-        0L, mpDoc);
+        nullptr, mpDoc);
 
     if(pObj)
     {
-        Rectangle aRect(rRectangle);
+        ::tools::Rectangle aRect(rRectangle);
 
         if(SID_DRAW_SQUARE == nID ||
             SID_DRAW_SQUARE_NOFILL == nID ||
@@ -826,14 +800,14 @@ SdrObject* FuConstructRectangle::CreateDefaultObject(const sal_uInt16 nID, const
             case SID_LINE_ARROW_SQUARE:
             case SID_LINE_SQUARE_ARROW:
             {
-                if(pObj->ISA(SdrPathObj))
+                if( dynamic_cast< const SdrPathObj *>( pObj ) !=  nullptr)
                 {
                     sal_Int32 nYMiddle((aRect.Top() + aRect.Bottom()) / 2);
 
                     ::basegfx::B2DPolygon aB2DPolygon;
                     aB2DPolygon.append(::basegfx::B2DPoint(aStart.X(), nYMiddle));
                     aB2DPolygon.append(::basegfx::B2DPoint(aEnd.X(), nYMiddle));
-                    ((SdrPathObj*)pObj)->SetPathPoly(::basegfx::B2DPolyPolygon(aB2DPolygon));
+                    static_cast<SdrPathObj*>(pObj)->SetPathPoly(::basegfx::B2DPolyPolygon(aB2DPolygon));
                 }
                 else
                 {
@@ -845,11 +819,11 @@ SdrObject* FuConstructRectangle::CreateDefaultObject(const sal_uInt16 nID, const
 
             case SID_DRAW_MEASURELINE:
             {
-                if(pObj->ISA(SdrMeasureObj))
+                if( auto pMeasureObj = dynamic_cast< SdrMeasureObj *>( pObj ) )
                 {
                     sal_Int32 nYMiddle((aRect.Top() + aRect.Bottom()) / 2);
-                    ((SdrMeasureObj*)pObj)->SetPoint(Point(aStart.X(), nYMiddle), 0);
-                    ((SdrMeasureObj*)pObj)->SetPoint(Point(aEnd.X(), nYMiddle), 1);
+                    pMeasureObj->SetPoint(Point(aStart.X(), nYMiddle), 0);
+                    pMeasureObj->SetPoint(Point(aEnd.X(), nYMiddle), 1);
                 }
                 else
                 {
@@ -888,10 +862,10 @@ SdrObject* FuConstructRectangle::CreateDefaultObject(const sal_uInt16 nID, const
             case SID_CONNECTOR_LINES_CIRCLE_END:
             case SID_CONNECTOR_LINES_CIRCLES:
             {
-                if(pObj->ISA(SdrEdgeObj))
+                if( auto pEdgeObj = dynamic_cast< SdrEdgeObj *>( pObj ) )
                 {
-                    ((SdrEdgeObj*)pObj)->SetTailPoint(sal_False, aStart);
-                    ((SdrEdgeObj*)pObj)->SetTailPoint(sal_True, aEnd);
+                    pEdgeObj->SetTailPoint(false, aStart);
+                    pEdgeObj->SetTailPoint(true, aEnd);
                 }
                 else
                 {
@@ -903,11 +877,11 @@ SdrObject* FuConstructRectangle::CreateDefaultObject(const sal_uInt16 nID, const
             case SID_DRAW_CAPTION:
             case SID_DRAW_CAPTION_VERTICAL:
             {
-                if(pObj->ISA(SdrCaptionObj))
+                if( auto pCaptionObj = dynamic_cast< SdrCaptionObj *>( pObj ) )
                 {
-                    sal_Bool bIsVertical(SID_DRAW_CAPTION_VERTICAL == nID);
+                    bool bIsVertical(SID_DRAW_CAPTION_VERTICAL == nID);
 
-                    ((SdrTextObj*)pObj)->SetVerticalWriting(bIsVertical);
+                    static_cast<SdrTextObj*>(pObj)->SetVerticalWriting(bIsVertical);
 
                     if(bIsVertical)
                     {
@@ -918,11 +892,9 @@ SdrObject* FuConstructRectangle::CreateDefaultObject(const sal_uInt16 nID, const
                     }
 
                     // The default text is not inserted anymore.
-                    //  String aText(SdResId(STR_POOLSHEET_TEXT));
-                    //  ((SdrCaptionObj*)pObj)->SetText(aText);
 
-                    ((SdrCaptionObj*)pObj)->SetLogicRect(aRect);
-                    ((SdrCaptionObj*)pObj)->SetTailPos(
+                    pCaptionObj->SetLogicRect(aRect);
+                    pCaptionObj->SetTailPos(
                         aRect.TopLeft() - Point(aRect.GetWidth() / 2, aRect.GetHeight() / 2));
                 }
                 else
