@@ -30,22 +30,21 @@
 #include <editeng/eeitem.hxx>
 #include <editeng/editeng.hxx>
 
-#include "sdmod.hxx"
+#include <sdmod.hxx>
 
-#include "fuformatpaintbrush.hxx"
-#include "drawview.hxx"
-#include "DrawDocShell.hxx"
-#include "DrawViewShell.hxx"
-#include "FrameView.hxx"
-#include "drawdoc.hxx"
-#include "Outliner.hxx"
-#include "ViewShellBase.hxx"
+#include <fuformatpaintbrush.hxx>
+#include <drawview.hxx>
+#include <DrawDocShell.hxx>
+#include <DrawViewShell.hxx>
+#include <FrameView.hxx>
+#include <drawdoc.hxx>
+#include <Outliner.hxx>
+#include <ViewShellBase.hxx>
 
-#include "Window.hxx"
+#include <Window.hxx>
 
 namespace sd {
 
-TYPEINIT1( FuFormatPaintBrush, FuText );
 
 FuFormatPaintBrush::FuFormatPaintBrush( ViewShell* pViewSh, ::sd::Window* pWin, ::sd::View* pView, SdDrawDocument* pDoc, SfxRequest& rReq )
 : FuText(pViewSh, pWin, pView, pDoc, rReq)
@@ -66,12 +65,12 @@ void FuFormatPaintBrush::DoExecute( SfxRequest& rReq )
     const SfxItemSet *pArgs = rReq.GetArgs();
     if( pArgs && pArgs->Count() >= 1 )
     {
-        mbPermanent = static_cast<bool>(static_cast<const SfxBoolItem &>(pArgs->Get(SID_FORMATPAINTBRUSH)).GetValue());
+        mbPermanent = static_cast<const SfxBoolItem &>(pArgs->Get(SID_FORMATPAINTBRUSH)).GetValue();
     }
 
     if( mpView )
     {
-        mpView->TakeFormatPaintBrush( mpItemSet );
+        mpView->TakeFormatPaintBrush( mxItemSet );
     }
 }
 
@@ -96,16 +95,14 @@ bool FuFormatPaintBrush::MouseButtonDown(const MouseEvent& rMEvt)
     if(mpView&&mpWindow)
     {
         SdrViewEvent aVEvt;
-        SdrHitKind eHit = mpView->PickAnything(rMEvt, SDRMOUSEBUTTONDOWN, aVEvt);
+        SdrHitKind eHit = mpView->PickAnything(rMEvt, SdrMouseEventKind::BUTTONDOWN, aVEvt);
 
-        if( (eHit == SDRHIT_TEXTEDIT) || (eHit == SDRHIT_TEXTEDITOBJ && ( mpViewShell->GetFrameView()->IsQuickEdit() || dynamic_cast< sdr::table::SdrTableObj* >( aVEvt.pObj ) != NULL ) ))
+        if( (eHit == SdrHitKind::TextEdit) || (eHit == SdrHitKind::TextEditObj && ( mpViewShell->GetFrameView()->IsQuickEdit() || dynamic_cast< sdr::table::SdrTableObj* >( aVEvt.pObj ) != nullptr ) ))
         {
-            SdrObject* pPickObj=0;
-            SdrPageView* pPV=0;
+            SdrPageView* pPV=nullptr;
             sal_uInt16 nHitLog = sal_uInt16 ( mpWindow->PixelToLogic(Size(HITPIX,0)).Width() );
-            mpView->PickObj( mpWindow->PixelToLogic( rMEvt.GetPosPixel() ),nHitLog, pPickObj, pPV, SDRSEARCH_PICKMARKABLE);
-
-            if( (pPickObj != 0) && !pPickObj->IsEmptyPresObj() )
+            SdrObject* pPickObj = mpView->PickObj(mpWindow->PixelToLogic(rMEvt.GetPosPixel()),nHitLog, pPV, SdrSearchOptions::PICKMARKABLE);
+            if( (pPickObj != nullptr) && !pPickObj->IsEmptyPresObj() )
             {
                 // if we text hit another shape than the one currently selected, unselect the old one now
                 const SdrMarkList& rMarkList = mpView->GetMarkedObjectList();
@@ -130,7 +127,7 @@ bool FuFormatPaintBrush::MouseButtonDown(const MouseEvent& rMEvt)
                 return FuText::MouseButtonDown(aMEvt);
             }
 
-            if( aVEvt.pObj == 0 )
+            if( aVEvt.pObj == nullptr )
                 aVEvt.pObj = pPickObj;
         }
 
@@ -139,8 +136,7 @@ bool FuFormatPaintBrush::MouseButtonDown(const MouseEvent& rMEvt)
         if( aVEvt.pObj )
         {
             sal_uInt16 nHitLog = sal_uInt16 ( mpWindow->PixelToLogic(Size(HITPIX,0)).Width() );
-            bool bToggle = false;
-            mpView->MarkObj(mpWindow->PixelToLogic( rMEvt.GetPosPixel() ), nHitLog, bToggle, false);
+            mpView->MarkObj(mpWindow->PixelToLogic( rMEvt.GetPosPixel() ), nHitLog, false/*bToggle*/);
             return true;
         }
     }
@@ -155,19 +151,17 @@ bool FuFormatPaintBrush::MouseMove(const MouseEvent& rMEvt)
         if ( mpView->IsTextEdit() )
         {
             bReturn = FuText::MouseMove( rMEvt );
-            mpWindow->SetPointer(Pointer(POINTER_FILL));
+            mpWindow->SetPointer(Pointer(PointerStyle::Fill));
         }
         else
         {
             sal_uInt16 nHitLog = sal_uInt16 ( mpWindow->PixelToLogic(Size(HITPIX,0)).Width() );
-            SdrObject* pObj=0;
-            SdrPageView* pPV=0;
-            bool bOverMarkableObject = mpView->PickObj( mpWindow->PixelToLogic( rMEvt.GetPosPixel() ),nHitLog, pObj, pPV, SDRSEARCH_PICKMARKABLE);
-
-            if(bOverMarkableObject && HasContentForThisType(pObj->GetObjInventor(),pObj->GetObjIdentifier()) )
-                mpWindow->SetPointer(Pointer(POINTER_FILL));
+            SdrPageView* pPV=nullptr;
+            SdrObject* pObj = mpView->PickObj(mpWindow->PixelToLogic( rMEvt.GetPosPixel() ),nHitLog, pPV, SdrSearchOptions::PICKMARKABLE);
+            if (pObj && HasContentForThisType(pObj->GetObjInventor(),pObj->GetObjIdentifier()) )
+                mpWindow->SetPointer(Pointer(PointerStyle::Fill));
             else
-                mpWindow->SetPointer(Pointer(POINTER_ARROW));
+                mpWindow->SetPointer(Pointer(PointerStyle::Arrow));
         }
     }
     return bReturn;
@@ -175,7 +169,7 @@ bool FuFormatPaintBrush::MouseMove(const MouseEvent& rMEvt)
 
 bool FuFormatPaintBrush::MouseButtonUp(const MouseEvent& rMEvt)
 {
-    if( mpItemSet.get() && mpView && mpView->AreObjectsMarked() )
+    if( mxItemSet.get() && mpView && mpView->AreObjectsMarked() )
     {
         bool bNoCharacterFormats = false;
         bool bNoParagraphFormats = false;
@@ -204,7 +198,7 @@ bool FuFormatPaintBrush::MouseButtonUp(const MouseEvent& rMEvt)
 
 bool FuFormatPaintBrush::KeyInput(const KeyEvent& rKEvt)
 {
-    if( (rKEvt.GetKeyCode().GetCode() == KEY_ESCAPE) && mpViewShell )
+    if (rKEvt.GetKeyCode().GetCode() == KEY_ESCAPE)
     {
         implcancel();
         return true;
@@ -231,11 +225,11 @@ void FuFormatPaintBrush::Deactivate()
     }
 }
 
-bool FuFormatPaintBrush::HasContentForThisType( sal_uInt32 nObjectInventor, sal_uInt16 nObjectIdentifier ) const
+bool FuFormatPaintBrush::HasContentForThisType( SdrInventor nObjectInventor, sal_uInt16 nObjectIdentifier ) const
 {
-    if( mpItemSet.get() == 0 )
+    if( mxItemSet.get() == nullptr )
         return false;
-    if( !mpView || (!mpView->SupportsFormatPaintbrush( nObjectInventor, nObjectIdentifier) ) )
+    if( !mpView || (!SdrObjEditView::SupportsFormatPaintbrush( nObjectInventor, nObjectIdentifier) ) )
         return false;
     return true;
 }
@@ -243,9 +237,9 @@ bool FuFormatPaintBrush::HasContentForThisType( sal_uInt32 nObjectInventor, sal_
 void FuFormatPaintBrush::Paste( bool bNoCharacterFormats, bool bNoParagraphFormats )
 {
     const SdrMarkList& rMarkList = mpView->GetMarkedObjectList();
-    if( mpItemSet.get() && ( rMarkList.GetMarkCount() == 1 ) )
+    if( mxItemSet.get() && ( rMarkList.GetMarkCount() == 1 ) )
     {
-        SdrObject* pObj( NULL );
+        SdrObject* pObj( nullptr );
         bool bUndo = mpDoc->IsUndoEnabled();
 
         if( bUndo && !mpView->GetTextEditOutlinerView() )
@@ -257,10 +251,11 @@ void FuFormatPaintBrush::Paste( bool bNoCharacterFormats, bool bNoParagraphForma
         {
             OUString sLabel( mpViewShell->GetViewShellBase().RetrieveLabelFromCommand(".uno:FormatPaintbrush" ) );
             mpDoc->BegUndo( sLabel );
-            mpDoc->AddUndo( mpDoc->GetSdrUndoFactory().CreateUndoAttrObject( *pObj, false, true ) );
+            if (dynamic_cast< sdr::table::SdrTableObj* >( pObj ) == nullptr)
+                mpDoc->AddUndo( mpDoc->GetSdrUndoFactory().CreateUndoAttrObject( *pObj, false, true ) );
         }
 
-        mpView->ApplyFormatPaintBrush( *mpItemSet.get(), bNoCharacterFormats, bNoParagraphFormats );
+        mpView->ApplyFormatPaintBrush( *mxItemSet.get(), bNoCharacterFormats, bNoParagraphFormats );
 
         if( pObj )
         {
@@ -269,14 +264,14 @@ void FuFormatPaintBrush::Paste( bool bNoCharacterFormats, bool bNoParagraphForma
     }
 }
 
-/* static */ void FuFormatPaintBrush::GetMenuState( DrawViewShell& rDrawViewShell, SfxItemSet &rSet )
+/* static */ void FuFormatPaintBrush::GetMenuState( DrawViewShell const & rDrawViewShell, SfxItemSet &rSet )
 {
     const SdrMarkList& rMarkList = rDrawViewShell.GetDrawView()->GetMarkedObjectList();
 
     if( rMarkList.GetMarkCount() == 1 )
     {
         SdrObject* pObj = rMarkList.GetMark(0)->GetMarkedSdrObj();
-        if( pObj && rDrawViewShell.GetDrawView()->SupportsFormatPaintbrush(pObj->GetObjInventor(),pObj->GetObjIdentifier()) )
+        if( pObj && SdrObjEditView::SupportsFormatPaintbrush(pObj->GetObjInventor(),pObj->GetObjIdentifier()) )
             return;
     }
     rSet.DisableItem( SID_FORMATPAINTBRUSH );
