@@ -17,24 +17,24 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "fuzoom.hxx"
+#include <fuzoom.hxx>
 
 #include <svx/svxids.hrc>
 #include <sfx2/bindings.hxx>
 #include <sfx2/viewfrm.hxx>
-#include "app.hrc"
+#include <app.hrc>
 #include <svx/svdpagv.hxx>
 
-#include "FrameView.hxx"
-#include "ViewShell.hxx"
-#include "View.hxx"
-#include "Window.hxx"
-#include "drawdoc.hxx"
-#include "zoomlist.hxx"
+#include <FrameView.hxx>
+#include <ViewShell.hxx>
+#include <View.hxx>
+#include <Window.hxx>
+#include <drawdoc.hxx>
+#include <zoomlist.hxx>
 
 namespace sd {
 
-sal_uInt16 SidArrayZoom[] = {
+const sal_uInt16 SidArrayZoom[] = {
                     SID_ATTR_ZOOM,
                     SID_ZOOM_OUT,
                     SID_ZOOM_IN,
@@ -125,7 +125,7 @@ bool FuZoom::MouseMove(const MouseEvent& rMEvt)
         }
         else
         {
-            Rectangle aRect(aBeginPos, aEndPos);
+            ::tools::Rectangle aRect(aBeginPos, aEndPos);
             aZoomRect = aRect;
             aZoomRect.Justify();
             mpViewShell->DrawMarkRect(aZoomRect);
@@ -181,7 +181,7 @@ bool FuZoom::MouseButtonUp(const MouseEvent& rMEvt)
         mpViewShell->GetViewFrame()->GetBindings().Invalidate( SidArrayZoom );
     }
 
-    Rectangle aVisAreaWin = mpWindow->PixelToLogic(Rectangle(Point(0,0),
+    ::tools::Rectangle aVisAreaWin = mpWindow->PixelToLogic(::tools::Rectangle(Point(0,0),
                                            mpWindow->GetOutputSizePixel()));
     mpViewShell->GetZoomList()->InsertZoomRect(aVisAreaWin);
 
