@@ -17,49 +17,48 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "controller/SlsClipboard.hxx"
+#include <controller/SlsClipboard.hxx>
 
-#include "SlideSorterViewShell.hxx"
-#include "SlideSorter.hxx"
-#include "model/SlideSorterModel.hxx"
-#include "model/SlsPageDescriptor.hxx"
-#include "model/SlsPageEnumerationProvider.hxx"
-#include "view/SlideSorterView.hxx"
-#include "view/SlsTheme.hxx"
-#include "controller/SlideSorterController.hxx"
-#include "controller/SlsInsertionIndicatorHandler.hxx"
-#include "controller/SlsPageSelector.hxx"
-#include "controller/SlsSelectionFunction.hxx"
-#include "controller/SlsCurrentSlideManager.hxx"
-#include "controller/SlsScrollBarManager.hxx"
-#include "controller/SlsFocusManager.hxx"
-#include "controller/SlsSelectionManager.hxx"
-#include "controller/SlsTransferableData.hxx"
-#include "controller/SlsSelectionObserver.hxx"
-#include "controller/SlsVisibleAreaManager.hxx"
-#include "cache/SlsPageCache.hxx"
+#include <SlideSorterViewShell.hxx>
+#include <SlideSorter.hxx>
+#include <model/SlideSorterModel.hxx>
+#include <model/SlsPageDescriptor.hxx>
+#include <model/SlsPageEnumerationProvider.hxx>
+#include <view/SlideSorterView.hxx>
+#include <view/SlsTheme.hxx>
+#include <controller/SlideSorterController.hxx>
+#include <controller/SlsInsertionIndicatorHandler.hxx>
+#include <controller/SlsPageSelector.hxx>
+#include <controller/SlsSelectionFunction.hxx>
+#include <controller/SlsCurrentSlideManager.hxx>
+#include <controller/SlsScrollBarManager.hxx>
+#include <controller/SlsFocusManager.hxx>
+#include <controller/SlsSelectionManager.hxx>
+#include <controller/SlsTransferableData.hxx>
+#include <controller/SlsSelectionObserver.hxx>
+#include <controller/SlsVisibleAreaManager.hxx>
+#include <cache/SlsPageCache.hxx>
 
-#include "ViewShellBase.hxx"
-#include "View.hxx"
-#include "DrawViewShell.hxx"
-#include "Window.hxx"
-#include "fupoor.hxx"
-#include "fuzoom.hxx"
-#include "fucushow.hxx"
-#include "fusldlg.hxx"
-#include "fuexpand.hxx"
-#include "fusumry.hxx"
-#include "app.hrc"
-#include "glob.hrc"
-#include "strings.hrc"
-#include "sdresid.hxx"
-#include "sdxfer.hxx"
-#include "sdmod.hxx"
-#include "ins_paste.hxx"
-#include "drawdoc.hxx"
-#include "DrawDocShell.hxx"
-#include "sdpage.hxx"
-#include "sdtreelb.hxx"
+#include <ViewShellBase.hxx>
+#include <View.hxx>
+#include <DrawViewShell.hxx>
+#include <Window.hxx>
+#include <fupoor.hxx>
+#include <fuzoom.hxx>
+#include <fucushow.hxx>
+#include <fusldlg.hxx>
+#include <fuexpand.hxx>
+#include <fusumry.hxx>
+#include <app.hrc>
+#include <strings.hrc>
+#include <sdresid.hxx>
+#include <sdxfer.hxx>
+#include <sdmod.hxx>
+#include <ins_paste.hxx>
+#include <drawdoc.hxx>
+#include <DrawDocShell.hxx>
+#include <sdpage.hxx>
+#include <sdtreelb.hxx>
 
 #include <com/sun/star/datatransfer/dnd/DNDConstants.hpp>
 #include <sfx2/request.hxx>
@@ -67,11 +66,10 @@
 #include <sfx2/bindings.hxx>
 #include <sfx2/docfile.hxx>
 #include <svx/svxids.hrc>
-#include <svx/svdstr.hrc>
+#include <svx/strings.hrc>
 #include <vcl/msgbox.hxx>
 #include <tools/urlobj.hxx>
 #include <rtl/ustring.hxx>
-#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 
 namespace sd { namespace slidesorter { namespace controller {
@@ -146,7 +144,6 @@ Clipboard::Clipboard (SlideSorter& rSlideSorter)
       mrController(mrSlideSorter.GetController()),
       maPagesToRemove(),
       maPagesToSelect(),
-      mbUpdateSelectionPending(false),
       mxUndoContext(),
       mxSelectionObserverContext(),
       mnDragFinishedUserEventId(nullptr)
@@ -427,9 +424,9 @@ void Clipboard::CreateSlideTransferable (
         if ( ! pDescriptor || pDescriptor->GetPage()==nullptr)
             continue;
         Bitmap aPreview (pPreviewCache->GetPreviewBitmap(pDescriptor->GetPage(), false));
-        aRepresentatives.push_back(TransferableData::Representative(
+        aRepresentatives.emplace_back(
             aPreview,
-            pDescriptor->HasState(model::PageDescriptor::ST_Excluded)));
+            pDescriptor->HasState(model::PageDescriptor::ST_Excluded));
         if (aRepresentatives.size() >= 3)
             break;
     }
@@ -439,8 +436,6 @@ void Clipboard::CreateSlideTransferable (
         mrSlideSorter.GetView().BrkAction();
         SdTransferable* pTransferable = TransferableData::CreateTransferable (
             pDocument,
-            nullptr,
-            false,
             dynamic_cast<SlideSorterViewShell*>(mrSlideSorter.GetViewShell()),
             aRepresentatives);
 
@@ -538,9 +533,9 @@ std::shared_ptr<SdTransferable::UserData> Clipboard::CreateTransferableUserData
         if ( ! pDescriptor || pDescriptor->GetPage()==nullptr)
             break;
         Bitmap aPreview (pPreviewCache->GetPreviewBitmap(pDescriptor->GetPage(), false));
-        aRepresentatives.push_back(TransferableData::Representative(
+        aRepresentatives.emplace_back(
                 aPreview,
-                pDescriptor->HasState(model::PageDescriptor::ST_Excluded)));
+                pDescriptor->HasState(model::PageDescriptor::ST_Excluded));
 
         // Remember the page in maPagesToRemove so that it can be removed
         // when drag and drop action is "move".
@@ -578,7 +573,6 @@ void Clipboard::StartDrag (
 {
     maPagesToRemove.clear();
     maPagesToSelect.clear();
-    mbUpdateSelectionPending = false;
     CreateSlideTransferable(pWindow, true);
 
     mrController.GetInsertionIndicatorHandler()->UpdatePosition(
@@ -800,7 +794,7 @@ sal_Int8 Clipboard::ExecuteDrop (
 }
 
 bool Clipboard::IsInsertionTrivial (
-    SdTransferable* pTransferable,
+    SdTransferable const * pTransferable,
     const sal_Int8 nDndAction) const
 {
     std::shared_ptr<TransferableData> pSlideSorterTransferable (
@@ -852,8 +846,6 @@ sal_uInt16 Clipboard::InsertSlides (
             maPagesToSelect.push_back(
                 dynamic_cast<SdPage*>(pDocument->GetPage(nInsertPosition+i)));
 
-    mbUpdateSelectionPending |= (nInsertedPageCount>0);
-
     return nInsertedPageCount;
 }
 
