@@ -17,28 +17,28 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "model/SlideSorterModel.hxx"
+#include <model/SlideSorterModel.hxx>
 
-#include "SlideSorter.hxx"
-#include "model/SlsPageDescriptor.hxx"
-#include "model/SlsPageEnumerationProvider.hxx"
-#include "controller/SlideSorterController.hxx"
-#include "controller/SlsProperties.hxx"
-#include "controller/SlsPageSelector.hxx"
-#include "controller/SlsCurrentSlideManager.hxx"
-#include "controller/SlsSlotManager.hxx"
-#include "view/SlideSorterView.hxx"
+#include <SlideSorter.hxx>
+#include <model/SlsPageDescriptor.hxx>
+#include <model/SlsPageEnumerationProvider.hxx>
+#include <controller/SlideSorterController.hxx>
+#include <controller/SlsProperties.hxx>
+#include <controller/SlsPageSelector.hxx>
+#include <controller/SlsCurrentSlideManager.hxx>
+#include <controller/SlsSlotManager.hxx>
+#include <view/SlideSorterView.hxx>
 #include <com/sun/star/drawing/XDrawPagesSupplier.hpp>
 #include <com/sun/star/drawing/XMasterPagesSupplier.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/beans/UnknownPropertyException.hpp>
 
-#include "ViewShellBase.hxx"
-#include "DrawViewShell.hxx"
-#include "DrawDocShell.hxx"
-#include "drawdoc.hxx"
-#include "sdpage.hxx"
-#include "FrameView.hxx"
+#include <ViewShellBase.hxx>
+#include <DrawViewShell.hxx>
+#include <DrawDocShell.hxx>
+#include <drawdoc.hxx>
+#include <sdpage.hxx>
+#include <FrameView.hxx>
 
 #include <tools/diagnose_ex.h>
 
@@ -78,19 +78,19 @@ namespace {
             if ( ! pDescriptor)
             {
                 PrintModel(rModel);
-                OSL_ASSERT(pDescriptor);
+                assert(pDescriptor);
                 return false;
             }
             if (nIndex != pDescriptor->GetPageIndex())
             {
                 PrintModel(rModel);
-                OSL_ASSERT(nIndex == pDescriptor->GetPageIndex());
+                assert(nIndex == pDescriptor->GetPageIndex());
                 return false;
             }
             if (nIndex != pDescriptor->GetVisualState().mnPageId)
             {
                 PrintModel(rModel);
-                OSL_ASSERT(nIndex == pDescriptor->GetVisualState().mnPageId);
+                assert(nIndex == pDescriptor->GetVisualState().mnPageId);
                 return false;
             }
         }
@@ -103,8 +103,7 @@ SlideSorterModel::SlideSorterModel (SlideSorter& rSlideSorter)
     : maMutex(),
       mrSlideSorter(rSlideSorter),
       mxSlides(),
-      mePageKind(PK_STANDARD),
-      meEditMode(EM_PAGE),
+      meEditMode(EditMode::Page),
       maPageDescriptors(0)
 {
 }
@@ -279,7 +278,7 @@ void SlideSorterModel::Resync()
     // Check if document and this model really differ.
     bool bIsUpToDate (true);
     SdDrawDocument* pDocument = GetDocument();
-    if (pDocument!=nullptr && maPageDescriptors.size()==pDocument->GetSdPageCount(mePageKind))
+    if (pDocument!=nullptr && maPageDescriptors.size()==pDocument->GetSdPageCount(PageKind::Standard))
     {
         for (sal_Int32 nIndex=0,nCount=maPageDescriptors.size(); nIndex<nCount; ++nIndex)
         {
@@ -296,7 +295,6 @@ void SlideSorterModel::Resync()
     else
     {
         bIsUpToDate = false;
-        OSL_TRACE("models differ");
     }
 
     if ( ! bIsUpToDate)
@@ -440,7 +438,7 @@ void SlideSorterModel::UpdatePageList()
     {
         switch (meEditMode)
         {
-            case EM_MASTERPAGE:
+            case EditMode::MasterPage:
             {
                 Reference<drawing::XMasterPagesSupplier> xSupplier (
                     xController->getModel(), UNO_QUERY);
@@ -451,7 +449,7 @@ void SlideSorterModel::UpdatePageList()
             }
             break;
 
-            case EM_PAGE:
+            case EditMode::Page:
             {
                 Reference<drawing::XDrawPagesSupplier> xSupplier (
                     xController->getModel(), UNO_QUERY);
@@ -464,7 +462,7 @@ void SlideSorterModel::UpdatePageList()
 
             default:
                 // We should never get here.
-                OSL_ASSERT(false);
+                assert(false);
                 break;
         }
     }
@@ -528,23 +526,25 @@ bool SlideSorterModel::NotifyPageEvent (const SdrPage* pSdrPage)
 
     // We are only interested in pages that are currently served by this
     // model.
-    if (pPage->GetPageKind() != mePageKind)
+    if (pPage->GetPageKind() != PageKind::Standard)
         return false;
-    if (pPage->IsMasterPage() != (meEditMode==EM_MASTERPAGE))
+    if (pPage->IsMasterPage() != (meEditMode==EditMode::MasterPage))
         return false;
 
     //NotifyPageEvent is called for add, remove, *and* change position so for
     //the change position case we must ensure we don't end up with the slide
     //duplicated in our list
-    DeleteSlide(pPage);
+    bool bSelected = DeleteSlide(pPage);
     if (pPage->IsInserted())
-        InsertSlide(pPage);
+    {
+        InsertSlide(pPage, bSelected);
+    }
     CheckModel(*this);
 
     return true;
 }
 
-void SlideSorterModel::InsertSlide (SdPage* pPage)
+void SlideSorterModel::InsertSlide(SdPage* pPage, bool bMarkSelected)
 {
     // Find the index at which to insert the given page.
     sal_uInt16 nCoreIndex (pPage->GetPageNum());
@@ -561,19 +561,24 @@ void SlideSorterModel::InsertSlide (SdPage* pPage)
         if (GetPage(nIndex+1) != GetPageDescriptor(nIndex)->GetPage())
             return;
 
+    auto iter = maPageDescriptors.begin() + nIndex;
+
     // Insert the given page at index nIndex
-    maPageDescriptors.insert(
-        maPageDescriptors.begin()+nIndex,
+    iter = maPageDescriptors.insert(
+        iter,
         std::make_shared<PageDescriptor>(
                 Reference<drawing::XDrawPage>(mxSlides->getByIndex(nIndex),UNO_QUERY),
                 pPage,
                 nIndex));
 
+    if (bMarkSelected)
+        (*iter)->SetState(PageDescriptor::ST_Selected, true);
+
     // Update page indices.
     UpdateIndices(nIndex+1);
 }
 
-void SlideSorterModel::DeleteSlide (const SdPage* pPage)
+bool SlideSorterModel::DeleteSlide (const SdPage* pPage)
 {
     sal_Int32 nIndex(0);
 
@@ -596,15 +601,21 @@ void SlideSorterModel::DeleteSlide (const SdPage* pPage)
         }
     }
 
+    bool bMarkedSelected(false);
+
     if(nIndex >= 0 && nIndex < static_cast<sal_Int32>(maPageDescriptors.size()))
     {
         if (maPageDescriptors[nIndex])
             if (maPageDescriptors[nIndex]->GetPage() != pPage)
-                return;
+                return false;
 
-        maPageDescriptors.erase(maPageDescriptors.begin()+nIndex);
+        auto iter = maPageDescriptors.begin() + nIndex;
+        bMarkedSelected = (*iter)->HasState(PageDescriptor::ST_Selected);
+        maPageDescriptors.erase(iter);
         UpdateIndices(nIndex);
     }
+
+    return bMarkedSelected;
 }
 
 void SlideSorterModel::UpdateIndices (const sal_Int32 nFirstIndex)
@@ -620,7 +631,7 @@ void SlideSorterModel::UpdateIndices (const sal_Int32 nFirstIndex)
             {
                 if (rpDescriptor->GetPageIndex()!=nDescriptorIndex)
                 {
-                    OSL_ASSERT(rpDescriptor->GetPageIndex()==nDescriptorIndex);
+                    assert(rpDescriptor->GetPageIndex()==nDescriptorIndex);
                 }
             }
             else
@@ -636,10 +647,10 @@ SdPage* SlideSorterModel::GetPage (const sal_Int32 nSdIndex) const
     SdDrawDocument* pModel = const_cast<SlideSorterModel*>(this)->GetDocument();
     if (pModel != nullptr)
     {
-        if (meEditMode == EM_PAGE)
-            return pModel->GetSdPage ((sal_uInt16)nSdIndex, mePageKind);
+        if (meEditMode == EditMode::Page)
+            return pModel->GetSdPage ((sal_uInt16)nSdIndex, PageKind::Standard);
         else
-            return pModel->GetMasterSdPage ((sal_uInt16)nSdIndex, mePageKind);
+            return pModel->GetMasterSdPage ((sal_uInt16)nSdIndex, PageKind::Standard);
     }
     else
         return nullptr;
