@@ -17,10 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "view/SlsLayouter.hxx"
-#include "model/SlideSorterModel.hxx"
-#include "model/SlsPageDescriptor.hxx"
-#include "Window.hxx"
+#include <view/SlsLayouter.hxx>
+#include <model/SlideSorterModel.hxx>
+#include <model/SlsPageDescriptor.hxx>
+#include <Window.hxx>
 #include <rtl/math.hxx>
 #include <basegfx/numeric/ftools.hxx>
 
@@ -30,10 +30,10 @@ class Layouter::Implementation
 {
 public:
     VclPtr<sd::Window> mpWindow;
-    sal_Int32 mnRequestedLeftBorder;
-    sal_Int32 mnRequestedRightBorder;
-    sal_Int32 mnRequestedTopBorder;
-    sal_Int32 mnRequestedBottomBorder;
+    static const sal_Int32 mnRequestedLeftBorder = 5;
+    static const sal_Int32 mnRequestedRightBorder = 5;
+    static const sal_Int32 mnRequestedTopBorder = 5;
+    static const sal_Int32 mnRequestedBottomBorder = 5;
     sal_Int32 mnLeftBorder;
     sal_Int32 mnRightBorder;
     sal_Int32 mnTopBorder;
@@ -103,7 +103,7 @@ public:
     sal_Int32 GetRowAtPosition (
         sal_Int32 nYPosition,
         bool bIncludeBordersAndGaps,
-        GapMembership eGapMembership = GM_NONE) const;
+        GapMembership eGapMembership) const;
 
     /** Calculate the column that the point with the given horizontal
         coordinate is over.  The vertical component is ignored.
@@ -118,7 +118,7 @@ public:
     sal_Int32 GetColumnAtPosition (
         sal_Int32 nXPosition,
         bool bIncludeBordersAndGaps,
-        GapMembership eGapMembership = GM_NONE) const;
+        GapMembership eGapMembership) const;
 
     /** This method is typically called from GetRowAtPosition() and
         GetColumnAtPosition() to handle a position that lies inside the gap
@@ -163,38 +163,38 @@ public:
         InsertPosition& rPosition,
         const Size& rIndicatorSize,
         const bool bIsVertical,
-        model::SlideSorterModel& rModel) const;
+        model::SlideSorterModel const & rModel) const;
 
     /** Return the bounding box of the preview or, when selected, of the page
         object.  Thus, it returns something like a visual bounding box.
     */
-    Rectangle GetInnerBoundingBox (
-        model::SlideSorterModel& rModel,
+    ::tools::Rectangle GetInnerBoundingBox (
+        model::SlideSorterModel const & rModel,
         const sal_Int32 nIndex) const;
 
     Range GetValidHorizontalSizeRange() const;
     Range GetValidVerticalSizeRange() const;
 
-    Range GetRangeOfVisiblePageObjects (const Rectangle& aVisibleArea) const;
+    Range GetRangeOfVisiblePageObjects (const ::tools::Rectangle& aVisibleArea) const;
     sal_Int32 GetIndex (
         const sal_Int32 nRow,
         const sal_Int32 nColumn,
         const bool bClampToValidRange) const;
 
-        Rectangle GetPageObjectBox (
+        ::tools::Rectangle GetPageObjectBox (
         const sal_Int32 nIndex,
         const bool bIncludeBorderAndGap = false) const;
 
-    Rectangle GetPageObjectBox (
+    ::tools::Rectangle GetPageObjectBox (
         const sal_Int32 nRow,
         const sal_Int32 nColumn) const;
 
-    Rectangle AddBorderAndGap (
-        const Rectangle& rBoundingBox,
+    ::tools::Rectangle AddBorderAndGap (
+        const ::tools::Rectangle& rBoundingBox,
         const sal_Int32 nRow,
         const sal_Int32 nColumn) const;
 
-    Rectangle GetTotalBoundingBox() const;
+    ::tools::Rectangle GetTotalBoundingBox() const;
 
     virtual ~Implementation();
 
@@ -207,11 +207,9 @@ protected:
     virtual void CalculateRowAndColumnCount (const Size& rWindowSize) = 0;
     virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize) = 0;
     virtual Size CalculateTargetSize (
-        const Size& rWindowSize,
-        const Size& rPreviewModelSize) const = 0;
+        const Size& rWindowSize) const = 0;
     Size GetTargetSize (
         const Size& rWindowSize,
-        const Size& rPreviewModelSize,
         const bool bCalculateWidth,
         const bool bCalculateHeight) const;
     void CalculateVerticalLogicalInsertPosition (
@@ -237,8 +235,7 @@ protected:
     virtual void CalculateRowAndColumnCount (const Size& rWindowSize) override;
     virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize) override;
     virtual Size CalculateTargetSize (
-        const Size& rWindowSize,
-        const Size& rPreviewModelSize) const override;
+        const Size& rWindowSize) const override;
 };
 
 /** The horizontal layouter has one row and as many columns as there are
@@ -259,8 +256,7 @@ protected:
     virtual void CalculateRowAndColumnCount (const Size& rWindowSize) override;
     virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize) override;
     virtual Size CalculateTargetSize (
-        const Size& rWindowSize,
-        const Size& rPreviewModelSize) const override;
+        const Size& rWindowSize) const override;
 };
 
 /** The number of columns of the grid layouter is defined via a control in
@@ -285,8 +281,7 @@ protected:
     virtual void CalculateRowAndColumnCount (const Size& rWindowSize) override;
     virtual void CalculateMaxRowAndColumnCount (const Size& rWindowSize) override;
     virtual Size CalculateTargetSize (
-        const Size& rWindowSize,
-        const Size& rPreviewModelSize) const override;
+        const Size& rWindowSize) const override;
 };
 
 //===== Layouter ==============================================================
@@ -348,14 +343,14 @@ Size Layouter::GetPageObjectSize() const
     return mpImplementation->maPageObjectSize;
 }
 
-Rectangle Layouter::GetPageObjectBox (
+::tools::Rectangle Layouter::GetPageObjectBox (
     const sal_Int32 nIndex,
     const bool bIncludeBorderAndGap) const
 {
     return mpImplementation->GetPageObjectBox(nIndex, bIncludeBorderAndGap);
 }
 
-Rectangle Layouter::GetTotalBoundingBox() const
+::tools::Rectangle Layouter::GetTotalBoundingBox() const
 {
     return mpImplementation->GetTotalBoundingBox();
 }
@@ -363,7 +358,7 @@ Rectangle Layouter::GetTotalBoundingBox() const
 InsertPosition Layouter::GetInsertPosition (
     const Point& rModelPosition,
     const Size& rIndicatorSize,
-    model::SlideSorterModel& rModel) const
+    model::SlideSorterModel const & rModel) const
 {
     InsertPosition aPosition;
     mpImplementation->CalculateLogicalInsertPosition(
@@ -387,7 +382,7 @@ Range Layouter::GetValidVerticalSizeRange() const
     return mpImplementation->GetValidVerticalSizeRange();
 }
 
-Range Layouter::GetRangeOfVisiblePageObjects (const Rectangle& aVisibleArea) const
+Range Layouter::GetRangeOfVisiblePageObjects (const ::tools::Rectangle& aVisibleArea) const
 {
     return mpImplementation->GetRangeOfVisiblePageObjects(aVisibleArea);
 }
@@ -430,10 +425,6 @@ Layouter::Implementation::Implementation (
     sd::Window *pWindow,
     const std::shared_ptr<view::Theme>& rpTheme)
     : mpWindow(pWindow),
-      mnRequestedLeftBorder(5),
-      mnRequestedRightBorder(5),
-      mnRequestedTopBorder(5),
-      mnRequestedBottomBorder(5),
       mnLeftBorder(5),
       mnRightBorder(5),
       mnTopBorder(5),
@@ -458,10 +449,6 @@ Layouter::Implementation::Implementation (
 
 Layouter::Implementation::Implementation (const Implementation& rImplementation)
     : mpWindow(rImplementation.mpWindow),
-      mnRequestedLeftBorder(rImplementation.mnRequestedLeftBorder),
-      mnRequestedRightBorder(rImplementation.mnRequestedRightBorder),
-      mnRequestedTopBorder(rImplementation.mnRequestedTopBorder),
-      mnRequestedBottomBorder(rImplementation.mnRequestedBottomBorder),
       mnLeftBorder(rImplementation.mnLeftBorder),
       mnRightBorder(rImplementation.mnRightBorder),
       mnTopBorder(rImplementation.mnTopBorder),
@@ -527,13 +514,12 @@ bool Layouter::Implementation::Rearrange (
 
     mpPageObjectLayouter.reset(
         new PageObjectLayouter(
-            CalculateTargetSize(rWindowSize, rPreviewModelSize),
+            CalculateTargetSize(rWindowSize),
             rPreviewModelSize,
             mpWindow,
             mnPageCount));
 
-    maPageObjectSize = mpPageObjectLayouter->GetGridMaxSize(
-        PageObjectLayouter::WindowCoordinateSystem);
+    maPageObjectSize = mpPageObjectLayouter->GetGridMaxSize();
 
     CalculateMaxRowAndColumnCount(rWindowSize);
 
@@ -682,7 +668,7 @@ void Layouter::Implementation::CalculateGeometricPosition (
     InsertPosition& rPosition,
     const Size& rIndicatorSize,
     const bool bIsVertical,
-    model::SlideSorterModel& rModel) const
+    model::SlideSorterModel const & rModel) const
 {
     // 1. Determine right/bottom of the leading page and the left/top of the
     // trailing page object and how to distribute the missing space.
@@ -696,8 +682,8 @@ void Layouter::Implementation::CalculateGeometricPosition (
     if (rPosition.IsAtRunStart())
     {
         // Place indicator at the top of the column.
-        const Rectangle aOuterBox (GetPageObjectBox(nIndex));
-        const Rectangle aInnerBox (GetInnerBoundingBox(rModel, nIndex));
+        const ::tools::Rectangle aOuterBox (GetPageObjectBox(nIndex));
+        const ::tools::Rectangle aInnerBox (GetInnerBoundingBox(rModel, nIndex));
         if (bIsVertical)
         {
             nLeadingLocation = aOuterBox.Top();
@@ -716,8 +702,8 @@ void Layouter::Implementation::CalculateGeometricPosition (
     {
         // Place indicator at the bottom/right of the column/row.
 
-        const Rectangle aOuterBox (GetPageObjectBox(nIndex-1));
-        const Rectangle aInnerBox (GetInnerBoundingBox(rModel, nIndex-1));
+        const ::tools::Rectangle aOuterBox (GetPageObjectBox(nIndex-1));
+        const ::tools::Rectangle aInnerBox (GetInnerBoundingBox(rModel, nIndex-1));
         if (bIsVertical)
         {
             nLeadingLocation = aInnerBox.Bottom();
@@ -737,8 +723,8 @@ void Layouter::Implementation::CalculateGeometricPosition (
     else
     {
         // Place indicator between two rows/columns.
-        const Rectangle aBox1 (GetInnerBoundingBox(rModel, nIndex-1));
-        const Rectangle aBox2 (GetInnerBoundingBox(rModel, nIndex));
+        const ::tools::Rectangle aBox1 (GetInnerBoundingBox(rModel, nIndex-1));
+        const ::tools::Rectangle aBox2 (GetInnerBoundingBox(rModel, nIndex));
         if (bIsVertical)
         {
             nLeadingLocation = aBox1.Bottom();
@@ -795,18 +781,18 @@ void Layouter::Implementation::CalculateGeometricPosition (
     }
 }
 
-Rectangle Layouter::Implementation::GetInnerBoundingBox (
-    model::SlideSorterModel& rModel,
+::tools::Rectangle Layouter::Implementation::GetInnerBoundingBox (
+    model::SlideSorterModel const & rModel,
     const sal_Int32 nIndex) const
 {
     model::SharedPageDescriptor pDescriptor (rModel.GetPageDescriptor(nIndex));
     if ( ! pDescriptor)
-        return Rectangle();
+        return ::tools::Rectangle();
 
-    PageObjectLayouter::Part ePart = PageObjectLayouter::Preview;
+    PageObjectLayouter::Part ePart = PageObjectLayouter::Part::Preview;
 
     if (pDescriptor->HasState(model::PageDescriptor::ST_Selected))
-        ePart = PageObjectLayouter::PageObject;
+        ePart = PageObjectLayouter::Part::PageObject;
 
     return mpPageObjectLayouter->GetBoundingBox(
             pDescriptor, ePart,
@@ -827,7 +813,7 @@ Range Layouter::Implementation::GetValidVerticalSizeRange() const
         mnTopBorder + maMaximalSize.Height() + mnBottomBorder);
 }
 
-Range Layouter::Implementation::GetRangeOfVisiblePageObjects (const Rectangle& aVisibleArea) const
+Range Layouter::Implementation::GetRangeOfVisiblePageObjects (const ::tools::Rectangle& aVisibleArea) const
 {
     const sal_Int32 nRow0 (GetRowAtPosition(aVisibleArea.Top(), true, GM_NEXT));
     const sal_Int32 nCol0 (GetColumnAtPosition(aVisibleArea.Left(),true, GM_NEXT));
@@ -841,12 +827,9 @@ Range Layouter::Implementation::GetRangeOfVisiblePageObjects (const Rectangle& a
 
 Size Layouter::Implementation::GetTargetSize (
     const Size& rWindowSize,
-    const Size& rPreviewModelSize,
     const bool bCalculateWidth,
     const bool bCalculateHeight) const
 {
-    (void)rPreviewModelSize;
-
     if (mnColumnCount<=0 || mnRowCount<=0)
         return maPreferredSize;
     if ( ! (bCalculateWidth || bCalculateHeight))
@@ -908,25 +891,25 @@ sal_Int32 Layouter::Implementation::GetIndex (
         return -1;
 }
 
-Rectangle Layouter::Implementation::GetPageObjectBox (
+::tools::Rectangle Layouter::Implementation::GetPageObjectBox (
     const sal_Int32 nIndex,
     const bool bIncludeBorderAndGap) const
 {
     const sal_Int32 nRow (nIndex / mnColumnCount);
     const sal_Int32 nColumn (nIndex % mnColumnCount);
 
-    const Rectangle aBoundingBox (GetPageObjectBox(nRow,nColumn));
+    const ::tools::Rectangle aBoundingBox (GetPageObjectBox(nRow,nColumn));
     if (bIncludeBorderAndGap)
         return AddBorderAndGap(aBoundingBox, nRow, nColumn);
     else
         return aBoundingBox;
 }
 
-Rectangle Layouter::Implementation::GetPageObjectBox (
+::tools::Rectangle Layouter::Implementation::GetPageObjectBox (
     const sal_Int32 nRow,
     const sal_Int32 nColumn) const
 {
-    return Rectangle(
+    return ::tools::Rectangle(
         Point (mnLeftBorder
             + nColumn * maPageObjectSize.Width()
             + (nColumn>0 ? nColumn : 0) * mnHorizontalGap,
@@ -936,12 +919,12 @@ Rectangle Layouter::Implementation::GetPageObjectBox (
         maPageObjectSize);
 }
 
-Rectangle Layouter::Implementation::AddBorderAndGap (
-    const Rectangle& rBoundingBox,
+::tools::Rectangle Layouter::Implementation::AddBorderAndGap (
+    const ::tools::Rectangle& rBoundingBox,
     const sal_Int32 nRow,
     const sal_Int32 nColumn) const
 {
-    Rectangle aBoundingBox (rBoundingBox);
+    ::tools::Rectangle aBoundingBox (rBoundingBox);
 
     if (nColumn == 0)
         aBoundingBox.Left() = 0;
@@ -962,7 +945,7 @@ Rectangle Layouter::Implementation::AddBorderAndGap (
     return aBoundingBox;
 }
 
-Rectangle Layouter::Implementation::GetTotalBoundingBox() const
+::tools::Rectangle Layouter::Implementation::GetTotalBoundingBox() const
 {
     sal_Int32 nHorizontalSize = 0;
     sal_Int32 nVerticalSize = 0;
@@ -983,7 +966,7 @@ Rectangle Layouter::Implementation::GetTotalBoundingBox() const
             nVerticalSize += (nRowCount-1) * mnVerticalGap;
     }
 
-    return Rectangle (
+    return ::tools::Rectangle (
         Point(0,0),
         Size (nHorizontalSize, nVerticalSize)
         );
@@ -1017,10 +1000,8 @@ Layouter::Orientation HorizontalImplementation::GetOrientation() const
     return Layouter::HORIZONTAL;
 }
 
-void HorizontalImplementation::CalculateRowAndColumnCount (const Size& rWindowSize)
+void HorizontalImplementation::CalculateRowAndColumnCount (const Size&)
 {
-    (void)rWindowSize;
-
     // Row and column count are fixed (for a given page count.)
     mnColumnCount = mnPageCount;
     mnRowCount = 1;
@@ -1034,10 +1015,9 @@ void HorizontalImplementation::CalculateMaxRowAndColumnCount (const Size& rWindo
 }
 
 Size HorizontalImplementation::CalculateTargetSize (
-    const Size& rWindowSize,
-    const Size& rPreviewModelSize) const
+    const Size& rWindowSize) const
 {
-    return Implementation::GetTargetSize(rWindowSize, rPreviewModelSize, false, true);
+    return Implementation::GetTargetSize(rWindowSize, false, true);
 }
 
 void HorizontalImplementation::CalculateLogicalInsertPosition (
@@ -1068,10 +1048,8 @@ Layouter::Orientation VerticalImplementation::GetOrientation() const
     return Layouter::VERTICAL;
 }
 
-void VerticalImplementation::CalculateRowAndColumnCount (const Size& rWindowSize)
+void VerticalImplementation::CalculateRowAndColumnCount (const Size&)
 {
-    (void)rWindowSize;
-
     // Row and column count are fixed (for a given page count.)
     mnRowCount = mnPageCount;
     mnColumnCount = 1;
@@ -1086,10 +1064,9 @@ void VerticalImplementation::CalculateMaxRowAndColumnCount (const Size& rWindowS
 }
 
 Size VerticalImplementation::CalculateTargetSize (
-    const Size& rWindowSize,
-    const Size& rPreviewModelSize) const
+    const Size& rWindowSize) const
 {
-    return Implementation::GetTargetSize(rWindowSize, rPreviewModelSize, true, false);
+    return Implementation::GetTargetSize(rWindowSize, true, false);
 }
 
 void VerticalImplementation::CalculateLogicalInsertPosition (
@@ -1140,10 +1117,9 @@ void GridImplementation::CalculateMaxRowAndColumnCount (const Size& rWindowSize)
 }
 
 Size GridImplementation::CalculateTargetSize (
-    const Size& rWindowSize,
-    const Size& rPreviewModelSize) const
+    const Size& rWindowSize) const
 {
-    return Implementation::GetTargetSize(rWindowSize, rPreviewModelSize, true, true);
+    return Implementation::GetTargetSize(rWindowSize, true, true);
 }
 
 void GridImplementation::CalculateLogicalInsertPosition (
