@@ -17,15 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <view/SlsPageObjectLayouter.hxx>
 
-#include "view/SlsPageObjectLayouter.hxx"
+#include <model/SlsPageDescriptor.hxx>
+#include <view/SlsFontProvider.hxx>
+#include <view/SlsTheme.hxx>
+#include <tools/IconCache.hxx>
+#include <Window.hxx>
 
-#include "model/SlsPageDescriptor.hxx"
-#include "view/SlsFontProvider.hxx"
-#include "view/SlsTheme.hxx"
-#include "tools/IconCache.hxx"
-#include "Window.hxx"
-#include "res_bmp.hrc"
+#include <bitmaps.hlst>
 
 namespace sd { namespace slidesorter { namespace view {
 
@@ -39,9 +39,9 @@ const static sal_Int32 gnInfoAreaMinWidth = 26;
 PageObjectLayouter::PageObjectLayouter (
     const Size& rPageObjectWindowSize,
     const Size& rPageSize,
-    const SharedSdWindow& rpWindow,
+    sd::Window *pWindow,
     const sal_Int32 nPageCount)
-    : mpWindow(rpWindow),
+    : mpWindow(pWindow),
       maPageObjectSize(rPageObjectWindowSize.Width(), rPageObjectWindowSize.Height()),
       maPageObjectBoundingBox(),
       maPageNumberAreaBoundingBox(),
@@ -49,7 +49,7 @@ PageObjectLayouter::PageObjectLayouter (
       maTransitionEffectBoundingBox(),
       maTransitionEffectIcon(IconCache::Instance().GetIcon(BMP_FADE_EFFECT_INDICATOR)),
       maCustomAnimationEffectIcon(IconCache::Instance().GetIcon(BMP_CUSTOM_ANIMATION_INDICATOR)),
-      mpPageNumberFont(Theme::GetFont(Theme::Font_PageNumber, *rpWindow))
+      mpPageNumberFont(Theme::GetFont(Theme::Font_PageNumber, *pWindow))
 {
     const Size aPageNumberAreaSize (GetPageNumberAreaSize(nPageCount));
 
@@ -61,8 +61,8 @@ PageObjectLayouter::PageObjectLayouter (
         Size(rPageSize.Width(), rPageSize.Height()),
         aPageNumberAreaSize.Width(),
         nFocusIndicatorWidth);
-    maFocusIndicatorBoundingBox = Rectangle(Point(0,0), maPageObjectSize);
-    maPageObjectBoundingBox = Rectangle(
+    maFocusIndicatorBoundingBox = ::tools::Rectangle(Point(0,0), maPageObjectSize);
+    maPageObjectBoundingBox = ::tools::Rectangle(
         Point(
             nFocusIndicatorWidth,
             nFocusIndicatorWidth),
@@ -70,7 +70,7 @@ PageObjectLayouter::PageObjectLayouter (
             maPageObjectSize.Width()-2*nFocusIndicatorWidth,
             maPageObjectSize.Height()-2*nFocusIndicatorWidth));
 
-    maPageNumberAreaBoundingBox = Rectangle(
+    maPageNumberAreaBoundingBox = ::tools::Rectangle(
         Point(
             std::max(gnLeftPageNumberOffset,
                 sal_Int32(maPreviewBoundingBox.Left()
@@ -80,29 +80,23 @@ PageObjectLayouter::PageObjectLayouter (
         aPageNumberAreaSize);
 
     const Size aIconSize (maTransitionEffectIcon.GetSizePixel());
-    maTransitionEffectBoundingBox = Rectangle(
+    maTransitionEffectBoundingBox = ::tools::Rectangle(
         Point(
             (maPreviewBoundingBox.Left() - 2*aIconSize.Width()) / 2,
             maPreviewBoundingBox.Bottom() - aIconSize.Height()),
         aIconSize);
-    maCustomAnimationEffectBoundingBox = Rectangle(
+    maCustomAnimationEffectBoundingBox = ::tools::Rectangle(
         Point(
             (maPreviewBoundingBox.Left() - 2*aIconSize.Width()) / 2,
             maPreviewBoundingBox.Bottom() - 2*aIconSize.Height()),
         aIconSize);
 }
 
-
-
-
-PageObjectLayouter::~PageObjectLayouter(void)
+PageObjectLayouter::~PageObjectLayouter()
 {
 }
 
-
-
-
-Rectangle PageObjectLayouter::CalculatePreviewBoundingBox (
+::tools::Rectangle PageObjectLayouter::CalculatePreviewBoundingBox (
     Size& rPageObjectSize,
     const Size& rPageSize,
     const sal_Int32 nPageNumberAreaWidth,
@@ -158,62 +152,54 @@ Rectangle PageObjectLayouter::CalculatePreviewBoundingBox (
     const int nLeft (rPageObjectSize.Width()
         - gnOuterBorderWidth - nPreviewWidth - nFocusIndicatorWidth - 1);
     const int nTop ((rPageObjectSize.Height() - nPreviewHeight)/2);
-    return Rectangle(
+    return ::tools::Rectangle(
         nLeft,
         nTop,
         nLeft + nPreviewWidth,
         nTop + nPreviewHeight);
 }
 
-
-
-
-Rectangle PageObjectLayouter::GetBoundingBox (
+::tools::Rectangle PageObjectLayouter::GetBoundingBox (
     const model::SharedPageDescriptor& rpPageDescriptor,
     const Part ePart,
-    const CoordinateSystem eCoordinateSystem)
+    const CoordinateSystem eCoordinateSystem,
+    bool bIgnoreLocation)
 {
     OSL_ASSERT(rpPageDescriptor);
-    Point aLocation (rpPageDescriptor ? rpPageDescriptor->GetLocation() : Point(0,0));
+    Point aLocation(0,0);
+    if (rpPageDescriptor)
+        aLocation = rpPageDescriptor->GetLocation( bIgnoreLocation );
     return GetBoundingBox(aLocation, ePart, eCoordinateSystem);
 }
 
-
-
-
-Rectangle PageObjectLayouter::GetBoundingBox (
+::tools::Rectangle PageObjectLayouter::GetBoundingBox (
     const Point& rPageObjectLocation,
     const Part ePart,
     const CoordinateSystem eCoordinateSystem)
 {
-    Rectangle aBoundingBox;
+    ::tools::Rectangle aBoundingBox;
     switch (ePart)
     {
-        case FocusIndicator:
+        case Part::FocusIndicator:
             aBoundingBox = maFocusIndicatorBoundingBox;
             break;
 
-        case PageObject:
-        case MouseOverIndicator:
+        case Part::PageObject:
             aBoundingBox = maPageObjectBoundingBox;
             break;
 
-        case Preview:
+        case Part::Preview:
             aBoundingBox = maPreviewBoundingBox;
             break;
 
-        case PageNumber:
+        case Part::PageNumber:
             aBoundingBox = maPageNumberAreaBoundingBox;
             break;
 
-        case Name:
-            aBoundingBox = maPageNumberAreaBoundingBox;
-            break;
-
-        case TransitionEffectIndicator:
+        case Part::TransitionEffectIndicator:
             aBoundingBox = maTransitionEffectBoundingBox;
             break;
-        case CustomAnimationEffectIndicator:
+        case Part::CustomAnimationEffectIndicator:
             aBoundingBox = maCustomAnimationEffectBoundingBox;
             break;
     }
@@ -223,30 +209,29 @@ Rectangle PageObjectLayouter::GetBoundingBox (
     if (eCoordinateSystem == WindowCoordinateSystem)
         aLocation += mpWindow->GetMapMode().GetOrigin();
 
-    return Rectangle(
+    return ::tools::Rectangle(
         aBoundingBox.TopLeft() + aLocation,
         aBoundingBox.BottomRight() + aLocation);
 }
 
-
-
-
-Size PageObjectLayouter::GetSize (
-    const Part ePart,
-    const CoordinateSystem eCoordinateSystem)
+Size PageObjectLayouter::GetPreviewSize ()
 {
-    return GetBoundingBox(Point(0,0), ePart, eCoordinateSystem).GetSize();
+    return GetBoundingBox(Point(0,0), PageObjectLayouter::Part::Preview,
+                          WindowCoordinateSystem).GetSize();
 }
 
-
-
+Size PageObjectLayouter::GetGridMaxSize()
+{
+    return GetBoundingBox(Point(0,0), PageObjectLayouter::Part::FocusIndicator,
+                          WindowCoordinateSystem).GetSize();
+}
 
 Size PageObjectLayouter::GetPageNumberAreaSize (const int nPageCount)
 {
     OSL_ASSERT(mpWindow);
 
     // Set the correct font.
-    Font aOriginalFont (mpWindow->GetFont());
+    vcl::Font aOriginalFont (mpWindow->GetFont());
     if (mpPageNumberFont)
         mpWindow->SetFont(*mpPageNumberFont);
 
@@ -273,20 +258,6 @@ Size PageObjectLayouter::GetPageNumberAreaSize (const int nPageCount)
     return aSize;
 }
 
-
-
-
-Image PageObjectLayouter::GetTransitionEffectIcon (void) const
-{
-    return maTransitionEffectIcon;
-}
-
-Image PageObjectLayouter::GetCustomAnimationEffectIcon (void) const
-{
-    return maCustomAnimationEffectIcon;
-}
-
-
 } } } // end of namespace ::sd::slidesorter::view
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
