@@ -17,11 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "tools/IdleDetection.hxx"
+#include <tools/IdleDetection.hxx>
 
-#include "ViewShell.hxx"
-#include "slideshow.hxx"
-#include "ViewShellBase.hxx"
+#include <ViewShell.hxx>
+#include <slideshow.hxx>
+#include <ViewShellBase.hxx>
 
 #include <vcl/window.hxx>
 #include <sfx2/viewfrm.hxx>
@@ -33,31 +33,29 @@ using namespace ::com::sun::star;
 
 namespace sd { namespace tools {
 
-sal_Int32 IdleDetection::GetIdleState (const vcl::Window* pWindow)
+IdleState IdleDetection::GetIdleState (const vcl::Window* pWindow)
 {
-    sal_Int32 nResult (CheckInputPending() | CheckSlideShowRunning());
+    IdleState nResult (CheckInputPending() | CheckSlideShowRunning());
     if (pWindow != nullptr)
         nResult |= CheckWindowPainting(*pWindow);
     return nResult;
 }
 
-sal_Int32 IdleDetection::CheckInputPending()
+IdleState IdleDetection::CheckInputPending()
 {
     if (Application::AnyInput(VclInputFlags::MOUSE | VclInputFlags::KEYBOARD | VclInputFlags::PAINT))
-        return IDET_SYSTEM_EVENT_PENDING;
+        return IdleState::SystemEventPending;
     else
-        return IDET_IDLE;
+        return IdleState::Idle;
 }
 
-sal_Int32 IdleDetection::CheckSlideShowRunning()
+IdleState IdleDetection::CheckSlideShowRunning()
 {
-    sal_Int32 eResult (IDET_IDLE);
-
-    bool bIsSlideShowShowing = false;
+    IdleState eResult (IdleState::Idle);
 
     // Iterate over all view frames.
     for (SfxViewFrame* pViewFrame = SfxViewFrame::GetFirst();
-         pViewFrame!=nullptr && !bIsSlideShowShowing;
+         pViewFrame!=nullptr;
          pViewFrame = SfxViewFrame::GetNext(*pViewFrame))
     {
         // Ignore the current frame when it does not exist, is not valid, or
@@ -83,9 +81,9 @@ sal_Int32 IdleDetection::CheckSlideShowRunning()
             if( xSlideShow.is() && xSlideShow->isRunning() )
             {
                 if (xSlideShow->isFullScreen())
-                    eResult |= IDET_FULL_SCREEN_SHOW_ACTIVE;
+                    eResult |= IdleState::FullScreenShowActive;
                 else
-                    eResult |= IDET_WINDOW_SHOW_ACTIVE;
+                    eResult |= IdleState::WindowShowActive;
             }
         }
     }
@@ -93,12 +91,12 @@ sal_Int32 IdleDetection::CheckSlideShowRunning()
     return eResult;
 }
 
-sal_Int32 IdleDetection::CheckWindowPainting (const vcl::Window& rWindow)
+IdleState IdleDetection::CheckWindowPainting (const vcl::Window& rWindow)
 {
     if (rWindow.IsInPaint())
-        return IDET_WINDOW_PAINTING;
+        return IdleState::WindowPainting;
     else
-        return IDET_IDLE;
+        return IdleState::Idle;
 }
 
 } } // end of namespace ::sd::tools
