@@ -17,20 +17,19 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "SdUnoDrawView.hxx"
+#include <SdUnoDrawView.hxx>
 
-#include "DrawController.hxx"
-#include "DrawDocShell.hxx"
-#include "DrawViewShell.hxx"
-#include "drawdoc.hxx"
+#include <DrawController.hxx>
+#include <DrawDocShell.hxx>
+#include <DrawViewShell.hxx>
+#include <drawdoc.hxx>
 #include "unolayer.hxx"
-#include "unomodel.hxx"
-#include "unopage.hxx"
-#include "Window.hxx"
-#include "pres.hxx"
+#include <unomodel.hxx>
+#include <unopage.hxx>
+#include <Window.hxx>
+#include <pres.hxx>
 
 #include <comphelper/processfactory.hxx>
-#include <cppuhelper/proptypehlp.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/viewfrm.hxx>
@@ -65,15 +64,15 @@ SdUnoDrawView::~SdUnoDrawView() throw()
 
 bool SdUnoDrawView::getMasterPageMode() const throw()
 {
-    return (mrDrawViewShell.GetEditMode() == EM_MASTERPAGE);
+    return (mrDrawViewShell.GetEditMode() == EditMode::MasterPage);
 }
 
 void SdUnoDrawView::setMasterPageMode (bool bMasterPageMode) throw()
 {
-    if ((mrDrawViewShell.GetEditMode() == EM_MASTERPAGE) != bMasterPageMode)
+    if ((mrDrawViewShell.GetEditMode() == EditMode::MasterPage) != bMasterPageMode)
     {
         mrDrawViewShell.ChangeEditMode (
-            bMasterPageMode ? EM_MASTERPAGE : EM_PAGE,
+            bMasterPageMode ? EditMode::MasterPage : EditMode::Page,
             mrDrawViewShell.IsLayerModeActive());
     }
 }
@@ -110,7 +109,7 @@ Reference<drawing::XLayer> SdUnoDrawView::getActiveLayer() throw ()
 
         // From the model get the current SdrLayer object via the layer admin.
         SdrLayerAdmin& rLayerAdmin = pSdModel->GetLayerAdmin ();
-        SdrLayer* pLayer = rLayerAdmin.GetLayer (mrView.GetActiveLayer(), true);
+        SdrLayer* pLayer = rLayerAdmin.GetLayer (mrView.GetActiveLayer());
         if (pLayer == nullptr)
             break;
 
@@ -127,7 +126,6 @@ Reference<drawing::XLayer> SdUnoDrawView::getActiveLayer() throw ()
 }
 
 void SdUnoDrawView::setActiveLayer (const Reference<drawing::XLayer>& rxLayer)
-    throw (uno::RuntimeException, std::exception)
 {
     // Get the SdrLayer object corresponding to the given reference.
     if ( ! rxLayer.is())
@@ -149,9 +147,6 @@ void SdUnoDrawView::setActiveLayer (const Reference<drawing::XLayer>& rxLayer)
 // XSelectionSupplier
 
 sal_Bool SAL_CALL SdUnoDrawView::select( const Any& aSelection )
-    throw (lang::IllegalArgumentException,
-           RuntimeException,
-           std::exception)
 {
     bool bOk = true;
 
@@ -247,7 +242,6 @@ sal_Bool SAL_CALL SdUnoDrawView::select( const Any& aSelection )
 }
 
 Any SAL_CALL SdUnoDrawView::getSelection()
-    throw (RuntimeException, std::exception)
 {
     Any aAny;
 
@@ -295,27 +289,16 @@ Any SAL_CALL SdUnoDrawView::getSelection()
 }
 
 void SAL_CALL SdUnoDrawView::addSelectionChangeListener (
-    const css::uno::Reference<css::view::XSelectionChangeListener>& rxListener)
-    throw(css::uno::RuntimeException, std::exception)
-{
-    (void)rxListener;
-}
+    const css::uno::Reference<css::view::XSelectionChangeListener>&)
+{}
 
 void SAL_CALL SdUnoDrawView::removeSelectionChangeListener (
-    const css::uno::Reference<css::view::XSelectionChangeListener>& rxListener)
-    throw(css::uno::RuntimeException, std::exception)
-{
-    (void)rxListener;
-}
+    const css::uno::Reference<css::view::XSelectionChangeListener>&)
+{}
 
 void SdUnoDrawView::setFastPropertyValue (
     sal_Int32 nHandle,
         const Any& rValue)
-    throw(css::beans::UnknownPropertyException,
-        css::beans::PropertyVetoException,
-        css::lang::IllegalArgumentException,
-        css::lang::WrappedTargetException,
-        css::uno::RuntimeException, std::exception)
 {
     switch( nHandle )
     {
@@ -371,15 +354,12 @@ void SdUnoDrawView::setFastPropertyValue (
             }
             break;
         default:
-            throw beans::UnknownPropertyException();
+            throw beans::UnknownPropertyException( OUString::number(nHandle), static_cast<cppu::OWeakObject*>(this));
     }
 }
 
 Any SAL_CALL SdUnoDrawView::getFastPropertyValue (
     sal_Int32 nHandle)
-    throw(css::beans::UnknownPropertyException,
-        css::lang::WrappedTargetException,
-        css::uno::RuntimeException, std::exception)
 {
     Any aValue;
     switch( nHandle )
@@ -415,7 +395,7 @@ Any SAL_CALL SdUnoDrawView::getFastPropertyValue (
             break;
 
         default:
-            throw beans::UnknownPropertyException();
+            throw beans::UnknownPropertyException( OUString::number(nHandle), static_cast<cppu::OWeakObject*>(this));
     }
 
     return aValue;
@@ -425,7 +405,6 @@ Any SAL_CALL SdUnoDrawView::getFastPropertyValue (
 
 void SAL_CALL SdUnoDrawView::setCurrentPage (
     const Reference< drawing::XDrawPage >& xPage )
-    throw (RuntimeException, std::exception)
 {
     SvxDrawPage* pDrawPage = SvxDrawPage::getImplementation( xPage );
     SdrPage *pSdrPage = pDrawPage ? pDrawPage->GetSdrPage() : nullptr;
@@ -443,7 +422,6 @@ void SAL_CALL SdUnoDrawView::setCurrentPage (
 }
 
 Reference< drawing::XDrawPage > SAL_CALL SdUnoDrawView::getCurrentPage()
-    throw(RuntimeException, std::exception)
 {
     Reference< drawing::XDrawPage >  xPage;
 
@@ -478,7 +456,8 @@ void SdUnoDrawView::SetZoom( sal_Int16 nZoom )
         SfxDispatcher* pDispatcher = pViewFrame->GetDispatcher();
         if( pDispatcher )
         {
-            pDispatcher->Execute(SID_ATTR_ZOOM,SfxCallMode::SYNCHRON,&aZoomItem, 0L);
+            pDispatcher->ExecuteList(SID_ATTR_ZOOM, SfxCallMode::SYNCHRON,
+                    { &aZoomItem });
         }
     }
 }
@@ -487,7 +466,7 @@ void SdUnoDrawView::SetViewOffset(const awt::Point& rWinPos )
 {
     Point aWinPos( rWinPos.X, rWinPos.Y );
     aWinPos += mrDrawViewShell.GetViewOrigin();
-    mrDrawViewShell.SetWinViewPos( aWinPos, true );
+    mrDrawViewShell.SetWinViewPos( aWinPos );
 }
 
 awt::Point SdUnoDrawView::GetViewOffset() const
@@ -528,7 +507,8 @@ void SdUnoDrawView::SetZoomType ( sal_Int16 nType )
                     return;
             }
             SvxZoomItem aZoomItem( eZoomType );
-            pDispatcher->Execute(SID_ATTR_ZOOM,SfxCallMode::SYNCHRON,&aZoomItem, 0L);
+            pDispatcher->ExecuteList(SID_ATTR_ZOOM, SfxCallMode::SYNCHRON,
+                    { &aZoomItem });
         }
     }
 }
@@ -549,25 +529,25 @@ Any SdUnoDrawView::getDrawViewMode() const
     Any aRet;
     switch( mrDrawViewShell.GetPageKind() )
     {
-    case PK_NOTES:  aRet <<= DrawViewMode_NOTES; break;
-    case PK_HANDOUT: aRet <<= DrawViewMode_HANDOUT; break;
-    case PK_STANDARD: aRet <<= DrawViewMode_DRAW; break;
+    case PageKind::Notes:  aRet <<= DrawViewMode_NOTES; break;
+    case PageKind::Handout: aRet <<= DrawViewMode_HANDOUT; break;
+    case PageKind::Standard: aRet <<= DrawViewMode_DRAW; break;
     }
     return aRet;
 }
 
 // XServiceInfo
-OUString SAL_CALL SdUnoDrawView::getImplementationName(  ) throw (RuntimeException, std::exception)
+OUString SAL_CALL SdUnoDrawView::getImplementationName(  )
 {
     return OUString( "com.sun.star.comp.sd.SdUnoDrawView") ;
 }
 
-sal_Bool SAL_CALL SdUnoDrawView::supportsService( const OUString& ServiceName ) throw (RuntimeException, std::exception)
+sal_Bool SAL_CALL SdUnoDrawView::supportsService( const OUString& ServiceName )
 {
     return cppu::supportsService( this, ServiceName );
 }
 
-Sequence< OUString > SAL_CALL SdUnoDrawView::getSupportedServiceNames(  ) throw (RuntimeException, std::exception)
+Sequence< OUString > SAL_CALL SdUnoDrawView::getSupportedServiceNames(  )
 {
     OUString aSN("com.sun.star.drawing.DrawingDocumentDrawView");
     uno::Sequence< OUString > aSeq( &aSN, 1 );
