@@ -17,17 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "PresentationViewShellBase.hxx"
-#include "sdresid.hxx"
-#include "DrawDocShell.hxx"
-#include "strings.hrc"
-#include "framework/FrameworkHelper.hxx"
-#include "framework/PresentationModule.hxx"
+#include <PresentationViewShellBase.hxx>
+#include <sdresid.hxx>
+#include <DrawDocShell.hxx>
+#include <strings.hrc>
+#include <framework/FrameworkHelper.hxx>
+#include <framework/PresentationModule.hxx>
 
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/viewsh.hxx>
 #include <com/sun/star/beans/XPropertySet.hpp>
-#include <com/sun/star/frame/XLayoutManager.hpp>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
