@@ -17,22 +17,25 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "ToolBarManager.hxx"
+#include <ToolBarManager.hxx>
 
-#include "DrawViewShell.hxx"
-#include "EventMultiplexer.hxx"
-#include "ViewShellBase.hxx"
-#include "ViewShellManager.hxx"
+#include <DrawViewShell.hxx>
+#include <EventMultiplexer.hxx>
+#include <ViewShellBase.hxx>
+#include <ViewShellManager.hxx>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/frame/XLayoutManager.hpp>
 #include <com/sun/star/ui/UIElementType.hpp>
 
 #include <osl/mutex.hxx>
+#include <o3tl/deleter.hxx>
+#include <o3tl/enumrange.hxx>
 #include <rtl/ref.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/objsh.hxx>
 #include <sfx2/request.hxx>
+#include <sfx2/toolbarids.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <svl/eitem.hxx>
 #include <svx/dialogs.hrc>
@@ -43,6 +46,7 @@
 
 #include <map>
 #include <utility>
+#include <memory>
 #include <vector>
 
 using namespace ::com::sun::star;
@@ -190,19 +194,19 @@ public:
     /** This method calls MainViewShellChanged() and SelectionHasChanged()
         for the current main view shell and its view.
     */
-    void Update (ViewShellBase& rBase);
+    void Update (ViewShellBase const & rBase);
 
     /** Reset all tool bars in all groups and add tool bars and tool bar
-        shells to the TBG_PERMANENT group for the specified ViewShell type.
+        shells to the ToolBarGroup::Permanent group for the specified ViewShell type.
     */
     void MainViewShellChanged (ViewShell::ShellType nShellType);
 
     /** Reset all tool bars in all groups and add tool bars and tool bar
-        shells to the TBG_PERMANENT group for the specified ViewShell.
+        shells to the ToolBarGroup::Permanent group for the specified ViewShell.
     */
     void MainViewShellChanged (const ViewShell& rMainViewShell);
 
-    /** Reset all tool bars in the TBG_FUNCTION group and add tool bars and tool bar
+    /** Reset all tool bars in the ToolBarGroup::Function group and add tool bars and tool bar
         shells to this group for the current selection.
     */
     void SelectionHasChanged (
@@ -296,8 +300,6 @@ public:
     ToolBarRules& GetToolBarRules() { return maToolBarRules;}
 
 private:
-    const static OUString msToolBarResourcePrefix;
-
     mutable ::osl::Mutex maMutex;
     ViewShellBase& mrBase;
     std::shared_ptr<sd::tools::EventMultiplexer> mpEventMultiplexer;
@@ -315,7 +317,7 @@ private:
     */
     ::std::unique_ptr<LayouterLock> mpSynchronousLayouterLock;
     ::std::unique_ptr<LayouterLock> mpAsynchronousLayouterLock;
-    ::std::unique_ptr<ViewShellManager::UpdateLock> mpViewShellManagerLock;
+    ::std::unique_ptr<ViewShellManager::UpdateLock, o3tl::default_delete<ViewShellManager::UpdateLock>> mpViewShellManagerLock;
     ImplSVEvent * mnPendingUpdateCall;
     ImplSVEvent * mnPendingSetValidCall;
     ToolBarRules maToolBarRules;
@@ -323,9 +325,9 @@ private:
     static OUString GetToolBarResourceName (const OUString& rsBaseName);
     bool CheckPlugInMode (const OUString& rsName) const;
 
-    DECL_LINK_TYPED(UpdateCallback, void *, void);
-    DECL_LINK_TYPED(EventMultiplexerCallback, sd::tools::EventMultiplexerEvent&, void);
-    DECL_LINK_TYPED(SetValidCallback, void*, void);
+    DECL_LINK(UpdateCallback, void *, void);
+    DECL_LINK(EventMultiplexerCallback, sd::tools::EventMultiplexerEvent&, void);
+    DECL_LINK(SetValidCallback, void*, void);
 };
 
 //===== ToolBarManager ========================================================
@@ -477,12 +479,12 @@ void ToolBarManager::UnlockUpdate()
         mpImpl->UnlockUpdate();
 }
 
-void ToolBarManager::MainViewShellChanged (ViewShell::ShellType nShellType)
+void ToolBarManager::MainViewShellChanged ()
 {
     if (mpImpl.get() != nullptr)
     {
         mpImpl->ReleaseAllToolBarShells();
-        mpImpl->GetToolBarRules().MainViewShellChanged(nShellType);
+        mpImpl->GetToolBarRules().MainViewShellChanged(ViewShell::ST_NONE);
     }
 }
 
@@ -511,8 +513,6 @@ void ToolBarManager::ToolBarsDestroyed()
 
 //===== ToolBarManager::Implementation =======================================
 
-const OUString ToolBarManager::Implementation::msToolBarResourcePrefix("private:resource/toolbar/");
-
 ToolBarManager::Implementation::Implementation (
     ViewShellBase& rBase,
     const std::shared_ptr<sd::tools::EventMultiplexer>& rpMultiplexer,
@@ -536,11 +536,7 @@ ToolBarManager::Implementation::Implementation (
       maToolBarRules(rpToolBarManager,rpViewShellManager)
 {
     Link<tools::EventMultiplexerEvent&,void> aLink (LINK(this,ToolBarManager::Implementation,EventMultiplexerCallback));
-    mpEventMultiplexer->AddEventListener(
-        aLink,
-        tools::EventMultiplexerEvent::EID_CONTROLLER_ATTACHED
-        | tools::EventMultiplexerEvent::EID_CONTROLLER_DETACHED
-        | tools::EventMultiplexerEvent::EID_PANE_MANAGER_DYING);
+    mpEventMultiplexer->AddEventListener( aLink );
 }
 
 /** The order of statements is important.
@@ -612,8 +608,8 @@ void ToolBarManager::Implementation::ResetToolBars (ToolBarGroup eGroup)
 void ToolBarManager::Implementation::ResetAllToolBars()
 {
     SAL_INFO("sd.view", OSL_THIS_FUNC << ": resetting all tool bars");
-    for (int i=TBG__FIRST; i<=TBG__LAST; ++i)
-        ResetToolBars((ToolBarGroup)i);
+    for (auto i : o3tl::enumrange<ToolBarGroup>())
+        ResetToolBars(i);
 }
 
 void ToolBarManager::Implementation::AddToolBar (
@@ -695,8 +691,7 @@ void ToolBarManager::Implementation::PreUpdate()
         for (iToolBar=aToolBars.begin(); iToolBar!=aToolBars.end(); ++iToolBar)
         {
             OUString sFullName (GetToolBarResourceName(*iToolBar));
-            SAL_INFO("sd.view", OSL_THIS_FUNC << ":    turning off tool bar " <<
-                OUStringToOString(sFullName, RTL_TEXTENCODING_UTF8).getStr());
+            SAL_INFO("sd.view", OSL_THIS_FUNC << ":    turning off tool bar " << sFullName);
             mxLayouter->destroyElement(sFullName);
             maToolBarList.MarkToolBarAsNotActive(*iToolBar);
         }
@@ -726,8 +721,7 @@ void ToolBarManager::Implementation::PostUpdate()
         for (iToolBar=aToolBars.begin(); iToolBar!=aToolBars.end(); ++iToolBar)
         {
             OUString sFullName (GetToolBarResourceName(*iToolBar));
-            SAL_INFO("sd.view", OSL_THIS_FUNC << ":    turning on tool bar " <<
-                OUStringToOString(sFullName, RTL_TEXTENCODING_UTF8).getStr());
+            SAL_INFO("sd.view", OSL_THIS_FUNC << ":    turning on tool bar " << sFullName);
             mxLayouter->requestElement(sFullName);
             maToolBarList.MarkToolBarAsActive(*iToolBar);
         }
@@ -793,7 +787,7 @@ void ToolBarManager::Implementation::Update (
 
         if (mbIsValid && mxLayouter.is() && (mbPreUpdatePending || mbPostUpdatePending))
         {
-            // 1) Release UNO tool bars that are not longer used.  Do this
+            // 1) Release UNO tool bars that are no longer used.  Do this
             // now so that they are not updated when the SFX shell stack is
             // modified.
             if (mbPreUpdatePending)
@@ -847,7 +841,7 @@ void ToolBarManager::Implementation::Update (
     }
 }
 
-IMPL_LINK_NOARG_TYPED(ToolBarManager::Implementation, UpdateCallback, void*, void)
+IMPL_LINK_NOARG(ToolBarManager::Implementation, UpdateCallback, void*, void)
 {
     mnPendingUpdateCall = nullptr;
     if (mnLockCount == 0)
@@ -861,28 +855,27 @@ IMPL_LINK_NOARG_TYPED(ToolBarManager::Implementation, UpdateCallback, void*, voi
     }
 }
 
-IMPL_LINK_TYPED(ToolBarManager::Implementation,EventMultiplexerCallback,
+IMPL_LINK(ToolBarManager::Implementation,EventMultiplexerCallback,
     sd::tools::EventMultiplexerEvent&, rEvent, void)
 {
+    SolarMutexGuard g;
     switch (rEvent.meEventId)
     {
-        case tools::EventMultiplexerEvent::EID_CONTROLLER_ATTACHED:
+        case EventMultiplexerEventId::ControllerAttached:
             if (mnPendingSetValidCall == nullptr)
                 mnPendingSetValidCall
                     = Application::PostUserEvent(LINK(this,Implementation,SetValidCallback));
             break;
 
-        case tools::EventMultiplexerEvent::EID_CONTROLLER_DETACHED:
+        case EventMultiplexerEventId::ControllerDetached:
             SetValid(false);
             break;
 
-        case tools::EventMultiplexerEvent::EID_PANE_MANAGER_DYING:
-            SetValid(false);
-            break;
+        default: break;
     }
 }
 
-IMPL_LINK_NOARG_TYPED(ToolBarManager::Implementation, SetValidCallback, void*, void)
+IMPL_LINK_NOARG(ToolBarManager::Implementation, SetValidCallback, void*, void)
 {
     mnPendingSetValidCall = nullptr;
     SetValid(true);
@@ -891,9 +884,7 @@ IMPL_LINK_NOARG_TYPED(ToolBarManager::Implementation, SetValidCallback, void*, v
 OUString ToolBarManager::Implementation::GetToolBarResourceName (
     const OUString& rsBaseName)
 {
-    OUString sToolBarName (msToolBarResourcePrefix);
-    sToolBarName += rsBaseName;
-    return sToolBarName;
+    return "private:resource/toolbar/" + rsBaseName;
 }
 
 bool ToolBarManager::Implementation::CheckPlugInMode (const OUString& rsName) const
@@ -920,7 +911,7 @@ bool ToolBarManager::Implementation::CheckPlugInMode (const OUString& rsName) co
     }
     while (false);
 
-    if (rsName.equals(msViewerToolBar))
+    if (rsName == msViewerToolBar)
         bValid = bIsPlugInMode;
     else
         bValid = ! bIsPlugInMode;
@@ -961,7 +952,7 @@ ToolBarRules::ToolBarRules (
 {
 }
 
-void ToolBarRules::Update (ViewShellBase& rBase)
+void ToolBarRules::Update (ViewShellBase const & rBase)
 {
     ViewShell* pMainViewShell = rBase.GetMainViewShell().get();
     if (pMainViewShell != nullptr)
@@ -987,48 +978,48 @@ void ToolBarRules::MainViewShellChanged (ViewShell::ShellType nShellType)
         case ::sd::ViewShell::ST_NOTES:
         case ::sd::ViewShell::ST_HANDOUT:
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msToolBar);
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msOptionsToolBar);
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msViewerToolBar);
             break;
 
         case ::sd::ViewShell::ST_DRAW:
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msToolBar);
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msOptionsToolBar);
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msViewerToolBar);
             break;
 
         case ViewShell::ST_OUTLINE:
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msOutlineToolBar);
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msViewerToolBar);
             mpToolBarManager->AddToolBarShell(
-                ToolBarManager::TBG_PERMANENT, RID_DRAW_TEXT_TOOLBOX);
+                ToolBarManager::ToolBarGroup::Permanent, ToolbarId::Draw_Text_Toolbox_Sd);
             break;
 
         case ViewShell::ST_SLIDE_SORTER:
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msViewerToolBar);
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msSlideSorterToolBar);
             mpToolBarManager->AddToolBar(
-                ToolBarManager::TBG_PERMANENT,
+                ToolBarManager::ToolBarGroup::Permanent,
                 ToolBarManager::msSlideSorterObjectBar);
             break;
 
@@ -1056,13 +1047,13 @@ void ToolBarRules::MainViewShellChanged (const ViewShell& rMainViewShell)
                 = dynamic_cast<const DrawViewShell*>(&rMainViewShell);
             if (pDrawViewShell != nullptr)
             {
-                if (pDrawViewShell->GetEditMode() == EM_MASTERPAGE)
+                if (pDrawViewShell->GetEditMode() == EditMode::MasterPage)
                     mpToolBarManager->AddToolBar(
-                        ToolBarManager::TBG_MASTER_MODE,
+                        ToolBarManager::ToolBarGroup::MasterMode,
                         ToolBarManager::msMasterViewToolBar);
                 else if ( rMainViewShell.GetShellType() != ::sd::ViewShell::ST_DRAW )
                     mpToolBarManager->AddToolBar(
-                        ToolBarManager::TBG_COMMON_TASK,
+                        ToolBarManager::ToolBarGroup::CommonTask,
                         ToolBarManager::msCommonTaskToolBar);
             }
             break;
@@ -1081,26 +1072,26 @@ void ToolBarRules::SelectionHasChanged (
     mpToolBarManager->LockViewShellManager();
     bool bTextEdit = rView.IsTextEdit();
 
-    mpToolBarManager->ResetToolBars(ToolBarManager::TBG_FUNCTION);
+    mpToolBarManager->ResetToolBars(ToolBarManager::ToolBarGroup::Function);
 
     switch (rView.GetContext())
     {
-        case SDRCONTEXT_GRAPHIC:
+        case SdrViewContext::Graphic:
             if( !bTextEdit )
-                mpToolBarManager->SetToolBarShell(ToolBarManager::TBG_FUNCTION, RID_DRAW_GRAF_TOOLBOX);
+                mpToolBarManager->SetToolBarShell(ToolBarManager::ToolBarGroup::Function, ToolbarId::Draw_Graf_Toolbox);
             break;
 
-        case SDRCONTEXT_MEDIA:
+        case SdrViewContext::Media:
             if( !bTextEdit )
-                mpToolBarManager->SetToolBarShell(ToolBarManager::TBG_FUNCTION, RID_DRAW_MEDIA_TOOLBOX);
+                mpToolBarManager->SetToolBarShell(ToolBarManager::ToolBarGroup::Function, ToolbarId::Draw_Media_Toolbox);
             break;
 
-        case SDRCONTEXT_TABLE:
-            mpToolBarManager->SetToolBarShell(ToolBarManager::TBG_FUNCTION, RID_DRAW_TABLE_TOOLBOX);
+        case SdrViewContext::Table:
+            mpToolBarManager->SetToolBarShell(ToolBarManager::ToolBarGroup::Function, ToolbarId::Draw_Table_Toolbox);
             bTextEdit = true;
             break;
 
-        case SDRCONTEXT_STANDARD:
+        case SdrViewContext::Standard:
         default:
             if( !bTextEdit )
             {
@@ -1111,7 +1102,7 @@ void ToolBarRules::SelectionHasChanged (
                     case ::sd::ViewShell::ST_NOTES:
                     case ::sd::ViewShell::ST_HANDOUT:
                         mpToolBarManager->SetToolBar(
-                            ToolBarManager::TBG_FUNCTION,
+                            ToolBarManager::ToolBarGroup::Function,
                             ToolBarManager::msDrawingObjectToolBar);
                         break;
                     default:
@@ -1122,20 +1113,20 @@ void ToolBarRules::SelectionHasChanged (
     }
 
     if( bTextEdit )
-        mpToolBarManager->AddToolBarShell(ToolBarManager::TBG_FUNCTION, RID_DRAW_TEXT_TOOLBOX);
+        mpToolBarManager->AddToolBarShell(ToolBarManager::ToolBarGroup::Function, ToolbarId::Draw_Text_Toolbox_Sd);
 
     SdrView* pView = &const_cast<SdrView&>(rView);
     // Check if the extrusion tool bar and the fontwork tool bar have to
     // be activated.
     if (svx::checkForSelectedCustomShapes(pView, true /* bOnlyExtruded */ ))
-        mpToolBarManager->AddToolBarShell(ToolBarManager::TBG_FUNCTION, RID_SVX_EXTRUSION_BAR);
+        mpToolBarManager->AddToolBarShell(ToolBarManager::ToolBarGroup::Function, ToolbarId::Svx_Extrusion_Bar);
     sal_uInt32 nCheckStatus = 0;
     if (svx::checkForSelectedFontWork(pView, nCheckStatus))
-        mpToolBarManager->AddToolBarShell(ToolBarManager::TBG_FUNCTION, RID_SVX_FONTWORK_BAR);
+        mpToolBarManager->AddToolBarShell(ToolBarManager::ToolBarGroup::Function, ToolbarId::Svx_Fontwork_Bar);
 
     // Switch on additional context-sensitive tool bars.
-    if (rView.GetContext() == SDRCONTEXT_POINTEDIT)
-        mpToolBarManager->AddToolBarShell(ToolBarManager::TBG_FUNCTION, RID_BEZIER_TOOLBOX);
+    if (rView.GetContext() == SdrViewContext::PointEdit)
+        mpToolBarManager->AddToolBarShell(ToolBarManager::ToolBarGroup::Function, ToolbarId::Bezier_Toolbox_Sd);
 }
 
 void ToolBarRules::SubShellAdded (
@@ -1146,25 +1137,28 @@ void ToolBarRules::SubShellAdded (
     // actual tool bar here.
     switch (nShellId)
     {
-        case RID_DRAW_GRAF_TOOLBOX:
+        case ToolbarId::Draw_Graf_Toolbox:
             mpToolBarManager->AddToolBar(eGroup, ToolBarManager::msGraphicObjectBar);
             break;
 
-        case RID_DRAW_MEDIA_TOOLBOX:
+        case ToolbarId::Draw_Media_Toolbox:
             mpToolBarManager->AddToolBar(eGroup, ToolBarManager::msMediaObjectBar);
             break;
 
-        case RID_DRAW_TEXT_TOOLBOX:
+        case ToolbarId::Draw_Text_Toolbox_Sd:
             mpToolBarManager->AddToolBar(eGroup, ToolBarManager::msTextObjectBar);
             break;
 
-        case RID_BEZIER_TOOLBOX:
+        case ToolbarId::Bezier_Toolbox_Sd:
             mpToolBarManager->AddToolBar(eGroup, ToolBarManager::msBezierObjectBar);
             break;
 
-        case RID_DRAW_TABLE_TOOLBOX:
+        case ToolbarId::Draw_Table_Toolbox:
             mpToolBarManager->AddToolBar(eGroup, ToolBarManager::msTableObjectBar);
             break;
+
+        default:
+            break;
     }
 }
 
@@ -1176,25 +1170,28 @@ void ToolBarRules::SubShellRemoved (
     // actual tool bar here.
     switch (nShellId)
     {
-        case RID_DRAW_GRAF_TOOLBOX:
+        case ToolbarId::Draw_Graf_Toolbox:
             mpToolBarManager->RemoveToolBar(eGroup, ToolBarManager::msGraphicObjectBar);
             break;
 
-        case RID_DRAW_MEDIA_TOOLBOX:
+        case ToolbarId::Draw_Media_Toolbox:
             mpToolBarManager->RemoveToolBar(eGroup, ToolBarManager::msMediaObjectBar);
             break;
 
-        case RID_DRAW_TEXT_TOOLBOX:
+        case ToolbarId::Draw_Text_Toolbox_Sd:
             mpToolBarManager->RemoveToolBar(eGroup, ToolBarManager::msTextObjectBar);
             break;
 
-        case RID_BEZIER_TOOLBOX:
+        case ToolbarId::Bezier_Toolbox_Sd:
             mpToolBarManager->RemoveToolBar(eGroup, ToolBarManager::msBezierObjectBar);
             break;
 
-        case RID_DRAW_TABLE_TOOLBOX:
+        case ToolbarId::Draw_Table_Toolbox:
             mpToolBarManager->RemoveToolBar(eGroup, ToolBarManager::msTableObjectBar);
             break;
+
+        default:
+            break;
     }
 }
 
@@ -1224,7 +1221,7 @@ void ToolBarList::AddToolBar (
 {
     Groups::iterator iGroup (maGroups.find(eGroup));
     if (iGroup == maGroups.end())
-        iGroup = maGroups.insert(Groups::value_type(eGroup,NameList())).first;
+        iGroup = maGroups.emplace(eGroup,NameList()).first;
 
     if (iGroup != maGroups.end())
     {
@@ -1257,9 +1254,8 @@ bool ToolBarList::RemoveToolBar (
 
 void ToolBarList::MakeRequestedToolBarList (NameList& rRequestedToolBars) const
 {
-    for (int i=sd::ToolBarManager::TBG__FIRST; i<=sd::ToolBarManager::TBG__LAST; ++i)
+    for (auto eGroup : o3tl::enumrange<sd::ToolBarManager::ToolBarGroup>())
     {
-        ::sd::ToolBarManager::ToolBarGroup eGroup = (::sd::ToolBarManager::ToolBarGroup)i;
         Groups::const_iterator iGroup (maGroups.find(eGroup));
         if (iGroup != maGroups.end())
             ::std::copy(
@@ -1411,7 +1407,7 @@ void ToolBarShellList::UpdateShells (
             std::insert_iterator<GroupedShellList>(aList,aList.begin()));
         for (GroupedShellList::iterator iShell=aList.begin(); iShell!=aList.end(); ++iShell)
         {
-            SAL_INFO("sd.view", OSL_THIS_FUNC << ": deactivating tool bar shell " << iShell->mnId);
+            SAL_INFO("sd.view", OSL_THIS_FUNC << ": deactivating tool bar shell " << (sal_uInt32)iShell->mnId);
             rpManager->DeactivateSubShell(*rpMainViewShell, iShell->mnId);
         }
 
@@ -1423,11 +1419,11 @@ void ToolBarShellList::UpdateShells (
             std::insert_iterator<GroupedShellList>(aList,aList.begin()));
         for (GroupedShellList::iterator iShell=aList.begin(); iShell!=aList.end(); ++iShell)
         {
-            SAL_INFO("sd.view", OSL_THIS_FUNC << ": activating tool bar shell " << iShell->mnId);
+            SAL_INFO("sd.view", OSL_THIS_FUNC << ": activating tool bar shell " << (sal_uInt32)iShell->mnId);
             rpManager->ActivateSubShell(*rpMainViewShell, iShell->mnId);
         }
 
-        // The maNewList now refelects the current state and thus is made
+        // The maNewList now reflects the current state and thus is made
         // maCurrentList.
         maCurrentList = maNewList;
     }
