@@ -17,9 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "OutlineView.hxx"
+#include <OutlineView.hxx>
 #include <editeng/forbiddencharacterstable.hxx>
 #include <sfx2/progress.hxx>
+#include <vcl/commandinfoprovider.hxx>
 #include <vcl/wrkwin.hxx>
 #include <svx/svxids.hrc>
 #include <editeng/outliner.hxx>
@@ -28,7 +29,6 @@
 #include <editeng/lrspitem.hxx>
 #include <svx/svdotext.hxx>
 #include <sfx2/printer.hxx>
-#include <sfx2/imagemgr.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/bindings.hxx>
 #include <svl/itempool.hxx>
@@ -42,6 +42,7 @@
 #include <editeng/numitem.hxx>
 #include <editeng/outlobj.hxx>
 #include <editeng/editeng.hxx>
+#include <xmloff/autolayout.hxx>
 
 #include <editeng/editobj.hxx>
 #include <editeng/editund2.hxx>
@@ -50,23 +51,22 @@
 #include <editeng/svxfont.hxx>
 #include <editeng/fhgtitem.hxx>
 
-#include "DrawDocShell.hxx"
-#include "drawdoc.hxx"
-#include "Window.hxx"
-#include "sdpage.hxx"
-#include "pres.hxx"
-#include "OutlineViewShell.hxx"
-#include "app.hrc"
-#include "glob.hrc"
-#include "sdresid.hxx"
-#include "Outliner.hxx"
-#include "strings.hrc"
-#include "EventMultiplexer.hxx"
-#include "ViewShellBase.hxx"
-#include "ViewShellManager.hxx"
-#include "undo/undoobjects.hxx"
-#include "undo/undomanager.hxx"
-#include "stlsheet.hxx"
+#include <DrawDocShell.hxx>
+#include <drawdoc.hxx>
+#include <Window.hxx>
+#include <sdpage.hxx>
+#include <pres.hxx>
+#include <OutlineViewShell.hxx>
+#include <app.hrc>
+#include <strings.hrc>
+#include <sdresid.hxx>
+#include <Outliner.hxx>
+#include <EventMultiplexer.hxx>
+#include <ViewShellBase.hxx>
+#include <ViewShellManager.hxx>
+#include <undo/undoobjects.hxx>
+#include <undo/undomanager.hxx>
+#include <stlsheet.hxx>
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::frame;
@@ -95,7 +95,7 @@ OutlineView::OutlineView( DrawDocShell& rDocSh, vcl::Window* pWindow, OutlineVie
         // initialize Outliner: set Reference Device
         bInitOutliner = true;
         mrOutliner.Init( OutlinerMode::OutlineView );
-        mrOutliner.SetRefDevice( SD_MOD()->GetRefDevice( rDocSh ) );
+        mrOutliner.SetRefDevice( SD_MOD()->GetVirtualRefDevice() );
         //viewsize without the width of the image and number in front
         mnPaperWidth = (mrOutlineViewShell.GetActiveWindow()->GetViewSize().Width() - 4000);
         mrOutliner.SetPaperSize(Size(mnPaperWidth, 400000000));
@@ -113,7 +113,7 @@ OutlineView::OutlineView( DrawDocShell& rDocSh, vcl::Window* pWindow, OutlineVie
     }
 
     mpOutlinerView[0] = new OutlinerView(&mrOutliner, pWindow);
-    Rectangle aNullRect;
+    ::tools::Rectangle aNullRect;
     mpOutlinerView[0]->SetOutputArea(aNullRect);
     mrOutliner.SetUpdateMode(false);
     mrOutliner.InsertView(mpOutlinerView[0], EE_APPEND);
@@ -127,10 +127,7 @@ OutlineView::OutlineView( DrawDocShell& rDocSh, vcl::Window* pWindow, OutlineVie
     }
 
     Link<tools::EventMultiplexerEvent&,void> aLink( LINK(this,OutlineView,EventMultiplexerListener) );
-    mrOutlineViewShell.GetViewShellBase().GetEventMultiplexer()->AddEventListener(
-        aLink,
-        tools::EventMultiplexerEvent::EID_CURRENT_PAGE
-        | tools::EventMultiplexerEvent::EID_PAGE_ORDER);
+    mrOutlineViewShell.GetViewShellBase().GetEventMultiplexer()->AddEventListener(aLink);
 
     LanguageType eLang = mrOutliner.GetDefaultLanguage();
     maPageNumberFont = OutputDevice::GetDefaultFont( DefaultFontType::SANS_UNICODE, eLang, GetDefaultFontFlags::NONE );
@@ -147,10 +144,8 @@ OutlineView::OutlineView( DrawDocShell& rDocSh, vcl::Window* pWindow, OutlineVie
     maBulletFont.SetOutline(false);
     maBulletFont.SetShadow(false);
 
-    Reference<XFrame> xFrame (mrOutlineViewShell.GetViewShellBase().GetFrame()->GetTopFrame().GetFrameInterface(), UNO_QUERY);
-
-    const OUString aSlotURL( ".uno:ShowSlide" );
-    maSlideImage = GetImage( xFrame, aSlotURL, true );
+    Reference<XFrame> xFrame (mrOutlineViewShell.GetViewShellBase().GetFrame()->GetFrame().GetFrameInterface(), UNO_QUERY);
+    maSlideImage = vcl::CommandInfoProvider::GetImageForCommand(".uno:ShowSlide", xFrame, vcl::ImageType::Size26);
 
     // Tell undo manager of the document about the undo manager of the
     // outliner, so that the former can synchronize with the later.
@@ -215,7 +210,7 @@ void OutlineView::DisconnectFromApplication()
     Application::RemoveEventListener(LINK(this, OutlineView, AppEventListenerHdl));
 }
 
-void OutlineView::Paint(const Rectangle& rRect, ::sd::Window* pWin)
+void OutlineView::Paint(const ::tools::Rectangle& rRect, ::sd::Window const * pWin)
 {
     OutlinerView* pOlView = GetViewByWindow(pWin);
 
@@ -234,7 +229,7 @@ void OutlineView::AddWindowToPaintView(OutputDevice* pWin, vcl::Window* pWindow)
 {
     bool bAdded = false;
     bool bValidArea = false;
-    Rectangle aOutputArea;
+    ::tools::Rectangle aOutputArea;
     const Color aWhiteColor( COL_WHITE );
     sal_uInt16 nView = 0;
 
@@ -297,7 +292,7 @@ void OutlineView::DeleteWindowFromPaintView(OutputDevice* pWin)
 /**
  * Return a pointer to the OutlinerView corresponding to the window
  */
-OutlinerView* OutlineView::GetViewByWindow (vcl::Window* pWin) const
+OutlinerView* OutlineView::GetViewByWindow (vcl::Window const * pWin) const
 {
     OutlinerView* pOlView = nullptr;
     for (OutlinerView* pView : mpOutlinerView)
@@ -318,7 +313,7 @@ OutlinerView* OutlineView::GetViewByWindow (vcl::Window* pWin) const
  */
 Paragraph* OutlineView::GetPrevTitle(const Paragraph* pPara)
 {
-    sal_Int32 nPos = mrOutliner.GetAbsPos(const_cast<Paragraph*>(pPara));
+    sal_Int32 nPos = mrOutliner.GetAbsPos(pPara);
 
     if (nPos > 0)
     {
@@ -358,7 +353,7 @@ Paragraph* OutlineView::GetNextTitle(const Paragraph* pPara)
 /**
  * Handler for inserting pages (paragraphs)
  */
-IMPL_LINK_TYPED( OutlineView, ParagraphInsertedHdl, ::Outliner *, pOutliner, void )
+IMPL_LINK( OutlineView, ParagraphInsertedHdl, Outliner::ParagraphHdlParam, aParam, void )
 {
     // we get calls to this handler during binary insert of drag and drop contents but
     // we ignore it here and handle it later in OnEndPasteOrDrop()
@@ -366,17 +361,15 @@ IMPL_LINK_TYPED( OutlineView, ParagraphInsertedHdl, ::Outliner *, pOutliner, voi
     {
         OutlineViewPageChangesGuard aGuard(this);
 
-        Paragraph* pPara = pOutliner->GetHdlParagraph();
-
-        sal_Int32 nAbsPos = mrOutliner.GetAbsPos( pPara );
+        sal_Int32 nAbsPos = mrOutliner.GetAbsPos( aParam.pPara );
 
         UpdateParagraph( nAbsPos );
 
         if( (nAbsPos == 0) ||
-            ::Outliner::HasParaFlag(pPara,ParaFlag::ISPAGE) ||
+            ::Outliner::HasParaFlag(aParam.pPara, ParaFlag::ISPAGE) ||
             ::Outliner::HasParaFlag(mrOutliner.GetParagraph( nAbsPos-1 ), ParaFlag::ISPAGE) )
         {
-            InsertSlideForParagraph( pPara );
+            InsertSlideForParagraph( aParam.pPara );
         }
     }
 }
@@ -390,8 +383,8 @@ SdPage* OutlineView::InsertSlideForParagraph( Paragraph* pPara )
 
     mrOutliner.SetParaFlag( pPara, ParaFlag::ISPAGE );
     // how many titles are there before the new title paragraph?
-    sal_uLong nExample = 0L;            // position of the "example" page
-    sal_uLong nTarget  = 0L;            // position of insertion
+    sal_uLong nExample = 0;            // position of the "example" page
+    sal_uLong nTarget  = 0;            // position of insertion
     while(pPara)
     {
         pPara = GetPrevTitle(pPara);
@@ -416,7 +409,7 @@ SdPage* OutlineView::InsertSlideForParagraph( Paragraph* pPara )
     {
         nExample = nTarget - 1;
 
-        sal_uInt16 nPageCount = mrDoc.GetSdPageCount( PK_STANDARD );
+        sal_uInt16 nPageCount = mrDoc.GetSdPageCount( PageKind::Standard );
         if( nExample >= nPageCount )
             nExample = nPageCount - 1;
     }
@@ -428,13 +421,13 @@ SdPage* OutlineView::InsertSlideForParagraph( Paragraph* pPara )
     **********************************************************************/
 
     // this page is exemplary
-    SdPage* pExample = mrDoc.GetSdPage((sal_uInt16)nExample, PK_STANDARD);
+    SdPage* pExample = mrDoc.GetSdPage((sal_uInt16)nExample, PageKind::Standard);
     SdPage* pPage = mrDoc.AllocSdPage(false);
 
     pPage->SetLayoutName(pExample->GetLayoutName());
 
     // insert (page)
-    mrDoc.InsertPage(pPage, (sal_uInt16)(nTarget) * 2 + 1);
+    mrDoc.InsertPage(pPage, (sal_uInt16)nTarget * 2 + 1);
     if( isRecordingUndo() )
         AddUndo(mrDoc.GetSdrUndoFactory().CreateUndoNewPage(*pPage));
 
@@ -443,19 +436,19 @@ SdPage* OutlineView::InsertSlideForParagraph( Paragraph* pPara )
 
     // set page size
     pPage->SetSize(pExample->GetSize());
-    pPage->SetBorder( pExample->GetLftBorder(),
-                      pExample->GetUppBorder(),
-                      pExample->GetRgtBorder(),
-                      pExample->GetLwrBorder() );
+    pPage->SetBorder( pExample->GetLeftBorder(),
+                      pExample->GetUpperBorder(),
+                      pExample->GetRightBorder(),
+                      pExample->GetLowerBorder() );
 
     // create new presentation objects (after <Title> or <Title with subtitle>
     // follows <Title with outline>, otherwise apply the layout of the previous
     // page
     AutoLayout eAutoLayout = pExample->GetAutoLayout();
     if (eAutoLayout == AUTOLAYOUT_TITLE ||
-        eAutoLayout == AUTOLAYOUT_ONLY_TITLE)
+        eAutoLayout == AUTOLAYOUT_TITLE_ONLY)
     {
-        pPage->SetAutoLayout(AUTOLAYOUT_ENUM, true);
+        pPage->SetAutoLayout(AUTOLAYOUT_TITLE_CONTENT, true);
     }
     else
     {
@@ -465,15 +458,15 @@ SdPage* OutlineView::InsertSlideForParagraph( Paragraph* pPara )
     /**********************************************************************
     |* now the notes page
     \*********************************************************************/
-    pExample = mrDoc.GetSdPage((sal_uInt16)nExample, PK_NOTES);
+    pExample = mrDoc.GetSdPage((sal_uInt16)nExample, PageKind::Notes);
     SdPage* pNotesPage = mrDoc.AllocSdPage(false);
 
     pNotesPage->SetLayoutName(pExample->GetLayoutName());
 
-    pNotesPage->SetPageKind(PK_NOTES);
+    pNotesPage->SetPageKind(PageKind::Notes);
 
     // insert (notes page)
-    mrDoc.InsertPage(pNotesPage, (sal_uInt16)(nTarget) * 2 + 2);
+    mrDoc.InsertPage(pNotesPage, (sal_uInt16)nTarget * 2 + 2);
     if( isRecordingUndo() )
         AddUndo(mrDoc.GetSdrUndoFactory().CreateUndoNewPage(*pNotesPage));
 
@@ -482,10 +475,10 @@ SdPage* OutlineView::InsertSlideForParagraph( Paragraph* pPara )
 
     // set page size, there must be already one page available
     pNotesPage->SetSize(pExample->GetSize());
-    pNotesPage->SetBorder( pExample->GetLftBorder(),
-                           pExample->GetUppBorder(),
-                           pExample->GetRgtBorder(),
-                           pExample->GetLwrBorder() );
+    pNotesPage->SetBorder( pExample->GetLeftBorder(),
+                           pExample->GetUpperBorder(),
+                           pExample->GetRightBorder(),
+                           pExample->GetLowerBorder() );
 
     // create presentation objects
     pNotesPage->SetAutoLayout(pExample->GetAutoLayout(), true);
@@ -498,17 +491,17 @@ SdPage* OutlineView::InsertSlideForParagraph( Paragraph* pPara )
 /**
  * Handler for deleting pages (paragraphs)
  */
-IMPL_LINK_TYPED( OutlineView, ParagraphRemovingHdl, ::Outliner *, pOutliner, void )
+IMPL_LINK( OutlineView, ParagraphRemovingHdl, ::Outliner::ParagraphHdlParam, aParam, void )
 {
     DBG_ASSERT( isRecordingUndo(), "sd::OutlineView::ParagraphRemovingHdl(), model change without undo?!" );
 
     OutlineViewPageChangesGuard aGuard(this);
 
-    Paragraph* pPara = pOutliner->GetHdlParagraph();
+    Paragraph* pPara = aParam.pPara;
     if( ::Outliner::HasParaFlag( pPara, ParaFlag::ISPAGE ) )
     {
         // how many titles are in front of the title paragraph in question?
-        sal_uLong nPos = 0L;
+        sal_uLong nPos = 0;
         while(pPara)
         {
             pPara = GetPrevTitle(pPara);
@@ -547,7 +540,7 @@ IMPL_LINK_TYPED( OutlineView, ParagraphRemovingHdl, ::Outliner *, pOutliner, voi
                 mnPagesProcessed = 0;
             }
         }
-        pOutliner->UpdateFields();
+        aParam.pOutliner->UpdateFields();
     }
 }
 
@@ -555,14 +548,15 @@ IMPL_LINK_TYPED( OutlineView, ParagraphRemovingHdl, ::Outliner *, pOutliner, voi
  * Handler for changing the indentation depth of paragraphs (requires inserting
  * or deleting of pages in some cases)
  */
-IMPL_LINK_TYPED( OutlineView, DepthChangedHdl, ::Outliner *, pOutliner, void )
+IMPL_LINK( OutlineView, DepthChangedHdl, ::Outliner::DepthChangeHdlParam, aParam, void )
 {
     DBG_ASSERT( isRecordingUndo(), "sd::OutlineView::DepthChangedHdl(), no undo for model change?!" );
 
     OutlineViewPageChangesGuard aGuard(this);
 
-    Paragraph* pPara = pOutliner->GetHdlParagraph();
-    if( ::Outliner::HasParaFlag( pPara, ParaFlag::ISPAGE ) && ((pOutliner->GetPrevFlags() & ParaFlag::ISPAGE) == ParaFlag::NONE) )
+    Paragraph* pPara = aParam.pPara;
+    ::Outliner* pOutliner = aParam.pOutliner;
+    if( ::Outliner::HasParaFlag( pPara, ParaFlag::ISPAGE ) && ((aParam.nPrevFlags & ParaFlag::ISPAGE) == ParaFlag::NONE) )
     {
         // the current paragraph is transformed into a slide
 
@@ -595,7 +589,7 @@ IMPL_LINK_TYPED( OutlineView, DepthChangedHdl, ::Outliner *, pOutliner, void )
             if (mnPagesToProcess > PROCESS_WITH_PROGRESS_THRESHOLD)
             {
                 delete mpProgress;
-                mpProgress = new SfxProgress( GetDocSh(), SD_RESSTR(STR_CREATE_PAGES), mnPagesToProcess );
+                mpProgress = new SfxProgress( GetDocSh(), SdResId(STR_CREATE_PAGES), mnPagesToProcess );
             }
             else
             {
@@ -603,7 +597,7 @@ IMPL_LINK_TYPED( OutlineView, DepthChangedHdl, ::Outliner *, pOutliner, void )
             }
         }
 
-        ParagraphInsertedHdl(pOutliner);
+        ParagraphInsertedHdl( { aParam.pOutliner, aParam.pPara } );
 
         mnPagesProcessed++;
 
@@ -630,12 +624,12 @@ IMPL_LINK_TYPED( OutlineView, DepthChangedHdl, ::Outliner *, pOutliner, void )
         }
         pOutliner->UpdateFields();
     }
-    else if( !::Outliner::HasParaFlag( pPara, ParaFlag::ISPAGE ) && ((pOutliner->GetPrevFlags() & ParaFlag::ISPAGE) != ParaFlag::NONE) )
+    else if( !::Outliner::HasParaFlag( pPara, ParaFlag::ISPAGE ) && ((aParam.nPrevFlags & ParaFlag::ISPAGE) != ParaFlag::NONE) )
     {
         // the paragraph was a page but now becomes a normal paragraph
 
         // how many titles are before the title paragraph in question?
-        sal_uLong nPos = 0L;
+        sal_uLong nPos = 0;
         Paragraph* pParagraph = pPara;
         while(pParagraph)
         {
@@ -684,7 +678,7 @@ IMPL_LINK_TYPED( OutlineView, DepthChangedHdl, ::Outliner *, pOutliner, void )
     else if ( (pOutliner->GetPrevDepth() == 1) && ( pOutliner->GetDepth( pOutliner->GetAbsPos( pPara ) ) == 2 ) )
     {
         // how many titles are in front of the title paragraph in question?
-        sal_Int32 nPos = -1L;
+        sal_Int32 nPos = -1;
 
         Paragraph* pParagraph = pPara;
         while(pParagraph)
@@ -696,7 +690,7 @@ IMPL_LINK_TYPED( OutlineView, DepthChangedHdl, ::Outliner *, pOutliner, void )
 
         if(nPos >= 0)
         {
-            SdPage*pPage = mrDoc.GetSdPage( (sal_uInt16) nPos, PK_STANDARD);
+            SdPage*pPage = mrDoc.GetSdPage( (sal_uInt16) nPos, PageKind::Standard);
 
             if(pPage && pPage->GetPresObj(PRESOBJ_TEXT))
                 pOutliner->SetDepth( pPara, 0 );
@@ -704,7 +698,7 @@ IMPL_LINK_TYPED( OutlineView, DepthChangedHdl, ::Outliner *, pOutliner, void )
 
     }
     // how many titles are in front of the title paragraph in question?
-    sal_Int32 nPos = -1L;
+    sal_Int32 nPos = -1;
 
     Paragraph* pTempPara = pPara;
     while(pTempPara)
@@ -716,7 +710,7 @@ IMPL_LINK_TYPED( OutlineView, DepthChangedHdl, ::Outliner *, pOutliner, void )
 
     if( nPos >= 0 )
     {
-        SdPage* pPage = mrDoc.GetSdPage( (sal_uInt16) nPos, PK_STANDARD );
+        SdPage* pPage = mrDoc.GetSdPage( (sal_uInt16) nPos, PageKind::Standard );
 
         if( pPage )
         {
@@ -769,15 +763,15 @@ IMPL_LINK_TYPED( OutlineView, DepthChangedHdl, ::Outliner *, pOutliner, void )
 /**
  * Handler for StatusEvents
  */
-IMPL_LINK_NOARG_TYPED(OutlineView, StatusEventHdl, EditStatus&, void)
+IMPL_LINK_NOARG(OutlineView, StatusEventHdl, EditStatus&, void)
 {
     ::sd::Window*   pWin = mrOutlineViewShell.GetActiveWindow();
     OutlinerView*   pOutlinerView = GetViewByWindow(pWin);
-    Rectangle       aVis          = pOutlinerView->GetVisArea();
-    Rectangle       aText = Rectangle(Point(0,0),
+    ::tools::Rectangle       aVis          = pOutlinerView->GetVisArea();
+    ::tools::Rectangle       aText = ::tools::Rectangle(Point(0,0),
                                       Size(mnPaperWidth,
                                       mrOutliner.GetTextHeight()));
-    Rectangle aWin(Point(0,0), pWin->GetOutputSizePixel());
+    ::tools::Rectangle aWin(Point(0,0), pWin->GetOutputSizePixel());
     aWin = pWin->PixelToLogic(aWin);
 
     if (!aVis.IsEmpty())        // not when opening
@@ -785,20 +779,19 @@ IMPL_LINK_NOARG_TYPED(OutlineView, StatusEventHdl, EditStatus&, void)
         if (aWin.GetHeight() > aText.Bottom())
             aText.Bottom() = aWin.GetHeight();
 
-        mrOutlineViewShell.InitWindows(Point(0,0), aText.GetSize(),
-                                       Point(aVis.TopLeft()));
+        mrOutlineViewShell.InitWindows(Point(0,0), aText.GetSize(), aVis.TopLeft());
         mrOutlineViewShell.UpdateScrollBars();
     }
 }
 
-IMPL_LINK_NOARG_TYPED(OutlineView, BeginDropHdl, EditView*, void)
+IMPL_LINK_NOARG(OutlineView, BeginDropHdl, EditView*, void)
 {
     DBG_ASSERT(maDragAndDropModelGuard.get() == nullptr, "sd::OutlineView::BeginDropHdl(), prior drag operation not finished correctly!" );
 
     maDragAndDropModelGuard.reset( new OutlineViewModelChangeGuard( *this ) );
 }
 
-IMPL_LINK_NOARG_TYPED(OutlineView, EndDropHdl, EditView*, void)
+IMPL_LINK_NOARG(OutlineView, EndDropHdl, EditView*, void)
 {
     maDragAndDropModelGuard.reset(nullptr);
 }
@@ -806,7 +799,7 @@ IMPL_LINK_NOARG_TYPED(OutlineView, EndDropHdl, EditView*, void)
 /**
  * Handler for the start of a paragraph movement
  */
-IMPL_LINK_TYPED( OutlineView, BeginMovingHdl, ::Outliner *, pOutliner, void )
+IMPL_LINK( OutlineView, BeginMovingHdl, ::Outliner *, pOutliner, void )
 {
     OutlineViewPageChangesGuard aGuard(this);
 
@@ -832,7 +825,7 @@ IMPL_LINK_TYPED( OutlineView, BeginMovingHdl, ::Outliner *, pOutliner, void )
         if( ::Outliner::HasParaFlag(pPara, ParaFlag::ISPAGE) )                     // one page?
         {
             maOldParaOrder.push_back(pPara);
-            SdPage* pPage = mrDoc.GetSdPage(nPos, PK_STANDARD);
+            SdPage* pPage = mrDoc.GetSdPage(nPos, PageKind::Standard);
 
             fiter = std::find(maSelectedParas.begin(),maSelectedParas.end(),pPara);
 
@@ -847,7 +840,7 @@ IMPL_LINK_TYPED( OutlineView, BeginMovingHdl, ::Outliner *, pOutliner, void )
 /**
  * Handler for the end of a paragraph movement
  */
-IMPL_LINK_TYPED( OutlineView, EndMovingHdl, ::Outliner *, pOutliner, void )
+IMPL_LINK( OutlineView, EndMovingHdl, ::Outliner *, pOutliner, void )
 {
     OutlineViewPageChangesGuard aGuard(this);
 
@@ -897,7 +890,7 @@ IMPL_LINK_TYPED( OutlineView, EndMovingHdl, ::Outliner *, pOutliner, void )
     sal_uInt16 nPageCount = (sal_uInt16)maSelectedParas.size();
     while (nPageCount)
     {
-        SdPage* pPage = mrDoc.GetSdPage(nPosNewOrder, PK_STANDARD);
+        SdPage* pPage = mrDoc.GetSdPage(nPosNewOrder, PageKind::Standard);
         pPage->SetSelected(false);
         nPosNewOrder++;
         nPageCount--;
@@ -912,7 +905,7 @@ IMPL_LINK_TYPED( OutlineView, EndMovingHdl, ::Outliner *, pOutliner, void )
 /**
  * Look for the title text object in one page of the model
  */
-SdrTextObj* OutlineView::GetTitleTextObject(SdrPage* pPage)
+SdrTextObj* OutlineView::GetTitleTextObject(SdrPage const * pPage)
 {
     const size_t nObjectCount = pPage->GetObjCount();
     SdrTextObj*     pResult      = nullptr;
@@ -920,7 +913,7 @@ SdrTextObj* OutlineView::GetTitleTextObject(SdrPage* pPage)
     for (size_t nObject = 0; nObject < nObjectCount; ++nObject)
     {
         SdrObject* pObject = pPage->GetObj(nObject);
-        if (pObject->GetObjInventor() == SdrInventor &&
+        if (pObject->GetObjInventor() == SdrInventor::Default &&
             pObject->GetObjIdentifier() == OBJ_TITLETEXT)
         {
             pResult = static_cast<SdrTextObj*>(pObject);
@@ -933,7 +926,7 @@ SdrTextObj* OutlineView::GetTitleTextObject(SdrPage* pPage)
 /**
  * Look for the outline text object in one page of the model
  */
-SdrTextObj* OutlineView::GetOutlineTextObject(SdrPage* pPage)
+SdrTextObj* OutlineView::GetOutlineTextObject(SdrPage const * pPage)
 {
     const size_t nObjectCount = pPage->GetObjCount();
     SdrTextObj*     pResult      = nullptr;
@@ -941,7 +934,7 @@ SdrTextObj* OutlineView::GetOutlineTextObject(SdrPage* pPage)
     for (size_t nObject = 0; nObject < nObjectCount; ++nObject)
     {
         SdrObject* pObject = pPage->GetObj(nObject);
-        if (pObject->GetObjInventor() == SdrInventor &&
+        if (pObject->GetObjInventor() == SdrInventor::Default &&
             pObject->GetObjIdentifier() == OBJ_OUTLINETEXT)
         {
             pResult = static_cast<SdrTextObj*>(pObject);
@@ -958,7 +951,7 @@ SdrTextObj* OutlineView::CreateTitleTextObject(SdPage* pPage)
     if( pPage->GetAutoLayout() == AUTOLAYOUT_NONE )
     {
         // simple case
-        pPage->SetAutoLayout( AUTOLAYOUT_ONLY_TITLE, true );
+        pPage->SetAutoLayout( AUTOLAYOUT_TITLE_ONLY, true );
     }
     else
     {
@@ -978,8 +971,8 @@ SdrTextObj* OutlineView::CreateOutlineTextObject(SdPage* pPage)
     switch( eNewLayout )
     {
     case AUTOLAYOUT_NONE:
-    case AUTOLAYOUT_ONLY_TITLE:
-    case AUTOLAYOUT_TITLE:  eNewLayout = AUTOLAYOUT_ENUM; break;
+    case AUTOLAYOUT_TITLE_ONLY:
+    case AUTOLAYOUT_TITLE:  eNewLayout = AUTOLAYOUT_TITLE_CONTENT; break;
 
     case AUTOLAYOUT_CHART:  eNewLayout = AUTOLAYOUT_CHARTTEXT; break;
 
@@ -1007,7 +1000,7 @@ SdrTextObj* OutlineView::CreateOutlineTextObject(SdPage* pPage)
 }
 
 /** updates draw model with all changes from outliner model */
-bool OutlineView::PrepareClose(bool)
+bool OutlineView::PrepareClose()
 {
     ::sd::UndoManager* pDocUndoMgr = dynamic_cast<sd::UndoManager*>(mpDocSh->GetUndoManager());
     if (pDocUndoMgr != nullptr)
@@ -1015,7 +1008,7 @@ bool OutlineView::PrepareClose(bool)
 
     mrOutliner.GetUndoManager().Clear();
 
-    BegUndo(SD_RESSTR(STR_UNDO_CHANGE_TITLE_AND_LAYOUT));
+    BegUndo(SdResId(STR_UNDO_CHANGE_TITLE_AND_LAYOUT));
     UpdateDocument();
     EndUndo();
     mrDoc.SetSelected(GetActualPage(), true);
@@ -1049,7 +1042,7 @@ void OutlineView::GetAttributes( SfxItemSet& rTargetSet, bool ) const
 {
     OutlinerView* pOlView = GetViewByWindow(
                                 mrOutlineViewShell.GetActiveWindow());
-    assert(pOlView && "keine OutlinerView gefunden");
+    assert(pOlView && "No OutlinerView found");
 
     rTargetSet.Put( pOlView->GetAttribs(), false );
 }
@@ -1063,12 +1056,12 @@ void OutlineView::FillOutliner()
     mrOutliner.SetUpdateMode(false);
 
     Paragraph* pTitleToSelect = nullptr;
-    sal_uInt16 nPageCount = mrDoc.GetSdPageCount(PK_STANDARD);
+    sal_uInt16 nPageCount = mrDoc.GetSdPageCount(PageKind::Standard);
 
     // fill outliner with paragraphs from slides title & (outlines|subtitles)
     for (sal_uInt16 nPage = 0; nPage < nPageCount; nPage++)
     {
-        SdPage*     pPage = mrDoc.GetSdPage(nPage, PK_STANDARD);
+        SdPage*     pPage = mrDoc.GetSdPage(nPage, PageKind::Standard);
         Paragraph * pPara = nullptr;
 
         // take text from title shape
@@ -1161,7 +1154,7 @@ void OutlineView::FillOutliner()
 /**
  * Handler for deleting of level 0 paragraphs (pages): Warning
  */
-IMPL_LINK_NOARG_TYPED(OutlineView, RemovingPagesHdl, OutlinerView*, bool)
+IMPL_LINK_NOARG(OutlineView, RemovingPagesHdl, OutlinerView*, bool)
 {
     sal_Int32 nNumOfPages = mrOutliner.GetSelPageCount();
 
@@ -1174,7 +1167,7 @@ IMPL_LINK_NOARG_TYPED(OutlineView, RemovingPagesHdl, OutlinerView*, bool)
     if (mnPagesToProcess)
     {
         delete mpProgress;
-        mpProgress = new SfxProgress( GetDocSh(), SD_RESSTR(STR_DELETE_PAGES), mnPagesToProcess );
+        mpProgress = new SfxProgress( GetDocSh(), SdResId(STR_DELETE_PAGES), mnPagesToProcess );
     }
     mrOutliner.UpdateFields();
 
@@ -1184,7 +1177,7 @@ IMPL_LINK_NOARG_TYPED(OutlineView, RemovingPagesHdl, OutlinerView*, bool)
 /**
  * Handler for indenting level 0 paragraphs (pages): Warning
  */
-IMPL_LINK_TYPED( OutlineView, IndentingPagesHdl, OutlinerView *, pOutlinerView, bool )
+IMPL_LINK( OutlineView, IndentingPagesHdl, OutlinerView *, pOutlinerView, bool )
 {
     return RemovingPagesHdl(pOutlinerView);
 }
@@ -1210,7 +1203,7 @@ SdPage* OutlineView::GetActualPage()
     if( pCurrent )
         return pCurrent;
 
-    return mrDoc.GetSdPage( 0, PK_STANDARD );
+    return mrDoc.GetSdPage( 0, PageKind::Standard );
 }
 
 SdPage* OutlineView::GetPageForParagraph( Paragraph* pPara )
@@ -1226,13 +1219,13 @@ SdPage* OutlineView::GetPageForParagraph( Paragraph* pPara )
             nPageToSelect++;
     }
 
-    if( nPageToSelect < (sal_uInt32)mrDoc.GetSdPageCount( PK_STANDARD ) )
-        return static_cast< SdPage* >( mrDoc.GetSdPage( (sal_uInt16)nPageToSelect, PK_STANDARD) );
+    if( nPageToSelect < (sal_uInt32)mrDoc.GetSdPageCount( PageKind::Standard ) )
+        return mrDoc.GetSdPage( (sal_uInt16)nPageToSelect, PageKind::Standard );
 
     return nullptr;
 }
 
-Paragraph* OutlineView::GetParagraphForPage( ::Outliner& rOutl, SdPage* pPage )
+Paragraph* OutlineView::GetParagraphForPage( ::Outliner const & rOutl, SdPage const * pPage )
 {
     // get the number of paragraphs with ident 0 we need to skip before
     // we finde the actual page
@@ -1261,9 +1254,9 @@ Paragraph* OutlineView::GetParagraphForPage( ::Outliner& rOutl, SdPage* pPage )
 }
 
 /** selects the paragraph for the given page at the outliner view*/
-void OutlineView::SetActualPage( SdPage* pActual )
+void OutlineView::SetActualPage( SdPage const * pActual )
 {
-    if( pActual && dynamic_cast<Outliner&>(mrOutliner).GetIgnoreCurrentPageChangesLevel()==0 && !mbFirstPaint)
+    if( pActual && dynamic_cast<SdOutliner&>(mrOutliner).GetIgnoreCurrentPageChangesLevel()==0 && !mbFirstPaint)
     {
         // if we found a paragraph, select its text at the outliner view
         Paragraph* pPara = GetParagraphForPage( mrOutliner, pActual );
@@ -1310,7 +1303,7 @@ void OutlineView::SetSelectedPages()
     {
         if( ::Outliner::HasParaFlag(pPara, ParaFlag::ISPAGE) )                     // one page
         {
-            SdPage* pPage = mrDoc.GetSdPage(nPos, PK_STANDARD);
+            SdPage* pPage = mrDoc.GetSdPage(nPos, PageKind::Standard);
             DBG_ASSERT(pPage!=nullptr,
                 "Trying to select non-existing page OutlineView::SetSelectedPages()");
 
@@ -1353,9 +1346,9 @@ void OutlineView::SetLinks()
  */
 void OutlineView::ResetLinks() const
 {
-    mrOutliner.SetParaInsertedHdl(Link<::Outliner*,void>());
-    mrOutliner.SetParaRemovingHdl(Link<::Outliner*,void>());
-    mrOutliner.SetDepthChangedHdl(Link<::Outliner*,void>());
+    mrOutliner.SetParaInsertedHdl(Link<::Outliner::ParagraphHdlParam,void>());
+    mrOutliner.SetParaRemovingHdl(Link<::Outliner::ParagraphHdlParam,void>());
+    mrOutliner.SetDepthChangedHdl(Link<::Outliner::DepthChangeHdlParam,void>());
     mrOutliner.SetBeginMovingHdl(Link<::Outliner*,void>());
     mrOutliner.SetEndMovingHdl(Link<::Outliner*,void>());
     mrOutliner.SetStatusEventHdl(Link<EditStatus&,void>());
@@ -1366,12 +1359,12 @@ void OutlineView::ResetLinks() const
     mrOutliner.SetEndPasteOrDropHdl(Link<PasteOrDropInfos*,void>());
 }
 
-sal_Int8 OutlineView::AcceptDrop( const AcceptDropEvent&, DropTargetHelper&, ::sd::Window*, sal_uInt16, sal_uInt16)
+sal_Int8 OutlineView::AcceptDrop( const AcceptDropEvent&, DropTargetHelper&, ::sd::Window*, sal_uInt16, SdrLayerID)
 {
     return DND_ACTION_NONE;
 }
 
-sal_Int8 OutlineView::ExecuteDrop( const ExecuteDropEvent&, ::sd::Window*, sal_uInt16, sal_uInt16)
+sal_Int8 OutlineView::ExecuteDrop( const ExecuteDropEvent&, ::sd::Window*, sal_uInt16, SdrLayerID)
 {
     return DND_ACTION_NONE;
 }
@@ -1418,21 +1411,21 @@ void OutlineView::onUpdateStyleSettings( bool bForceUpdate /* = false */ )
     }
 }
 
-IMPL_LINK_NOARG_TYPED(OutlineView, AppEventListenerHdl, VclSimpleEvent&, void)
+IMPL_LINK_NOARG(OutlineView, AppEventListenerHdl, VclSimpleEvent&, void)
 {
-    onUpdateStyleSettings();
+    onUpdateStyleSettings(false);
 }
 
-IMPL_LINK_TYPED(OutlineView, EventMultiplexerListener, ::sd::tools::EventMultiplexerEvent&, rEvent, void)
+IMPL_LINK(OutlineView, EventMultiplexerListener, ::sd::tools::EventMultiplexerEvent&, rEvent, void)
 {
     switch (rEvent.meEventId)
     {
-        case tools::EventMultiplexerEvent::EID_CURRENT_PAGE:
+        case EventMultiplexerEventId::CurrentPageChanged:
             SetActualPage(mrOutlineViewShell.GetActualPage());
             break;
 
-        case tools::EventMultiplexerEvent::EID_PAGE_ORDER:
-            if (dynamic_cast<Outliner&>(mrOutliner).GetIgnoreCurrentPageChangesLevel()==0)
+        case EventMultiplexerEventId::PageOrder:
+            if (dynamic_cast<SdOutliner&>(mrOutliner).GetIgnoreCurrentPageChangesLevel()==0)
             {
                 if (((mrDoc.GetPageCount()-1)%2) == 0)
                 {
@@ -1444,23 +1437,25 @@ IMPL_LINK_TYPED(OutlineView, EventMultiplexerListener, ::sd::tools::EventMultipl
                 }
             }
             break;
+
+        default: break;
     }
 }
 
 void OutlineView::IgnoreCurrentPageChanges (bool bIgnoreChanges)
 {
     if (bIgnoreChanges)
-        dynamic_cast<Outliner&>(mrOutliner).IncreIgnoreCurrentPageChangesLevel();
+        dynamic_cast<SdOutliner&>(mrOutliner).IncreIgnoreCurrentPageChangesLevel();
     else
-        dynamic_cast<Outliner&>(mrOutliner).DecreIgnoreCurrentPageChangesLevel();
+        dynamic_cast<SdOutliner&>(mrOutliner).DecreIgnoreCurrentPageChangesLevel();
 }
 
 /** call this method before you do anything that can modify the outliner
     and or the drawing document model. It will create needed undo actions */
 void OutlineView::BeginModelChange()
 {
-    mrOutliner.GetUndoManager().EnterListAction("", "");
-    BegUndo(SD_RESSTR(STR_UNDO_CHANGE_TITLE_AND_LAYOUT));
+    mrOutliner.GetUndoManager().EnterListAction("", "", 0, mrOutlineViewShell.GetViewShellBase().GetViewShellId());
+    BegUndo(SdResId(STR_UNDO_CHANGE_TITLE_AND_LAYOUT));
 }
 
 /** call this method after BeginModelChange(), when all possible model
@@ -1491,12 +1486,12 @@ void OutlineView::UpdateDocument()
 {
     OutlineViewPageChangesGuard aGuard(this);
 
-    const sal_uInt32 nPageCount = mrDoc.GetSdPageCount(PK_STANDARD);
+    const sal_uInt32 nPageCount = mrDoc.GetSdPageCount(PageKind::Standard);
     Paragraph* pPara = mrOutliner.GetParagraph( 0 );
     sal_uInt32 nPage;
     for (nPage = 0; nPage < nPageCount; nPage++)
     {
-        SdPage* pPage = mrDoc.GetSdPage( (sal_uInt16)nPage, PK_STANDARD);
+        SdPage* pPage = mrDoc.GetSdPage( (sal_uInt16)nPage, PageKind::Standard);
         mrDoc.SetSelected(pPage, false);
 
         mrOutlineViewShell.UpdateTitleObject( pPage, pPara );
@@ -1568,47 +1563,6 @@ void OutlineView::TryToMergeUndoActions()
                     pListAction->aUndoActions.Remove(nEditPos);
                     delete pEditUndo;
 
-                    // now check if we also can merge the draw undo actions
-                    ::svl::IUndoManager* pDocUndoManager = mpDocSh->GetUndoManager();
-                    if( pDocUndoManager && ( pListAction->aUndoActions.size() == 1 ))
-                    {
-                        SfxLinkUndoAction* pLinkAction = dynamic_cast< SfxLinkUndoAction* >( pListAction->aUndoActions.GetUndoAction(0) );
-                        SfxLinkUndoAction* pPrevLinkAction = nullptr;
-
-                        if( pLinkAction )
-                        {
-                            nAction = pPrevListAction->aUndoActions.size();
-                            while( !pPrevLinkAction && nAction )
-                                pPrevLinkAction = dynamic_cast< SfxLinkUndoAction* >(pPrevListAction->aUndoActions.GetUndoAction(--nAction));
-                        }
-
-                        if( pLinkAction && pPrevLinkAction &&
-                            ( pLinkAction->GetAction() == pDocUndoManager->GetUndoAction() ) &&
-                            ( pPrevLinkAction->GetAction() == pDocUndoManager->GetUndoAction(1) ) )
-                        {
-                            SfxListUndoAction* pSourceList = dynamic_cast< SfxListUndoAction* >(pLinkAction->GetAction());
-                            SfxListUndoAction* pDestinationList = dynamic_cast< SfxListUndoAction* >(pPrevLinkAction->GetAction());
-
-                            if( pSourceList && pDestinationList )
-                            {
-                                sal_uInt16 nCount = pSourceList->aUndoActions.size();
-                                sal_uInt16 nDestAction = pDestinationList->aUndoActions.size();
-                                while( nCount-- )
-                                {
-                                    SfxUndoAction* pTemp = pSourceList->aUndoActions.GetUndoAction(0);
-                                    pSourceList->aUndoActions.Remove(0);
-                                    pDestinationList->aUndoActions.Insert( pTemp, nDestAction++ );
-                                }
-                                pDestinationList->nCurUndoAction = pDestinationList->aUndoActions.size();
-
-                                pListAction->aUndoActions.Remove(0);
-                                delete pLinkAction;
-
-                                pDocUndoManager->RemoveLastUndoAction();
-                            }
-                        }
-                    }
-
                     if ( !pListAction->aUndoActions.empty() )
                     {
                         // now we have to move all remaining doc undo actions from the top undo
@@ -1633,7 +1587,7 @@ void OutlineView::TryToMergeUndoActions()
     }
 }
 
-IMPL_LINK_TYPED(OutlineView, PaintingFirstLineHdl, PaintFirstLineInfo*, pInfo, void)
+IMPL_LINK(OutlineView, PaintingFirstLineHdl, PaintFirstLineInfo*, pInfo, void)
 {
     if( !pInfo )
         return;
@@ -1676,7 +1630,7 @@ IMPL_LINK_TYPED(OutlineView, PaintingFirstLineHdl, PaintFirstLineInfo*, pInfo, v
             const float fImageRatio  = (float)aImageSize.Height() / (float)aImageSize.Width();
             aImageSize.Width() = (long)( fImageRatio * fImageHeight );
         }
-        aImageSize.Height() = (long)( fImageHeight );
+        aImageSize.Height() = (long)fImageHeight;
 
         Point aImagePos( pInfo->mrStartPos );
         aImagePos.X() += aOutSize.Width() - aImageSize.Width() - aOffset.Width() ;
@@ -1803,7 +1757,7 @@ OutlineViewModelChangeGuard::OutlineViewModelChangeGuard( OutlineView& rView )
     mrView.BeginModelChange();
 }
 
-OutlineViewModelChangeGuard::~OutlineViewModelChangeGuard()
+OutlineViewModelChangeGuard::~OutlineViewModelChangeGuard() COVERITY_NOEXCEPT_FALSE
 {
     mrView.EndModelChange();
 }
