@@ -17,20 +17,18 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
-#include "Ruler.hxx"
+#include <Ruler.hxx>
 #include <svl/ptitem.hxx>
 #include <svx/ruler.hxx>
 #include <svx/svxids.hrc>
 #include <sfx2/ctrlitem.hxx>
 #include <sfx2/bindings.hxx>
 
+#include <View.hxx>
+#include <DrawViewShell.hxx>
+#include <Window.hxx>
 
-#include "View.hxx"
-#include "DrawViewShell.hxx"
-#include "Window.hxx"
-
-#include "helpids.h"
+#include <helpids.h>
 
 namespace sd {
 
@@ -43,14 +41,14 @@ class RulerCtrlItem : public SfxControllerItem
 
  protected:
     virtual void StateChanged( sal_uInt16 nSId, SfxItemState eState,
-                                const SfxPoolItem* pItem );
+                                const SfxPoolItem* pItem ) override;
 
  public:
-    RulerCtrlItem(sal_uInt16 nId, Ruler& rRlr, SfxBindings& rBind);
+    RulerCtrlItem(Ruler& rRlr, SfxBindings& rBind);
 };
 
-RulerCtrlItem::RulerCtrlItem(sal_uInt16 _nId, Ruler& rRlr, SfxBindings& rBind)
-: SfxControllerItem(_nId, rBind)
+RulerCtrlItem::RulerCtrlItem(Ruler& rRlr, SfxBindings& rBind)
+: SfxControllerItem(SID_RULER_NULL_OFFSET, rBind)
 , rRuler(rRlr)
 {
 }
@@ -62,7 +60,7 @@ void RulerCtrlItem::StateChanged( sal_uInt16 nSId, SfxItemState, const SfxPoolIt
         case SID_RULER_NULL_OFFSET:
         {
             const SfxPointItem* pItem = dynamic_cast< const SfxPointItem* >(pState);
-            DBG_ASSERT(pState ? pItem != NULL : sal_True, "SfxPointItem expected");
+            DBG_ASSERT(pState == nullptr || pItem != nullptr, "SfxPointItem expected");
             if ( pItem )
                 rRuler.SetNullOffset(pItem->GetValue());
         }
@@ -70,39 +68,40 @@ void RulerCtrlItem::StateChanged( sal_uInt16 nSId, SfxItemState, const SfxPoolIt
     }
 }
 
-
-
-Ruler::Ruler( DrawViewShell& rViewSh, ::Window* pParent, ::sd::Window* pWin, sal_uInt16 nRulerFlags,  SfxBindings& rBindings, WinBits nWinStyle)
-: SvxRuler(pParent, pWin, nRulerFlags, rBindings, nWinStyle)
-, pSdWin(pWin)
-, pDrViewShell(&rViewSh)
+Ruler::Ruler( DrawViewShell& rViewSh, vcl::Window* pParent, ::sd::Window* pWin, SvxRulerSupportFlags nRulerFlags,  SfxBindings& rBindings, WinBits nWinStyle)
+    : SvxRuler(pParent, pWin, nRulerFlags, rBindings, nWinStyle)
+    , pDrViewShell(&rViewSh)
 {
     rBindings.EnterRegistrations();
-    pCtrlItem = new RulerCtrlItem(SID_RULER_NULL_OFFSET, *this, rBindings);
+    pCtrlItem = new RulerCtrlItem(*this, rBindings);
     rBindings.LeaveRegistrations();
 
     if ( nWinStyle & WB_HSCROLL )
     {
-        bHorz = sal_True;
+        bHorz = true;
         SetHelpId( HID_SD_RULER_HORIZONTAL );
     }
     else
     {
-        bHorz = sal_False;
+        bHorz = false;
         SetHelpId( HID_SD_RULER_VERTICAL );
     }
 }
 
-
 Ruler::~Ruler()
+{
+    disposeOnce();
+}
+
+void Ruler::dispose()
 {
     SfxBindings& rBindings = pCtrlItem->GetBindings();
     rBindings.EnterRegistrations();
-    delete pCtrlItem;
+    DELETEZ( pCtrlItem );
     rBindings.LeaveRegistrations();
+    SvxRuler::dispose();
 }
 
-
 void Ruler::MouseButtonDown(const MouseEvent& rMEvt)
 {
     Point aMPos = rMEvt.GetPosPixel();
@@ -110,7 +109,7 @@ void Ruler::MouseButtonDown(const MouseEvent& rMEvt)
 
     if ( !pDrViewShell->GetView()->IsTextEdit() &&
         rMEvt.IsLeft() && rMEvt.GetClicks() == 1 &&
-        (eType == RULER_TYPE_DONTKNOW || eType == RULER_TYPE_OUTSIDE) )
+        (eType == RulerType::DontKnow || eType == RulerType::Outside) )
     {
         pDrViewShell->StartRulerDrag(*this, rMEvt);
     }
@@ -118,19 +117,6 @@ void Ruler::MouseButtonDown(const MouseEvent& rMEvt)
         SvxRuler::MouseButtonDown(rMEvt);
 }
 
-
-void Ruler::MouseMove(const MouseEvent& rMEvt)
-{
-    SvxRuler::MouseMove(rMEvt);
-}
-
-
-void Ruler::MouseButtonUp(const MouseEvent& rMEvt)
-{
-    SvxRuler::MouseButtonUp(rMEvt);
-}
-
-
 void Ruler::SetNullOffset(const Point& rOffset)
 {
     long nOffset;
@@ -141,17 +127,15 @@ void Ruler::SetNullOffset(const Point& rOffset)
     SetNullOffsetLogic(nOffset);
 }
 
-
 void Ruler::Command(const CommandEvent& rCEvt)
 {
-    if( rCEvt.GetCommand() == COMMAND_CONTEXTMENU &&
+    if( rCEvt.GetCommand() == CommandEventId::ContextMenu &&
         !pDrViewShell->GetView()->IsTextEdit() )
     {
         SvxRuler::Command( rCEvt );
     }
 }
 
-
 void Ruler::ExtraDown()
 {
     if( !pDrViewShell->GetView()->IsTextEdit() )
