@@ -17,8 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
-#include "Window.hxx"
+#include <Window.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/request.hxx>
 
@@ -27,17 +26,26 @@
 
 #include <editeng/outliner.hxx>
 #include <editeng/editview.hxx>
+#include <editeng/editeng.hxx>
 
-#include "app.hrc"
-#include "helpids.h"
-#include "ViewShell.hxx"
-#include "DrawViewShell.hxx"
-#include "View.hxx"
-#include "FrameView.hxx"
-#include "OutlineViewShell.hxx"
-#include "drawdoc.hxx"
-#include "AccessibleDrawDocumentView.hxx"
-#include "WindowUpdater.hxx"
+#include <app.hrc>
+#include <helpids.h>
+#include <ViewShell.hxx>
+#include <DrawViewShell.hxx>
+#include <View.hxx>
+#include <FrameView.hxx>
+#include <OutlineViewShell.hxx>
+#include <drawdoc.hxx>
+#include <AccessibleDrawDocumentView.hxx>
+#include <WindowUpdater.hxx>
+#include <ViewShellBase.hxx>
+#include <uiobject.hxx>
+
+#include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
+#include <LibreOfficeKit/LibreOfficeKitEnums.h>
+#include <comphelper/lok.hxx>
+#include <sfx2/lokhelper.hxx>
 
 namespace sd {
 
@@ -48,12 +56,10 @@ namespace sd {
 #define MIN_ZOOM           5        ///< minimal zoom factor
 #define MAX_ZOOM           3000     ///< maximal zoom factor
 
-
-
-Window::Window(::Window* pParent)
-    : ::Window(pParent, WinBits(WB_CLIPCHILDREN | WB_DIALOGCONTROL)),
+Window::Window(vcl::Window* pParent)
+    : vcl::Window(pParent, WinBits(WB_CLIPCHILDREN | WB_DIALOGCONTROL)),
       DropTargetHelper( this ),
-      mpShareWin(NULL),
+      mpShareWin(nullptr),
       maWinPos(0, 0),           // precautionary; but the values should be set
       maViewOrigin(0, 0),       // again from the owner of the window
       maViewSize(1000, 1000),
@@ -61,72 +67,75 @@ Window::Window(::Window* pParent)
       mnMinZoom(MIN_ZOOM),
       mnMaxZoom(MAX_ZOOM),
       mbMinZoomAutoCalc(false),
-      mbCalcMinZoomByMinSide(true),
       mbCenterAllowed(true),
       mnTicks (0),
-      mbDraggedFrom(false),
-      mpViewShell(NULL),
+      mpViewShell(nullptr),
       mbUseDropScroll (true)
 {
-    SetDialogControlFlags( WINDOW_DLGCTRL_RETURN | WINDOW_DLGCTRL_WANTFOCUS );
+    SetDialogControlFlags( DialogControlFlags::Return | DialogControlFlags::WantFocus );
 
     MapMode aMap(GetMapMode());
-    aMap.SetMapUnit(MAP_100TH_MM);
+    aMap.SetMapUnit(MapUnit::Map100thMM);
     SetMapMode(aMap);
 
-    // whit it, the ::WindowColor is used in the slide mode
+    // whit it, the vcl::WindowColor is used in the slide mode
     SetBackground( Wallpaper( GetSettings().GetStyleSettings().GetWindowColor() ) );
 
     // adjust contrast mode initially
     bool bUseContrast = GetSettings().GetStyleSettings().GetHighContrastMode();
     SetDrawMode( bUseContrast
-        ? ViewShell::OUTPUT_DRAWMODE_CONTRAST
-        : ViewShell::OUTPUT_DRAWMODE_COLOR );
-
-    // set Help ID
-    // SetHelpId(HID_SD_WIN_DOCUMENT);
-    SetUniqueId(HID_SD_WIN_DOCUMENT);
+        ? sd::OUTPUT_DRAWMODE_CONTRAST
+        : sd::OUTPUT_DRAWMODE_COLOR );
 
     // #i78183# Added after discussed with AF
-    EnableRTL(sal_False);
+    EnableRTL(false);
 }
 
-
-Window::~Window (void)
+Window::~Window()
 {
-    if (mpViewShell != NULL)
+    disposeOnce();
+}
+
+void Window::dispose()
+{
+    if (mpViewShell != nullptr)
     {
         WindowUpdater* pWindowUpdater = mpViewShell->GetWindowUpdater();
-        if (pWindowUpdater != NULL)
+        if (pWindowUpdater != nullptr)
             pWindowUpdater->UnregisterWindow (this);
     }
+    mpShareWin.clear();
+    DropTargetHelper::dispose();
+    vcl::Window::dispose();
 }
 
-
-
-
 void Window::SetViewShell (ViewShell* pViewSh)
 {
-    WindowUpdater* pWindowUpdater = NULL;
+    WindowUpdater* pWindowUpdater = nullptr;
     // Unregister at device updater of old view shell.
-    if (mpViewShell != NULL)
+    if (mpViewShell != nullptr)
     {
         pWindowUpdater = mpViewShell->GetWindowUpdater();
-        if (pWindowUpdater != NULL)
+        if (pWindowUpdater != nullptr)
             pWindowUpdater->UnregisterWindow (this);
     }
 
     mpViewShell = pViewSh;
 
     // Register at device updater of new view shell
-    if (mpViewShell != NULL)
+    if (mpViewShell != nullptr)
     {
         pWindowUpdater = mpViewShell->GetWindowUpdater();
-        if (pWindowUpdater != NULL)
+        if (pWindowUpdater != nullptr)
             pWindowUpdater->RegisterWindow (this);
     }
 }
 
+ViewShell* Window::GetViewShell()
+{
+    return mpViewShell;
+}
+
 void Window::CalcMinZoom()
 {
     // Are we entitled to change the minimal zoom factor?
@@ -153,13 +162,9 @@ void Window::CalcMinZoom()
                 * (double) ZOOM_MULTIPLICATOR / (double) maViewSize.Height());
 
             // Decide whether to take the larger or the smaller factor.
-            sal_uLong nFact;
-            if (mbCalcMinZoomByMinSide)
-                nFact = std::min(nX, nY);
-            else
-                nFact = std::max(nX, nY);
+            sal_uLong nFact = std::min(nX, nY);
 
-            // The factor is tansfomed according to the current zoom factor.
+            // The factor is transformed according to the current zoom factor.
             nFact = nFact * nZoom / ZOOM_MULTIPLICATOR;
             mnMinZoom = std::max((sal_uInt16) MIN_ZOOM, (sal_uInt16) nFact);
         }
@@ -171,47 +176,21 @@ void Window::CalcMinZoom()
     }
 }
 
-
-
-
 void Window::SetMinZoom (long int nMin)
 {
     mnMinZoom = (sal_uInt16) nMin;
 }
 
-
-
-
-long Window::GetMinZoom (void) const
-{
-    return mnMinZoom;
-}
-
-
-
-
 void Window::SetMaxZoom (long int nMax)
 {
     mnMaxZoom = (sal_uInt16) nMax;
 }
 
-
-
-
-long Window::GetMaxZoom (void) const
-{
-    return mnMaxZoom;
-}
-
-
-
-
-long Window::GetZoom (void) const
+long Window::GetZoom() const
 {
     if( GetMapMode().GetScaleX().GetDenominator() )
     {
-        return GetMapMode().GetScaleX().GetNumerator() * 100L
-            / GetMapMode().GetScaleX().GetDenominator();
+        return long(GetMapMode().GetScaleX() * 100);
     }
     else
     {
@@ -219,36 +198,38 @@ long Window::GetZoom (void) const
     }
 }
 
-
-
-
-
 void Window::Resize()
 {
-    ::Window::Resize();
+    vcl::Window::Resize();
     CalcMinZoom();
 
     if( mpViewShell && mpViewShell->GetViewFrame() )
         mpViewShell->GetViewFrame()->GetBindings().Invalidate( SID_ATTR_ZOOMSLIDER );
 }
 
-
-void Window::PrePaint()
+void Window::PrePaint(vcl::RenderContext& /*rRenderContext*/)
 {
     if ( mpViewShell )
         mpViewShell->PrePaint();
 }
 
-
-void Window::Paint(const Rectangle& rRect)
+void Window::Paint(vcl::RenderContext& /*rRenderContext*/, const ::tools::Rectangle& rRect)
 {
     if ( mpViewShell )
         mpViewShell->Paint(rRect, this);
 }
 
-
 void Window::KeyInput(const KeyEvent& rKEvt)
 {
+    if (getenv("SD_DEBUG") && rKEvt.GetKeyCode().GetCode() == KEY_F12 && mpViewShell)
+    {
+        mpViewShell->GetDoc()->dumpAsXml(nullptr);
+        OutlinerView *pOLV = mpViewShell->GetView()->GetTextEditOutlinerView();
+        if (pOLV)
+            pOLV->GetEditView().GetEditEngine()->dumpAsXmlEditDoc(nullptr);
+        return;
+    }
+
     if (!(mpViewShell && mpViewShell->KeyInput(rKEvt, this)))
     {
         if (mpViewShell && rKEvt.GetKeyCode().GetCode() == KEY_ESCAPE)
@@ -257,26 +238,23 @@ void Window::KeyInput(const KeyEvent& rKEvt)
         }
         else
         {
-            ::Window::KeyInput(rKEvt);
+            vcl::Window::KeyInput(rKEvt);
         }
     }
 }
 
-
 void Window::MouseButtonDown(const MouseEvent& rMEvt)
 {
     if ( mpViewShell )
         mpViewShell->MouseButtonDown(rMEvt, this);
 }
 
-
 void Window::MouseMove(const MouseEvent& rMEvt)
 {
     if ( mpViewShell )
         mpViewShell->MouseMove(rMEvt, this);
 }
 
-
 void Window::MouseButtonUp(const MouseEvent& rMEvt)
 {
     mnTicks = 0;
@@ -285,66 +263,39 @@ void Window::MouseButtonUp(const MouseEvent& rMEvt)
         mpViewShell->MouseButtonUp(rMEvt, this);
 }
 
-
 void Window::Command(const CommandEvent& rCEvt)
 {
-    if ( mpViewShell )
+    if (mpViewShell)
         mpViewShell->Command(rCEvt, this);
+    //pass at least alt press/release to parent impl
+    if (rCEvt.GetCommand() == CommandEventId::ModKeyChange)
+        vcl::Window::Command(rCEvt);
 }
 
-
-long Window::Notify( NotifyEvent& rNEvt )
+bool Window::EventNotify( NotifyEvent& rNEvt )
 {
-    long nResult = sal_False;
+    bool bResult = false;
     if ( mpViewShell )
     {
-        nResult = mpViewShell->Notify(rNEvt, this);
+        bResult = mpViewShell->Notify(rNEvt, this);
     }
-    if( !nResult )
-        nResult = ::Window::Notify( rNEvt );
+    if( !bResult )
+        bResult = vcl::Window::EventNotify(rNEvt);
 
-    return nResult;
+    return bResult;
 }
 
-
 void Window::RequestHelp(const HelpEvent& rEvt)
 {
     if ( mpViewShell )
     {
-        if( !mpViewShell->RequestHelp( rEvt, this) )
-            ::Window::RequestHelp( rEvt );
+        if( !mpViewShell->RequestHelp( rEvt ) )
+            vcl::Window::RequestHelp( rEvt );
     }
     else
-        ::Window::RequestHelp( rEvt );
+        vcl::Window::RequestHelp( rEvt );
 }
 
-
-
-
-Point Window::GetWinViewPos (void) const
-{
-    return maWinPos;
-}
-
-
-
-
-Point Window::GetViewOrigin (void) const
-{
-    return maViewOrigin;
-}
-
-
-
-
-Size Window::GetViewSize (void) const
-{
-    return maViewSize;
-}
-
-
-
-
 /**
  * Set the position of the upper left corner from the visible area of the
  * window.
@@ -371,17 +322,11 @@ void Window::SetViewSize(const Size& rSize)
     CalcMinZoom();
 }
 
-
-
-
 void Window::SetCenterAllowed (bool bIsAllowed)
 {
     mbCenterAllowed = bIsAllowed;
 }
 
-
-
-
 long Window::SetZoomFactor(long nZoom)
 {
     // Clip the zoom factor to the valid range marked by nMinZoom as
@@ -392,10 +337,13 @@ long Window::SetZoomFactor(long nZoom)
         nZoom = mnMinZoom;
 
     // Set the zoom factor at the window's map mode.
-    MapMode aMap(GetMapMode());
-    aMap.SetScaleX(Fraction(nZoom, 100));
-    aMap.SetScaleY(Fraction(nZoom, 100));
-    SetMapMode(aMap);
+    if (!comphelper::LibreOfficeKit::isActive())
+    {
+        MapMode aMap(GetMapMode());
+        aMap.SetScaleX(Fraction(nZoom, 100));
+        aMap.SetScaleY(Fraction(nZoom, 100));
+        SetMapMode(aMap);
+    }
 
     // invalidate previous size - it was relative to the old scaling
     maPrevSize = Size(-1,-1);
@@ -404,8 +352,8 @@ long Window::SetZoomFactor(long nZoom)
     UpdateMapOrigin();
 
     // Update the view's snapping to the new zoom factor.
-    if ( mpViewShell && mpViewShell->ISA(DrawViewShell) )
-        ((DrawViewShell*) mpViewShell)->GetView()->
+    if ( mpViewShell && dynamic_cast< DrawViewShell *>( mpViewShell ) !=  nullptr )
+        static_cast<DrawViewShell*>(mpViewShell)->GetView()->
                                         RecalcLogicSnapMagnetic(*this);
 
     // Return the zoom factor just in case it has been changed above to lie
@@ -437,7 +385,7 @@ void Window::SetZoomIntegral(long nZoom)
     SetZoomFactor(nZoom);
 }
 
-long Window::GetZoomForRect( const Rectangle& rZoomRect )
+long Window::GetZoomForRect( const ::tools::Rectangle& rZoomRect )
 {
     long nRetZoom = 100;
 
@@ -447,8 +395,8 @@ long Window::GetZoomForRect( const Rectangle& rZoomRect )
         // rectangle being fully visible (when translated accordingly) as
         // large as possible in the output area independently in both
         // coordinate directions .
-        sal_uLong nX(0L);
-        sal_uLong nY(0L);
+        sal_uLong nX(0);
+        sal_uLong nY(0);
 
         const Size aWinSize( PixelToLogic(GetOutputSizePixel()) );
         if(rZoomRect.GetHeight())
@@ -496,7 +444,7 @@ long Window::GetZoomForRect( const Rectangle& rZoomRect )
     is displayed centered and as large as possible while still being fully
     visible in the window.
 */
-long Window::SetZoomRect (const Rectangle& rZoomRect)
+long Window::SetZoomRect (const ::tools::Rectangle& rZoomRect)
 {
     long nNewZoom = 100;
 
@@ -521,8 +469,8 @@ long Window::SetZoomRect (const Rectangle& rZoomRect)
         // rectangle being fully visible (when translated accordingly) as
         // large as possible in the output area independently in both
         // coordinate directions .
-        sal_uLong nX(0L);
-        sal_uLong nY(0L);
+        sal_uLong nX(0);
+        sal_uLong nY(0);
 
         if(rZoomRect.GetHeight())
         {
@@ -572,28 +520,22 @@ long Window::SetZoomRect (const Rectangle& rZoomRect)
         }
     }
 
-    return(nNewZoom);
+    return nNewZoom;
 }
 
-
-
-
 void Window::SetMinZoomAutoCalc (bool bAuto)
 {
     mbMinZoomAutoCalc = bAuto;
 }
 
-
-
-
 /**
  * Calculate and set new MapMode origin.
  * If aWinPos.X()/Y() == -1, then we center the corresponding position (e.g. for
  * initialization).
  */
-void Window::UpdateMapOrigin(sal_Bool bInvalidate)
+void Window::UpdateMapOrigin(bool bInvalidate)
 {
-    sal_Bool       bChanged = sal_False;
+    bool       bChanged = false;
     const Size aWinSize = PixelToLogic(GetOutputSizePixel());
 
     if ( mbCenterAllowed )
@@ -604,28 +546,28 @@ void Window::UpdateMapOrigin(sal_Bool bInvalidate)
             // resizes
             maWinPos.X() -= (aWinSize.Width() - maPrevSize.Width()) / 2;
             maWinPos.Y() -= (aWinSize.Height() - maPrevSize.Height()) / 2;
-            bChanged = sal_True;
+            bChanged = true;
         }
 
         if ( maWinPos.X() > maViewSize.Width() - aWinSize.Width() )
         {
             maWinPos.X() = maViewSize.Width() - aWinSize.Width();
-            bChanged = sal_True;
+            bChanged = true;
         }
         if ( maWinPos.Y() > maViewSize.Height() - aWinSize.Height() )
         {
             maWinPos.Y() = maViewSize.Height() - aWinSize.Height();
-            bChanged = sal_True;
+            bChanged = true;
         }
         if ( aWinSize.Width() > maViewSize.Width() || maWinPos.X() < 0 )
         {
             maWinPos.X() = maViewSize.Width()  / 2 - aWinSize.Width()  / 2;
-            bChanged = sal_True;
+            bChanged = true;
         }
         if ( aWinSize.Height() > maViewSize.Height() || maWinPos.Y() < 0 )
         {
             maWinPos.Y() = maViewSize.Height() / 2 - aWinSize.Height() / 2;
-            bChanged = sal_True;
+            bChanged = true;
         }
     }
 
@@ -633,14 +575,12 @@ void Window::UpdateMapOrigin(sal_Bool bInvalidate)
 
     maPrevSize = aWinSize;
 
-    if (bChanged && bInvalidate)
+    // When tiled rendering, the above UpdateMapMode() call doesn't touch the map mode.
+    if (bChanged && bInvalidate && !comphelper::LibreOfficeKit::isActive())
         Invalidate();
 }
 
-
-
-
-void Window::UpdateMapMode (void)
+void Window::UpdateMapMode()
 {
     maWinPos -= maViewOrigin;
     Size aPix(maWinPos.X(), maWinPos.Y());
@@ -651,7 +591,7 @@ void Window::UpdateMapMode (void)
     // removed old stuff here which still forced zoom to be
     // %BRUSH_SIZE which is outdated now
 
-    if (mpViewShell && mpViewShell->ISA(DrawViewShell))
+    if (mpViewShell && dynamic_cast< DrawViewShell *>( mpViewShell ) !=  nullptr)
     {
         // page should not "stick" to the window border
         if (aPix.Width() == 0)
@@ -676,14 +616,14 @@ void Window::UpdateMapMode (void)
     Point aNewOrigin (-maWinPos.X(), -maWinPos.Y());
     maWinPos += maViewOrigin;
 
-    MapMode aMap(GetMapMode());
-    aMap.SetOrigin(aNewOrigin);
-    SetMapMode(aMap);
+    if (!comphelper::LibreOfficeKit::isActive())
+    {
+        MapMode aMap(GetMapMode());
+        aMap.SetOrigin(aNewOrigin);
+        SetMapMode(aMap);
+    }
 }
 
-
-
-
 /**
  * @returns X position of the visible area as fraction (< 1) of the whole
  * working area.
@@ -715,8 +655,8 @@ void Window::SetVisibleXY(double fX, double fY)
         maWinPos.X() = (long) (fX * maViewSize.Width());
     if ( fY >= 0 )
         maWinPos.Y() = (long) (fY * maViewSize.Height());
-    UpdateMapOrigin(sal_False);
-    Scroll(nOldX - maWinPos.X(), nOldY - maWinPos.Y(), SCROLL_CHILDREN);
+    UpdateMapOrigin(false);
+    Scroll(nOldX - maWinPos.X(), nOldY - maWinPos.Y(), ScrollFlags::Children);
     Update();
 }
 
@@ -786,7 +726,7 @@ double Window::GetScrlPageHeight()
 void Window::LoseFocus()
 {
     mnTicks = 0;
-    ::Window::LoseFocus ();
+    vcl::Window::LoseFocus ();
 }
 
 /**
@@ -795,39 +735,27 @@ void Window::LoseFocus()
 void Window::GrabFocus()
 {
     mnTicks      = 0;
-    ::Window::GrabFocus ();
+    vcl::Window::GrabFocus ();
 }
 
-
-
 void Window::DataChanged( const DataChangedEvent& rDCEvt )
 {
-    ::Window::DataChanged( rDCEvt );
+    vcl::Window::DataChanged( rDCEvt );
 
     /* Omit PRINTER by all documents which are not using a printer.
        Omit FONTS and FONTSUBSTITUTION if no text output is available or if the
        document does not allow text.  */
 
-    if ( (rDCEvt.GetType() == DATACHANGED_PRINTER) ||
-         (rDCEvt.GetType() == DATACHANGED_DISPLAY) ||
-         (rDCEvt.GetType() == DATACHANGED_FONTS) ||
-         (rDCEvt.GetType() == DATACHANGED_FONTSUBSTITUTION) ||
-         ((rDCEvt.GetType() == DATACHANGED_SETTINGS) &&
-          (rDCEvt.GetFlags() & SETTINGS_STYLE)) )
+    if ( (rDCEvt.GetType() == DataChangedEventType::PRINTER) ||
+         (rDCEvt.GetType() == DataChangedEventType::DISPLAY) ||
+         (rDCEvt.GetType() == DataChangedEventType::FONTS) ||
+         (rDCEvt.GetType() == DataChangedEventType::FONTSUBSTITUTION) ||
+         ((rDCEvt.GetType() == DataChangedEventType::SETTINGS) &&
+          (rDCEvt.GetFlags() & AllSettingsFlags::STYLE)) )
     {
-        if ( (rDCEvt.GetType() == DATACHANGED_SETTINGS) &&
-             (rDCEvt.GetFlags() & SETTINGS_STYLE) )
+        if ( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) &&
+             (rDCEvt.GetFlags() & AllSettingsFlags::STYLE) )
         {
-            // When the screen zoom factor has changed then reset the zoom
-            // factor of the frame to always display the whole page.
-            const AllSettings* pOldSettings = rDCEvt.GetOldSettings ();
-            const AllSettings& rNewSettings = GetSettings ();
-            if (pOldSettings)
-                if (pOldSettings->GetStyleSettings().GetScreenZoom()
-                    != rNewSettings.GetStyleSettings().GetScreenZoom())
-                    mpViewShell->GetViewFrame()->GetDispatcher()->
-                        Execute(SID_SIZE_PAGE, SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD);
-
             /* Rearrange or initiate Resize for scroll bars since the size of
                the scroll bars my have changed. Within this, inside the resize-
                handler, the size of the scroll bars will be asked from the
@@ -841,20 +769,20 @@ void Window::DataChanged( const DataChangedEvent& rDCEvt )
             {
                 const StyleSettings&    rStyleSettings = GetSettings().GetStyleSettings();
                 SvtAccessibilityOptions aAccOptions;
-                sal_uLong                   nOutputMode;
-                sal_uInt16                  nPreviewSlot;
+                DrawModeFlags           nOutputMode;
+                sal_uInt16              nPreviewSlot;
 
                 if( rStyleSettings.GetHighContrastMode() )
-                    nOutputMode = ViewShell::OUTPUT_DRAWMODE_CONTRAST;
+                    nOutputMode = sd::OUTPUT_DRAWMODE_CONTRAST;
                 else
-                    nOutputMode = ViewShell::OUTPUT_DRAWMODE_COLOR;
+                    nOutputMode = sd::OUTPUT_DRAWMODE_COLOR;
 
                 if( rStyleSettings.GetHighContrastMode() && aAccOptions.GetIsForPagePreviews() )
                     nPreviewSlot = SID_PREVIEW_QUALITY_CONTRAST;
                 else
                     nPreviewSlot = SID_PREVIEW_QUALITY_COLOR;
 
-                if( mpViewShell->ISA( DrawViewShell ) )
+                if( dynamic_cast< DrawViewShell *>( mpViewShell ) !=  nullptr )
                 {
                     SetDrawMode( nOutputMode );
                     mpViewShell->GetFrameView()->SetDrawMode( nOutputMode );
@@ -862,40 +790,40 @@ void Window::DataChanged( const DataChangedEvent& rDCEvt )
                 }
 
                 // Overwrite window color for OutlineView
-                if( mpViewShell->ISA(OutlineViewShell ) )
+                if( dynamic_cast< OutlineViewShell *>( mpViewShell ) !=  nullptr )
                 {
                     svtools::ColorConfig aColorConfig;
                     const Color aDocColor( aColorConfig.GetColorValue( svtools::DOCCOLOR ).nColor );
                     SetBackground( Wallpaper( aDocColor ) );
                 }
 
-                SfxRequest aReq( nPreviewSlot, 0, mpViewShell->GetDocSh()->GetDoc()->GetItemPool() );
+                SfxRequest aReq( nPreviewSlot, SfxCallMode::SLOT, mpViewShell->GetDocSh()->GetDoc()->GetItemPool() );
                 mpViewShell->ExecReq( aReq );
                 mpViewShell->Invalidate();
                 mpViewShell->ArrangeGUIElements();
 
                 // re-create handles to show new outfit
-                if(mpViewShell->ISA(DrawViewShell))
+                if(dynamic_cast< DrawViewShell *>( mpViewShell ) !=  nullptr)
                 {
                     mpViewShell->GetView()->AdjustMarkHdl();
                 }
             }
         }
 
-        if ( (rDCEvt.GetType() == DATACHANGED_DISPLAY) ||
-             ((rDCEvt.GetType() == DATACHANGED_SETTINGS) &&
-              (rDCEvt.GetFlags() & SETTINGS_STYLE)) )
+        if ( (rDCEvt.GetType() == DataChangedEventType::DISPLAY) ||
+             ((rDCEvt.GetType() == DataChangedEventType::SETTINGS) &&
+              (rDCEvt.GetFlags() & AllSettingsFlags::STYLE)) )
         {
             /* Virtual devices, which also depends on the resolution or the
                system control, should be updated. Otherwise, we should update
-               the virtual devices at least at DATACHANGED_DISPLAY since some
+               the virtual devices at least at DataChangedEventType::DISPLAY since some
                systems allow to change the resolution and color depth during
                runtime. Or the virtual devices have to be updated when the color
                palette has changed since a different color matching can be used
                when outputting. */
         }
 
-        if ( rDCEvt.GetType() == DATACHANGED_FONTS )
+        if ( rDCEvt.GetType() == DataChangedEventType::FONTS )
         {
             /* If the document provides font choose boxes, we have to update
                them. I don't know how this looks like (also not really me, I
@@ -904,20 +832,20 @@ void Window::DataChanged( const DataChangedEvent& rDCEvt )
                Before we handle it here, discuss it with PB and me. */
         }
 
-        if ( (rDCEvt.GetType() == DATACHANGED_FONTS) ||
-             (rDCEvt.GetType() == DATACHANGED_FONTSUBSTITUTION) )
+        if ( (rDCEvt.GetType() == DataChangedEventType::FONTS) ||
+             (rDCEvt.GetType() == DataChangedEventType::FONTSUBSTITUTION) )
         {
-            /* Do reformating since the fonts of the document may no longer
+            /* Do reformatting since the fonts of the document may no longer
                exist, or exist now, or are replaced with others. */
             if( mpViewShell )
             {
                 DrawDocShell* pDocSh = mpViewShell->GetDocSh();
                 if( pDocSh )
-                    pDocSh->SetPrinter( pDocSh->GetPrinter( sal_True ) );
+                    pDocSh->SetPrinter( pDocSh->GetPrinter( true ) );
             }
         }
 
-        if ( rDCEvt.GetType() == DATACHANGED_PRINTER )
+        if ( rDCEvt.GetType() == DataChangedEventType::PRINTER )
         {
             /* I don't know how the handling should look like. Maybe we delete a
                printer and look what we have to do. Maybe I have to add
@@ -928,7 +856,7 @@ void Window::DataChanged( const DataChangedEvent& rDCEvt )
             {
                 DrawDocShell* pDocSh = mpViewShell->GetDocSh();
                 if( pDocSh )
-                    pDocSh->SetPrinter( pDocSh->GetPrinter( sal_True ) );
+                    pDocSh->SetPrinter( pDocSh->GetPrinter( true ) );
             }
         }
 
@@ -937,10 +865,6 @@ void Window::DataChanged( const DataChangedEvent& rDCEvt )
     }
 }
 
-
-
-
-
 sal_Int8 Window::AcceptDrop( const AcceptDropEvent& rEvt )
 {
     sal_Int8 nRet = DND_ACTION_NONE;
@@ -950,14 +874,13 @@ sal_Int8 Window::AcceptDrop( const AcceptDropEvent& rEvt )
         if( mpViewShell )
             nRet = mpViewShell->AcceptDrop( rEvt, *this, this, SDRPAGE_NOTFOUND, SDRLAYER_NOTFOUND );
 
-        if (mbUseDropScroll && ! mpViewShell->ISA(OutlineViewShell))
+        if (mbUseDropScroll && dynamic_cast< OutlineViewShell *>( mpViewShell ) ==  nullptr)
             DropScroll( rEvt.maPosPixel );
     }
 
     return nRet;
 }
 
-
 sal_Int8 Window::ExecuteDrop( const ExecuteDropEvent& rEvt )
 {
     sal_Int8 nRet = DND_ACTION_NONE;
@@ -970,18 +893,11 @@ sal_Int8 Window::ExecuteDrop( const ExecuteDropEvent& rEvt )
     return nRet;
 }
 
-
-
-
 void Window::SetUseDropScroll (bool bUseDropScroll)
 {
     mbUseDropScroll = bUseDropScroll;
 }
 
-
-
-
-
 void Window::DropScroll(const Point& rMousePos)
 {
     short nDx = 0;
@@ -1024,19 +940,29 @@ void Window::DropScroll(const Point& rMousePos)
     }
 }
 
-
-
-
-::com::sun::star::uno::Reference<
-    ::com::sun::star::accessibility::XAccessible>
-    Window::CreateAccessible (void)
+css::uno::Reference<css::accessibility::XAccessible>
+    Window::CreateAccessible()
 {
-    if (mpViewShell != NULL)
-        return mpViewShell->CreateAccessibleDocumentView (this);
+    // If current viewshell is PresentationViewShell, just return empty because the correct ShowWin will be created later.
+    if (mpViewShell && dynamic_cast< PresentationViewShell *>( mpViewShell ) !=  nullptr)
+    {
+        return vcl::Window::CreateAccessible ();
+    }
+    css::uno::Reference< css::accessibility::XAccessible > xAcc = GetAccessible(false);
+    if (xAcc.get())
+    {
+        return xAcc;
+    }
+    if (mpViewShell != nullptr)
+    {
+        xAcc = mpViewShell->CreateAccessibleDocumentView (this);
+        SetAccessible(xAcc);
+        return xAcc;
+    }
     else
     {
-        OSL_TRACE ("::sd::Window::CreateAccessible: no view shell");
-        return ::Window::CreateAccessible ();
+        SAL_WARN("sd", "::sd::Window::CreateAccessible: no view shell");
+        return vcl::Window::CreateAccessible ();
     }
 }
 
@@ -1069,6 +995,34 @@ Selection Window::GetSurroundingTextSelection() const
     }
 }
 
+void Window::LogicInvalidate(const ::tools::Rectangle* pRectangle)
+{
+    DrawViewShell* pDrawViewShell = dynamic_cast<DrawViewShell*>(mpViewShell);
+    if (pDrawViewShell && pDrawViewShell->IsInSwitchPage())
+        return;
+
+    OString sRectangle;
+    if (!pRectangle)
+        sRectangle = "EMPTY";
+    else
+    {
+        ::tools::Rectangle aRectangle(*pRectangle);
+        if (GetMapMode().GetMapUnit() == MapUnit::Map100thMM)
+            aRectangle = OutputDevice::LogicToLogic(aRectangle, MapMode(MapUnit::Map100thMM), MapMode(MapUnit::MapTwip));
+        sRectangle = aRectangle.toString();
+    }
+    SfxViewShell& rSfxViewShell = mpViewShell->GetViewShellBase();
+    SfxLokHelper::notifyInvalidation(&rSfxViewShell, sRectangle);
+}
+
+FactoryFunction Window::GetUITestFactory() const
+{
+    if (get_id() == "impress_win")
+        return ImpressWindowUIObject::create;
+
+    return WindowUIObject::create;
+}
+
 } // end of namespace sd
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
