@@ -24,11 +24,11 @@
 #include <com/sun/star/drawing/FillStyle.hpp>
 #include <com/sun/star/drawing/LineStyle.hpp>
 
-#include "ViewShell.hxx"
-#include "ViewShellHint.hxx"
+#include <ViewShell.hxx>
+#include <ViewShellHint.hxx>
 
-#include "ViewShellImplementation.hxx"
-#include "FactoryIds.hxx"
+#include <ViewShellImplementation.hxx>
+#include <FactoryIds.hxx>
 
 #include <svx/svxids.hrc>
 #include <vcl/scrbar.hxx>
@@ -46,26 +46,26 @@
 #include <svx/dialogs.hrc>
 #include <comphelper/classids.hxx>
 
-#include "strings.hrc"
-#include "app.hrc"
-#include "unokywds.hxx"
+#include <strings.hrc>
+#include <app.hrc>
+#include <unokywds.hxx>
 
-#include "sdundogr.hxx"
-#include "FrameView.hxx"
-#include "undopage.hxx"
-#include "sdresid.hxx"
-#include "drawdoc.hxx"
-#include "View.hxx"
-#include "fupoor.hxx"
-#include "Client.hxx"
-#include "DrawDocShell.hxx"
-#include "fusearch.hxx"
-#include "slideshow.hxx"
-#include "sdpage.hxx"
-#include "DrawViewShell.hxx"
-#include "ViewShellBase.hxx"
+#include <sdundogr.hxx>
+#include <FrameView.hxx>
+#include <undopage.hxx>
+#include <sdresid.hxx>
+#include <drawdoc.hxx>
+#include <View.hxx>
+#include <fupoor.hxx>
+#include <Client.hxx>
+#include <DrawDocShell.hxx>
+#include <fusearch.hxx>
+#include <slideshow.hxx>
+#include <sdpage.hxx>
+#include <DrawViewShell.hxx>
+#include <ViewShellBase.hxx>
 
-#include "Window.hxx"
+#include <Window.hxx>
 
 #include <sfx2/viewfrm.hxx>
 #include <svtools/soerr.hxx>
@@ -490,8 +490,8 @@ void ViewShell::SetPageSizeAndBorder(PageKind ePageKind, const Size& rNewSize,
 
         SdUndoAction* pUndo = new SdPageFormatUndoAction(GetDoc(), pPage,
                             pPage->GetSize(),
-                            pPage->GetLftBorder(), pPage->GetRgtBorder(),
-                            pPage->GetUppBorder(), pPage->GetLwrBorder(),
+                            pPage->GetLeftBorder(), pPage->GetRightBorder(),
+                            pPage->GetUpperBorder(), pPage->GetLowerBorder(),
                             pPage->GetOrientation(),
                             pPage->GetPaperBin(),
                             pPage->IsBackgroundFullSize(),
@@ -538,8 +538,8 @@ void ViewShell::SetPageSizeAndBorder(PageKind ePageKind, const Size& rNewSize,
 
         SdUndoAction* pUndo = new SdPageFormatUndoAction(GetDoc(), pPage,
                                 pPage->GetSize(),
-                                pPage->GetLftBorder(), pPage->GetRgtBorder(),
-                                pPage->GetUppBorder(), pPage->GetLwrBorder(),
+                                pPage->GetLeftBorder(), pPage->GetRightBorder(),
+                                pPage->GetUpperBorder(), pPage->GetLowerBorder(),
                                 pPage->GetOrientation(),
                                 pPage->GetPaperBin(),
                                 pPage->IsBackgroundFullSize(),
@@ -611,7 +611,7 @@ void ViewShell::SetPageSizeAndBorder(PageKind ePageKind, const Size& rNewSize,
 
     UpdateScrollBars();
 
-    Point aNewOrigin(pPage->GetLftBorder(), pPage->GetUppBorder());
+    Point aNewOrigin(pPage->GetLeftBorder(), pPage->GetUpperBorder());
 
     if (pView)
     {
@@ -716,9 +716,9 @@ void ViewShell::WriteFrameViewData()
 
 bool ViewShell::ActivateObject(SdrOle2Obj* pObj, long nVerb)
 {
-    ErrCode aErrCode = 0;
+    ErrCode aErrCode = ERRCODE_NONE;
 
-    SfxErrorContext aEC(ERRCTX_SO_DOVERB, GetActiveWindow(), RID_SO_ERRCTX);
+    SfxErrorContext aEC(ERRCTX_SO_DOVERB, GetActiveWindow(), getRID_SO_ERRCTX());
     bool bAbort = false;
     GetDocSh()->SetWaitCursor( true );
     SfxViewShell* pViewShell = GetViewShell();
@@ -814,7 +814,7 @@ bool ViewShell::ActivateObject(SdrOle2Obj* pObj, long nVerb)
         }
     }
 
-    if( aErrCode == 0 )
+    if( aErrCode == ERRCODE_NONE )
     {
         ::sd::View* pView = GetView();
 
@@ -851,7 +851,7 @@ bool ViewShell::ActivateObject(SdrOle2Obj* pObj, long nVerb)
 
         Fraction aScaleWidth (aDrawSize.Width(),  aObjAreaSize.Width() );
         Fraction aScaleHeight(aDrawSize.Height(), aObjAreaSize.Height() );
-        aScaleWidth.ReduceInaccurate(10);       // kompatibel zum SdrOle2Obj
+        aScaleWidth.ReduceInaccurate(10);       // compatible to the SdrOle2Obj
         aScaleHeight.ReduceInaccurate(10);
         pSdClient->SetSizeScale(aScaleWidth, aScaleHeight);
 
@@ -872,12 +872,12 @@ bool ViewShell::ActivateObject(SdrOle2Obj* pObj, long nVerb)
 
     GetDocSh()->SetWaitCursor( false );
 
-    if (aErrCode != 0 && !bAbort)
+    if (aErrCode != ERRCODE_NONE && !bAbort)
     {
         ErrorHandler::HandleError(* new StringErrorInfo(aErrCode, OUString() ) );
     }
 
-    return aErrCode == 0;
+    return aErrCode == ERRCODE_NONE;
 }
 
 /**
