@@ -17,15 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "ViewShell.hxx"
-#include "ViewShellImplementation.hxx"
-#include "createtableobjectbar.hxx"
+#include <memory>
+#include <ViewShell.hxx>
+#include <ViewShellImplementation.hxx>
+#include <createtableobjectbar.hxx>
 
 #include <com/sun/star/embed/EmbedStates.hpp>
-#include "ViewShellBase.hxx"
-#include "ShellFactory.hxx"
-#include "DrawController.hxx"
-#include "LayerTabBar.hxx"
+#include <ViewShellBase.hxx>
+#include <ShellFactory.hxx>
+#include <DrawController.hxx>
+#include <LayerTabBar.hxx>
 
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/bindings.hxx>
@@ -35,59 +36,61 @@
 #include <svx/ruler.hxx>
 #include <svx/svxids.hrc>
 #include <svx/fmshell.hxx>
-#include "WindowUpdater.hxx"
-#include "GraphicViewShell.hxx"
+#include <WindowUpdater.hxx>
+#include <GraphicViewShell.hxx>
 #include <sfx2/childwin.hxx>
 #include <sdxfer.hxx>
 
-#include "app.hrc"
-#include "helpids.h"
-#include "strings.hrc"
-#include "res_bmp.hrc"
-#include "OutlineView.hxx"
-#include "Client.hxx"
-#include "sdresid.hxx"
-#include "DrawDocShell.hxx"
-#include "slideshow.hxx"
-#include "drawdoc.hxx"
-#include "sdpage.hxx"
-#include "zoomlist.hxx"
-#include "FrameView.hxx"
-#include "optsitem.hxx"
-#include "BezierObjectBar.hxx"
-#include "TextObjectBar.hxx"
-#include "GraphicObjectBar.hxx"
-#include "MediaObjectBar.hxx"
-#include "SlideSorter.hxx"
-#include "SlideSorterViewShell.hxx"
-#include "ViewShellManager.hxx"
-#include "FormShellManager.hxx"
+#include <app.hrc>
+#include <helpids.h>
+
+#include <OutlineView.hxx>
+#include <Client.hxx>
+#include <sdresid.hxx>
+#include <DrawDocShell.hxx>
+#include <slideshow.hxx>
+#include <drawdoc.hxx>
+#include <sdpage.hxx>
+#include <zoomlist.hxx>
+#include <FrameView.hxx>
+#include <optsitem.hxx>
+#include <BezierObjectBar.hxx>
+#include <TextObjectBar.hxx>
+#include <GraphicObjectBar.hxx>
+#include <MediaObjectBar.hxx>
+#include <SlideSorter.hxx>
+#include <SlideSorterViewShell.hxx>
+#include <ViewShellManager.hxx>
+#include <FormShellManager.hxx>
 #include <svx/dialogs.hrc>
 #include <svx/extrusionbar.hxx>
 #include <svx/fontworkbar.hxx>
 #include <svx/svdoutl.hxx>
 #include <tools/diagnose_ex.h>
+#include <comphelper/lok.hxx>
 
 #include <svl/slstitm.hxx>
 #include <sfx2/request.hxx>
-#include "SpellDialogChildWindow.hxx"
-#include "controller/SlideSorterController.hxx"
-#include "controller/SlsPageSelector.hxx"
-#include "controller/SlsSelectionObserver.hxx"
-#include "view/SlideSorterView.hxx"
+#include <SpellDialogChildWindow.hxx>
+#include <controller/SlideSorterController.hxx>
+#include <controller/SlsPageSelector.hxx>
+#include <controller/SlsSelectionObserver.hxx>
+#include <view/SlideSorterView.hxx>
 
-#include <basegfx/tools/zoomtools.hxx>
+#include <basegfx/utils/zoomtools.hxx>
 
-#include "Window.hxx"
-#include "fupoor.hxx"
+#include <Window.hxx>
+#include <fupoor.hxx>
+#include <futext.hxx>
 
 #include <editeng/numitem.hxx>
 #include <editeng/eeitem.hxx>
 #include <editeng/editview.hxx>
 #include <editeng/editeng.hxx>
 #include <svl/poolitem.hxx>
-#include <glob.hrc>
-#include "AccessibleDocumentViewBase.hxx"
+#include <strings.hrc>
+#include <strings.hxx>
+#include <AccessibleDocumentViewBase.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -100,11 +103,8 @@ class ViewShellObjectBarFactory
 {
 public:
     explicit ViewShellObjectBarFactory (::sd::ViewShell& rViewShell);
-    virtual ~ViewShellObjectBarFactory();
-    virtual SfxShell* CreateShell (
-        ::sd::ShellId nId,
-        vcl::Window* pParentWindow,
-        ::sd::FrameView* pFrameView) override;
+    virtual ~ViewShellObjectBarFactory() override;
+    virtual SfxShell* CreateShell( ::sd::ShellId nId ) override;
     virtual void ReleaseShell (SfxShell* pShell) override;
 private:
     ::sd::ViewShell& mrViewShell;
@@ -140,9 +140,8 @@ SfxViewFrame* ViewShell::GetViewFrame() const
 
 /// declare SFX-Slotmap and standard interface
 
-ViewShell::ViewShell( SfxViewFrame*, vcl::Window* pParentWindow, ViewShellBase& rViewShellBase, bool bAllowCenter)
+ViewShell::ViewShell( vcl::Window* pParentWindow, ViewShellBase& rViewShellBase)
 :   SfxShell(&rViewShellBase)
-,   mbCenterAllowed(bAllowCenter)
 ,   mpParentWindow(pParentWindow)
 {
     construct();
@@ -166,7 +165,7 @@ ViewShell::~ViewShell()
     if (mpContentWindow)
     {
         SAL_INFO(
-            "sd.ui",
+            "sd.view",
             "destroying mpContentWindow at " << mpContentWindow.get()
                 << " with parent " << mpContentWindow->GetParent());
         mpContentWindow.disposeAndClear();
@@ -208,7 +207,7 @@ void ViewShell::construct()
 
     GetParentWindow()->SetBackground (Wallpaper());
     mpContentWindow->SetBackground (Wallpaper());
-    mpContentWindow->SetCenterAllowed(mbCenterAllowed);
+    mpContentWindow->SetCenterAllowed(true);
     mpContentWindow->SetViewShell(this);
     mpContentWindow->SetPosSizePixel(
         GetParentWindow()->GetPosPixel(),GetParentWindow()->GetSizePixel());
@@ -228,12 +227,10 @@ void ViewShell::construct()
         mpScrollBarBox.reset(VclPtr<ScrollBarBox>::Create(GetParentWindow(), WB_SIZEABLE));
     }
 
-    OUString aName( "ViewShell" );
-    SetName (aName);
+    SetName ("ViewShell");
 
     GetDoc()->StartOnlineSpelling(false);
 
-    mpWindowUpdater->SetViewShell (*this);
     mpWindowUpdater->SetDocument (GetDoc());
 
     // Re-initialize the spell dialog.
@@ -321,11 +318,10 @@ void ViewShell::Activate(bool bIsMDIActivate)
         // thus, the Navigator will also get a current status
         SfxBoolItem aItem( SID_NAVIGATOR_INIT, true );
         if (GetDispatcher() != nullptr)
-            GetDispatcher()->Execute(
+            GetDispatcher()->ExecuteList(
                 SID_NAVIGATOR_INIT,
                 SfxCallMode::ASYNCHRON | SfxCallMode::RECORD,
-                &aItem,
-                0L);
+                { &aItem });
 
         SfxViewShell* pViewShell = GetViewShell();
         OSL_ASSERT (pViewShell!=nullptr);
@@ -383,7 +379,7 @@ void ViewShell::Deactivate(bool bIsMDIActivate)
     {
         rtl::Reference< SlideShow > xSlideShow( SlideShow::GetSlideShow( GetViewShellBase() ) );
         if(xSlideShow.is() && xSlideShow->isRunning() )
-            xSlideShow->deactivate(GetViewShellBase());
+            xSlideShow->deactivate();
 
         if(HasCurrentFunction())
             GetCurrentFunction()->Deactivate();
@@ -442,6 +438,12 @@ bool ViewShell::KeyInput(const KeyEvent& rKEvt, ::sd::Window* pWin)
                 else
                 {
                     bReturn = true;
+                    if (HasCurrentFunction())
+                    {
+                        FuText* pTextFunction = dynamic_cast<FuText*>(GetCurrentFunction().get());
+                        if(pTextFunction != nullptr)
+                            pTextFunction->InvalidateBindings();
+                    }
                 }
             }
         }
@@ -500,13 +502,22 @@ void ViewShell::MouseButtonDown(const MouseEvent& rMEvt, ::sd::Window* pWin)
             if(HasCurrentFunction())
                 GetCurrentFunction()->MouseButtonDown(rMEvt);
         }
+        else
+        {
+            if (HasCurrentFunction())
+            {
+                FuText* pTextFunction = dynamic_cast<FuText*>(GetCurrentFunction().get());
+                if (pTextFunction != nullptr)
+                    pTextFunction->InvalidateBindings();
+            }
+        }
     }
 }
 
 void ViewShell::LogicMouseButtonDown(const MouseEvent& rMouseEvent)
 {
     // When we're not doing tiled rendering, then positions must be passed as pixels.
-    assert(GetDoc()->isTiledRendering());
+    assert(comphelper::LibreOfficeKit::isActive());
 
     Point aPoint = mpActiveWindow->GetPointerPosPixel();
     mpActiveWindow->SetLastMousePos(rMouseEvent.GetPosPixel());
@@ -519,7 +530,7 @@ void ViewShell::LogicMouseButtonDown(const MouseEvent& rMouseEvent)
 void ViewShell::LogicMouseButtonUp(const MouseEvent& rMouseEvent)
 {
     // When we're not doing tiled rendering, then positions must be passed as pixels.
-    assert(GetDoc()->isTiledRendering());
+    assert(comphelper::LibreOfficeKit::isActive());
 
     Point aPoint = mpActiveWindow->GetPointerPosPixel();
     mpActiveWindow->SetLastMousePos(rMouseEvent.GetPosPixel());
@@ -532,7 +543,7 @@ void ViewShell::LogicMouseButtonUp(const MouseEvent& rMouseEvent)
 void ViewShell::LogicMouseMove(const MouseEvent& rMouseEvent)
 {
     // When we're not doing tiled rendering, then positions must be passed as pixels.
-    assert(GetDoc()->isTiledRendering());
+    assert(comphelper::LibreOfficeKit::isActive());
 
     Point aPoint = mpActiveWindow->GetPointerPosPixel();
     mpActiveWindow->SetLastMousePos(rMouseEvent.GetPosPixel());
@@ -684,6 +695,15 @@ void ViewShell::MouseButtonUp(const MouseEvent& rMEvt, ::sd::Window* pWin)
             if(HasCurrentFunction())
                 GetCurrentFunction()->MouseButtonUp(rMEvt);
         }
+        else
+        {
+            if (HasCurrentFunction())
+            {
+                FuText* pTextFunction = dynamic_cast<FuText*>(GetCurrentFunction().get());
+                if (pTextFunction != nullptr)
+                    pTextFunction->InvalidateBindings();
+            }
+        }
     }
 
     if ( ! mpImpl->mpUpdateLockForMouse.expired())
@@ -719,7 +739,7 @@ void ViewShell::Command(const CommandEvent& rCEvt, ::sd::Window* pWin)
     }
 }
 
-bool ViewShell::Notify(NotifyEvent& rNEvt, ::sd::Window* pWin)
+bool ViewShell::Notify(NotifyEvent const & rNEvt, ::sd::Window* pWin)
 {
     // handle scroll commands when they arrived at child windows
     bool bRet = false;
@@ -777,7 +797,7 @@ bool ViewShell::HandleScrollCommand(const CommandEvent& rCEvt, ::sd::Window* pWi
                     break;
                 }
             }
-            // fall through when not running slideshow
+            SAL_FALLTHROUGH;
         case CommandEventId::StartAutoScroll:
         case CommandEventId::AutoScroll:
         {
@@ -793,15 +813,15 @@ bool ViewShell::HandleScrollCommand(const CommandEvent& rCEvt, ::sd::Window* pWi
                         long        nNewZoom;
                         Point aOldMousePos = GetActiveWindow()->PixelToLogic(rCEvt.GetMousePosPixel());
 
-                        if( pData->GetDelta() < 0L )
-                            nNewZoom = std::max( (long) pWin->GetMinZoom(), basegfx::zoomtools::zoomOut( nOldZoom ));
+                        if( pData->GetDelta() < 0 )
+                            nNewZoom = std::max<long>( pWin->GetMinZoom(), basegfx::zoomtools::zoomOut( nOldZoom ));
                         else
-                            nNewZoom = std::min( (long) pWin->GetMaxZoom(), basegfx::zoomtools::zoomIn( nOldZoom ));
+                            nNewZoom = std::min<long>( pWin->GetMaxZoom(), basegfx::zoomtools::zoomIn( nOldZoom ));
 
                         SetZoom( nNewZoom );
                         // Keep mouse at same doc point before zoom
                         Point aNewMousePos = GetActiveWindow()->PixelToLogic(rCEvt.GetMousePosPixel());
-                        SetWinViewPos(GetWinViewPos() - (aNewMousePos - aOldMousePos), true);
+                        SetWinViewPos(GetWinViewPos() - (aNewMousePos - aOldMousePos));
 
                         Invalidate( SID_ATTR_ZOOM );
                         Invalidate( SID_ATTR_ZOOMSLIDER );
@@ -854,7 +874,7 @@ void ViewShell::SetupRulers()
         }
         if ( mpHorizontalRuler.get() == nullptr )
         {
-            mpHorizontalRuler.reset(CreateHRuler(GetActiveWindow(), true));
+            mpHorizontalRuler.reset(CreateHRuler(GetActiveWindow()));
             if ( mpHorizontalRuler.get() != nullptr )
             {
                 mpHorizontalRuler->SetWinPos(nHRulerOfs);
@@ -892,7 +912,7 @@ const SfxPoolItem* ViewShell::GetNumBulletItem(SfxItemSet& aNewAttr, sal_uInt16&
                 for(size_t nNum = 0; nNum < nCount; ++nNum)
                 {
                     SdrObject* pObj = rMarkList.GetMark(nNum)->GetMarkedSdrObj();
-                    if( pObj->GetObjInventor() == SdrInventor )
+                    if( pObj->GetObjInventor() == SdrInventor::Default )
                     {
                         switch(pObj->GetObjIdentifier())
                         {
@@ -911,20 +931,20 @@ const SfxPoolItem* ViewShell::GetNumBulletItem(SfxItemSet& aNewAttr, sal_uInt16&
             if(bOutliner)
             {
                 SfxStyleSheetBasePool* pSSPool = mpView->GetDocSh()->GetStyleSheetPool();
-                OUString aStyleName(SD_RESSTR(STR_LAYOUT_OUTLINE) + " 1");
-                SfxStyleSheetBase* pFirstStyleSheet = pSSPool->Find( aStyleName, SD_STYLE_FAMILY_PSEUDO);
+                SfxStyleSheetBase* pFirstStyleSheet = pSSPool->Find( STR_LAYOUT_OUTLINE " 1", SD_STYLE_FAMILY_PSEUDO);
                 if( pFirstStyleSheet )
                     pFirstStyleSheet->GetItemSet().GetItemState(EE_PARA_NUMBULLET, false, reinterpret_cast<const SfxPoolItem**>(&pItem));
             }
 
             if( pItem == nullptr )
-                pItem = static_cast<const SvxNumBulletItem*>( aNewAttr.GetPool()->GetSecondaryPool()->GetPoolDefaultItem(EE_PARA_NUMBULLET) );
+                pItem = aNewAttr.GetPool()->GetSecondaryPool()->GetPoolDefaultItem(EE_PARA_NUMBULLET);
 
-            aNewAttr.Put(*pItem, EE_PARA_NUMBULLET);
+            std::unique_ptr<SfxPoolItem> pNewItem(pItem->CloneSetWhich(EE_PARA_NUMBULLET));
+            aNewAttr.Put(*pNewItem);
 
             if(bTitle && aNewAttr.GetItemState(EE_PARA_NUMBULLET) == SfxItemState::SET )
             {
-                const SvxNumBulletItem* pBulletItem = static_cast<const SvxNumBulletItem*>(aNewAttr.GetItem(EE_PARA_NUMBULLET));
+                const SvxNumBulletItem* pBulletItem = aNewAttr.GetItem(EE_PARA_NUMBULLET);
                 SvxNumRule* pRule = pBulletItem->GetNumRule();
                 if(pRule)
                 {
@@ -971,7 +991,7 @@ void ViewShell::Resize()
         pView->VisAreaChanged(GetActiveWindow());
 }
 
-SvBorder ViewShell::GetBorder (bool )
+SvBorder ViewShell::GetBorder()
 {
     SvBorder aBorder;
 
@@ -1091,7 +1111,7 @@ void ViewShell::ArrangeGUIElements()
     }
 
     // Windows in the center and rulers at the left and top side.
-    maAllWindowRectangle = Rectangle(
+    maAllWindowRectangle = ::tools::Rectangle(
         maViewPos,
         Size(maViewSize.Width()-maScrBarWH.Width(),
             maViewSize.Height()-maScrBarWH.Height()));
@@ -1240,7 +1260,7 @@ class KeepSlideSorterInSyncWithPageChanges
     sd::slidesorter::controller::SelectionObserver::Context m_aContext;
 
 public:
-    KeepSlideSorterInSyncWithPageChanges(sd::slidesorter::SlideSorter& rSlideSorter)
+    explicit KeepSlideSorterInSyncWithPageChanges(sd::slidesorter::SlideSorter const & rSlideSorter)
         : m_aDrawLock(rSlideSorter)
         , m_aModelLock(rSlideSorter.GetController())
         , m_aUpdateLock(rSlideSorter)
@@ -1249,7 +1269,7 @@ public:
     }
 };
 
-void ViewShell::ImpSidUndo(bool, SfxRequest& rReq)
+void ViewShell::ImpSidUndo(SfxRequest& rReq)
 {
     //The xWatcher keeps the SlideSorter selection in sync
     //with the page insertions/deletions that Undo may introduce
@@ -1262,11 +1282,18 @@ void ViewShell::ImpSidUndo(bool, SfxRequest& rReq)
     ::svl::IUndoManager* pUndoManager = ImpGetUndoManager();
     sal_uInt16 nNumber(1);
     const SfxItemSet* pReqArgs = rReq.GetArgs();
+    bool bRepair = false;
 
     if(pReqArgs)
     {
         const SfxUInt16Item* pUIntItem = static_cast<const SfxUInt16Item*>(&pReqArgs->Get(SID_UNDO));
         nNumber = pUIntItem->GetValue();
+
+        // Repair mode: allow undo/redo of all undo actions, even if access would
+        // be limited based on the view shell ID.
+        const SfxPoolItem* pRepairItem;
+        if (pReqArgs->GetItemState(SID_REPAIRPACKAGE, false, &pRepairItem) == SfxItemState::SET)
+            bRepair = static_cast<const SfxBoolItem*>(pRepairItem)->GetValue();
     }
 
     if(nNumber && pUndoManager)
@@ -1274,6 +1301,17 @@ void ViewShell::ImpSidUndo(bool, SfxRequest& rReq)
         sal_uInt16 nCount(pUndoManager->GetUndoActionCount());
         if(nCount >= nNumber)
         {
+            if (comphelper::LibreOfficeKit::isActive() && !bRepair)
+            {
+                // If an other view created the first undo action, prevent redoing it from this view.
+                const SfxUndoAction* pAction = pUndoManager->GetUndoAction();
+                if (pAction->GetViewShellId() != GetViewShellBase().GetViewShellId())
+                {
+                    rReq.SetReturnValue(SfxUInt32Item(SID_UNDO, static_cast<sal_uInt32>(SID_REPAIRPACKAGE)));
+                    return;
+                }
+            }
+
             try
             {
                 // when UndoStack is cleared by ModifyPageUndoAction
@@ -1300,7 +1338,7 @@ void ViewShell::ImpSidUndo(bool, SfxRequest& rReq)
     rReq.Done();
 }
 
-void ViewShell::ImpSidRedo(bool, SfxRequest& rReq)
+void ViewShell::ImpSidRedo(SfxRequest& rReq)
 {
     //The xWatcher keeps the SlideSorter selection in sync
     //with the page insertions/deletions that Undo may introduce
@@ -1313,11 +1351,17 @@ void ViewShell::ImpSidRedo(bool, SfxRequest& rReq)
     ::svl::IUndoManager* pUndoManager = ImpGetUndoManager();
     sal_uInt16 nNumber(1);
     const SfxItemSet* pReqArgs = rReq.GetArgs();
+    bool bRepair = false;
 
     if(pReqArgs)
     {
         const SfxUInt16Item* pUIntItem = static_cast<const SfxUInt16Item*>(&pReqArgs->Get(SID_REDO));
         nNumber = pUIntItem->GetValue();
+        // Repair mode: allow undo/redo of all undo actions, even if access would
+        // be limited based on the view shell ID.
+        const SfxPoolItem* pRepairItem;
+        if (pReqArgs->GetItemState(SID_REPAIRPACKAGE, false, &pRepairItem) == SfxItemState::SET)
+            bRepair = static_cast<const SfxBoolItem*>(pRepairItem)->GetValue();
     }
 
     if(nNumber && pUndoManager)
@@ -1325,6 +1369,17 @@ void ViewShell::ImpSidRedo(bool, SfxRequest& rReq)
         sal_uInt16 nCount(pUndoManager->GetRedoActionCount());
         if(nCount >= nNumber)
         {
+            if (comphelper::LibreOfficeKit::isActive() && !bRepair)
+            {
+                // If an other view created the first undo action, prevent redoing it from this view.
+                const SfxUndoAction* pAction = pUndoManager->GetRedoAction();
+                if (pAction->GetViewShellId() != GetViewShellBase().GetViewShellId())
+                {
+                    rReq.SetReturnValue(SfxUInt32Item(SID_REDO, static_cast<sal_uInt32>(SID_REPAIRPACKAGE)));
+                    return;
+                }
+            }
+
             try
             {
                 // when UndoStack is cleared by ModifyPageRedoAction
@@ -1401,7 +1456,7 @@ void ViewShell::ExecReq( SfxRequest& rReq )
 css::uno::Reference<css::accessibility::XAccessible>
 ViewShell::CreateAccessibleDocumentView (::sd::Window* )
 {
-    OSL_FAIL("ViewShell::CreateAccessibleDocumentView should not be called!, perhaps Meyers, 3rd edition, Item 9:\n");
+    OSL_FAIL("ViewShell::CreateAccessibleDocumentView should not be called!, perhaps Meyers, 3rd edition, Item 9:");
 
     return css::uno::Reference<css::accessibility::XAccessible> ();
 }
@@ -1528,14 +1583,12 @@ void ViewShell::PrePaint()
 {
 }
 
-void ViewShell::Paint (const Rectangle&, ::sd::Window* )
+void ViewShell::Paint (const ::tools::Rectangle&, ::sd::Window* )
 {
 }
 
 void ViewShell::ShowUIControls (bool bVisible)
 {
-    mpImpl->mbIsShowingUIControls = bVisible;
-
     if (mbHasRulers)
     {
         if (mpHorizontalRuler.get() != nullptr)
@@ -1562,8 +1615,7 @@ bool ViewShell::RelocateToParentWindow (vcl::Window* pParentWindow)
 {
     mpParentWindow = pParentWindow;
 
-    if (mpParentWindow)
-        mpParentWindow->SetBackground (Wallpaper());
+    mpParentWindow->SetBackground (Wallpaper());
 
     if (mpContentWindow.get() != nullptr)
         mpContentWindow->SetParent(pParentWindow);
@@ -1578,7 +1630,7 @@ bool ViewShell::RelocateToParentWindow (vcl::Window* pParentWindow)
     return true;
 }
 
-void ViewShell::SwitchViewFireFocus(css::uno::Reference< css::accessibility::XAccessible > xAcc )
+void ViewShell::SwitchViewFireFocus(const css::uno::Reference< css::accessibility::XAccessible >& xAcc )
 {
     if (xAcc.get())
     {
@@ -1604,6 +1656,11 @@ void ViewShell::NotifyAccUpdate( )
     GetViewShellBase().GetDrawController().NotifyAccUpdate();
 }
 
+sd::Window* ViewShell::GetContentWindow() const
+{
+    return mpContentWindow.get();
+}
+
 } // end of namespace sd
 
 //===== ViewShellObjectBarFactory =============================================
@@ -1626,10 +1683,7 @@ ViewShellObjectBarFactory::~ViewShellObjectBarFactory()
     }
 }
 
-SfxShell* ViewShellObjectBarFactory::CreateShell (
-    ::sd::ShellId nId,
-    vcl::Window*,
-    ::sd::FrameView* )
+SfxShell* ViewShellObjectBarFactory::CreateShell( ::sd::ShellId nId )
 {
     SfxShell* pShell = nullptr;
 
@@ -1639,33 +1693,33 @@ SfxShell* ViewShellObjectBarFactory::CreateShell (
         ::sd::View* pView = mrViewShell.GetView();
         switch (nId)
         {
-            case RID_BEZIER_TOOLBOX:
+            case ToolbarId::Bezier_Toolbox_Sd:
                 pShell = new ::sd::BezierObjectBar(&mrViewShell, pView);
                 break;
 
-            case RID_DRAW_TEXT_TOOLBOX:
+            case ToolbarId::Draw_Text_Toolbox_Sd:
                 pShell = new ::sd::TextObjectBar(
                     &mrViewShell, mrViewShell.GetDoc()->GetPool(), pView);
                 break;
 
-            case RID_DRAW_GRAF_TOOLBOX:
+            case ToolbarId::Draw_Graf_Toolbox:
                 pShell = new ::sd::GraphicObjectBar(&mrViewShell, pView);
                 break;
 
-            case RID_DRAW_MEDIA_TOOLBOX:
+            case ToolbarId::Draw_Media_Toolbox:
                 pShell = new ::sd::MediaObjectBar(&mrViewShell, pView);
                 break;
 
-            case RID_DRAW_TABLE_TOOLBOX:
+            case ToolbarId::Draw_Table_Toolbox:
                 pShell = ::sd::ui::table::CreateTableObjectBar( mrViewShell, pView );
                 break;
 
-            case RID_SVX_EXTRUSION_BAR:
+            case ToolbarId::Svx_Extrusion_Bar:
                 pShell = new svx::ExtrusionBar(
                     &mrViewShell.GetViewShellBase());
                 break;
 
-            case RID_SVX_FONTWORK_BAR:
+            case ToolbarId::Svx_Fontwork_Bar:
                 pShell = new svx::FontworkBar(
                     &mrViewShell.GetViewShellBase());
                 break;
@@ -1683,8 +1737,7 @@ SfxShell* ViewShellObjectBarFactory::CreateShell (
 
 void ViewShellObjectBarFactory::ReleaseShell (SfxShell* pShell)
 {
-    if (pShell != nullptr)
-        delete pShell;
+    delete pShell;
 }
 
 } // end of anonymous namespace
