@@ -25,8 +25,8 @@
 #include "informationdialog.hxx"
 
 #include <vector>
-#include "com/sun/star/util/URL.hpp"
-#include "com/sun/star/util/XURLTransformer.hpp"
+#include <com/sun/star/util/URL.hpp>
+#include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/awt/Rectangle.hpp>
 #include <com/sun/star/awt/Size.hpp>
@@ -45,9 +45,7 @@
 #include <com/sun/star/drawing/XMasterPageTarget.hpp>
 #include <com/sun/star/drawing/XDrawPagesSupplier.hpp>
 #include <com/sun/star/drawing/XMasterPagesSupplier.hpp>
-#include <com/sun/star/presentation/XPresentationSupplier.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
-#include <com/sun/star/presentation/XPresentation.hpp>
 #include <com/sun/star/presentation/XPresentationPage.hpp>
 #include <com/sun/star/document/XFilter.hpp>
 #include <com/sun/star/document/XExporter.hpp>
@@ -208,7 +206,7 @@ void ImpConvertOLE( const Reference< XModel >& rxModel, sal_Int32 nOLEOptimizati
     }
 }
 
-void ImpCompressGraphic( Reference< XGraphicProvider >& rxGraphicProvider, const Reference< XGraphic >& rxGraphic, Reference< XOutputStream >& rxOutputStream,
+void ImpCompressGraphic( Reference< XGraphicProvider > const & rxGraphicProvider, const Reference< XGraphic >& rxGraphic, Reference< XOutputStream > const & rxOutputStream,
     const OUString& rDestMimeType, const awt::Size& rLogicalSize, sal_Int32 nJPEGQuality, sal_Int32 nImageResolution, bool bRemoveCropping, const text::GraphicCrop& rGraphicCropLogic )
 {
     try
@@ -352,7 +350,7 @@ Reference< XGraphic > ImpCompressGraphic( const Reference< XComponentContext >&
             }
             else // this is a metafile
             {
-                OUString aDestMimeType( aSourceMimeType );
+                const OUString& aDestMimeType( aSourceMimeType );
                 Reference< XStream > xTempFile( io::TempFile::create(rxContext), UNO_QUERY_THROW );
                 Reference< XOutputStream > xOutputStream( xTempFile->getOutputStream() );
                 Reference< XGraphicProvider > xGraphicProvider( GraphicProvider::create( rxContext ) );
@@ -385,7 +383,7 @@ void CompressGraphics( ImpOptimizer& rOptimizer, const Reference< XComponentCont
         {
             i++;
             sal_Int32 nProgress = static_cast< sal_Int32 >( 40.0 * ( i / static_cast< double >( rGraphicList.size() ) ) ) + 50;
-            rOptimizer.SetStatusValue( TK_Progress, Any( static_cast< sal_Int32 >( nProgress ) ) );
+            rOptimizer.SetStatusValue( TK_Progress, Any( nProgress ) );
             rOptimizer.DispatchStatus();
 
             if ( aGraphicIter->maUser.size() )
@@ -418,9 +416,8 @@ void CompressGraphics( ImpOptimizer& rOptimizer, const Reference< XComponentCont
                         {
                             if ( aGraphicUserIter->mxShape.is() )
                             {
-                                OUString sEmptyGraphicURL;
                                 Reference< XPropertySet > xShapePropertySet( aGraphicUserIter->mxShape, UNO_QUERY_THROW );
-                                xShapePropertySet->setPropertyValue( "GraphicURL", Any( sEmptyGraphicURL ) );
+                                xShapePropertySet->setPropertyValue( "GraphicURL", Any( OUString() ) );
                                 xShapePropertySet->setPropertyValue( "Graphic", Any( xNewGraphic ) );
 
                                 if ( aGraphicUserIter->maGraphicCropLogic.Left || aGraphicUserIter->maGraphicCropLogic.Top
@@ -454,7 +451,7 @@ void CompressGraphics( ImpOptimizer& rOptimizer, const Reference< XComponentCont
                                     {
                                         if ( !aSize.Width || !aSize.Height )
                                         {
-                                            rxPropertySet->setPropertyValue( "FillBitmapLogicalSize", Any( sal_True ) );
+                                            rxPropertySet->setPropertyValue( "FillBitmapLogicalSize", Any( true ) );
                                             rxPropertySet->setPropertyValue( "FillBitmapSizeX", Any( aGraphicUserIter->maLogicalSize.Width ) );
                                             rxPropertySet->setPropertyValue( "FillBitmapSizeY", Any( aGraphicUserIter->maLogicalSize.Height ) );
                                         }
@@ -477,9 +474,6 @@ void CompressGraphics( ImpOptimizer& rOptimizer, const Reference< XComponentCont
 }
 
 
-// - ImpOptimizer -
-
-
 ImpOptimizer::ImpOptimizer( const Reference< XComponentContext >& rxContext, const Reference< XModel >& rxModel ) :
     mxContext                   ( rxContext ),
     mxModel                     ( rxModel ),
@@ -498,13 +492,11 @@ ImpOptimizer::ImpOptimizer( const Reference< XComponentContext >& rxContext, con
 }
 
 
-
 ImpOptimizer::~ImpOptimizer()
 {
 }
 
 
-
 void ImpOptimizer::DispatchStatus()
 {
     if ( mxStatusDispatcher.is() )
@@ -517,7 +509,6 @@ void ImpOptimizer::DispatchStatus()
 }
 
 
-
 bool ImpOptimizer::Optimize()
 {
 
@@ -571,7 +562,7 @@ bool ImpOptimizer::Optimize()
     return true;
 }
 
-static void DispatchURL( Reference< XComponentContext > xContext, const OUString& sURL, Reference< XFrame > xFrame )
+static void DispatchURL( const Reference< XComponentContext >& xContext, const OUString& sURL, const Reference< XFrame >& xFrame )
 {
     try
     {
@@ -591,11 +582,8 @@ static void DispatchURL( Reference< XComponentContext > xContext, const OUString
 }
 
 
-
-bool ImpOptimizer::Optimize( const Sequence< PropertyValue >& rArguments )
+void ImpOptimizer::Optimize( const Sequence< PropertyValue >& rArguments )
 {
-    bool bRet = true;
-
     if ( mxModel.is() )
     {
         sal_Int64 nEstimatedFileSize = 0;
@@ -692,7 +680,7 @@ bool ImpOptimizer::Optimize( const Sequence< PropertyValue >& rArguments )
         if ( xStorable.is() && !xStorable->isReadonly() )
         {
             mxModel->lockControllers();
-            bRet = Optimize();
+            Optimize();
             mxModel->unlockControllers();
 
             // clearing undo stack:
@@ -726,7 +714,7 @@ bool ImpOptimizer::Optimize( const Sequence< PropertyValue >& rArguments )
             if ( mbOpenNewDocument && xSelf.is() )
             {
                 Reference< awt::XWindow > xContainerWindow( xSelf->getContainerWindow() );
-                xContainerWindow->setVisible( sal_True );
+                xContainerWindow->setVisible( true );
             }
             else
             {
@@ -741,9 +729,6 @@ bool ImpOptimizer::Optimize( const Sequence< PropertyValue >& rArguments )
             DispatchStatus();
         }
     }
-    else
-        bRet = false;
-    return bRet;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
