@@ -25,7 +25,6 @@
 #include <com/sun/star/awt/XMessageBoxFactory.hpp>
 #include <com/sun/star/container/XIndexAccess.hpp>
 #include <com/sun/star/drawing/XShapes.hpp>
-#include <com/sun/star/frame/XDispatch.hpp>
 #include <com/sun/star/text/XTextRange.hpp>
 #include <com/sun/star/view/XSelectionSupplier.hpp>
 #include <com/sun/star/view/XControlAccess.hpp>
@@ -38,9 +37,8 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::view;
 using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::beans;
-using namespace ::com::sun::star::script;
 
-UnoDialog::UnoDialog( const Reference< XComponentContext > &rxContext, Reference< XFrame >& rxFrame ) :
+UnoDialog::UnoDialog( const Reference< XComponentContext > &rxContext, Reference< XFrame > const & rxFrame ) :
     mxContext( rxContext ),
     mxController( rxFrame->getController() ),
     mxDialogModel( mxContext->getServiceManager()->createInstanceWithContext(
@@ -84,7 +82,6 @@ void UnoDialog::endExecute( bool bStatus )
 
 
 Reference< XWindowPeer > UnoDialog::createWindowPeer( Reference< XWindowPeer > const & xParentPeer )
-    throw ( Exception )
 {
     mxDialog->setVisible( false );
     Reference< XToolkit > xToolkit( Toolkit::create( mxContext ), UNO_QUERY_THROW  );
