@@ -18,10 +18,10 @@
  */
 
 
-#include "xmlemitter.hxx"
-#include "genericelements.hxx"
-#include "pdfiprocessor.hxx"
-#include "pdfihelper.hxx"
+#include <xmlemitter.hxx>
+#include <genericelements.hxx>
+#include <pdfiprocessor.hxx>
+#include <pdfihelper.hxx>
 #include "style.hxx"
 
 
@@ -32,10 +32,6 @@
 namespace pdfi
 {
 
-ElementFactory::~ElementFactory()
-{
-}
-
 Element::~Element()
 {
     while( !Children.empty() )
@@ -52,7 +48,7 @@ void Element::applyToChildren( ElementTreeVisitor& rVisitor )
         (*it)->visitedBy( rVisitor, it );
 }
 
-void Element::setParent( std::list<Element*>::iterator& el, Element* pNewParent )
+void Element::setParent( std::list<Element*>::iterator const & el, Element* pNewParent )
 {
     if( pNewParent )
     {
@@ -90,16 +86,15 @@ void Element::updateGeometryWith( const Element* pMergeFrom )
 }
 
 
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
 #include <typeinfo>
 void Element::emitStructure( int nLevel)
 {
-    OSL_TRACE( "%*s<%s %p> (%.1f,%.1f)+(%.1fx%.1f)\n",
-               nLevel, "", typeid( *this ).name(), this,
-               x, y, w, h );
+    SAL_INFO( "sdext", std::string(nLevel, ' ') << "<" << typeid( *this ).name() << " " << this << "> ("
+                << std::setprecision(1) << x << "," << y << ")+(" << w << "x" << h << ")" );
     for( std::list< Element* >::iterator it = Children.begin(); it != Children.end(); ++it )
         (*it)->emitStructure(nLevel+1 );
-    OSL_TRACE( "%*s</%s>", nLevel, "", typeid( *this ).name() );
+    SAL_INFO( "sdext", std::string(nLevel, ' ') << "</" << typeid( *this ).name() << ">"  );
 }
 #endif
 
@@ -147,9 +142,9 @@ void PolyPolyElement::updateGeometry()
 {
     basegfx::B2DRange aRange;
     if( PolyPoly.areControlPointsUsed() )
-        aRange = basegfx::tools::getRange( basegfx::tools::adaptiveSubdivideByAngle( PolyPoly ) );
+        aRange = basegfx::utils::getRange( basegfx::utils::adaptiveSubdivideByAngle( PolyPoly ) );
     else
-        aRange = basegfx::tools::getRange( PolyPoly );
+        aRange = basegfx::utils::getRange( PolyPoly );
     x = aRange.getMinX();
     y = aRange.getMinY();
     w = aRange.getWidth();
@@ -166,26 +161,27 @@ void PolyPolyElement::visitedBy( ElementTreeVisitor&                          rV
     rVisitor.visit( *this, rParentIt);
 }
 
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
 void PolyPolyElement::emitStructure( int nLevel)
 {
-    OSL_TRACE( "%*s<%s %p>", nLevel, "", typeid( *this ).name(), this  );
-    OSL_TRACE( "path=" );
+    SAL_WARN( "sdext", std::string(nLevel, ' ') << "<" << typeid( *this ).name() << " " << this << ">" );
+    SAL_WARN( "sdext", "path=" );
     int nPoly = PolyPoly.count();
     for( int i = 0; i < nPoly; i++ )
     {
+        OUStringBuffer buff;
         basegfx::B2DPolygon aPoly = PolyPoly.getB2DPolygon( i );
         int nPoints = aPoly.count();
         for( int n = 0; n < nPoints; n++ )
         {
             basegfx::B2DPoint aPoint = aPoly.getB2DPoint( n );
-            OSL_TRACE( " (%g,%g)", aPoint.getX(), aPoint.getY() );
+            buff.append( " (").append(aPoint.getX()).append(",").append(aPoint.getY()).append(")");
         }
-        OSL_TRACE( "\n" );
+        SAL_WARN( "sdext", "    " << buff.makeStringAndClear() );
     }
     for( std::list< Element* >::iterator it = Children.begin(); it != Children.end(); ++it )
         (*it)->emitStructure( nLevel+1 );
-    OSL_TRACE( "%*s</%s>", nLevel, "", typeid( *this ).name() );
+    SAL_WARN( "sdext", std::string(nLevel, ' ') << "</" << typeid( *this ).name() << ">");
 }
 #endif
 
@@ -195,7 +191,7 @@ void ParagraphElement::visitedBy( ElementTreeVisitor&                          r
     rVisitor.visit(*this,rParentIt);
 }
 
-bool ParagraphElement::isSingleLined( PDFIProcessor& rProc ) const
+bool ParagraphElement::isSingleLined( PDFIProcessor const & rProc ) const
 {
     std::list< Element* >::const_iterator it = Children.begin();
     TextElement* pText = nullptr, *pLastText = nullptr;
@@ -306,7 +302,7 @@ void PageElement::updateParagraphGeometry( Element* pEle )
     }
 }
 
-bool PageElement::resolveHyperlink( std::list<Element*>::iterator link_it, std::list<Element*>& rElements )
+bool PageElement::resolveHyperlink( const std::list<Element*>::iterator& link_it, std::list<Element*>& rElements )
 {
     HyperlinkElement* pLink = dynamic_cast<HyperlinkElement*>(*link_it);
     if( ! pLink ) // sanity check
@@ -370,12 +366,12 @@ void PageElement::resolveHyperlinks()
     }
 }
 
-void PageElement::resolveFontStyles( PDFIProcessor& rProc )
+void PageElement::resolveFontStyles( PDFIProcessor const & rProc )
 {
     resolveUnderlines(rProc);
 }
 
-void PageElement::resolveUnderlines( PDFIProcessor& rProc )
+void PageElement::resolveUnderlines( PDFIProcessor const & rProc )
 {
     // FIXME: currently the algorithm used is quadratic
     // this could be solved by some sorting beforehand
