@@ -18,7 +18,7 @@
  */
 
 
-#include "treevisitorfactory.hxx"
+#include <treevisitorfactory.hxx>
 #include "writertreevisiting.hxx"
 #include "drawtreevisiting.hxx"
 
@@ -28,21 +28,21 @@ namespace pdfi
     {
         WriterTreeVisitorFactory() {}
 
-        virtual boost::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const
+        virtual std::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const override
         {
-            return boost::shared_ptr<ElementTreeVisitor>(new WriterXmlOptimizer(rProc));
+            return std::shared_ptr<ElementTreeVisitor>(new WriterXmlOptimizer(rProc));
         }
 
-        virtual boost::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
+        virtual std::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
             StyleContainer& rStyles,
-            PDFIProcessor&  rProc ) const
+            PDFIProcessor&  rProc ) const override
         {
-            return boost::shared_ptr<ElementTreeVisitor>(new WriterXmlFinalizer(rStyles,rProc));
+            return std::shared_ptr<ElementTreeVisitor>(new WriterXmlFinalizer(rStyles,rProc));
         }
 
-        virtual boost::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext, PDFIProcessor&) const
+        virtual std::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext) const override
         {
-            return boost::shared_ptr<ElementTreeVisitor>(new WriterXmlEmitter(rEmitContext));
+            return std::shared_ptr<ElementTreeVisitor>(new WriterXmlEmitter(rEmitContext));
         }
     };
 
@@ -50,23 +50,22 @@ namespace pdfi
     {
         ImpressTreeVisitorFactory() {}
 
-        virtual boost::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const
+        virtual std::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const override
         {
-            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlOptimizer(rProc));
+            return std::shared_ptr<ElementTreeVisitor>(new DrawXmlOptimizer(rProc));
         }
 
-        virtual boost::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
+        virtual std::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
             StyleContainer& rStyles,
-            PDFIProcessor&  rProc ) const
+            PDFIProcessor&  rProc ) const override
         {
-            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlFinalizer(rStyles,rProc));
+            return std::shared_ptr<ElementTreeVisitor>(new DrawXmlFinalizer(rStyles,rProc));
         }
 
-        virtual boost::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext, PDFIProcessor& rProc) const
+        virtual std::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext) const override
         {
-            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlEmitter(rEmitContext,
-                                                                            DrawXmlEmitter::IMPRESS_DOC,
-                                                                            rProc
+            return std::shared_ptr<ElementTreeVisitor>(new DrawXmlEmitter(rEmitContext,
+                                                                            DrawXmlEmitter::IMPRESS_DOC
                                                                             ));
         }
     };
@@ -75,23 +74,22 @@ namespace pdfi
     {
         DrawTreeVisitorFactory() {}
 
-        virtual boost::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const
+        virtual std::shared_ptr<ElementTreeVisitor> createOptimizingVisitor(PDFIProcessor& rProc) const override
         {
-            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlOptimizer(rProc));
+            return std::shared_ptr<ElementTreeVisitor>(new DrawXmlOptimizer(rProc));
         }
 
-        virtual boost::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
+        virtual std::shared_ptr<ElementTreeVisitor> createStyleCollectingVisitor(
             StyleContainer& rStyles,
-            PDFIProcessor&  rProc ) const
+            PDFIProcessor&  rProc ) const override
         {
-            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlFinalizer(rStyles,rProc));
+            return std::shared_ptr<ElementTreeVisitor>(new DrawXmlFinalizer(rStyles,rProc));
         }
 
-        virtual boost::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext, PDFIProcessor& rProc) const
+        virtual std::shared_ptr<ElementTreeVisitor> createEmittingVisitor(EmitContext& rEmitContext) const override
         {
-            return boost::shared_ptr<ElementTreeVisitor>(new DrawXmlEmitter(rEmitContext,
-                                                                            DrawXmlEmitter::DRAW_DOC,
-                                                                            rProc
+            return std::shared_ptr<ElementTreeVisitor>(new DrawXmlEmitter(rEmitContext,
+                                                                            DrawXmlEmitter::DRAW_DOC
                                                                             ));
         }
     };
