@@ -25,32 +25,31 @@
 #include <assert.h>
 #include <math.h>
 
-#include <boost/shared_array.hpp>
+#include <memory>
+#include <vector>
 
-#if defined __SUNPRO_CC
-#pragma disable_warn
-#elif defined _MSC_VER
+#if defined _MSC_VER
 #pragma warning(push, 1)
 #endif
 
-// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1
+// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1, then renamed to UnicodeMapFuncs.h in 0.62.0
 // FIXME: we can't use #if POPPLER_CHECK_VERSION(0, 21, 0) && !POPPLER_CHECK_VERSION(0, 21, 1)
 //        because the internal poppler does not provide poppler-version.h and the macro always returns 0
-#if POPPLER_CHECK_VERSION(0, 21, 1)
-#include "UTF8.h"
+#if POPPLER_CHECK_VERSION(0, 62, 0)
+#include <UnicodeMapFuncs.h>
+#elif POPPLER_CHECK_VERSION(0, 21, 1)
+#include <UTF8.h>
 #elif POPPLER_CHECK_VERSION(0, 21, 0)
 #include "UTF.h"
 #else
 #include "UTF8.h"
 #endif
 
-#if defined __SUNPRO_CC
-#pragma enable_warn
-#elif defined _MSC_VER
+#if defined _MSC_VER
 #pragma warning(pop)
 #endif
 
-#ifdef WNT
+#ifdef _WIN32
 # define snprintf _snprintf
 
 #if defined __GNUC__
@@ -62,7 +61,7 @@
 /* SYNC STREAMS
    ============
 
-   We stream human-readble tokens to stdout, and binary data (fonts,
+   We stream human-readable tokens to stdout, and binary data (fonts,
    bitmaps) to g_binary_out. Another process reads from those pipes, and
    there lies the rub: things can deadlock, if the two involved
    processes access the pipes in different order. At any point in
@@ -86,37 +85,37 @@ namespace
 
 /** Escapes line-ending characters (\n and \r) in input string.
   */
-boost::shared_array<char> lcl_escapeLineFeeds(const char* const i_pStr)
+std::vector<char> lcl_escapeLineFeeds(const char* const i_pStr)
 {
     size_t nLength(strlen(i_pStr));
-    char* pBuffer = new char[2*nLength+1];
+    std::vector<char> aBuffer;
+    aBuffer.reserve(2*nLength+1);
 
     const char* pRead = i_pStr;
-    char* pWrite = pBuffer;
     while( nLength-- )
     {
         if( *pRead == '\r' )
         {
-            *pWrite++ = '\\';
-            *pWrite++ = 'r';
+            aBuffer.push_back('\\');
+            aBuffer.push_back('r');
         }
         else if( *pRead == '\n' )
         {
-            *pWrite++ = '\\';
-            *pWrite++ = 'n';
+            aBuffer.push_back('\\');
+            aBuffer.push_back('n');
         }
         else if( *pRead == '\\' )
         {
-            *pWrite++ = '\\';
-            *pWrite++ = '\\';
+            aBuffer.push_back('\\');
+            aBuffer.push_back('\\');
         }
         else
-            *pWrite++ = *pRead;
+            aBuffer.push_back(*pRead);
         pRead++;
     }
-    *pWrite++ = 0;
+    aBuffer.push_back(0);
 
-    return boost::shared_array<char>(pBuffer);
+    return aBuffer;
 }
 
 }
@@ -147,20 +146,84 @@ void writeBinaryBuffer( const OutputBuffer& rBuffer )
     fflush(g_binary_out);
 }
 
+bool ExtractJpegData(Stream* str, OutputBuffer& outBuf)
+{
+    int bytesToMarker = 0;
+    int bytesToLen = -1;
+    bool collectBytes = false;
+    int startOfScan = 0;
+    int b1 = -1;
+    for (; ; )
+    {
+        const int b2 = b1;
+        b1 = str->getChar();
+
+        if (b1 == -1)
+            return false;
+
+        if (collectBytes)
+        {
+            outBuf.push_back((Output_t)b1);
+
+            bytesToMarker--;
+            bytesToLen--;
+        }
+
+        if (bytesToMarker == 0)
+        {
+            if (startOfScan == 1)
+            {
+                bytesToMarker = -1;
+                startOfScan = 2;
+            }
+            else if (b2 == 0xFF)
+            {
+                if (b1 == 0xD8)
+                {
+                    collectBytes = true;
+                    bytesToMarker = 2;
+
+                    outBuf.push_back((Output_t)0xFF);
+                    outBuf.push_back((Output_t)0xD8);
+                }
+                else
+                {
+                    bytesToLen = 2;
+                }
+                if (b1 == 0xDA)
+                {
+                    startOfScan = 1;
+                }
+            }
+            else if (collectBytes)
+            {
+                return false;
+            }
+        }
+
+        if (bytesToLen == 0)
+        {
+            bytesToMarker = b2 * 256 + b1;
+        }
+
+        if (startOfScan == 2)
+            if ((b2 == 0xFF) && (b1 == 0xD9))
+                return true;
+    }
+}
+
 void writeJpeg_( OutputBuffer& o_rOutputBuf, Stream* str, bool bWithLinefeed )
 {
     // dump JPEG file as-is
 #if POPPLER_CHECK_VERSION(0, 17, 3)
-    str = str->getBaseStream();
+    str = str->getNextStream();
 #else
     str = ((DCTStream *)str)->getRawStream();
 #endif
     str->reset();
 
-    int c;
     o_rOutputBuf.clear();
-    while((c=str->getChar()) != EOF)
-        o_rOutputBuf.push_back(static_cast<char>(c));
+    ExtractJpegData(str, o_rOutputBuf);
 
     printf( " JPEG %d", (int)o_rOutputBuf.size() );
     if( bWithLinefeed )
@@ -249,11 +312,11 @@ void writePpm_( OutputBuffer&     o_rOutputBuf,
     // initialize stream
     Guchar *p;
     GfxRGB rgb;
-    ImageStream* imgStr =
+    std::unique_ptr<ImageStream> imgStr(
         new ImageStream(str,
                         width,
                         colorMap->getNumPixelComps(),
-                        colorMap->getBits());
+                        colorMap->getBits()));
     imgStr->reset();
 
     for( int y=0; y<height; ++y)
@@ -269,9 +332,6 @@ void writePpm_( OutputBuffer&     o_rOutputBuf,
             p +=colorMap->getNumPixelComps();
         }
     }
-
-    delete imgStr;
-
 }
 
 // call this only for 1 bit image streams !
@@ -298,8 +358,7 @@ void writePng_( OutputBuffer& o_rOutputBuf,
                 Stream* str,
                 int width, int height, GfxImageColorMap* colorMap,
                 Stream* maskStr,
-                int maskWidth, int maskHeight, GfxImageColorMap* maskColorMap,
-                bool bWithLinefeed )
+                int maskWidth, int maskHeight, GfxImageColorMap* maskColorMap )
 {
     o_rOutputBuf.clear();
 
@@ -307,16 +366,14 @@ void writePng_( OutputBuffer& o_rOutputBuf,
     PngHelper::createPng( o_rOutputBuf, str, width, height, colorMap, maskStr, maskWidth, maskHeight, maskColorMap );
 
     printf( " PNG %d", (int)o_rOutputBuf.size() );
-    if( bWithLinefeed )
-        printf("\n");
+    printf("\n");
 }
 
 void writePng_( OutputBuffer& o_rOutputBuf,
                 Stream* str,
                 int width, int height, GfxImageColorMap* colorMap,
                 Stream* maskStr,
-                int maskWidth, int maskHeight, bool maskInvert,
-                bool bWithLinefeed )
+                int maskWidth, int maskHeight, bool maskInvert )
 {
     o_rOutputBuf.clear();
 
@@ -324,32 +381,30 @@ void writePng_( OutputBuffer& o_rOutputBuf,
     PngHelper::createPng( o_rOutputBuf, str, width, height, colorMap, maskStr, maskWidth, maskHeight, maskInvert );
 
     printf( " PNG %d", (int)o_rOutputBuf.size() );
-    if( bWithLinefeed )
-        printf("\n");
+    printf("\n");
 }
 
 // stolen from ImageOutputDev.cc
-void writeMask_( OutputBuffer& o_rOutputBuf, Stream* str, int width, int height, bool bWithLinefeed, bool bInvert )
+void writeMask_( OutputBuffer& o_rOutputBuf, Stream* str, int width, int height, bool bInvert )
 {
     if( str->getKind() == strDCT )
-        writeJpeg_(o_rOutputBuf, str, bWithLinefeed);
+        writeJpeg_(o_rOutputBuf, str, true/*bWithLinefeed*/);
     else
-        writePbm_(o_rOutputBuf, str, width, height, bWithLinefeed, bInvert );
+        writePbm_(o_rOutputBuf, str, width, height, true/*bWithLinefeed*/, bInvert );
 }
 
 void writeImage_( OutputBuffer&     o_rOutputBuf,
                   Stream*           str,
                   int               width,
                   int               height,
-                  GfxImageColorMap* colorMap,
-                  bool              bWithLinefeed )
+                  GfxImageColorMap* colorMap )
 {
     // dump JPEG file
     if( str->getKind() == strDCT &&
         (colorMap->getNumPixelComps() == 1 ||
          colorMap->getNumPixelComps() == 3) )
     {
-        writeJpeg_(o_rOutputBuf, str, bWithLinefeed);
+        writeJpeg_(o_rOutputBuf, str, true/*bWithLinefeed*/);
     }
     else if (colorMap->getNumPixelComps() == 1 &&
              colorMap->getBits() == 1)
@@ -365,37 +420,25 @@ void writeImage_( OutputBuffer&     o_rOutputBuf,
             nIndex = 1;
             colorMap->getRGB( &nIndex, &oneColor );
         }
-        writePng_( o_rOutputBuf, str, width, height, zeroColor, oneColor, false, bWithLinefeed );
+        writePng_( o_rOutputBuf, str, width, height, zeroColor, oneColor, false, true/*bWithLinefeed*/ );
     }
     else
-        writePpm_( o_rOutputBuf, str, width, height, colorMap, bWithLinefeed );
+        writePpm_( o_rOutputBuf, str, width, height, colorMap, true/*bWithLinefeed*/ );
 }
 
 // forwarders
-// ------------------------------------------------------------------
 
-inline void writeImage( OutputBuffer&     o_rOutputBuf,
-                        Stream*           str,
-                        int               width,
-                        int               height,
-                        GfxImageColorMap* colorMap ) { writeImage_(o_rOutputBuf,str,width,height,colorMap,false); }
+
 inline void writeImageLF( OutputBuffer&     o_rOutputBuf,
                           Stream*           str,
                           int               width,
                           int               height,
-                          GfxImageColorMap* colorMap ) { writeImage_(o_rOutputBuf,str,width,height,colorMap,true); }
-inline void writeMask( OutputBuffer&     o_rOutputBuf,
-                       Stream*           str,
-                       int               width,
-                       int               height,
-                       bool              bInvert ) { writeMask_(o_rOutputBuf,str,width,height,false,bInvert); }
+                          GfxImageColorMap* colorMap ) { writeImage_(o_rOutputBuf,str,width,height,colorMap); }
 inline void writeMaskLF( OutputBuffer&     o_rOutputBuf,
                          Stream*           str,
                          int               width,
                          int               height,
-                         bool              bInvert ) { writeMask_(o_rOutputBuf,str,width,height,true,bInvert); }
-
-// ------------------------------------------------------------------
+                         bool              bInvert ) { writeMask_(o_rOutputBuf,str,width,height,bInvert); }
 
 
 int PDFOutDev::parseFont( long long nNewId, GfxFont* gfxFont, GfxState* state ) const
@@ -403,6 +446,9 @@ int PDFOutDev::parseFont( long long nNewId, GfxFont* gfxFont, GfxState* state )
     FontAttributes aNewFont;
     int nSize = 0;
 
+#if POPPLER_CHECK_VERSION(0, 64, 0)
+    const
+#endif
     GooString* pFamily = gfxFont->getName();
     if( pFamily )
     {
@@ -459,7 +505,7 @@ void PDFOutDev::writeFontFile( GfxFont* gfxFont ) const
     gfree(pBuf);
 }
 
-void PDFOutDev::printPath( GfxPath* pPath ) const
+void PDFOutDev::printPath( GfxPath* pPath )
 {
     int nSubPaths = pPath ? pPath->getNumSubpaths() : 0;
     for( int i=0; i<nSubPaths; i++ )
@@ -482,12 +528,12 @@ void PDFOutDev::printPath( GfxPath* pPath ) const
 PDFOutDev::PDFOutDev( PDFDoc* pDoc ) :
     m_pDoc( pDoc ),
     m_aFontMap(),
-    m_pUtf8Map( new UnicodeMap((char*)"UTF-8", gTrue, &mapUTF8) )
+    m_pUtf8Map( new UnicodeMap("UTF-8", gTrue, &mapUTF8) ),
+    m_bSkipImages(false)
 {
 }
 PDFOutDev::~PDFOutDev()
 {
-    delete m_pUtf8Map;
 }
 
 void PDFOutDev::startPage(int /*pageNum*/, GfxState* state
@@ -525,14 +571,14 @@ void PDFOutDev::processLink(Link* link, Catalog*)
     {
         const char* pURI = static_cast<LinkURI*>(pAction)->getURI()->getCString();
 
-        boost::shared_array<char> pEsc( lcl_escapeLineFeeds(pURI) );
+        std::vector<char> aEsc( lcl_escapeLineFeeds(pURI) );
 
         printf( "drawLink %f %f %f %f %s\n",
                 normalize(x1),
                 normalize(y1),
                 normalize(x2),
                 normalize(y2),
-                pEsc.get() );
+                aEsc.data() );
     }
 }
 
@@ -554,8 +600,8 @@ void PDFOutDev::setDefaultCTM(double *pMat)
 
     printf( "updateCtm %f %f %f %f %f %f\n",
             normalize(pMat[0]),
-            normalize(pMat[2]),
             normalize(pMat[1]),
+            normalize(pMat[2]),
             normalize(pMat[3]),
             normalize(pMat[4]),
             normalize(pMat[5]) );
@@ -573,8 +619,8 @@ void PDFOutDev::updateCTM(GfxState* state,
 
     printf( "updateCtm %f %f %f %f %f %f\n",
             normalize(pMat[0]),
-            normalize(pMat[2]),
             normalize(pMat[1]),
+            normalize(pMat[2]),
             normalize(pMat[3]),
             normalize(pMat[4]),
             normalize(pMat[5]) );
@@ -582,6 +628,8 @@ void PDFOutDev::updateCTM(GfxState* state,
 
 void PDFOutDev::updateLineDash(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
 
     double* dashArray; int arrayLen; double startOffset;
@@ -599,36 +647,48 @@ void PDFOutDev::updateLineDash(GfxState *state)
 
 void PDFOutDev::updateFlatness(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
     printf( "updateFlatness %d\n", state->getFlatness() );
 }
 
 void PDFOutDev::updateLineJoin(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
     printf( "updateLineJoin %d\n", state->getLineJoin() );
 }
 
 void PDFOutDev::updateLineCap(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
     printf( "updateLineCap %d\n", state->getLineCap() );
 }
 
 void PDFOutDev::updateMiterLimit(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
     printf( "updateMiterLimit %f\n", normalize(state->getMiterLimit()) );
 }
 
 void PDFOutDev::updateLineWidth(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
     printf( "updateLineWidth %f\n", normalize(state->getLineWidth()) );
 }
 
 void PDFOutDev::updateFillColor(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
 
     GfxRGB aRGB;
@@ -643,6 +703,8 @@ void PDFOutDev::updateFillColor(GfxState *state)
 
 void PDFOutDev::updateStrokeColor(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
 
     GfxRGB aRGB;
@@ -657,11 +719,15 @@ void PDFOutDev::updateStrokeColor(GfxState *state)
 
 void PDFOutDev::updateFillOpacity(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     updateFillColor(state);
 }
 
 void PDFOutDev::updateStrokeOpacity(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     updateStrokeColor(state);
 }
 
@@ -679,10 +745,13 @@ void PDFOutDev::updateFont(GfxState *state)
         FontAttributes aFont;
         int nEmbedSize=0;
 
+#if POPPLER_CHECK_VERSION(0, 64, 0)
+        const
+#endif
         Ref* pID = gfxFont->getID();
         // TODO(Q3): Portability problem
         long long fontID = (long long)pID->gen << 32 | (long long)pID->num;
-        boost::unordered_map< long long, FontAttributes >::const_iterator it =
+        std::unordered_map< long long, FontAttributes >::const_iterator it =
             m_aFontMap.find( fontID );
         if( it == m_aFontMap.end() )
         {
@@ -698,7 +767,7 @@ void PDFOutDev::updateFont(GfxState *state)
 
             aFont = it->second;
 
-            boost::shared_array<char> pEsc( lcl_escapeLineFeeds(aFont.familyName.getCString()) );
+            std::vector<char> aEsc( lcl_escapeLineFeeds(aFont.familyName.getCString()) );
             printf( " %d %d %d %d %f %d %s",
                     aFont.isEmbedded,
                     aFont.isBold,
@@ -706,7 +775,7 @@ void PDFOutDev::updateFont(GfxState *state)
                     aFont.isUnderline,
                     normalize(state->getTransformedFontSize()),
                     nEmbedSize,
-                    pEsc.get() );
+                    aEsc.data() );
         }
         printf( "\n" );
 
@@ -724,6 +793,8 @@ void PDFOutDev::updateRender(GfxState *state)
 
 void PDFOutDev::stroke(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
 
     printf( "strokePath" );
@@ -733,6 +804,8 @@ void PDFOutDev::stroke(GfxState *state)
 
 void PDFOutDev::fill(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
 
     printf( "fillPath" );
@@ -742,6 +815,8 @@ void PDFOutDev::fill(GfxState *state)
 
 void PDFOutDev::eoFill(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
 
     printf( "eoFillPath" );
@@ -751,6 +826,8 @@ void PDFOutDev::eoFill(GfxState *state)
 
 void PDFOutDev::clip(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
 
     printf( "clipPath" );
@@ -760,6 +837,8 @@ void PDFOutDev::clip(GfxState *state)
 
 void PDFOutDev::eoClip(GfxState *state)
 {
+    if (m_bSkipImages)
+        return;
     assert(state);
 
     printf( "eoClipPath" );
@@ -793,51 +872,77 @@ void PDFOutDev::drawChar(GfxState *state, double x, double y,
 {
     assert(state);
 
-    if( u == NULL )
+    if( u == nullptr )
         return;
 
-    // normalize coordinates: correct from baseline-relative to upper
-    // left corner of glyphs
-    double x2(0.0), y2(0.0);
-    state->textTransformDelta( 0.0,
-                               state->getFont()->getAscent(),
-                               &x2, &y2 );
-    const double fFontSize(state->getFontSize());
-    x += x2*fFontSize;
-    y += y2*fFontSize;
+    // Fix for tdf#96080
+    if (uLen == 4 && u[0] == '\t' && u[1] == '\r' && u[2] == ' ' && u[3] == 0xA0)
+    {
+        u += 2;
+        uLen = 1;
+    }
+
+    double csdx = 0.0;
+    double csdy = 0.0;
+    if (state->getFont()->getWMode())
+    {
+        csdy = state->getCharSpace();
+        if (*u == ' ')
+            csdy += state->getWordSpace();
+    }
+    else
+    {
+        csdx = state->getCharSpace();
+        if (*u == ' ')
+            csdx += state->getWordSpace();
+        csdx *= state->getHorizScaling();
+    }
+
+    double cstdx = 0.0;
+    double cstdy = 0.0;
+    state->textTransformDelta(csdx, csdy, &cstdx, &cstdy);
+
+    const double fontSize = state->getFontSize();
 
     const double aPositionX(x-originX);
     const double aPositionY(y-originY);
-    // TODO(F2): use leading here, when set
-    const double nWidth(dx != 0.0 ? dx : fFontSize);
-    const double nHeight(dy != 0.0 ? dy : fFontSize);
 
     const double* pTextMat=state->getTextMat();
-    printf( "drawChar %f %f %f %f %f %f %f %f ",
+    printf( "drawChar %f %f %f %f %f %f %f %f %f ",
             normalize(aPositionX),
             normalize(aPositionY),
-            normalize(aPositionX+nWidth),
-            normalize(aPositionY-nHeight),
+            normalize(aPositionX + dx - cstdx),
+            normalize(aPositionY + dy - cstdy),
             normalize(pTextMat[0]),
             normalize(pTextMat[2]),
             normalize(pTextMat[1]),
-            normalize(pTextMat[3]) );
+            normalize(pTextMat[3]),
+            normalize(fontSize)
+            );
 
     // silence spurious warning
+#if POPPLER_CHECK_VERSION(0, 62, 0)
+    (void)&mapUTF16;
+#else
     (void)&mapUCS2;
+#endif
 
     char buf[9];
     for( int i=0; i<uLen; ++i )
     {
         buf[ m_pUtf8Map->mapUnicode(u[i], buf, sizeof(buf)-1) ] = 0;
-        boost::shared_array<char> pEsc( lcl_escapeLineFeeds(buf) );
-        printf( "%s", pEsc.get() );
+        std::vector<char> aEsc( lcl_escapeLineFeeds(buf) );
+        printf( "%s", aEsc.data() );
     }
 
     printf( "\n" );
 }
 
+#if POPPLER_CHECK_VERSION(0, 64, 0)
+void PDFOutDev::drawString(GfxState*, const GooString* /*s*/)
+#else
 void PDFOutDev::drawString(GfxState*, GooString* /*s*/)
+#endif
 {
     // TODO(F3): NYI
 }
@@ -854,6 +959,8 @@ void PDFOutDev::drawImageMask(GfxState* pState, Object*, Stream* str,
 #endif
                               GBool /*inlineImg*/ )
 {
+    if (m_bSkipImages)
+        return;
     OutputBuffer aBuf; initBuf(aBuf);
 
     printf( "drawMask %d %d %d", width, height, invert );
@@ -872,7 +979,7 @@ void PDFOutDev::drawImageMask(GfxState* pState, Object*, Stream* str,
             writePng_( aBuf, str, width, height, zeroColor, oneColor, true, true );
     }
     else
-        writeMaskLF(aBuf, str, width, height, invert != 0);
+        writeMaskLF(aBuf, str, width, height, invert);
     writeBinaryBuffer(aBuf);
 }
 
@@ -883,6 +990,8 @@ void PDFOutDev::drawImage(GfxState*, Object*, Stream* str,
 #endif
                           int* maskColors, GBool /*inlineImg*/ )
 {
+    if (m_bSkipImages)
+        return;
     OutputBuffer aBuf; initBuf(aBuf);
     OutputBuffer aMaskBuf;
 
@@ -901,12 +1010,12 @@ void PDFOutDev::drawImage(GfxState*, Object*, Stream* str,
         {
             GfxRGB aMinRGB;
             colorMap->getColorSpace()->getRGB(
-                (GfxColor*)maskColors,
+                reinterpret_cast<GfxColor*>(maskColors),
                 &aMinRGB );
 
             GfxRGB aMaxRGB;
             colorMap->getColorSpace()->getRGB(
-                (GfxColor*)maskColors+gfxColorMaxComps,
+                reinterpret_cast<GfxColor*>(maskColors)+gfxColorMaxComps,
                 &aMaxRGB );
 
             aMaskBuf.push_back( colToByte(aMinRGB.r) );
@@ -938,9 +1047,11 @@ void PDFOutDev::drawMaskedImage(GfxState*, Object*, Stream* str,
 #endif
                                )
 {
+    if (m_bSkipImages)
+        return;
     OutputBuffer aBuf;     initBuf(aBuf);
     printf( "drawImage %d %d 0", width, height );
-    writePng_( aBuf, str, width, height, colorMap, maskStr, maskWidth, maskHeight, maskInvert, true );
+    writePng_( aBuf, str, width, height, colorMap, maskStr, maskWidth, maskHeight, maskInvert );
     writeBinaryBuffer( aBuf );
 }
 
@@ -958,9 +1069,11 @@ void PDFOutDev::drawSoftMaskedImage(GfxState*, Object*, Stream* str,
 #endif
                                    )
 {
+    if (m_bSkipImages)
+        return;
     OutputBuffer aBuf;     initBuf(aBuf);
     printf( "drawImage %d %d 0", width, height );
-    writePng_( aBuf, str, width, height, colorMap, maskStr, maskWidth, maskHeight, maskColorMap, true );
+    writePng_( aBuf, str, width, height, colorMap, maskStr, maskWidth, maskHeight, maskColorMap );
     writeBinaryBuffer( aBuf );
 }
 
@@ -970,6 +1083,11 @@ void PDFOutDev::setPageNum( int nNumPages )
     printf("setPageNum %d\n", nNumPages);
 }
 
+void PDFOutDev::setSkipImages( bool bSkipImages )
+{
+    m_bSkipImages = bSkipImages;
+}
+
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
