@@ -20,14 +20,10 @@
 #include <com/sun/star/uno/Reference.h>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/frame/FrameSearchFlag.hpp>
-#include <com/sun/star/frame/XComponentLoader.hpp>
-#include <com/sun/star/frame/XNotifyingDispatch.hpp>
 #include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/util/XCloseable.hpp>
 #include <com/sun/star/frame/XFrame.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
-#include <com/sun/star/frame/DispatchResultState.hpp>
-#include <com/sun/star/frame/XDispatchResultListener.hpp>
 #include <com/sun/star/util/URL.hpp>
 #include <com/sun/star/util/URLTransformer.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
@@ -40,6 +36,7 @@
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
+#include <com/sun/star/packages/WrongPasswordException.hpp>
 #include <com/sun/star/uno/Sequence.h>
 #include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
 #include <rtl/ustring.hxx>
@@ -56,7 +53,7 @@
 #include <svl/eitem.hxx>
 #include <sfx2/doctempl.hxx>
 #include <svtools/sfxecode.hxx>
-#include <framework/preventduplicateinteraction.hxx>
+#include <preventduplicateinteraction.hxx>
 #include <svtools/ehdl.hxx>
 #include <basic/sbxobj.hxx>
 #include <svl/urihelper.hxx>
@@ -69,9 +66,6 @@
 #include <comphelper/docpasswordhelper.hxx>
 #include <vcl/svapp.hxx>
 
-#include <osl/mutex.hxx>
-
-
 #include <sfx2/app.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/dispatch.hxx>
@@ -81,14 +75,14 @@
 #include <sfx2/objitem.hxx>
 #include <sfx2/objsh.hxx>
 #include <svl/slstitm.hxx>
-#include "appopen.hxx"
-#include "objshimp.hxx"
-#include "openflag.hxx"
+#include <appopen.hxx>
+#include <objshimp.hxx>
+#include <openflag.hxx>
 #include <sfx2/passwd.hxx>
 #include <sfx2/request.hxx>
 #include <sfx2/sfxresid.hxx>
 #include <sfx2/viewsh.hxx>
-#include "app.hrc"
+#include <sfx2/strings.hrc>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/sfxuno.hxx>
 #include <sfx2/objface.hxx>
@@ -96,7 +90,7 @@
 #include <sfx2/docfac.hxx>
 #include <sfx2/event.hxx>
 #include <sfx2/templatedlg.hxx>
-#include "openuriexternally.hxx"
+#include <openuriexternally.hxx>
 
 #include <officecfg/Office/ProtocolHandler.hxx>
 
@@ -124,7 +118,7 @@ void SetTemplate_Impl( const OUString &rFileName,
 class SfxDocPasswordVerifier : public ::comphelper::IDocPasswordVerifier
 {
 public:
-    inline explicit     SfxDocPasswordVerifier( const Reference< embed::XStorage >& rxStorage ) :
+    explicit     SfxDocPasswordVerifier( const Reference< embed::XStorage >& rxStorage ) :
                             mxStorage( rxStorage ) {}
 
     virtual ::comphelper::DocPasswordVerifierResult
@@ -145,15 +139,14 @@ private:
 }
 
 
-
 ::comphelper::DocPasswordVerifierResult SfxDocPasswordVerifier::verifyEncryptionData( const uno::Sequence< beans::NamedValue >& rEncryptionData )
 {
-    ::comphelper::DocPasswordVerifierResult eResult = ::comphelper::DocPasswordVerifierResult_WRONG_PASSWORD;
+    ::comphelper::DocPasswordVerifierResult eResult = ::comphelper::DocPasswordVerifierResult::WrongPassword;
     try
     {
         // check the encryption data
         // if the data correct is the stream will be opened successfully
-        // and immediatelly closed
+        // and immediately closed
         ::comphelper::OStorageHelper::SetCommonStorageEncryptionData( mxStorage, rEncryptionData );
 
         mxStorage->openStreamElement(
@@ -161,29 +154,25 @@ private:
                 embed::ElementModes::READ | embed::ElementModes::NOCREATE );
 
         // no exception -> success
-        eResult = ::comphelper::DocPasswordVerifierResult_OK;
+        eResult = ::comphelper::DocPasswordVerifierResult::OK;
     }
     catch( const packages::WrongPasswordException& )
     {
-        eResult = ::comphelper::DocPasswordVerifierResult_WRONG_PASSWORD;
+        eResult = ::comphelper::DocPasswordVerifierResult::WrongPassword;
     }
     catch( const uno::Exception& )
     {
         // unknown error, report it as wrong password
         // TODO/LATER: we need an additional way to report unknown problems in this case
-        eResult = ::comphelper::DocPasswordVerifierResult_WRONG_PASSWORD;
+        eResult = ::comphelper::DocPasswordVerifierResult::WrongPassword;
     }
     return eResult;
 }
 
 
-
-
-
-sal_uInt32 CheckPasswd_Impl
+ErrCode CheckPasswd_Impl
 (
     SfxObjectShell*  pDoc,
-    SfxItemPool&     /*rPool*/, // Pool, if a Set has to be created
     SfxMedium*       pFile      // the Medium and its Password shold be obtained
 )
 
@@ -195,9 +184,9 @@ sal_uInt32 CheckPasswd_Impl
     If the set does not exist the it is created.
 */
 {
-    sal_uIntPtr nRet = ERRCODE_NONE;
+    ErrCode nRet = ERRCODE_NONE;
 
-    if( ( !pFile->GetFilter() || pFile->IsStorage() ) )
+    if( !pFile->GetFilter() || pFile->IsStorage() )
     {
         uno::Reference< embed::XStorage > xStorage = pFile->GetStorage();
         if( xStorage.is() )
@@ -206,9 +195,12 @@ sal_uInt32 CheckPasswd_Impl
             if ( xStorageProps.is() )
             {
                 bool bIsEncrypted = false;
+                uno::Sequence< uno::Sequence< beans::NamedValue > > aGpgProperties;
                 try {
                     xStorageProps->getPropertyValue("HasEncryptedEntries")
                         >>= bIsEncrypted;
+                    xStorageProps->getPropertyValue("EncryptionGpGProperties")
+                        >>= aGpgProperties;
                 } catch( uno::Exception& )
                 {
                     // TODO/LATER:
@@ -241,9 +233,15 @@ sal_uInt32 CheckPasswd_Impl
                             if ( pEncryptionDataItem )
                                 pEncryptionDataItem->GetValue() >>= aEncryptionData;
 
+                            // try if one of the public key entries is
+                            // decryptable, then extract session key
+                            // from it
+                            if ( !aEncryptionData.hasElements() && aGpgProperties.hasElements() )
+                                aEncryptionData = ::comphelper::DocPasswordHelper::decryptGpgSession(aGpgProperties);
+
                             SfxDocPasswordVerifier aVerifier( xStorage );
                             aEncryptionData = ::comphelper::DocPasswordHelper::requestAndVerifyDocPassword(
-                                aVerifier, aEncryptionData, aPassword, xInteractionHandler, pFile->GetOrigURL(), comphelper::DocPasswordRequestType_STANDARD );
+                                aVerifier, aEncryptionData, aPassword, xInteractionHandler, pFile->GetOrigURL(), comphelper::DocPasswordRequestType::Standard );
 
                             pSet->ClearItem( SID_PASSWORD );
                             pSet->ClearItem( SID_ENCRYPTIONDATA );
@@ -282,11 +280,9 @@ sal_uInt32 CheckPasswd_Impl
 }
 
 
-
-
-sal_uIntPtr SfxApplication::LoadTemplate( SfxObjectShellLock& xDoc, const OUString &rFileName, bool bCopy, SfxItemSet* pSet )
+ErrCode SfxApplication::LoadTemplate( SfxObjectShellLock& xDoc, const OUString &rFileName, SfxItemSet* pSet )
 {
-    const SfxFilter* pFilter = nullptr;
+    std::shared_ptr<const SfxFilter> pFilter;
     SfxMedium aMedium( rFileName,  ( StreamMode::READ | StreamMode::SHARE_DENYNONE ) );
 
     if ( !aMedium.GetStorage( false ).is() )
@@ -299,8 +295,8 @@ sal_uIntPtr SfxApplication::LoadTemplate( SfxObjectShellLock& xDoc, const OUStri
     }
 
     aMedium.UseInteractionHandler( true );
-    sal_uIntPtr nErr = GetFilterMatcher().GuessFilter( aMedium,&pFilter,SfxFilterFlags::TEMPLATE, SfxFilterFlags::NONE );
-    if ( 0 != nErr)
+    ErrCode nErr = GetFilterMatcher().GuessFilter( aMedium, pFilter, SfxFilterFlags::TEMPLATE, SfxFilterFlags::NONE );
+    if ( ERRCODE_NONE != nErr)
     {
         delete pSet;
         return ERRCODE_SFX_NOTATEMPLATE;
@@ -320,7 +316,9 @@ sal_uIntPtr SfxApplication::LoadTemplate( SfxObjectShellLock& xDoc, const OUStri
         SfxStringItem aReferer( SID_REFERER, OUString("private:user") );
         SfxStringItem aFlags( SID_OPTIONS, OUString("T") );
         SfxBoolItem aHidden( SID_HIDDEN, true );
-        const SfxPoolItem *pRet = GetDispatcher_Impl()->Execute( SID_OPENDOC, SfxCallMode::SYNCHRON, &aName, &aHidden, &aReferer, &aFlags, 0L );
+        const SfxPoolItem *pRet = GetDispatcher_Impl()->ExecuteList(
+            SID_OPENDOC, SfxCallMode::SYNCHRON,
+            { &aName, &aHidden, &aReferer, &aFlags } );
         const SfxObjectItem *pObj = dynamic_cast<const SfxObjectItem*>( pRet  );
         if ( pObj )
             xDoc = dynamic_cast<SfxObjectShell*>( pObj->GetShell()  );
@@ -344,7 +342,7 @@ sal_uIntPtr SfxApplication::LoadTemplate( SfxObjectShellLock& xDoc, const OUStri
             xDoc = SfxObjectShell::CreateObject( pFilter->GetServiceName() );
 
         //pMedium takes ownership of pSet
-        SfxMedium *pMedium = new SfxMedium( rFileName, STREAM_STD_READ, pFilter, pSet );
+        SfxMedium *pMedium = new SfxMedium( rFileName, StreamMode::STD_READ, pFilter, pSet );
         if(!xDoc->DoLoad(pMedium))
         {
             ErrCode nErrCode = xDoc->GetErrorCode();
@@ -354,34 +352,29 @@ sal_uIntPtr SfxApplication::LoadTemplate( SfxObjectShellLock& xDoc, const OUStri
         }
     }
 
-    if( bCopy )
+    try
     {
-        try
-        {
-            // TODO: introduce error handling
+        // TODO: introduce error handling
 
-            uno::Reference< embed::XStorage > xTempStorage = ::comphelper::OStorageHelper::GetTemporaryStorage();
-            if( !xTempStorage.is() )
-                throw uno::RuntimeException();
+        uno::Reference< embed::XStorage > xTempStorage = ::comphelper::OStorageHelper::GetTemporaryStorage();
+        if( !xTempStorage.is() )
+            throw uno::RuntimeException();
 
-               xDoc->GetStorage()->copyToStorage( xTempStorage );
+        xDoc->GetStorage()->copyToStorage( xTempStorage );
 
-            if ( !xDoc->DoSaveCompleted( new SfxMedium( xTempStorage, OUString() ) ) )
-                throw uno::RuntimeException();
-        }
-        catch( uno::Exception& )
-        {
-            xDoc->DoClose();
-            xDoc.Clear();
-
-            // TODO: transfer correct error outside
-            return ERRCODE_SFX_GENERAL;
-        }
-
-        SetTemplate_Impl( rFileName, OUString(), xDoc );
+        if ( !xDoc->DoSaveCompleted( new SfxMedium( xTempStorage, OUString() ) ) )
+            throw uno::RuntimeException();
     }
-    else
-        SetTemplate_Impl( rFileName, OUString(), xDoc );
+    catch( uno::Exception& )
+    {
+        xDoc->DoClose();
+        xDoc.Clear();
+
+        // TODO: transfer correct error outside
+        return ERRCODE_SFX_GENERAL;
+    }
+
+    SetTemplate_Impl( rFileName, OUString(), xDoc );
 
     xDoc->SetNoName();
     xDoc->InvalidateName();
@@ -399,7 +392,7 @@ sal_uIntPtr SfxApplication::LoadTemplate( SfxObjectShellLock& xDoc, const OUStri
         sal_Int32 nLength = aArgs.getLength();
         aArgs.realloc( nLength + 1 );
         aArgs[nLength].Name = "Title";
-        aArgs[nLength].Value <<= OUString( xDoc->GetTitle( SFX_TITLE_DETECT ) );
+        aArgs[nLength].Value <<= xDoc->GetTitle( SFX_TITLE_DETECT );
         xModel->attachResource( OUString(), aArgs );
         delete pNew;
     }
@@ -408,7 +401,6 @@ sal_uIntPtr SfxApplication::LoadTemplate( SfxObjectShellLock& xDoc, const OUStri
 }
 
 
-
 void SfxApplication::NewDocDirectExec_Impl( SfxRequest& rReq )
 {
     const SfxStringItem* pFactoryItem = rReq.GetArg<SfxStringItem>(SID_NEWDOCDIRECT);
@@ -441,7 +433,6 @@ void SfxApplication::NewDocDirectExec_Impl( SfxRequest& rReq )
 }
 
 
-
 void SfxApplication::NewDocExec_Impl( SfxRequest& rReq )
 {
     // No Parameter from BASIC only Factory given?
@@ -459,7 +450,16 @@ void SfxApplication::NewDocExec_Impl( SfxRequest& rReq )
         bool bNewWin = false;
         vcl::Window* pTopWin = GetTopWindow();
 
+        SfxObjectShell* pCurrentShell = SfxObjectShell::Current();
+        Reference<XModel> xModel;
+        if(pCurrentShell)
+            xModel = pCurrentShell->GetModel();
+
         ScopedVclPtrInstance< SfxTemplateManagerDlg > aTemplDlg;
+
+        if (xModel.is())
+            aTemplDlg->setDocumentModel(xModel);
+
         int nRet = aTemplDlg->Execute();
         if ( nRet == RET_OK )
         {
@@ -497,7 +497,7 @@ void SfxApplication::NewDocExec_Impl( SfxRequest& rReq )
         }
     }
 
-    sal_uIntPtr lErr = 0;
+    ErrCode lErr = ERRCODE_NONE;
     SfxItemSet* pSet = new SfxAllItemSet( GetPool() );
     pSet->Put( SfxBoolItem( SID_TEMPLATE, true ) );
     if ( !bDirect )
@@ -515,7 +515,7 @@ void SfxApplication::NewDocExec_Impl( SfxRequest& rReq )
 
     if ( lErr != ERRCODE_NONE )
     {
-        sal_uIntPtr lFatalErr = ERRCODE_TOERROR(lErr);
+        ErrCode lFatalErr = lErr.IgnoreWarning();
         if ( lFatalErr )
             ErrorHandler::HandleError(lErr);
     }
@@ -530,15 +530,17 @@ void SfxApplication::NewDocExec_Impl( SfxRequest& rReq )
         {
             DBG_ASSERT( aObj.GetProtocol() != INetProtocol::NotValid, "Illegal URL!" );
 
-            SfxStringItem aName( SID_FILE_NAME, aObj.GetMainURL( INetURLObject::NO_DECODE ) );
+            SfxStringItem aName( SID_FILE_NAME, aObj.GetMainURL( INetURLObject::DecodeMechanism::NONE ) );
             SfxStringItem aTemplName( SID_TEMPLATE_NAME, aTemplateName );
             SfxStringItem aTemplRegionName( SID_TEMPLATE_REGIONNAME, aTemplateRegion );
-            pRet = GetDispatcher_Impl()->Execute( SID_OPENDOC, eMode, &aName, &aTarget, &aReferer, &aTemplName, &aTemplRegionName, 0L );
+            pRet = GetDispatcher_Impl()->ExecuteList(SID_OPENDOC, eMode,
+                {&aName, &aTarget, &aReferer, &aTemplName, &aTemplRegionName});
         }
         else
         {
             SfxStringItem aName( SID_FILE_NAME, "private:factory" );
-            pRet = GetDispatcher_Impl()->Execute( SID_OPENDOC, eMode, &aName, &aTarget, &aReferer, 0L );
+            pRet = GetDispatcher_Impl()->ExecuteList(SID_OPENDOC, eMode,
+                    { &aName, &aTarget, &aReferer } );
         }
 
         if ( pRet )
@@ -547,7 +549,6 @@ void SfxApplication::NewDocExec_Impl( SfxRequest& rReq )
 }
 
 
-
 namespace {
 
 /**
@@ -561,7 +562,7 @@ bool lcl_isFilterNativelySupported(const SfxFilter& rFilter)
     if (rFilter.IsOwnFormat())
         return true;
 
-    OUString aName = rFilter.GetFilterName();
+    const OUString& aName = rFilter.GetFilterName();
     if (aName.startsWith("MS Excel"))
         // We can handle all Excel variants natively.
         return true;
@@ -602,7 +603,7 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
     if ( !pFileNameItem )
     {
         // get FileName from dialog
-        std::vector<OUString> pURLList;
+        std::vector<OUString> aURLList;
         OUString aFilter;
         SfxItemSet* pSet = nullptr;
         OUString aPath;
@@ -625,6 +626,15 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
         if ( pRemoteDialogItem && pRemoteDialogItem->GetValue())
             nDialog = SFX2_IMPL_DIALOG_REMOTE;
 
+        sal_Int16 nDialogType = ui::dialogs::TemplateDescription::FILEOPEN_READONLY_VERSION;
+        FileDialogFlags eDialogFlags = FileDialogFlags::MultiSelection;
+        const SfxBoolItem* pSignPDFItem = rReq.GetArg<SfxBoolItem>(SID_SIGNPDF);
+        if (pSignPDFItem && pSignPDFItem->GetValue())
+        {
+            eDialogFlags |= FileDialogFlags::SignPDF;
+            nDialogType = ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE;
+        }
+
         OUString sStandardDir;
 
         const SfxStringItem* pStandardDirItem = rReq.GetArg<SfxStringItem>(SID_STANDARD_DIR);
@@ -638,14 +648,14 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
             pBlackListItem->GetStringList( aBlackList );
 
 
-        sal_uIntPtr nErr = sfx2::FileOpenDialog_Impl(
-                ui::dialogs::TemplateDescription::FILEOPEN_READONLY_VERSION,
-                SFXWB_MULTISELECTION, OUString(), pURLList,
-                aFilter, pSet, &aPath, nDialog, sStandardDir, aBlackList );
+        ErrCode nErr = sfx2::FileOpenDialog_Impl(GetTopWindow(),
+                nDialogType,
+                eDialogFlags, OUString(), aURLList,
+                aFilter, pSet, &aPath, nDialog, sStandardDir, aBlackList);
 
         if ( nErr == ERRCODE_ABORT )
         {
-            pURLList.clear();
+            aURLList.clear();
             return;
         }
 
@@ -656,7 +666,7 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
         rReq.AppendItem( SfxStringItem( SID_REFERER, "private:user" ) );
         delete pSet;
 
-        if(!pURLList.empty())
+        if(!aURLList.empty())
         {
             if ( nSID == SID_OPENTEMPLATE )
                 rReq.AppendItem( SfxBoolItem( SID_TEMPLATE, false ) );
@@ -665,7 +675,7 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
             // intercept all incoming interactions and provide useful information
             // later if the following transaction was finished.
 
-            ::framework::PreventDuplicateInteraction*                 pHandler       = new ::framework::PreventDuplicateInteraction(::comphelper::getProcessComponentContext());
+            ::sfx2::PreventDuplicateInteraction*                 pHandler       = new ::sfx2::PreventDuplicateInteraction(::comphelper::getProcessComponentContext());
             css::uno::Reference< css::task::XInteractionHandler >     xHandler       (static_cast< css::task::XInteractionHandler* >(pHandler), css::uno::UNO_QUERY);
             css::uno::Reference< css::task::XInteractionHandler >     xWrappedHandler;
 
@@ -684,7 +694,7 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
 
             // define rules for this handler
             css::uno::Type                                            aInteraction = ::cppu::UnoType<css::task::ErrorCodeRequest>::get();
-            ::framework::PreventDuplicateInteraction::InteractionInfo aRule        (aInteraction, 1);
+            ::sfx2::PreventDuplicateInteraction::InteractionInfo aRule        (aInteraction, 1);
             pHandler->addInteractionRule(aRule);
 
             if (!aDocService.isEmpty())
@@ -693,7 +703,7 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
                 rReq.AppendItem(SfxStringItem(SID_DOC_SERVICE, aDocService));
             }
 
-            for(std::vector<OUString>::const_iterator i = pURLList.begin(); i != pURLList.end(); ++i)
+            for(std::vector<OUString>::const_iterator i = aURLList.begin(); i != aURLList.end(); ++i)
             {
                 rReq.RemoveItem( SID_FILE_NAME );
                 rReq.AppendItem( SfxStringItem( SID_FILE_NAME, *i ) );
@@ -715,9 +725,7 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
                             css::task::ErrorCodeRequest aRequest;
                             if (aRule.m_xRequest->getRequest() >>= aRequest)
                             {
-                                if (aRequest.ErrCode ==
-                                    sal::static_int_cast< sal_Int32 >(
-                                        ERRCODE_SFX_NOMOREDOCUMENTSALLOWED))
+                                if (aRequest.ErrCode == sal_Int32(sal_uInt32(ERRCODE_SFX_NOMOREDOCUMENTSALLOWED)))
                                     break;
                             }
                         }
@@ -725,10 +733,10 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
                 }
             }
 
-            pURLList.clear();
+            aURLList.clear();
             return;
         }
-        pURLList.clear();
+        aURLList.clear();
     }
 
     bool bHyperlinkUsed = false;
@@ -831,15 +839,15 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
 
                 ScopedVclPtrInstance<MessageDialog> aSecurityWarningBox(pWindow,
                                                   SfxResId(STR_SECURITY_WARNING_NO_HYPERLINKS),
-                                                  VCL_MESSAGE_WARNING);
-                aSecurityWarningBox->SetText( SfxResId(RID_SECURITY_WARNING_TITLE).toString() );
+                                                  VclMessageType::Warning);
+                aSecurityWarningBox->SetText( SfxResId(RID_SECURITY_WARNING_TITLE) );
                 aSecurityWarningBox->Execute();
                 return;
             }
 
             aTypeName = xTypeDetection->queryTypeByURL( aURL.Main );
             SfxFilterMatcher& rMatcher = SfxGetpApp()->GetFilterMatcher();
-            const SfxFilter* pFilter = rMatcher.GetFilter4EA( aTypeName );
+            std::shared_ptr<const SfxFilter> pFilter = rMatcher.GetFilter4EA( aTypeName );
             if (!pFilter || !lcl_isFilterNativelySupported(*pFilter))
             {
                 // hyperlink does not link to own type => special handling (http, ftp) browser and (other external protocols) OS
@@ -885,9 +893,9 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
                     }
 
                     bool bFound = false;
-                    for ( size_t nProt=0; nProt<aProtocols.size(); nProt++ )
+                    for (const OUString & rProtocol : aProtocols)
                     {
-                        WildCard aPattern(aProtocols[nProt]);
+                        WildCard aPattern(rProtocol);
                         if ( aPattern.Matches( aURL.Complete ) )
                         {
                             bFound = true;
@@ -1002,88 +1010,88 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
     }
 
     Reference < XController > xController;
-        // if a frame is given, it must be used for the starting point of the targeting mechanism
-        // this code is also used if asynchronous loading is possible, because loadComponent always is synchron
-        if ( !xTargetFrame.is() )
+    // if a frame is given, it must be used for the starting point of the targeting mechanism
+    // this code is also used if asynchronous loading is possible, because loadComponent always is synchron
+    if ( !xTargetFrame.is() )
+    {
+        if ( pTargetFrame )
         {
-            if ( pTargetFrame )
-            {
-                xTargetFrame = pTargetFrame->GetFrameInterface();
-            }
-            else
-            {
-                xTargetFrame.set( Desktop::create(::comphelper::getProcessComponentContext()), UNO_QUERY );
-            }
-        }
-
-        // make URL ready
-        const SfxStringItem* pURLItem = rReq.GetArg<SfxStringItem>(SID_FILE_NAME);
-        aFileName = pURLItem->GetValue();
-        if( aFileName.startsWith("#") ) // Mark without URL
-        {
-            SfxViewFrame *pView = pTargetFrame ? pTargetFrame->GetCurrentViewFrame() : nullptr;
-            if ( !pView )
-                pView = SfxViewFrame::Current();
-            pView->GetViewShell()->JumpToMark( aFileName.copy(1) );
-            rReq.SetReturnValue( SfxViewFrameItem( 0, pView ) );
-            return;
-        }
-
-        // convert items to properties for framework API calls
-        Sequence < PropertyValue > aArgs;
-        TransformItems( SID_OPENDOC, *rReq.GetArgs(), aArgs );
-        // Any Referer (that was relevant in the above call to
-        // SvtSecurityOptions::isSecureMacroUri) is no longer relevant, assuming
-        // this "open" request is initiated directly by the user:
-        for (sal_Int32 i = 0; i != aArgs.getLength(); ++i) {
-            if (aArgs[i].Name == "Referer") {
-                ++i;
-                for (; i != aArgs.getLength(); ++i) {
-                    aArgs[i - 1] = aArgs[i];
-                }
-                aArgs.realloc(aArgs.getLength()-1);
-                break;
-            }
-        }
-
-        // TODO/LATER: either remove LinkItem or create an asynchronous process for it
-        if( bHidden || pLinkItem || rReq.IsSynchronCall() )
-        {
-            // if loading must be done synchron, we must wait for completion to get a return value
-            // find frame by myself; I must know the exact frame to get the controller for the return value from it
-            Reference < XComponent > xComp;
-
-            try
-            {
-                xComp = ::comphelper::SynchronousDispatch::dispatch( xTargetFrame, aFileName, aTarget, 0, aArgs );
-            }
-            catch(const RuntimeException&)
-            {
-                throw;
-            }
-            catch(const css::uno::Exception&)
-            {
-            }
-
-            Reference < XModel > xModel( xComp, UNO_QUERY );
-            if ( xModel.is() )
-                xController = xModel->getCurrentController();
-            else
-                xController.set( xComp, UNO_QUERY );
-
+            xTargetFrame = pTargetFrame->GetFrameInterface();
         }
         else
         {
-            URL aURL;
-            aURL.Complete = aFileName;
-            Reference< util::XURLTransformer > xTrans( util::URLTransformer::create( ::comphelper::getProcessComponentContext() ) );
-            xTrans->parseStrict( aURL );
-
-            Reference < XDispatchProvider > xProv( xTargetFrame, UNO_QUERY );
-            Reference < XDispatch > xDisp = xProv.is() ? xProv->queryDispatch( aURL, aTarget, FrameSearchFlag::ALL ) : Reference < XDispatch >();;
-            if ( xDisp.is() )
-                xDisp->dispatch( aURL, aArgs );
+            xTargetFrame.set( Desktop::create(::comphelper::getProcessComponentContext()), UNO_QUERY );
         }
+    }
+
+    // make URL ready
+    const SfxStringItem* pURLItem = rReq.GetArg<SfxStringItem>(SID_FILE_NAME);
+    aFileName = pURLItem->GetValue();
+    if( aFileName.startsWith("#") ) // Mark without URL
+    {
+        SfxViewFrame *pView = pTargetFrame ? pTargetFrame->GetCurrentViewFrame() : nullptr;
+        if ( !pView )
+            pView = SfxViewFrame::Current();
+        pView->GetViewShell()->JumpToMark( aFileName.copy(1) );
+        rReq.SetReturnValue( SfxViewFrameItem( pView ) );
+        return;
+    }
+
+    // convert items to properties for framework API calls
+    Sequence < PropertyValue > aArgs;
+    TransformItems( SID_OPENDOC, *rReq.GetArgs(), aArgs );
+    // Any Referer (that was relevant in the above call to
+    // SvtSecurityOptions::isSecureMacroUri) is no longer relevant, assuming
+    // this "open" request is initiated directly by the user:
+    for (sal_Int32 i = 0; i != aArgs.getLength(); ++i) {
+        if (aArgs[i].Name == "Referer") {
+            ++i;
+            for (; i != aArgs.getLength(); ++i) {
+                aArgs[i - 1] = aArgs[i];
+            }
+            aArgs.realloc(aArgs.getLength()-1);
+            break;
+        }
+    }
+
+    // TODO/LATER: either remove LinkItem or create an asynchronous process for it
+    if( bHidden || pLinkItem || rReq.IsSynchronCall() )
+    {
+        // if loading must be done synchron, we must wait for completion to get a return value
+        // find frame by myself; I must know the exact frame to get the controller for the return value from it
+        Reference < XComponent > xComp;
+
+        try
+        {
+            xComp = ::comphelper::SynchronousDispatch::dispatch( xTargetFrame, aFileName, aTarget, 0, aArgs );
+        }
+        catch(const RuntimeException&)
+        {
+            throw;
+        }
+        catch(const css::uno::Exception&)
+        {
+        }
+
+        Reference < XModel > xModel( xComp, UNO_QUERY );
+        if ( xModel.is() )
+            xController = xModel->getCurrentController();
+        else
+            xController.set( xComp, UNO_QUERY );
+
+    }
+    else
+    {
+        URL aURL;
+        aURL.Complete = aFileName;
+        Reference< util::XURLTransformer > xTrans( util::URLTransformer::create( ::comphelper::getProcessComponentContext() ) );
+        xTrans->parseStrict( aURL );
+
+        Reference < XDispatchProvider > xProv( xTargetFrame, UNO_QUERY );
+        Reference < XDispatch > xDisp = xProv.is() ? xProv->queryDispatch( aURL, aTarget, FrameSearchFlag::ALL ) : Reference < XDispatch >();
+        if ( xDisp.is() )
+            xDisp->dispatch( aURL, aArgs );
+    }
 
     if ( xController.is() )
     {
@@ -1103,7 +1111,7 @@ void SfxApplication::OpenDocExec_Impl( SfxRequest& rReq )
             SfxObjectShell* pSh = pCntrFrame->GetCurrentDocument();
             DBG_ASSERT( pSh, "Controller without ObjectShell ?!" );
 
-            rReq.SetReturnValue( SfxViewFrameItem( 0, pCntrFrame->GetCurrentViewFrame() ) );
+            rReq.SetReturnValue( SfxViewFrameItem( pCntrFrame->GetCurrentViewFrame() ) );
 
             if ( bHidden )
                 pSh->RestoreNoDelete();
@@ -1128,4 +1136,10 @@ void SfxApplication::OpenRemoteExec_Impl( SfxRequest& rReq )
     GetDispatcher_Impl()->Execute( SID_OPENDOC, SfxCallMode::SYNCHRON, *rReq.GetArgs() );
 }
 
+void SfxApplication::SignPDFExec_Impl(SfxRequest& rReq)
+{
+    rReq.AppendItem(SfxBoolItem(SID_SIGNPDF, true));
+    GetDispatcher_Impl()->Execute(SID_OPENDOC, SfxCallMode::SYNCHRON, *rReq.GetArgs());
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
