@@ -48,7 +48,6 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::util;
 
 SfxMacroLoader::SfxMacroLoader(const css::uno::Sequence< css::uno::Any >& aArguments)
-    throw (css::uno::Exception, css::uno::RuntimeException)
 {
     Reference < XFrame > xFrame;
     if ( aArguments.getLength() )
@@ -59,19 +58,16 @@ SfxMacroLoader::SfxMacroLoader(const css::uno::Sequence< css::uno::Any >& aArgum
 }
 
 OUString SAL_CALL SfxMacroLoader::getImplementationName()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return OUString("com.sun.star.comp.sfx2.SfxMacroLoader");
 }
 
 sal_Bool SAL_CALL SfxMacroLoader::supportsService(OUString const & ServiceName)
-    throw (css::uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 css::uno::Sequence<OUString> SAL_CALL SfxMacroLoader::getSupportedServiceNames()
-    throw (css::uno::RuntimeException, std::exception)
 {
     css::uno::Sequence< OUString > aSeq { "com.sun.star.frame.ProtocolHandler" };
     return aSeq;
@@ -101,7 +97,7 @@ SfxObjectShell* SfxMacroLoader::GetObjectShell_Impl()
 uno::Reference<frame::XDispatch> SAL_CALL SfxMacroLoader::queryDispatch(
     const util::URL&   aURL            ,
     const OUString&               /*sTargetFrameName*/,
-    sal_Int32                            /*nSearchFlags*/    ) throw( uno::RuntimeException, std::exception )
+    sal_Int32                            /*nSearchFlags*/    )
 {
     uno::Reference<frame::XDispatch> xDispatcher;
     if(aURL.Complete.startsWith("macro:"))
@@ -112,12 +108,11 @@ uno::Reference<frame::XDispatch> SAL_CALL SfxMacroLoader::queryDispatch(
 
 uno::Sequence< uno::Reference<frame::XDispatch> > SAL_CALL
                 SfxMacroLoader::queryDispatches( const uno::Sequence < frame::DispatchDescriptor >& seqDescriptor )
-                    throw( uno::RuntimeException, std::exception )
 {
     sal_Int32 nCount = seqDescriptor.getLength();
     uno::Sequence< uno::Reference<frame::XDispatch> > lDispatcher(nCount);
     for( sal_Int32 i=0; i<nCount; ++i )
-        lDispatcher[i] = this->queryDispatch( seqDescriptor[i].FeatureURL,
+        lDispatcher[i] = queryDispatch( seqDescriptor[i].FeatureURL,
                                               seqDescriptor[i].FrameName,
                                               seqDescriptor[i].SearchFlags );
     return lDispatcher;
@@ -127,7 +122,6 @@ uno::Sequence< uno::Reference<frame::XDispatch> > SAL_CALL
 void SAL_CALL SfxMacroLoader::dispatchWithNotification(
     const util::URL& aURL, const uno::Sequence<beans::PropertyValue>& /*lArgs*/,
     const uno::Reference<frame::XDispatchResultListener>& xListener )
-              throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -151,16 +145,30 @@ void SAL_CALL SfxMacroLoader::dispatchWithNotification(
 
 uno::Any SAL_CALL SfxMacroLoader::dispatchWithReturnValue(
     const util::URL& aURL, const uno::Sequence<beans::PropertyValue>& )
-        throw (uno::RuntimeException, std::exception)
 {
     uno::Any aRet;
-    loadMacro( aURL.Complete, aRet, GetObjectShell_Impl() );
+    ErrCode nErr = loadMacro( aURL.Complete, aRet, GetObjectShell_Impl() );
+
+    // aRet gets set to a different value only if nErr == ERRCODE_NONE
+    // Return it in such case to preserve the original behaviour
+
+    // In all other cases (nErr != ERRCODE_NONE), the calling code gets
+    // the actual error code back
+    if ( nErr != ERRCODE_NONE )
+    {
+        beans::PropertyValue aErrorCode;
+
+        aErrorCode.Name = "ErrorCode";
+        aErrorCode.Value <<= sal_uInt32(nErr);
+
+        aRet <<= aErrorCode;
+    }
+
     return aRet;
 }
 
 void SAL_CALL SfxMacroLoader::dispatch(
     const util::URL& aURL, const uno::Sequence<beans::PropertyValue>& /*lArgs*/ )
-        throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -171,7 +179,6 @@ void SAL_CALL SfxMacroLoader::dispatch(
 void SAL_CALL SfxMacroLoader::addStatusListener(
     const uno::Reference< frame::XStatusListener >& ,
     const util::URL&                                                    )
-              throw (uno::RuntimeException, std::exception)
 {
     /* TODO
             How we can handle different listener for further coming or currently running dispatch() jobs
@@ -183,12 +190,10 @@ void SAL_CALL SfxMacroLoader::addStatusListener(
 void SAL_CALL SfxMacroLoader::removeStatusListener(
     const uno::Reference< frame::XStatusListener >&,
     const util::URL&                                                  )
-        throw (uno::RuntimeException, std::exception)
 {
 }
 
 ErrCode SfxMacroLoader::loadMacro( const OUString& rURL, css::uno::Any& rRetval, SfxObjectShell* pSh )
-    throw ( ucb::ContentCreationException, uno::RuntimeException, std::exception )
 {
 #if !HAVE_FEATURE_SCRIPTING
     (void) rURL;
@@ -204,7 +209,7 @@ ErrCode SfxMacroLoader::loadMacro( const OUString& rURL, css::uno::Any& rRetval,
     // 'macro:///lib.mod.proc(args)' => macro of App-BASIC
     // 'macro://[docname|.]/lib.mod.proc(args)' => macro of current or qualified document
     // 'macro://obj.method(args)' => direct API call, execute it via App-BASIC
-    OUString aMacro( rURL );
+    const OUString& aMacro( rURL );
     sal_Int32 nHashPos = aMacro.indexOf( '/', 8 );
     sal_Int32 nArgsPos = aMacro.indexOf( '(' );
     BasicManager *pAppMgr = SfxApplication::GetBasicManager();
@@ -216,7 +221,7 @@ ErrCode SfxMacroLoader::loadMacro( const OUString& rURL, css::uno::Any& rRetval,
     {
         // find BasicManager
         SfxObjectShell* pDoc = nullptr;
-        OUString aBasMgrName( INetURLObject::decode(aMacro.copy( 8, nHashPos-8 ), INetURLObject::DECODE_WITH_CHARSET) );
+        OUString aBasMgrName( INetURLObject::decode(aMacro.copy( 8, nHashPos-8 ), INetURLObject::DecodeMechanism::WithCharset) );
         if ( aBasMgrName.isEmpty() )
             pBasMgr = pAppMgr;
         else if ( aBasMgrName == "." )
@@ -247,13 +252,13 @@ ErrCode SfxMacroLoader::loadMacro( const OUString& rURL, css::uno::Any& rRetval,
             if ( pDoc )
             {
                 // security check for macros from document basic if an SFX doc is given
-                if ( !pDoc->AdjustMacroMode( OUString() ) )
+                if ( !pDoc->AdjustMacroMode() )
                     // check forbids execution
                     return ERRCODE_IO_ACCESSDENIED;
             }
 
             // find BASIC method
-            OUString aQualifiedMethod( INetURLObject::decode(aMacro.copy( nHashPos+1 ), INetURLObject::DECODE_WITH_CHARSET) );
+            OUString aQualifiedMethod( INetURLObject::decode(aMacro.copy( nHashPos+1 ), INetURLObject::DecodeMechanism::WithCharset) );
             OUString aArgs;
             if ( -1 != nArgsPos )
             {
@@ -290,9 +295,9 @@ ErrCode SfxMacroLoader::loadMacro( const OUString& rURL, css::uno::Any& rRetval,
 
                     // execute the method
                     SbxVariableRef retValRef = new SbxVariable;
-                    nErr = pBasMgr->ExecuteMacro( aQualifiedMethod, aArgs, retValRef );
+                    nErr = pBasMgr->ExecuteMacro( aQualifiedMethod, aArgs, retValRef.get() );
                     if ( nErr == ERRCODE_NONE )
-                        rRetval = sbxToUnoValue( retValRef );
+                        rRetval = sbxToUnoValue( retValRef.get() );
                 }
 
                 if ( bSetGlobalThisComponent )
@@ -317,7 +322,7 @@ ErrCode SfxMacroLoader::loadMacro( const OUString& rURL, css::uno::Any& rRetval,
         // direct API call on a specified object
         OUStringBuffer aCall;
         aCall.append('[').append(INetURLObject::decode(aMacro.copy(6),
-            INetURLObject::DECODE_WITH_CHARSET));
+            INetURLObject::DecodeMechanism::WithCharset));
         aCall.append(']');
         pAppMgr->GetLib(0)->Execute(aCall.makeStringAndClear());
         nErr = SbxBase::GetError();
