@@ -23,23 +23,23 @@
 
 #include <boost/logic/tribool.hpp>
 #include <config_folders.h>
-#include <shutdownicon.hxx>
-#include <app.hrc>
+#include "shutdownicon.hxx"
+#include <sfx2/strings.hrc>
 #include <sfx2/app.hxx>
 #include <osl/mutex.hxx>
 #include <svtools/imagemgr.hxx>
 #include <svtools/miscopt.hxx>
 #include <com/sun/star/task/InteractionHandler.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
+#include <com/sun/star/frame/TerminationVetoException.hpp>
 #include <com/sun/star/frame/XDispatchResultListener.hpp>
 #include <com/sun/star/frame/XNotifyingDispatch.hpp>
 #include <com/sun/star/frame/XFramesSupplier.hpp>
-#include <com/sun/star/frame/XComponentLoader.hpp>
 #include <com/sun/star/frame/XFrame.hpp>
 #include <com/sun/star/util/URLTransformer.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/ui/dialogs/XFilePickerControlAccess.hpp>
-#include <com/sun/star/ui/dialogs/XFilePicker2.hpp>
+#include <com/sun/star/ui/dialogs/XFilePicker3.hpp>
 #include <com/sun/star/ui/dialogs/XFilterManager.hpp>
 #include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
 #include <com/sun/star/ui/dialogs/ExtendedFilePickerElementIds.hpp>
@@ -55,7 +55,6 @@
 #include <sfx2/dispatch.hxx>
 #include <comphelper/extract.hxx>
 #include <tools/urlobj.hxx>
-#include <tools/rcid.h>
 #include <osl/security.hxx>
 #include <osl/file.hxx>
 #include <rtl/bootstrap.hxx>
@@ -80,7 +79,7 @@ using namespace ::com::sun::star::ui::dialogs;
 using namespace ::sfx2;
 
 #ifdef ENABLE_QUICKSTART_APPLET
-# if !defined(WIN32) && !defined(MACOSX)
+# if !defined(_WIN32) && !defined(MACOSX)
 extern "C" { static void SAL_CALL thisModule() {} }
 # endif
 #endif
@@ -88,33 +87,30 @@ extern "C" { static void SAL_CALL thisModule() {} }
 class SfxNotificationListener_Impl : public cppu::WeakImplHelper< XDispatchResultListener >
 {
 public:
-    virtual void SAL_CALL dispatchFinished( const DispatchResultEvent& aEvent ) throw( RuntimeException, std::exception ) override;
-    virtual void SAL_CALL disposing( const EventObject& aEvent ) throw( RuntimeException, std::exception ) override;
+    virtual void SAL_CALL dispatchFinished( const DispatchResultEvent& aEvent ) override;
+    virtual void SAL_CALL disposing( const EventObject& aEvent ) override;
 };
 
-void SAL_CALL SfxNotificationListener_Impl::dispatchFinished( const DispatchResultEvent& ) throw( RuntimeException, std::exception )
+void SAL_CALL SfxNotificationListener_Impl::dispatchFinished( const DispatchResultEvent& )
 {
     ShutdownIcon::LeaveModalMode();
 }
 
-void SAL_CALL SfxNotificationListener_Impl::disposing( const EventObject& ) throw( RuntimeException, std::exception )
+void SAL_CALL SfxNotificationListener_Impl::disposing( const EventObject& )
 {
 }
 
 OUString SAL_CALL ShutdownIcon::getImplementationName()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return OUString("com.sun.star.comp.desktop.QuickstartWrapper");
 }
 
 sal_Bool SAL_CALL ShutdownIcon::supportsService(OUString const & ServiceName)
-    throw (css::uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 css::uno::Sequence<OUString> SAL_CALL ShutdownIcon::getSupportedServiceNames()
-    throw (css::uno::RuntimeException, std::exception)
 {
     css::uno::Sequence< OUString > aSeq { "com.sun.star.office.Quickstart" };
     return aSeq;
@@ -139,7 +135,7 @@ bool LoadModule()
     if (boost::logic::indeterminate(loaded))
     {
 #ifdef ENABLE_QUICKSTART_APPLET
-#  ifdef WIN32
+#  ifdef _WIN32
         pInitSystray = win32_init_sys_tray;
         pDeInitSystray = win32_shutdown_sys_tray;
         loaded = true;
@@ -210,7 +206,6 @@ ShutdownIcon::ShutdownIcon( const css::uno::Reference< XComponentContext > & rxC
     m_bVeto ( false ),
     m_bListenForTermination ( false ),
     m_bSystemDialogs( false ),
-    m_pResMgr( nullptr ),
     m_pFileDlg( nullptr ),
     m_xContext( rxContext ),
     m_bInitialized( false )
@@ -297,7 +292,7 @@ void ShutdownIcon::FromTemplate()
             if (xNotifier.is())
             {
                 EnterModalMode();
-                xNotifier->dispatchWithNotification(aTargetURL, aArgs, new SfxNotificationListener_Impl());
+                xNotifier->dispatchWithNotification(aTargetURL, aArgs, new SfxNotificationListener_Impl);
             }
             else
                 xDisp->dispatch( aTargetURL, aArgs );
@@ -305,35 +300,23 @@ void ShutdownIcon::FromTemplate()
     }
 }
 
-
-OUString ShutdownIcon::GetResString( int id )
+OUString ShutdownIcon::GetResString(const char* id)
 {
-    ::SolarMutexGuard aGuard;
-
-    if( ! m_pResMgr )
-        m_pResMgr = SfxResId::GetResMgr();
-    ResId aResId( id, *m_pResMgr );
-    aResId.SetRT( RSC_STRING );
-    if (!m_pResMgr->IsAvailable(aResId))
-        return OUString();
-
-    return ResId(id, *m_pResMgr).toString();
+    return SfxResId(id);
 }
 
-
 OUString ShutdownIcon::GetUrlDescription( const OUString& aUrl )
 {
     ::SolarMutexGuard aGuard;
 
-    return OUString( SvFileInformationManager::GetDescription( INetURLObject( aUrl ) ) );
+    return SvFileInformationManager::GetDescription( INetURLObject( aUrl ) );
 }
 
-
 void ShutdownIcon::StartFileDialog()
 {
     ::SolarMutexGuard aGuard;
 
-    bool bDirty = ( m_bSystemDialogs != static_cast<bool>(SvtMiscOptions().UseSystemFileDialog()) );
+    bool bDirty = ( m_bSystemDialogs != SvtMiscOptions().UseSystemFileDialog() );
 
     if ( m_pFileDlg && bDirty )
     {
@@ -346,11 +329,10 @@ void ShutdownIcon::StartFileDialog()
     if ( !m_pFileDlg )
         m_pFileDlg = new FileDialogHelper(
                 ui::dialogs::TemplateDescription::FILEOPEN_READONLY_VERSION,
-                FileDialogFlags::MultiSelection, OUString() );
+                FileDialogFlags::MultiSelection, OUString(), SfxFilterFlags::NONE, SfxFilterFlags::NONE, nullptr );
     m_pFileDlg->StartExecuteModal( LINK( this, ShutdownIcon, DialogClosedHdl_Impl ) );
 }
 
-
 IMPL_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, /*unused*/, void )
 {
     DBG_ASSERT( m_pFileDlg, "ShutdownIcon, DialogClosedHdl_Impl(): no file dialog" );
@@ -358,7 +340,7 @@ IMPL_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, /*unused*/, vo
     // use constructor for filling up filters automatically!
     if ( ERRCODE_NONE == m_pFileDlg->GetError() )
     {
-        css::uno::Reference< XFilePicker2 >    xPicker = m_pFileDlg->GetFilePicker();
+        css::uno::Reference< XFilePicker3 >    xPicker = m_pFileDlg->GetFilePicker();
 
         try
         {
@@ -367,7 +349,6 @@ IMPL_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, /*unused*/, vo
             {
 
                 css::uno::Reference < XFilePickerControlAccess > xPickerControls ( xPicker, UNO_QUERY );
-                css::uno::Reference < XFilterManager > xFilterManager ( xPicker, UNO_QUERY );
 
                 Sequence< OUString >        sFiles = xPicker->getSelectedFiles();
                 int                         nFiles = sFiles.getLength();
@@ -381,13 +362,11 @@ IMPL_LINK( ShutdownIcon, DialogClosedHdl_Impl, FileDialogHelper*, /*unused*/, vo
                 aArgs[0].Name = "InteractionHandler";
                 aArgs[0].Value <<= xInteraction;
 
-                sal_Int16 nMacroExecMode = css::document::MacroExecMode::USE_CONFIG;
                 aArgs[1].Name = "MacroExecutionMode";
-                aArgs[1].Value <<= nMacroExecMode;
+                aArgs[1].Value <<= sal_Int16(css::document::MacroExecMode::USE_CONFIG);
 
-                sal_Int16 nUpdateDoc = css::document::UpdateDocMode::ACCORDING_TO_CONFIG;
                 aArgs[2].Name = "UpdateDocMode";
-                aArgs[2].Value <<= nUpdateDoc;
+                aArgs[2].Value <<= sal_Int16(css::document::UpdateDocMode::ACCORDING_TO_CONFIG);
 
                 // use the filedlghelper to get the current filter name,
                 // because it removes the extensions before you get the filter name.
@@ -559,14 +538,9 @@ ShutdownIcon* ShutdownIcon::createInstance()
     return pShutdownIcon;
 }
 
-void ShutdownIcon::init() throw( css::uno::Exception, std::exception )
+void ShutdownIcon::init()
 {
-    // access resource system and sfx only protected by solarmutex
-    ::SolarMutexGuard aSolarGuard;
-    ResMgr *pResMgr = SfxResId::GetResMgr();
-
     ::osl::ResettableMutexGuard aGuard( m_aMutex );
-    m_pResMgr = pResMgr;
     aGuard.clear();
     css::uno::Reference < XDesktop2 > xDesktop = Desktop::create( m_xContext );
     aGuard.reset();
@@ -585,14 +559,12 @@ void SAL_CALL ShutdownIcon::disposing()
 
 // XEventListener
 void SAL_CALL ShutdownIcon::disposing( const css::lang::EventObject& )
-    throw(css::uno::RuntimeException, std::exception)
 {
 }
 
 
 // XTerminateListener
 void SAL_CALL ShutdownIcon::queryTermination( const css::lang::EventObject& )
-throw(css::frame::TerminationVetoException, css::uno::RuntimeException, std::exception)
 {
     SAL_INFO("sfx.appl", "ShutdownIcon::queryTermination: veto is " << m_bVeto);
     ::osl::ClearableMutexGuard  aGuard( m_aMutex );
@@ -603,13 +575,11 @@ throw(css::frame::TerminationVetoException, css::uno::RuntimeException, std::exc
 
 
 void SAL_CALL ShutdownIcon::notifyTermination( const css::lang::EventObject& )
-throw(css::uno::RuntimeException, std::exception)
 {
 }
 
 
 void SAL_CALL ShutdownIcon::initialize( const css::uno::Sequence< css::uno::Any>& aArguments )
-    throw( css::uno::Exception, std::exception )
 {
     ::osl::ResettableMutexGuard aGuard( m_aMutex );
 
@@ -725,14 +695,8 @@ OUString ShutdownIcon::getShortcutName()
     return OUString();
 #else
 
-    OUString aShortcutName( "StarOffice 6.0"  );
-    ResMgr* pMgr = SfxResId::GetResMgr();
-    if( pMgr )
-    {
-        ::SolarMutexGuard aGuard;
-        aShortcutName = SFX2_RESSTR(STR_QUICKSTART_LNKNAME);
-    }
 #ifdef _WIN32
+    OUString aShortcutName(SfxResId(STR_QUICKSTART_LNKNAME));
     aShortcutName += ".lnk";
 
     OUString aShortcut(GetAutostartFolderNameW32());
@@ -793,8 +757,8 @@ void ShutdownIcon::SetAutostart( bool bActivate )
         if ((0 != symlink(aDesktopFileUnx.getStr(), aShortcutUnx.getStr())) && (errno == EEXIST))
         {
             unlink(aShortcutUnx.getStr());
-            int ret = symlink(aDesktopFileUnx.getStr(), aShortcutUnx.getStr());
-            (void)ret; //deliberately ignore return value, it's non-critical if it fails
+            (void) symlink(aDesktopFileUnx.getStr(), aShortcutUnx.getStr());
+                //deliberately ignore return value, it's non-critical if it fails
         }
 
         ShutdownIcon *pIcon = ShutdownIcon::createInstance();
@@ -825,11 +789,6 @@ static const ::sal_Int32 PROPHANDLE_TERMINATEVETOSTATE = 0;
 // XFastPropertySet
 void SAL_CALL ShutdownIcon::setFastPropertyValue(       ::sal_Int32                  nHandle,
                                                   const css::uno::Any& aValue )
-    throw (css::beans::UnknownPropertyException,
-            css::beans::PropertyVetoException,
-            css::lang::IllegalArgumentException,
-            css::lang::WrappedTargetException,
-            css::uno::RuntimeException, std::exception)
 {
     switch(nHandle)
     {
@@ -853,9 +812,6 @@ void SAL_CALL ShutdownIcon::setFastPropertyValue(       ::sal_Int32
 
 // XFastPropertySet
 css::uno::Any SAL_CALL ShutdownIcon::getFastPropertyValue( ::sal_Int32 nHandle )
-    throw (css::beans::UnknownPropertyException,
-            css::lang::WrappedTargetException,
-            css::uno::RuntimeException, std::exception)
 {
     css::uno::Any aValue;
     switch(nHandle)
