@@ -25,32 +25,22 @@
 #include <tools/urlobj.hxx>
 #include <osl/file.h>
 #include <comphelper/sequenceashashmap.hxx>
-#include <osl/mutex.hxx>
 #include <sfx2/app.hxx>
 #include <sal/macros.h>
-#include "app.hrc"
-#define USE_APP_SHORTCUTS
+#include <sfx2/strings.hrc>
 #include "shutdownicon.hxx"
 
 #include <com/sun/star/util/XStringWidth.hpp>
 
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 
 #include <set>
 #include <vector>
 
-#include "premac.h"
+#include <premac.h>
 #include <objc/objc-runtime.h>
 #include <Cocoa/Cocoa.h>
-#include "postmac.h"
-
-using namespace ::rtl;
-using namespace ::osl;
-using namespace ::com::sun::star::uno;
-using namespace ::com::sun::star::task;
-using namespace ::com::sun::star::lang;
-using namespace ::com::sun::star::beans;
-using namespace ::com::sun::star::util;
+#include <postmac.h>
 
 #define MI_OPEN                    1
 #define MI_WRITER                  2
@@ -78,28 +68,28 @@ using namespace ::com::sun::star::util;
         ShutdownIcon::FileOpen();
         break;
     case MI_WRITER:
-        ShutdownIcon::OpenURL( OUString(  WRITER_URL ), OUString( "_default" ) );
+        ShutdownIcon::OpenURL( WRITER_URL, "_default" );
         break;
     case MI_CALC:
-        ShutdownIcon::OpenURL( OUString( CALC_URL ), OUString( "_default" ) );
+        ShutdownIcon::OpenURL( CALC_URL, "_default" );
         break;
     case MI_IMPRESS:
-        ShutdownIcon::OpenURL( OUString( IMPRESS_URL ), OUString( "_default" ) );
+        ShutdownIcon::OpenURL( IMPRESS_URL, "_default" );
         break;
     case MI_DRAW:
-        ShutdownIcon::OpenURL( OUString( DRAW_URL ), OUString( "_default" ) );
+        ShutdownIcon::OpenURL( DRAW_URL, "_default" );
         break;
     case MI_BASE:
-        ShutdownIcon::OpenURL( OUString( BASE_URL ), OUString( "_default" ) );
+        ShutdownIcon::OpenURL( BASE_URL, "_default" );
         break;
     case MI_MATH:
-        ShutdownIcon::OpenURL( OUString( MATH_URL ), OUString( "_default" ) );
+        ShutdownIcon::OpenURL( MATH_URL, "_default" );
         break;
     case MI_TEMPLATE:
         ShutdownIcon::FromTemplate();
         break;
     case MI_STARTMODULE:
-        ShutdownIcon::OpenURL( OUString( STARTMODULE_URL ), OUString( "_default" ) );
+        ShutdownIcon::OpenURL( STARTMODULE_URL, "_default" );
         break;
     default:
         break;
@@ -109,8 +99,8 @@ using namespace ::com::sun::star::util;
 -(void)dockIconClicked: (NSObject*)pSender
 {
     (void)pSender;
-    // start start module
-    ShutdownIcon::OpenURL( OUString( STARTMODULE_URL ), OUString( "_default" ) );
+    // start module
+    ShutdownIcon::OpenURL( STARTMODULE_URL, "_default" );
 }
 
 @end
@@ -127,7 +117,7 @@ static std::set< OUString > aShortcuts;
 
 static NSString* getAutoreleasedString( const rtl::OUString& rStr )
 {
-    return [[[NSString alloc] initWithCharacters: rStr.getStr() length: rStr.getLength()] autorelease];
+    return [[[NSString alloc] initWithCharacters: reinterpret_cast<unichar const *>(rStr.getStr()) length: rStr.getLength()] autorelease];
 }
 
 struct RecentMenuEntry
@@ -138,15 +128,13 @@ struct RecentMenuEntry
     rtl::OUString aPassword;
 };
 
-class RecentFilesStringLength : public ::cppu::WeakImplHelper1< ::com::sun::star::util::XStringWidth >
+class RecentFilesStringLength : public ::cppu::WeakImplHelper< css::util::XStringWidth >
 {
     public:
         RecentFilesStringLength() {}
-        virtual ~RecentFilesStringLength() {}
 
         // XStringWidth
-        sal_Int32 SAL_CALL queryStringWidth( const ::rtl::OUString& aString )
-            throw (::com::sun::star::uno::RuntimeException)
+        sal_Int32 SAL_CALL queryStringWidth( const ::rtl::OUString& aString ) override
         {
             return aString.getLength();
         }
@@ -184,24 +172,24 @@ class RecentFilesStringLength : public ::cppu::WeakImplHelper1< ::com::sun::star
     int nItems = [menu numberOfItems];
     while( nItems -- )
         [menu removeItemAtIndex: 0];
-    
+
     // update recent item list
-    Sequence< Sequence< PropertyValue > > aHistoryList( SvtHistoryOptions().GetList( ePICKLIST ) );
+    css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > aHistoryList( SvtHistoryOptions().GetList( ePICKLIST ) );
 
     int nPickListMenuItems = ( aHistoryList.getLength() > 99 ) ? 99 : aHistoryList.getLength();
-        
+
     m_pRecentFilesItems->clear();
-    if( ( nPickListMenuItems > 0 ) )
+    if( nPickListMenuItems > 0 )
     {
         for ( int i = 0; i < nPickListMenuItems; i++ )
         {
-            Sequence< PropertyValue >& rPickListEntry = aHistoryList[i];
+            css::uno::Sequence< css::beans::PropertyValue >& rPickListEntry = aHistoryList[i];
             RecentMenuEntry aRecentFile;
-            
+
             for ( int j = 0; j < rPickListEntry.getLength(); j++ )
             {
-                Any a = rPickListEntry[j].Value;
-                
+                css::uno::Any a = rPickListEntry[j].Value;
+
                 if ( rPickListEntry[j].Name == HISTORY_PROPERTYNAME_URL )
                     a >>= aRecentFile.aURL;
                 else if ( rPickListEntry[j].Name == HISTORY_PROPERTYNAME_FILTER )
@@ -211,25 +199,25 @@ class RecentFilesStringLength : public ::cppu::WeakImplHelper1< ::com::sun::star
                 else if ( rPickListEntry[j].Name == HISTORY_PROPERTYNAME_PASSWORD )
                     a >>= aRecentFile.aPassword;
             }
-            
+
             m_pRecentFilesItems->push_back( aRecentFile );
         }
     }
 
     // insert new recent items
-    for ( sal_uInt32 i = 0; i < m_pRecentFilesItems->size(); i++ )
+    for ( std::vector<RecentMenuEntry>::size_type i = 0; i < m_pRecentFilesItems->size(); i++ )
     {
         rtl::OUString   aMenuTitle;
         INetURLObject   aURL( (*m_pRecentFilesItems)[i].aURL );
-        
-        if ( aURL.GetProtocol() == INET_PROT_FILE )
+
+        if ( aURL.GetProtocol() == INetProtocol::File )
         {
             // Do handle file URL differently => convert it to a system
             // path and abbreviate it with a special function:
-            ::rtl::OUString aSystemPath( aURL.getFSysPath( INetURLObject::FSYS_DETECT ) );
+            ::rtl::OUString aSystemPath( aURL.getFSysPath( FSysStyle::Detect ) );
             ::rtl::OUString aCompactedSystemPath;
-            
-            oslFileError nError = osl_abbreviateSystemPath( aSystemPath.pData, &aCompactedSystemPath.pData, 46, NULL );
+
+            oslFileError nError = osl_abbreviateSystemPath( aSystemPath.pData, &aCompactedSystemPath.pData, 46, nullptr );
             if ( !nError )
                 aMenuTitle = aCompactedSystemPath;
             else
@@ -238,10 +226,10 @@ class RecentFilesStringLength : public ::cppu::WeakImplHelper1< ::com::sun::star
         else
         {
             // Use INetURLObject to abbreviate all other URLs
-            Reference< XStringWidth > xStringLength( new RecentFilesStringLength() );
-            aMenuTitle = aURL.getAbbreviated( xStringLength, 46, INetURLObject::DECODE_UNAMBIGUOUS );
+            css::uno::Reference< css::util::XStringWidth > xStringLength( new RecentFilesStringLength() );
+            aMenuTitle = aURL.getAbbreviated( xStringLength, 46, INetURLObject::DecodeMechanism::Unambiguous );
         }
-        
+
         NSMenuItem* pNewItem = [[NSMenuItem alloc] initWithTitle: getAutoreleasedString( aMenuTitle )
                                                    action: @selector(executeRecentEntry:)
                                                    keyEquivalent: @""];
@@ -260,14 +248,14 @@ class RecentFilesStringLength : public ::cppu::WeakImplHelper1< ::com::sun::star
     {
         const RecentMenuEntry& rRecentFile = (*m_pRecentFilesItems)[ nIndex ];
         int NUM_OF_PICKLIST_ARGS = 3;
-        Sequence< PropertyValue > aArgsList( NUM_OF_PICKLIST_ARGS );
-        
+        css::uno::Sequence< css::beans::PropertyValue > aArgsList( NUM_OF_PICKLIST_ARGS );
+
         aArgsList[0].Name = "Referer";
-        aArgsList[0].Value = makeAny( OUString( "private:user" ) );
+        aArgsList[0].Value <<= OUString( "private:user" );
 
         // documents in the picklist will never be opened as templates
         aArgsList[1].Name = "AsTemplate";
-        aArgsList[1].Value = makeAny( (sal_Bool) sal_False );
+        aArgsList[1].Value <<= false;
 
         ::rtl::OUString  aFilter( rRecentFile.aFilter );
         sal_Int32 nPos = aFilter.indexOf( '|' );
@@ -279,23 +267,23 @@ class RecentFilesStringLength : public ::cppu::WeakImplHelper1< ::com::sun::star
                 aFilterOptions = aFilter.copy( nPos+1 );
 
             aArgsList[2].Name = "FilterOptions";
-            aArgsList[2].Value = makeAny( aFilterOptions );
+            aArgsList[2].Value <<= aFilterOptions;
 
             aFilter = aFilter.copy( 0, nPos-1 );
             aArgsList.realloc( ++NUM_OF_PICKLIST_ARGS );
         }
 
         aArgsList[NUM_OF_PICKLIST_ARGS-1].Name = "FilterName";
-        aArgsList[NUM_OF_PICKLIST_ARGS-1].Value = makeAny( aFilter );
+        aArgsList[NUM_OF_PICKLIST_ARGS-1].Value <<= aFilter;
 
-        ShutdownIcon::OpenURL( rRecentFile.aURL, OUString( "_default" ), aArgsList );
+        ShutdownIcon::OpenURL( rRecentFile.aURL, "_default", aArgsList );
     }
 }
 @end
 
 static RecentMenuDelegate* pRecentDelegate = nil;
 
-static rtl::OUString getShortCut( const rtl::OUString i_rTitle )
+static rtl::OUString getShortCut( const rtl::OUString& i_rTitle )
 {
     // create shortcut
     rtl::OUString aKeyEquiv;
@@ -317,7 +305,7 @@ static void appendMenuItem( NSMenu* i_pMenu, NSMenu* i_pDockMenu, const rtl::OUS
 {
     if( ! i_rTitle.getLength() )
         return;
-    
+
     NSMenuItem* pItem = [[NSMenuItem alloc] initWithTitle: getAutoreleasedString( i_rTitle )
                                             action: @selector(executeMenuItem:)
                                             keyEquivalent: (i_rKeyEquiv.getLength() ? getAutoreleasedString( i_rKeyEquiv ) : @"")
@@ -345,7 +333,7 @@ static void appendRecentMenu( NSMenu* i_pMenu, NSMenu* i_pDockMenu, const OUStri
 {
     if( ! pRecentDelegate )
         pRecentDelegate = [[RecentMenuDelegate alloc] init];
-    
+
     NSMenuItem* pItem = [i_pMenu addItemWithTitle: getAutoreleasedString( i_rTitle )
                                                    action: @selector(executeMenuItem:)
                                                    keyEquivalent: @""
@@ -399,39 +387,36 @@ void aqua_init_systray()
 
     // disable shutdown
     pShutdownIcon->SetVeto( true );
-    pShutdownIcon->addTerminateListener();
-    
+    ShutdownIcon::addTerminateListener();
+
     if( ! pDefMenu )
     {
         if( [NSApp respondsToSelector: @selector(addFallbackMenuItem:)] )
         {
             aShortcuts.clear();
-            
+
             pExecute = [[QSMenuExecute alloc] init];
-            pDefMenu = [[NSMenuItem alloc] initWithTitle: getAutoreleasedString( pShutdownIcon->GetResString( STR_QUICKSTART_FILE ) ) action: NULL keyEquivalent: @""];
-            pDockSubMenu = [[NSMenuItem alloc] initWithTitle: getAutoreleasedString( pShutdownIcon->GetResString( STR_QUICKSTART_FILE ) ) action: NULL keyEquivalent: @""];
-            NSMenu* pMenu = [[NSMenu alloc] initWithTitle: getAutoreleasedString( pShutdownIcon->GetResString( STR_QUICKSTART_FILE ) )];
+            pDefMenu = [[NSMenuItem alloc] initWithTitle: getAutoreleasedString( ShutdownIcon::GetResString(STR_QUICKSTART_FILE) ) action: nullptr keyEquivalent: @""];
+            pDockSubMenu = [[NSMenuItem alloc] initWithTitle: getAutoreleasedString( ShutdownIcon::GetResString(STR_QUICKSTART_FILE) ) action: nullptr keyEquivalent: @""];
+            NSMenu* pMenu = [[NSMenu alloc] initWithTitle: getAutoreleasedString( ShutdownIcon::GetResString(STR_QUICKSTART_FILE) )];
             [pMenu setAutoenablesItems: NO];
-            NSMenu* pDockMenu = [[NSMenu alloc] initWithTitle: getAutoreleasedString( pShutdownIcon->GetResString( STR_QUICKSTART_FILE ) )];
+            NSMenu* pDockMenu = [[NSMenu alloc] initWithTitle: getAutoreleasedString( ShutdownIcon::GetResString(STR_QUICKSTART_FILE) )];
             [pDockMenu setAutoenablesItems: NO];
-            
+
             // collect the URLs of the entries in the File/New menu
             SvtModuleOptions    aModuleOptions;
             std::set< rtl::OUString > aFileNewAppsAvailable;
             SvtDynamicMenuOptions aOpt;
-            Sequence < Sequence < PropertyValue > > aNewMenu = aOpt.GetMenu( E_NEWMENU );
-            const rtl::OUString sURLKey( "URL" );
-        
-            const Sequence< PropertyValue >* pNewMenu = aNewMenu.getConstArray();
-            const Sequence< PropertyValue >* pNewMenuEnd = aNewMenu.getConstArray() + aNewMenu.getLength();
-            for ( ; pNewMenu != pNewMenuEnd; ++pNewMenu )
+            css::uno::Sequence < css::uno::Sequence < css::beans::PropertyValue > > aNewMenu = aOpt.GetMenu( EDynamicMenuType::NewMenu );
+
+            for ( auto const & newMenuProp : aNewMenu )
             {
-                comphelper::SequenceAsHashMap aEntryItems( *pNewMenu );
-                rtl::OUString sURL( aEntryItems.getUnpackedValueOrDefault( sURLKey, rtl::OUString() ) );
+                comphelper::SequenceAsHashMap aEntryItems( newMenuProp );
+                rtl::OUString sURL( aEntryItems.getUnpackedValueOrDefault( "URL", rtl::OUString() ) );
                 if ( sURL.getLength() )
                     aFileNewAppsAvailable.insert( sURL );
             }
-            
+
             // describe the menu entries for launching the applications
             struct MenuEntryDescriptor
             {
@@ -440,72 +425,70 @@ void aqua_init_systray()
                 const char*                 pAsciiURLDescription;
             }   aMenuItems[] =
             {
-                { SvtModuleOptions::E_SWRITER,    MI_WRITER,  WRITER_URL },
-                { SvtModuleOptions::E_SCALC,      MI_CALC,    CALC_URL },
-                { SvtModuleOptions::E_SIMPRESS,   MI_IMPRESS, IMPRESS_WIZARD_URL },
-                { SvtModuleOptions::E_SDRAW,      MI_DRAW,    DRAW_URL },
-                { SvtModuleOptions::E_SDATABASE,  MI_BASE,    BASE_URL },
-                { SvtModuleOptions::E_SMATH,      MI_MATH,    MATH_URL }
+                { SvtModuleOptions::EModule::WRITER,    MI_WRITER,  WRITER_URL },
+                { SvtModuleOptions::EModule::CALC,      MI_CALC,    CALC_URL },
+                { SvtModuleOptions::EModule::IMPRESS,   MI_IMPRESS, IMPRESS_WIZARD_URL },
+                { SvtModuleOptions::EModule::DRAW,      MI_DRAW,    DRAW_URL },
+                { SvtModuleOptions::EModule::DATABASE,  MI_BASE,    BASE_URL },
+                { SvtModuleOptions::EModule::MATH,      MI_MATH,    MATH_URL }
             };
 
             // insert entry for startcenter
-            if( aModuleOptions.IsModuleInstalled( SvtModuleOptions::E_SSTARTMODULE ) )
+            if( aModuleOptions.IsModuleInstalled( SvtModuleOptions::EModule::STARTMODULE ) )
             {
-                appendMenuItem( pMenu, nil, pShutdownIcon->GetResString( STR_QUICKSTART_STARTCENTER ), MI_STARTMODULE, OUString( "n" ) );
+                appendMenuItem( pMenu, nil, ShutdownIcon::GetResString(STR_QUICKSTART_STARTCENTER), MI_STARTMODULE, "n" );
                 if( [NSApp respondsToSelector: @selector(setDockIconClickHandler:)] )
                     [NSApp performSelector:@selector(setDockIconClickHandler:) withObject: pExecute];
                 else
-                    OSL_FAIL( "setDockIconClickHandler selector failed on NSApp\n" );
+                    OSL_FAIL( "setDockIconClickHandler selector failed on NSApp" );
 
             }
-            
+
             // insert the menu entries for launching the applications
             for ( size_t i = 0; i < SAL_N_ELEMENTS( aMenuItems ); ++i )
             {
                 if ( !aModuleOptions.IsModuleInstalled( aMenuItems[i].eModuleIdentifier ) )
                     // the complete application is not even installed
                     continue;
-        
+
                 rtl::OUString sURL( ::rtl::OUString::createFromAscii( aMenuItems[i].pAsciiURLDescription ) );
-        
+
                 if ( aFileNewAppsAvailable.find( sURL ) == aFileNewAppsAvailable.end() )
                     // the application is installed, but the entry has been configured to *not* appear in the File/New
                     // menu => also let not appear it in the quickstarter
                     continue;
-                
-                rtl::OUString aKeyEquiv( getShortCut( pShutdownIcon->GetUrlDescription( sURL ) ) );
-        
-                appendMenuItem( pMenu, pDockMenu, pShutdownIcon->GetUrlDescription( sURL ), aMenuItems[i].nMenuTag, aKeyEquiv );
+
+                rtl::OUString aKeyEquiv( getShortCut( ShutdownIcon::GetUrlDescription( sURL ) ) );
+
+                appendMenuItem( pMenu, pDockMenu, ShutdownIcon::GetUrlDescription( sURL ), aMenuItems[i].nMenuTag, aKeyEquiv );
             }
 
             // insert the remaining menu entries
 
             // add recent menu
-            appendRecentMenu( pMenu, pDockMenu, pShutdownIcon->GetResString( STR_QUICKSTART_RECENTDOC ) );
+            appendRecentMenu( pMenu, pDockMenu, ShutdownIcon::GetResString(STR_QUICKSTART_RECENTDOC) );
 
-            rtl::OUString aTitle( pShutdownIcon->GetResString( STR_QUICKSTART_FROMTEMPLATE ) );
+            rtl::OUString aTitle( ShutdownIcon::GetResString(STR_QUICKSTART_FROMTEMPLATE) );
             rtl::OUString aKeyEquiv( getShortCut( aTitle ) );
             appendMenuItem( pMenu, pDockMenu, aTitle, MI_TEMPLATE, aKeyEquiv );
-            aTitle = pShutdownIcon->GetResString( STR_QUICKSTART_FILEOPEN );
+            aTitle = ShutdownIcon::GetResString(STR_QUICKSTART_FILEOPEN);
             aKeyEquiv = getShortCut( aTitle );
             appendMenuItem( pMenu, pDockMenu, aTitle, MI_OPEN, aKeyEquiv );
-            
+
             [pDefMenu setSubmenu: pMenu];
             [NSApp performSelector:@selector(addFallbackMenuItem:) withObject: pDefMenu];
 
             if( [NSApp respondsToSelector: @selector(addDockMenuItem:)] )
             {
                 [pDockSubMenu setSubmenu: pDockMenu];
-                // insert a separator to the dock menu
-                [NSApp performSelector:@selector(addDockMenuItem:) withObject: [NSMenuItem separatorItem]];
-                // and now add the submenu
+                // add the submenu
                 [NSApp performSelector:@selector(addDockMenuItem:) withObject: pDockSubMenu];
             }
             else
-                OSL_FAIL( "addDockMenuItem selector failed on NSApp\n" );
+                OSL_FAIL( "addDockMenuItem selector failed on NSApp" );
         }
         else
-            OSL_FAIL( "addFallbackMenuItem selector failed on NSApp\n" );
+            OSL_FAIL( "addFallbackMenuItem selector failed on NSApp" );
     }
 }
 
