@@ -21,23 +21,18 @@
 #include <svtools/htmltokn.h>
 #include <svtools/asynclink.hxx>
 
-#include <sfx2/sfx.hrc>
-
 #include <sfx2/frmhtml.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/evntconf.hxx>
 #include <sfx2/request.hxx>
 #include <sfx2/fcontnr.hxx>
-#include "sfxtypes.hxx"
+#include <sfxtypes.hxx>
 
 static sal_Char const sHTML_SC_yes[] =  "YES";
 static sal_Char const sHTML_SC_no[] =       "NO";
 static sal_Char const sHTML_SC_auto[] = "AUTO";
 
-#define HTML_O_READONLY "READONLY"
-#define HTML_O_EDIT     "EDIT"
-
 static HTMLOptionEnum<ScrollingMode> const aScrollingTable[] =
 {
     { sHTML_SC_yes,     ScrollingMode::Yes    },
@@ -63,13 +58,6 @@ void SfxFrameHTMLParser::ParseFrameOptions(
     {
         switch( rOption.GetToken() )
         {
-        case HtmlOptionId::BORDERCOLOR:
-            {
-                Color aColor;
-                rOption.GetColor( aColor );
-                pFrame->SetWallpaper( Wallpaper( aColor ) );
-                break;
-            }
         case HtmlOptionId::SRC:
             pFrame->SetURL(
                     INetURLObject::GetAbsURL(
@@ -105,27 +93,7 @@ void SfxFrameHTMLParser::ParseFrameOptions(
             pFrame->SetFrameBorder( bBorder );
             break;
         }
-        case HtmlOptionId::NORESIZE:
-            pFrame->SetResizable( false );
-            break;
         default:
-            if (rOption.GetTokenString().equalsIgnoreAsciiCase(HTML_O_READONLY))
-            {
-                const OUString& aStr = rOption.GetString();
-                bool bReadonly = true;
-                if ( aStr.equalsIgnoreAsciiCase("FALSE") )
-                    bReadonly = false;
-                pFrame->SetReadOnly( bReadonly );
-            }
-            else if (rOption.GetTokenString().equalsIgnoreAsciiCase(HTML_O_EDIT))
-            {
-                const OUString& aStr = rOption.GetString();
-                bool bEdit = true;
-                if ( aStr.equalsIgnoreAsciiCase("FALSE") )
-                    bEdit = false;
-                pFrame->SetEditable( bEdit );
-            }
-
             break;
         }
     }
