@@ -19,7 +19,7 @@
 
 #include <sal/config.h>
 
-#include "itemdel.hxx"
+#include <itemdel.hxx>
 #include <vcl/idle.hxx>
 
 #include <svl/itempool.hxx>
@@ -46,6 +46,7 @@ SfxItemDisruptor_Impl::SfxItemDisruptor_Impl(SfxPoolItem *const pItemToDisrupt)
 {
     m_Idle.SetInvokeHandler(LINK(this, SfxItemDisruptor_Impl, Delete));
     m_Idle.SetPriority(TaskPriority::DEFAULT_IDLE);
+    m_Idle.SetDebugName("sfx::SfxItemDisruptor_Impl m_Idle");
 
     DBG_ASSERT( 0 == pItem->GetRefCount(), "disrupting pooled item" );
     pItem->SetKind(SfxItemKind::DeleteOnIdle);
