@@ -55,10 +55,10 @@
 #include <vcl/layout.hxx>
 
 #include <sfx2/mailmodelapi.hxx>
-#include "sfxtypes.hxx"
+#include <sfxtypes.hxx>
 #include <sfx2/sfxresid.hxx>
 #include <sfx2/sfxsids.hrc>
-#include "dialog.hrc"
+#include <sfx2/strings.hrc>
 
 #include <unotools/tempfile.hxx>
 #include <unotools/configitem.hxx>
@@ -665,13 +665,12 @@ void SfxMailModel::AddToAddress( const OUString& rAddress )
 }
 
 SfxMailModel::SendMailResult SfxMailModel::AttachDocument(
-    const OUString& sDocumentType,
     const css::uno::Reference< css::uno::XInterface >& xFrameOrModel,
     const OUString& sAttachmentTitle )
 {
     OUString sFileName;
 
-    SaveResult eSaveResult = SaveDocumentAsFormat( sAttachmentTitle, xFrameOrModel, sDocumentType, sFileName );
+    SaveResult eSaveResult = SaveDocumentAsFormat( sAttachmentTitle, xFrameOrModel, OUString()/*sDocumentType*/, sFileName );
     if ( eSaveResult == SAVE_SUCCESSFULL &&  !sFileName.isEmpty() )
         maAttachedDocuments.push_back(sFileName);
     return eSaveResult == SAVE_SUCCESSFULL ? SEND_MAIL_OK : SEND_MAIL_ERROR;
@@ -726,55 +725,23 @@ SfxMailModel::SendMailResult SfxMailModel::Send( const css::uno::Reference< css:
                 xSimpleMailMessage->setOriginator( maFromAddress );
 
                 size_t nToCount     = mpToList ? mpToList->size() : 0;
-                size_t nCcCount     = mpCcList ? mpCcList->size() : 0;
-                size_t nCcSeqCount  = nCcCount;
 
                 // set recipient (only one) for this simple mail server!!
-                if ( nToCount > 1 )
-                {
-                    nCcSeqCount = nToCount - 1 + nCcCount;
-                    xSimpleMailMessage->setRecipient( mpToList->at( 0 ) );
-                    nSendFlags = SimpleMailClientFlags::NO_USER_INTERFACE;
-                }
-                else if ( nToCount == 1 )
+                if ( nToCount >= 1 )
                 {
                     xSimpleMailMessage->setRecipient( mpToList->at( 0 ) );
                     nSendFlags = SimpleMailClientFlags::NO_USER_INTERFACE;
                 }
 
                 // all other recipient must be handled with CC recipients!
-                if ( nCcSeqCount > 0 )
+                if ( nToCount > 1 )
                 {
-                    size_t                  nIndex = 0;
-                    Sequence< OUString >    aCcRecipientSeq;
-
-                    aCcRecipientSeq.realloc( nCcSeqCount );
-                    if ( nCcSeqCount > nCcCount )
-                    {
-                        for ( size_t i = 1; i < nToCount; ++i )
-                        {
-                            aCcRecipientSeq[nIndex++] = mpToList->at(i);
-                        }
-                    }
-
-                    for ( size_t i = 0; i < nCcCount; i++ )
-                    {
-                        aCcRecipientSeq[nIndex++] = mpCcList->at(i);
-                    }
+                    Sequence< OUString >    aCcRecipientSeq( nToCount - 1 );
+                    for ( size_t i = 1; i < nToCount; ++i )
+                        aCcRecipientSeq[i - 1] = mpToList->at(i);
                     xSimpleMailMessage->setCcRecipient( aCcRecipientSeq );
                 }
 
-                size_t nBccCount = mpBccList ? mpBccList->size() : 0;
-                if ( nBccCount > 0 )
-                {
-                    Sequence< OUString > aBccRecipientSeq( nBccCount );
-                    for ( size_t i = 0; i < nBccCount; ++i )
-                    {
-                        aBccRecipientSeq[i] = mpBccList->at(i);
-                    }
-                    xSimpleMailMessage->setBccRecipient( aBccRecipientSeq );
-                }
-
                 Sequence< OUString > aAttachmentSeq(&(maAttachedDocuments[0]),maAttachedDocuments.size());
 
                 if ( xSimpleMailMessage->getSubject().isEmpty() ) {
