@@ -19,17 +19,21 @@
 
 
 // Include ---------------------------------------------------------------
-#include <vcl/msgbox.hxx>
+#include <vcl/layout.hxx>
 
 #include <sfx2/passwd.hxx>
-#include "sfxtypes.hxx"
+#include <sfxtypes.hxx>
 #include <sfx2/sfxresid.hxx>
 
-#include "dialog.hrc"
+#include <sfx2/strings.hrc>
 
 
+IMPL_LINK( SfxPasswordDialog, EditModifyHdl, Edit&, rEdit, void )
+{
+    ModifyHdl(&rEdit);
+}
 
-IMPL_LINK_INLINE_START( SfxPasswordDialog, EditModifyHdl, Edit *, pEdit )
+void SfxPasswordDialog::ModifyHdl(Edit* pEdit)
 {
     if (mbAsciiOnly && (pEdit == mpPassword1ED || pEdit == mpPassword2ED))
     {
@@ -57,39 +61,34 @@ IMPL_LINK_INLINE_START( SfxPasswordDialog, EditModifyHdl, Edit *, pEdit )
     if( mpPassword2ED->IsVisible() )
         bEnable = (bEnable && (mpPassword2ED->GetText().getLength() >= mnMinLen));
     mpOKBtn->Enable( bEnable );
-    return 0;
 }
-IMPL_LINK_INLINE_END(SfxPasswordDialog, EditModifyHdl, Edit *, pEdit)
 
-
-
-IMPL_LINK_NOARG(SfxPasswordDialog, OKHdl)
+IMPL_LINK_NOARG(SfxPasswordDialog, OKHdl, Button*, void)
 {
-    bool bConfirmFailed = ( ( mnExtras & SHOWEXTRAS_CONFIRM ) == SHOWEXTRAS_CONFIRM ) &&
-                            ( GetConfirm() != GetPassword() );
-    if( ( mnExtras & SHOWEXTRAS_CONFIRM2 ) == SHOWEXTRAS_CONFIRM2 && ( GetConfirm2() != GetPassword2() ) )
+    bool bConfirmFailed = bool( mnExtras & SfxShowExtras::CONFIRM ) &&
+                          ( GetConfirm() != GetPassword() );
+    if( ( mnExtras & SfxShowExtras::CONFIRM2 ) && ( mpConfirm2ED->GetText() != GetPassword2() ) )
         bConfirmFailed = true;
     if ( bConfirmFailed )
     {
-        ErrorBox aBox( this, SfxResId( MSG_ERROR_WRONG_CONFIRM ) );
-        aBox.Execute();
+        ScopedVclPtrInstance< MessageDialog > aBox(this, SfxResId(STR_ERROR_WRONG_CONFIRM));
+        aBox->Execute();
         mpConfirm1ED->SetText( OUString() );
         mpConfirm1ED->GrabFocus();
     }
     else
         EndDialog( RET_OK );
-    return 0;
 }
 
 // CTOR / DTOR -----------------------------------------------------------
 
-SfxPasswordDialog::SfxPasswordDialog(Window* pParent, const OUString* pGroupText)
+SfxPasswordDialog::SfxPasswordDialog(vcl::Window* pParent, const OUString* pGroupText)
     : ModalDialog(pParent, "PasswordDialog", "sfx/ui/password.ui")
-    , maMinLenPwdStr(SFX2_RESSTR(STR_PASSWD_MIN_LEN))
-    , maMinLenPwdStr1(SFX2_RESSTR(STR_PASSWD_MIN_LEN1))
-    , maEmptyPwdStr(SFX2_RESSTR(STR_PASSWD_EMPTY))
+    , maMinLenPwdStr(SfxResId(STR_PASSWD_MIN_LEN))
+    , maMinLenPwdStr1(SfxResId(STR_PASSWD_MIN_LEN1))
+    , maEmptyPwdStr(SfxResId(STR_PASSWD_EMPTY))
     , mnMinLen(5)
-    , mnExtras(0)
+    , mnExtras(SfxShowExtras::NONE)
     , mbAsciiOnly(false)
 {
     get(mpPassword1Box, "password1frame");
@@ -110,13 +109,10 @@ SfxPasswordDialog::SfxPasswordDialog(Window* pParent, const OUString* pGroupText
 
     get(mpOKBtn, "ok");
 
-    mpPassword1ED->SetAccessibleName(SFX2_RESSTR(STR_PASSWD));
-
-    Link aLink = LINK( this, SfxPasswordDialog, EditModifyHdl );
+    Link<Edit&,void> aLink = LINK( this, SfxPasswordDialog, EditModifyHdl );
     mpPassword1ED->SetModifyHdl( aLink );
     mpPassword2ED->SetModifyHdl( aLink );
-    aLink = LINK( this, SfxPasswordDialog, OKHdl );
-    mpOKBtn->SetClickHdl( aLink );
+    mpOKBtn->SetClickHdl( LINK( this, SfxPasswordDialog, OKHdl ) );
 
     if (pGroupText)
         mpPassword1Box->set_label(*pGroupText);
@@ -125,7 +121,29 @@ SfxPasswordDialog::SfxPasswordDialog(Window* pParent, const OUString* pGroupText
     SetPasswdText();
 }
 
+SfxPasswordDialog::~SfxPasswordDialog()
+{
+    disposeOnce();
+}
 
+void SfxPasswordDialog::dispose()
+{
+    mpPassword1Box.clear();
+    mpUserFT.clear();
+    mpUserED.clear();
+    mpPassword1FT.clear();
+    mpPassword1ED.clear();
+    mpConfirm1FT.clear();
+    mpConfirm1ED.clear();
+    mpPassword2Box.clear();
+    mpPassword2FT.clear();
+    mpPassword2ED.clear();
+    mpConfirm2FT.clear();
+    mpConfirm2ED.clear();
+    mpMinLengthFT.clear();
+    mpOKBtn.clear();
+    ModalDialog::dispose();
+}
 
 void SfxPasswordDialog::SetPasswdText( )
 {
@@ -146,12 +164,11 @@ void SfxPasswordDialog::SetPasswdText( )
 }
 
 
-
 void SfxPasswordDialog::SetMinLen( sal_uInt16 nLen )
 {
     mnMinLen = nLen;
     SetPasswdText();
-    EditModifyHdl( NULL );
+    ModifyHdl( nullptr );
 }
 
 void SfxPasswordDialog::ShowMinLengthText(bool bShow)
@@ -160,7 +177,6 @@ void SfxPasswordDialog::ShowMinLengthText(bool bShow)
 }
 
 
-
 short SfxPasswordDialog::Execute()
 {
     mpUserFT->Hide();
@@ -175,25 +191,25 @@ short SfxPasswordDialog::Execute()
     mpConfirm2FT->Hide();
     mpConfirm2ED->Hide();
 
-    if (mnExtras != SHOWEXTRAS_NONE)
+    if (mnExtras != SfxShowExtras::NONE)
         mpPassword1FT->Show();
-    if (mnExtras & SHOWEXTRAS_USER)
+    if (mnExtras & SfxShowExtras::USER)
     {
         mpUserFT->Show();
         mpUserED->Show();
     }
-    if (mnExtras & SHOWEXTRAS_CONFIRM)
+    if (mnExtras & SfxShowExtras::CONFIRM)
     {
         mpConfirm1FT->Show();
         mpConfirm1ED->Show();
     }
-    if (mnExtras & SHOWEXTRAS_PASSWORD2)
+    if (mnExtras & SfxShowExtras::PASSWORD2)
     {
         mpPassword2Box->Show();
         mpPassword2FT->Show();
         mpPassword2ED->Show();
     }
-    if (mnExtras & SHOWEXTRAS_CONFIRM2)
+    if (mnExtras & SfxShowExtras::CONFIRM2)
     {
         mpConfirm2FT->Show();
         mpConfirm2ED->Show();
