@@ -25,8 +25,8 @@
 #include <vcl/msgbox.hxx>
 #include <unotools/viewoptions.hxx>
 
-#include "appdata.hxx"
-#include "sfxtypes.hxx"
+#include <appdata.hxx>
+#include <sfxtypes.hxx>
 #include <sfx2/tabdlg.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/app.hxx>
@@ -37,8 +37,10 @@
 #include <sfx2/sfxdlg.hxx>
 #include <sfx2/itemconnect.hxx>
 
-#include "dialog.hrc"
-#include "helpid.hrc"
+#include <uitest/sfx_uiobject.hxx>
+
+#include <sfx2/strings.hrc>
+#include <helpids.h>
 
 using namespace ::com::sun::star::uno;
 
@@ -60,18 +62,16 @@ struct Data_Impl
     CreateTabPage fnCreatePage;   // Pointer to Factory
     GetTabPageRanges fnGetRanges; // Pointer to Ranges-Function
     VclPtr<SfxTabPage> pTabPage;         // The TabPage itself
-    bool bOnDemand;              // Flag: ItemSet onDemand
     bool bRefresh;                // Flag: Page must be re-initialized
 
     // Constructor
     Data_Impl( sal_uInt16 Id, CreateTabPage fnPage,
-               GetTabPageRanges fnRanges, bool bDemand ) :
+               GetTabPageRanges fnRanges ) :
 
         nId         ( Id ),
         fnCreatePage( fnPage ),
         fnGetRanges ( fnRanges ),
         pTabPage    ( nullptr ),
-        bOnDemand   ( bDemand ),
         bRefresh    ( false )
     {
         if ( !fnCreatePage  )
@@ -111,22 +111,16 @@ typedef std::vector<Data_Impl*> SfxTabDlgData_Impl;
 
 struct TabDlg_Impl
 {
-    bool                bModified       : 1,
-                        bModal          : 1,
+    bool                bModal          : 1,
                         bHideResetBtn   : 1;
     SfxTabDlgData_Impl  aData;
 
     explicit TabDlg_Impl( sal_uInt8 nCnt ) :
-
-        bModified       ( false ),
         bModal          ( true ),
         bHideResetBtn   ( false )
     {
         aData.reserve( nCnt );
     }
-    ~TabDlg_Impl()
-    {
-    }
 };
 
 
@@ -176,8 +170,7 @@ SfxTabPage::~SfxTabPage()
 
 void SfxTabPage::dispose()
 {
-    delete pImpl;
-    pImpl = nullptr;
+    pImpl.reset();
     TabPage::dispose();
 }
 
@@ -188,8 +181,8 @@ bool SfxTabPage::FillItemSet( SfxItemSet* rSet )
 
 void SfxTabPage::Reset( const SfxItemSet* rSet )
 {
-    pImpl->maItemConn.DoApplyFlags( *rSet );
-    pImpl->maItemConn.DoReset( *rSet );
+    pImpl->maItemConn.DoApplyFlags( rSet );
+    pImpl->maItemConn.DoReset( rSet );
 }
 
 void SfxTabPage::ActivatePage( const SfxItemSet& )
@@ -202,7 +195,7 @@ void SfxTabPage::ActivatePage( const SfxItemSet& )
 {
 }
 
-SfxTabPage::sfxpg SfxTabPage::DeactivatePage( SfxItemSet* )
+DeactivateRC SfxTabPage::DeactivatePage( SfxItemSet* )
 
 /*  [Description]
 
@@ -216,15 +209,14 @@ SfxTabPage::sfxpg SfxTabPage::DeactivatePage( SfxItemSet* )
 
     [Return value]
 
-    LEAVE_PAGE; Allow leaving the page
+    DeactivateRC::LeavePage; Allow leaving the page
 */
 
 {
-    return LEAVE_PAGE;
+    return DeactivateRC::LeavePage;
 }
 
 
-
 void SfxTabPage::FillUserData()
 
 /*  [Description]
@@ -238,14 +230,12 @@ void SfxTabPage::FillUserData()
 }
 
 
-
 bool SfxTabPage::IsReadOnly() const
 {
     return false;
 }
 
 
-
 const SfxPoolItem* SfxTabPage::GetItem( const SfxItemSet& rSet, sal_uInt16 nSlot, bool bDeep )
 
 /*  [Description]
@@ -266,7 +256,6 @@ const SfxPoolItem* SfxTabPage::GetItem( const SfxItemSet& rSet, sal_uInt16 nSlot
 }
 
 
-
 const SfxPoolItem* SfxTabPage::GetOldItem( const SfxItemSet& rSet,
                                            sal_uInt16 nSlot, bool bDeep )
 
@@ -292,7 +281,7 @@ const SfxPoolItem* SfxTabPage::GetOldItem( const SfxItemSet& rSet,
 
 void SfxTabPage::PageCreated( const SfxAllItemSet& /*aSet*/ )
 {
-    DBG_ASSERT(false, "SfxTabPage::PageCreated should not be called");
+    SAL_WARN( "sfx.dialog", "SfxTabPage::PageCreated should not be called");
 }
 
 void SfxTabPage::ChangesApplied()
@@ -310,7 +299,6 @@ SfxTabDialog* SfxTabPage::GetTabDialog() const
 }
 
 
-
 SfxTabDialog::SfxTabDialog
 
 /*  [Description]
@@ -326,19 +314,23 @@ SfxTabDialog::SfxTabDialog
     bool bEditFmt                 // when yes -> additional Button for standard
 )
     : TabDialog(pParent, rID, rUIXMLDescription)
-    , pSet(pItemSet ? new SfxItemSet(*pItemSet) : nullptr)
-    , pOutSet(nullptr)
-    , pRanges(nullptr)
-    , nAppPageId(USHRT_MAX)
-    , bItemsReset(false)
-    , bStandardPushed(false)
-    , pExampleSet(nullptr)
+    , m_pSet(pItemSet ? new SfxItemSet(*pItemSet) : nullptr)
+    , m_pOutSet(nullptr)
+    , m_pRanges(nullptr)
+    , m_nAppPageId(USHRT_MAX)
+    , m_bStandardPushed(false)
+    , m_pExampleSet(nullptr)
 {
     Init_Impl(bEditFmt);
+
+    sal_uInt16 nPageCount = m_pTabCtrl->GetPageCount();
+    for (sal_uInt16 nPage = 0; nPage < nPageCount; ++nPage)
+    {
+        sal_uInt16 nPageId = m_pTabCtrl->GetPageId(nPage);
+        m_pTabCtrl->SetTabPage(nPageId, nullptr);
+    }
 }
 
-
-
 SfxTabDialog::~SfxTabDialog()
 {
     disposeOnce();
@@ -348,7 +340,7 @@ void SfxTabDialog::dispose()
 {
     SavePosAndId();
 
-    for ( SfxTabDlgData_Impl::const_iterator it = pImpl->aData.begin(); it != pImpl->aData.end(); ++it )
+    for ( SfxTabDlgData_Impl::const_iterator it = m_pImpl->aData.begin(); it != m_pImpl->aData.end(); ++it )
     {
         Data_Impl* pDataObject = *it;
 
@@ -364,32 +356,29 @@ void SfxTabDialog::dispose()
                     RTL_TEXTENCODING_UTF8);
                 if (sConfigId.isEmpty())
                 {
-                    SAL_WARN("sfx.config", "Tabpage needs to be converted to .ui format");
+                    SAL_WARN("sfx.dialog", "Tabpage needs to be converted to .ui format");
                     sConfigId = OUString::number(pDataObject->nId);
                 }
 
-                SvtViewOptions aPageOpt(E_TABPAGE, sConfigId);
-                aPageOpt.SetUserItem( USERITEM_NAME, makeAny( OUString( aPageData ) ) );
+                SvtViewOptions aPageOpt(EViewType::TabPage, sConfigId);
+                aPageOpt.SetUserItem( USERITEM_NAME, makeAny( aPageData ) );
             }
 
-            if ( pDataObject->bOnDemand )
-                delete &pDataObject->pTabPage->GetItemSet();
             pDataObject->pTabPage.disposeAndClear();
         }
         delete pDataObject;
         pDataObject = nullptr;
     }
 
-    delete pImpl;
-    pImpl = nullptr;
-    delete pSet;
-    pSet = nullptr;
-    delete pOutSet;
-    pOutSet = nullptr;
-    delete pExampleSet;
-    pExampleSet = nullptr;
-    delete [] pRanges;
-    pRanges = nullptr;
+    m_pImpl.reset();
+    delete m_pSet;
+    m_pSet = nullptr;
+    delete m_pOutSet;
+    m_pOutSet = nullptr;
+    delete m_pExampleSet;
+    m_pExampleSet = nullptr;
+    delete [] m_pRanges;
+    m_pRanges = nullptr;
 
     if (m_bOwnsBaseFmtBtn)
         m_pBaseFmtBtn.disposeAndClear();
@@ -425,7 +414,7 @@ void SfxTabDialog::Init_Impl(bool bFmtFlag)
     assert(m_pBox);
     m_pUIBuilder->get(m_pTabCtrl, "tabcontrol");
 
-    pImpl = new TabDlg_Impl(m_pTabCtrl->GetPageCount());
+    m_pImpl.reset( new TabDlg_Impl(m_pTabCtrl->GetPageCount()) );
 
     m_pActionArea = get_action_area();
     assert(m_pActionArea);
@@ -450,19 +439,25 @@ void SfxTabDialog::Init_Impl(bool bFmtFlag)
     m_pResetBtn = m_pUIBuilder->get<PushButton>("reset");
     m_bOwnsResetBtn = m_pResetBtn == nullptr;
     if (m_bOwnsResetBtn)
+    {
         m_pResetBtn = VclPtr<PushButton>::Create(m_pActionArea.get());
+        m_pResetBtn->set_id("reset");
+    }
     else
-        pImpl->bHideResetBtn = !m_pResetBtn->IsVisible();
+        m_pImpl->bHideResetBtn = !m_pResetBtn->IsVisible();
 
     m_pBaseFmtBtn = m_pUIBuilder->get<PushButton>("standard");
     m_bOwnsBaseFmtBtn = m_pBaseFmtBtn == nullptr;
     if (m_bOwnsBaseFmtBtn)
+    {
         m_pBaseFmtBtn = VclPtr<PushButton>::Create(m_pActionArea.get());
+        m_pBaseFmtBtn->set_id("standard");
+    }
 
     m_pOKBtn->SetClickHdl( LINK( this, SfxTabDialog, OkHdl ) );
     m_pCancelBtn->SetClickHdl( LINK( this, SfxTabDialog, CancelHdl ) );
     m_pResetBtn->SetClickHdl( LINK( this, SfxTabDialog, ResetHdl ) );
-    m_pResetBtn->SetText( SfxResId( STR_RESET ).toString() );
+    m_pResetBtn->SetText( SfxResId( STR_RESET ) );
     m_pTabCtrl->SetActivatePageHdl(
             LINK( this, SfxTabDialog, ActivatePageHdl ) );
     m_pTabCtrl->SetDeactivatePageHdl(
@@ -484,23 +479,23 @@ void SfxTabDialog::Init_Impl(bool bFmtFlag)
 
     if ( bFmtFlag )
     {
-        m_pBaseFmtBtn->SetText( SfxResId( STR_STANDARD_SHORTCUT ).toString() );
+        m_pBaseFmtBtn->SetText( SfxResId( STR_STANDARD_SHORTCUT ) );
         m_pBaseFmtBtn->SetClickHdl( LINK( this, SfxTabDialog, BaseFmtHdl ) );
         m_pBaseFmtBtn->SetHelpId( HID_TABDLG_STANDARD_BTN );
         m_pBaseFmtBtn->Show();
     }
 
-    if ( pSet )
+    if ( m_pSet )
     {
-        pExampleSet = new SfxItemSet( *pSet );
-        pOutSet = new SfxItemSet( *pSet->GetPool(), pSet->GetRanges() );
+        m_pExampleSet = new SfxItemSet( *m_pSet );
+        m_pOutSet = new SfxItemSet( *m_pSet->GetPool(), m_pSet->GetRanges() );
     }
 }
 
 void SfxTabDialog::RemoveResetButton()
 {
     m_pResetBtn->Hide();
-    pImpl->bHideResetBtn = true;
+    m_pImpl->bHideResetBtn = true;
 }
 
 void SfxTabDialog::RemoveStandardButton()
@@ -517,7 +512,6 @@ short SfxTabDialog::Execute()
 }
 
 
-
 void SfxTabDialog::StartExecuteModal( const Link<Dialog&,void>& rEndDialogHdl )
 {
     if ( !m_pTabCtrl->GetPageCount() )
@@ -527,21 +521,18 @@ void SfxTabDialog::StartExecuteModal( const Link<Dialog&,void>& rEndDialogHdl )
 }
 
 
-
-void SfxTabDialog::Start( bool bShow )
+void SfxTabDialog::Start()
 {
-    pImpl->bModal = false;
+    m_pImpl->bModal = false;
     Start_Impl();
 
-    if ( bShow )
-        Show();
+    Show();
 
     if ( IsVisible() && ( !HasChildPathFocus() || HasFocus() ) )
         GrabFocusToFirstControl();
 }
 
 
-
 void SfxTabDialog::SetApplyHandler(const Link<Button*, void>& _rHdl)
 {
     DBG_ASSERT( m_pApplyBtn, "SfxTabDialog::GetApplyHandler: no apply button enabled!" );
@@ -550,44 +541,37 @@ void SfxTabDialog::SetApplyHandler(const Link<Button*, void>& _rHdl)
 }
 
 
-
 void SfxTabDialog::Start_Impl()
 {
-    assert(pImpl->aData.size() == m_pTabCtrl->GetPageCount()
+    assert(m_pImpl->aData.size() == m_pTabCtrl->GetPageCount()
             && "not all pages registered");
     sal_uInt16 nActPage = m_pTabCtrl->GetPageId( 0 );
 
     // load old settings, when exists
-    SvtViewOptions aDlgOpt(E_TABDIALOG, OStringToOUString(GetHelpId(),RTL_TEXTENCODING_UTF8));
+    SvtViewOptions aDlgOpt(EViewType::TabDialog, OStringToOUString(GetHelpId(),RTL_TEXTENCODING_UTF8));
     if ( aDlgOpt.Exists() )
     {
-        SetWindowState(OUStringToOString(aDlgOpt.GetWindowState().getStr(), RTL_TEXTENCODING_ASCII_US));
+        SetWindowState(OUStringToOString(aDlgOpt.GetWindowState(), RTL_TEXTENCODING_ASCII_US));
 
         // initial TabPage from Program/Help/config
         nActPage = (sal_uInt16)aDlgOpt.GetPageID();
 
-        if ( USHRT_MAX != nAppPageId )
-            nActPage = nAppPageId;
-        else
-        {
-            sal_uInt16 nAutoTabPageId = SfxGetpApp()->Get_Impl()->nAutoTabPageId;
-            if ( nAutoTabPageId )
-                nActPage = nAutoTabPageId;
-        }
+        if ( USHRT_MAX != m_nAppPageId )
+            nActPage = m_nAppPageId;
 
         if ( TAB_PAGE_NOTFOUND == m_pTabCtrl->GetPagePos( nActPage ) )
             nActPage = m_pTabCtrl->GetPageId( 0 );
     }
-    else if ( USHRT_MAX != nAppPageId && TAB_PAGE_NOTFOUND != m_pTabCtrl->GetPagePos( nAppPageId ) )
-        nActPage = nAppPageId;
+    else if ( USHRT_MAX != m_nAppPageId && TAB_PAGE_NOTFOUND != m_pTabCtrl->GetPagePos( m_nAppPageId ) )
+        nActPage = m_nAppPageId;
 
     m_pTabCtrl->SetCurPageId( nActPage );
     ActivatePageHdl( m_pTabCtrl );
 }
 
-void SfxTabDialog::AddTabPage( sal_uInt16 nId, const OUString &rRiderText, bool bItemsOnDemand, sal_uInt16 nPos )
+void SfxTabDialog::AddTabPage( sal_uInt16 nId, const OUString &rRiderText )
 {
-    AddTabPage( nId, rRiderText, nullptr, nullptr, bItemsOnDemand, nPos );
+    AddTabPage( nId, rRiderText, nullptr, nullptr );
 }
 
 /*
@@ -598,15 +582,13 @@ sal_uInt16 SfxTabDialog::AddTabPage
 (
     const OString &rName,          // Page ID
     CreateTabPage pCreateFunc,     // Pointer to the Factory Method
-    GetTabPageRanges pRangesFunc,  // Pointer to the Method for quering
+    GetTabPageRanges pRangesFunc   // Pointer to the Method for querying
                                    // Ranges onDemand
-    bool bItemsOnDemand            // indicates whether the set of this page is
-                                   // requested when created
 )
 {
     sal_uInt16 nId = m_pTabCtrl->GetPageId(rName);
-    pImpl->aData.push_back(
-        new Data_Impl( nId, pCreateFunc, pRangesFunc, bItemsOnDemand ) );
+    m_pImpl->aData.push_back(
+        new Data_Impl( nId, pCreateFunc, pRangesFunc ) );
     return nId;
 }
 
@@ -626,12 +608,11 @@ sal_uInt16 SfxTabDialog::AddTabPage
     assert(pCreateFunc);
     GetTabPageRanges pRangesFunc = pFact->GetTabPageRangesFunc(nPageCreateId);
     sal_uInt16 nPageId = m_pTabCtrl->GetPageId(rName);
-    pImpl->aData.push_back(new Data_Impl(nPageId, pCreateFunc, pRangesFunc, false));
+    m_pImpl->aData.push_back(new Data_Impl(nPageId, pCreateFunc, pRangesFunc));
     return nPageId;
 }
 
 
-
 void SfxTabDialog::AddTabPage
 
 /*  [Description]
@@ -645,15 +626,13 @@ void SfxTabDialog::AddTabPage
     const OUString& rRiderText,
     CreateTabPage pCreateFunc,
     GetTabPageRanges pRangesFunc,
-    bool bItemsOnDemand,
     sal_uInt16 nPos
 )
 {
     DBG_ASSERT( TAB_PAGE_NOTFOUND == m_pTabCtrl->GetPagePos( nId ),
                 "Double Page-Ids in the Tabpage" );
     m_pTabCtrl->InsertPage( nId, rRiderText, nPos );
-    pImpl->aData.push_back(
-        new Data_Impl( nId, pCreateFunc, pRangesFunc, bItemsOnDemand ) );
+    m_pImpl->aData.push_back( new Data_Impl( nId, pCreateFunc, pRangesFunc ) );
 }
 
 void SfxTabDialog::RemoveTabPage( sal_uInt16 nId )
@@ -666,7 +645,7 @@ void SfxTabDialog::RemoveTabPage( sal_uInt16 nId )
 {
     sal_uInt16 nPos = 0;
     m_pTabCtrl->RemovePage( nId );
-    Data_Impl* pDataObject = Find( pImpl->aData, nId, &nPos );
+    Data_Impl* pDataObject = Find( m_pImpl->aData, nId, &nPos );
 
     if ( pDataObject )
     {
@@ -681,21 +660,19 @@ void SfxTabDialog::RemoveTabPage( sal_uInt16 nId )
                     RTL_TEXTENCODING_UTF8);
                 if (sConfigId.isEmpty())
                 {
-                    SAL_WARN("sfx.config", "Tabpage needs to be converted to .ui format");
+                    SAL_WARN("sfx.dialog", "Tabpage needs to be converted to .ui format");
                     sConfigId = OUString::number(pDataObject->nId);
                 }
 
-                SvtViewOptions aPageOpt(E_TABPAGE, sConfigId);
-                aPageOpt.SetUserItem( USERITEM_NAME, makeAny( OUString( aPageData ) ) );
+                SvtViewOptions aPageOpt(EViewType::TabPage, sConfigId);
+                aPageOpt.SetUserItem( USERITEM_NAME, makeAny( aPageData ) );
             }
 
-            if ( pDataObject->bOnDemand )
-                delete &pDataObject->pTabPage->GetItemSet();
             pDataObject->pTabPage.disposeAndClear();
         }
 
         delete pDataObject;
-        pImpl->aData.erase( pImpl->aData.begin() + nPos );
+        m_pImpl->aData.erase( m_pImpl->aData.begin() + nPos );
     }
     else
     {
@@ -709,7 +686,6 @@ void SfxTabDialog::RemoveTabPage(const OString &rName)
 }
 
 
-
 void SfxTabDialog::PageCreated
 
 /*  [Description]
@@ -727,7 +703,6 @@ void SfxTabDialog::PageCreated
 }
 
 
-
 SfxItemSet* SfxTabDialog::GetInputSetImpl()
 
 /*  [Description]
@@ -737,11 +712,10 @@ SfxItemSet* SfxTabDialog::GetInputSetImpl()
 */
 
 {
-    return pSet;
+    return m_pSet;
 }
 
 
-
 SfxTabPage* SfxTabDialog::GetTabPage( sal_uInt16 nPageId ) const
 
 /*  [Description]
@@ -751,7 +725,7 @@ SfxTabPage* SfxTabDialog::GetTabPage( sal_uInt16 nPageId ) const
 
 {
     sal_uInt16 nPos = 0;
-    Data_Impl* pDataObject = Find( pImpl->aData, nPageId, &nPos );
+    Data_Impl* pDataObject = Find( m_pImpl->aData, nPageId, &nPos );
 
     if ( pDataObject )
         return pDataObject->pTabPage;
@@ -761,14 +735,13 @@ SfxTabPage* SfxTabDialog::GetTabPage( sal_uInt16 nPageId ) const
 void SfxTabDialog::SavePosAndId()
 {
     // save settings (screen position and current page)
-    SvtViewOptions aDlgOpt(E_TABDIALOG, OStringToOUString(GetHelpId(),RTL_TEXTENCODING_UTF8));
-    aDlgOpt.SetWindowState(OStringToOUString(GetWindowState(WINDOWSTATE_MASK_POS),RTL_TEXTENCODING_ASCII_US));
+    SvtViewOptions aDlgOpt(EViewType::TabDialog, OStringToOUString(GetHelpId(),RTL_TEXTENCODING_UTF8));
+    aDlgOpt.SetWindowState(OStringToOUString(GetWindowState(WindowStateMask::Pos),RTL_TEXTENCODING_ASCII_US));
     // to-do replace with name of page when all pages are converted to .ui
     aDlgOpt.SetPageID( m_pTabCtrl->GetCurPageId() );
 }
 
 
-
 short SfxTabDialog::Ok()
 
 /*  [Description]
@@ -790,58 +763,51 @@ short SfxTabDialog::Ok()
 {
     SavePosAndId(); //See fdo#38828 "Apply" resetting window position
 
-    if ( !pOutSet )
+    if ( !m_pOutSet )
     {
-        if ( !pExampleSet && pSet )
-            pOutSet = pSet->Clone( false );  // without Items
-        else if ( pExampleSet )
-            pOutSet = new SfxItemSet( *pExampleSet );
+        if ( !m_pExampleSet && m_pSet )
+            m_pOutSet = m_pSet->Clone( false );  // without Items
+        else if ( m_pExampleSet )
+            m_pOutSet = new SfxItemSet( *m_pExampleSet );
     }
     bool bModified = false;
 
-    for ( SfxTabDlgData_Impl::const_iterator it = pImpl->aData.begin(); it != pImpl->aData.end(); ++it )
+    for ( SfxTabDlgData_Impl::const_iterator it = m_pImpl->aData.begin(); it != m_pImpl->aData.end(); ++it )
     {
         Data_Impl* pDataObject = *it;
         SfxTabPage* pTabPage = pDataObject->pTabPage;
 
         if ( pTabPage )
         {
-            if ( pDataObject->bOnDemand )
+            if ( m_pSet && !pTabPage->HasExchangeSupport() )
             {
-                SfxItemSet& rSet = (SfxItemSet&)pTabPage->GetItemSet();
-                rSet.ClearItem();
-                bModified |= pTabPage->FillItemSet( &rSet );
-            }
-            else if ( pSet && !pTabPage->HasExchangeSupport() )
-            {
-                SfxItemSet aTmp( *pSet->GetPool(), pSet->GetRanges() );
+                SfxItemSet aTmp( *m_pSet->GetPool(), m_pSet->GetRanges() );
 
                 if ( pTabPage->FillItemSet( &aTmp ) )
                 {
                     bModified = true;
-                    if (pExampleSet)
-                        pExampleSet->Put( aTmp );
-                    pOutSet->Put( aTmp );
+                    if (m_pExampleSet)
+                        m_pExampleSet->Put( aTmp );
+                    m_pOutSet->Put( aTmp );
                 }
             }
         }
     }
 
-    if ( pImpl->bModified || ( pOutSet && pOutSet->Count() > 0 ) )
+    if ( m_pOutSet && m_pOutSet->Count() > 0 )
         bModified = true;
 
-    if (bStandardPushed)
+    if (m_bStandardPushed)
         bModified = true;
     return bModified ? RET_OK : RET_CANCEL;
 }
 
-IMPL_LINK_NOARG_TYPED(SfxTabDialog, CancelHdl, Button*, void)
+IMPL_LINK_NOARG(SfxTabDialog, CancelHdl, Button*, void)
 {
     EndDialog( RET_USER_CANCEL );
 }
 
 
-
 SfxItemSet* SfxTabDialog::CreateInputItemSet( sal_uInt16 )
 
 /*  [Description]
@@ -856,14 +822,13 @@ SfxItemSet* SfxTabDialog::CreateInputItemSet( sal_uInt16 )
 }
 
 
-
 void SfxTabDialog::RefreshInputSet()
 
 /*  [Description]
 
     Default implementation of the virtual Method.
     This is called, when <SfxTabPage::DeactivatePage(SfxItemSet *)>
-    returns <SfxTabPage::REFRESH_SET>.
+    returns <DeactivateRC::RefreshSet>.
 */
 
 {
@@ -871,21 +836,20 @@ void SfxTabDialog::RefreshInputSet()
 }
 
 
-
-IMPL_LINK_NOARG_TYPED(SfxTabDialog, OkHdl, Button*, void)
+IMPL_LINK_NOARG(SfxTabDialog, OkHdl, Button*, void)
 
 /*  [Description]
 
     Handler of the Ok-Buttons
     This calls the current page <SfxTabPage::DeactivatePage(SfxItemSet *)>.
-    Returns <SfxTabPage::LEAVE_PAGE>, <SfxTabDialog::Ok()> is called
+    Returns <DeactivateRC::LeavePage>, <SfxTabDialog::Ok()> is called
     and the Dialog is ended.
 */
 
 {
     if (PrepareLeaveCurrentPage())
     {
-        if ( pImpl->bModal )
+        if ( m_pImpl->bModal )
             EndDialog( Ok() );
         else
         {
@@ -915,7 +879,6 @@ bool SfxTabDialog::Apply()
 }
 
 
-
 bool SfxTabDialog::PrepareLeaveCurrentPage()
 {
     sal_uInt16 const nId = m_pTabCtrl->GetCurPageId();
@@ -924,41 +887,39 @@ bool SfxTabDialog::PrepareLeaveCurrentPage()
 
     if ( pPage )
     {
-        int nRet = SfxTabPage::LEAVE_PAGE;
-        if ( pSet )
+        DeactivateRC nRet = DeactivateRC::LeavePage;
+        if ( m_pSet )
         {
-            SfxItemSet aTmp( *pSet->GetPool(), pSet->GetRanges() );
+            SfxItemSet aTmp( *m_pSet->GetPool(), m_pSet->GetRanges() );
 
             if ( pPage->HasExchangeSupport() )
                 nRet = pPage->DeactivatePage( &aTmp );
             else
                 nRet = pPage->DeactivatePage( nullptr );
 
-            if ( ( SfxTabPage::LEAVE_PAGE & nRet ) == SfxTabPage::LEAVE_PAGE
+            if ( ( DeactivateRC::LeavePage & nRet ) == DeactivateRC::LeavePage
                  && aTmp.Count() )
             {
-                pExampleSet->Put( aTmp );
-                pOutSet->Put( aTmp );
+                m_pExampleSet->Put( aTmp );
+                m_pOutSet->Put( aTmp );
             }
         }
         else
             nRet = pPage->DeactivatePage( nullptr );
-        bEnd = nRet;
+        bEnd = nRet != DeactivateRC::KeepPage;
     }
 
     return bEnd;
 }
 
 
-
-
-IMPL_LINK_NOARG_TYPED(SfxTabDialog, UserHdl, Button*, void)
+IMPL_LINK_NOARG(SfxTabDialog, UserHdl, Button*, void)
 
 /*  [Description]
 
     Handler of the User-Buttons
     This calls the current page <SfxTabPage::DeactivatePage(SfxItemSet *)>.
-    returns this <SfxTabPage::LEAVE_PAGE> and  <SfxTabDialog::Ok()> is called.
+    returns this <DeactivateRC::LeavePage> and  <SfxTabDialog::Ok()> is called.
     Then the Dialog is ended with the Return value <SfxTabDialog::Ok()>
 */
 
@@ -976,8 +937,7 @@ IMPL_LINK_NOARG_TYPED(SfxTabDialog, UserHdl, Button*, void)
 }
 
 
-
-IMPL_LINK_NOARG_TYPED(SfxTabDialog, ResetHdl, Button*, void)
+IMPL_LINK_NOARG(SfxTabDialog, ResetHdl, Button*, void)
 
 /*  [Description]
 
@@ -988,22 +948,14 @@ IMPL_LINK_NOARG_TYPED(SfxTabDialog, ResetHdl, Button*, void)
 
 {
     const sal_uInt16 nId = m_pTabCtrl->GetCurPageId();
-    Data_Impl* pDataObject = Find( pImpl->aData, nId );
+    Data_Impl* pDataObject = Find( m_pImpl->aData, nId );
     DBG_ASSERT( pDataObject, "Id not known" );
 
-    if ( pDataObject->bOnDemand )
-    {
-        // CSet on AIS has problems here, thus separated
-        const SfxItemSet* pItemSet = &pDataObject->pTabPage->GetItemSet();
-        pDataObject->pTabPage->Reset( pItemSet );
-    }
-    else
-        pDataObject->pTabPage->Reset( pSet );
+    pDataObject->pTabPage->Reset( m_pSet );
 }
 
 
-
-IMPL_LINK_NOARG_TYPED(SfxTabDialog, BaseFmtHdl, Button*, void)
+IMPL_LINK_NOARG(SfxTabDialog, BaseFmtHdl, Button*, void)
 
 /*  [Description]
 
@@ -1013,20 +965,20 @@ IMPL_LINK_NOARG_TYPED(SfxTabDialog, BaseFmtHdl, Button*, void)
 */
 
 {
-    bStandardPushed = true;
+    m_bStandardPushed = true;
 
     const sal_uInt16 nId = m_pTabCtrl->GetCurPageId();
-    Data_Impl* pDataObject = Find( pImpl->aData, nId );
+    Data_Impl* pDataObject = Find( m_pImpl->aData, nId );
     DBG_ASSERT( pDataObject, "Id not known" );
 
     if ( pDataObject->fnGetRanges )
     {
-        if ( !pExampleSet )
-            pExampleSet = new SfxItemSet( *pSet );
+        if ( !m_pExampleSet )
+            m_pExampleSet = new SfxItemSet( *m_pSet );
 
-        const SfxItemPool* pPool = pSet->GetPool();
+        const SfxItemPool* pPool = m_pSet->GetPool();
         const sal_uInt16* pTmpRanges = (pDataObject->fnGetRanges)();
-        SfxItemSet aTmpSet( *pExampleSet );
+        SfxItemSet aTmpSet( *m_pExampleSet );
 
         while ( *pTmpRanges )
         {
@@ -1036,11 +988,11 @@ IMPL_LINK_NOARG_TYPED(SfxTabDialog, BaseFmtHdl, Button*, void)
             {
                 // Range which two identical values -> only set one Item
                 sal_uInt16 nWh = pPool->GetWhich( *pTmpRanges );
-                pExampleSet->ClearItem( nWh );
+                m_pExampleSet->ClearItem( nWh );
                 aTmpSet.ClearItem( nWh );
                 // At the Outset of InvalidateItem,
                 // so that the change takes effect
-                pOutSet->InvalidateItem( nWh );
+                m_pOutSet->InvalidateItem( nWh );
             }
             else
             {
@@ -1060,11 +1012,11 @@ IMPL_LINK_NOARG_TYPED(SfxTabDialog, BaseFmtHdl, Button*, void)
                 {
                     // Iterate over the Range and set the Items
                     sal_uInt16 nWh = pPool->GetWhich( nTmp );
-                    pExampleSet->ClearItem( nWh );
+                    m_pExampleSet->ClearItem( nWh );
                     aTmpSet.ClearItem( nWh );
                     // At the Outset of InvalidateItem,
                     // so that the change takes effect
-                    pOutSet->InvalidateItem( nWh );
+                    m_pOutSet->InvalidateItem( nWh );
                     nTmp++;
                 }
             }
@@ -1079,8 +1031,7 @@ IMPL_LINK_NOARG_TYPED(SfxTabDialog, BaseFmtHdl, Button*, void)
 }
 
 
-
-IMPL_LINK_TYPED( SfxTabDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
+IMPL_LINK( SfxTabDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
 
 /*  [Description]
 
@@ -1094,43 +1045,32 @@ IMPL_LINK_TYPED( SfxTabDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
 {
     sal_uInt16 nId = pTabCtrl->GetCurPageId();
 
-    DBG_ASSERT( pImpl->aData.size(), "no Pages registered" );
-    SfxGetpApp();
+    DBG_ASSERT( m_pImpl->aData.size(), "no Pages registered" );
 
-    // Tab Page schon da?
+    // Tab Page already there?
     VclPtr<SfxTabPage> pTabPage = dynamic_cast<SfxTabPage*> (pTabCtrl->GetTabPage( nId ));
-    Data_Impl* pDataObject = Find( pImpl->aData, nId );
+    Data_Impl* pDataObject = Find( m_pImpl->aData, nId );
 
-    //UUUU fallback to 1st page when requested one does not exist
+    // fallback to 1st page when requested one does not exist
     if(!pDataObject && pTabCtrl->GetPageCount())
     {
         pTabCtrl->SetCurPageId(pTabCtrl->GetPageId(0));
         nId = pTabCtrl->GetCurPageId();
         pTabPage = dynamic_cast< SfxTabPage* >(pTabCtrl->GetTabPage(nId));
-        pDataObject = Find(pImpl->aData, nId);
+        pDataObject = Find(m_pImpl->aData, nId);
     }
 
     if (!pDataObject)
     {
-        SAL_WARN("sfx.config", "Tab Page ID not known, this is pretty serious and needs investigation");
+        SAL_WARN("sfx.dialog", "Tab Page ID not known, this is pretty serious and needs investigation");
         return;
     }
 
     // Create TabPage if possible:
     if ( !pTabPage )
     {
-        const SfxItemSet* pTmpSet = nullptr;
-
-        if ( pSet )
-        {
-            if ( bItemsReset && pSet->GetParent() )
-                pTmpSet = pSet->GetParent();
-            else
-                pTmpSet = pSet;
-        }
-
-        if ( pTmpSet && !pDataObject->bOnDemand )
-            pTabPage = (pDataObject->fnCreatePage)( pTabCtrl, pTmpSet );
+        if ( m_pSet )
+            pTabPage = (pDataObject->fnCreatePage)( pTabCtrl, m_pSet );
         else
             pTabPage = (pDataObject->fnCreatePage)
                             ( pTabCtrl, CreateInputItemSet( nId ) );
@@ -1140,10 +1080,10 @@ IMPL_LINK_TYPED( SfxTabDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
         OUString sConfigId = OStringToOUString(pTabPage->GetConfigId(), RTL_TEXTENCODING_UTF8);
         if (sConfigId.isEmpty())
         {
-            SAL_WARN("sfx.config", "Tabpage needs to be converted to .ui format");
+            SAL_WARN("sfx.dialog", "Tabpage needs to be converted to .ui format");
             sConfigId = OUString::number(pDataObject->nId);
         }
-        SvtViewOptions aPageOpt(E_TABPAGE, sConfigId);
+        SvtViewOptions aPageOpt(EViewType::TabPage, sConfigId);
         OUString sUserData;
         Any aUserItem = aPageOpt.GetUserItem( USERITEM_NAME );
         OUString aTemp;
@@ -1162,29 +1102,25 @@ IMPL_LINK_TYPED( SfxTabDialog, ActivatePageHdl, TabControl *, pTabCtrl, void )
 
         PageCreated( nId, *pTabPage );
 
-        if ( pDataObject->bOnDemand )
-            pTabPage->Reset( &pTabPage->GetItemSet() );
-        else
-            pTabPage->Reset( pSet );
+        pTabPage->Reset( m_pSet );
 
         pTabCtrl->SetTabPage( nId, pTabPage );
     }
     else if ( pDataObject->bRefresh )
-        pTabPage->Reset( pSet );
+        pTabPage->Reset( m_pSet );
     pDataObject->bRefresh = false;
 
-    if ( pExampleSet )
-        pTabPage->ActivatePage( *pExampleSet );
+    if ( m_pExampleSet )
+        pTabPage->ActivatePage( *m_pExampleSet );
 
-    if ( pTabPage->IsReadOnly() || pImpl->bHideResetBtn )
+    if ( pTabPage->IsReadOnly() || m_pImpl->bHideResetBtn )
         m_pResetBtn->Hide();
     else
         m_pResetBtn->Show();
 }
 
 
-
-IMPL_LINK_TYPED( SfxTabDialog, DeactivatePageHdl, TabControl *, pTabCtrl, bool )
+IMPL_LINK( SfxTabDialog, DeactivatePageHdl, TabControl *, pTabCtrl, bool )
 
 /*  [Description]
 
@@ -1197,62 +1133,57 @@ IMPL_LINK_TYPED( SfxTabDialog, DeactivatePageHdl, TabControl *, pTabCtrl, bool )
 
 {
     sal_uInt16 nId = pTabCtrl->GetCurPageId();
-    SfxGetpApp();
     SfxTabPage *pPage = dynamic_cast<SfxTabPage*> (pTabCtrl->GetTabPage( nId ));
     DBG_ASSERT( pPage, "no active Page" );
     if (!pPage)
         return false;
 #ifdef DBG_UTIL
-    Data_Impl* pDataObject = Find( pImpl->aData, pTabCtrl->GetCurPageId() );
+    Data_Impl* pDataObject = Find( m_pImpl->aData, pTabCtrl->GetCurPageId() );
     DBG_ASSERT( pDataObject, "no Data structure for current page" );
-    if ( pPage->HasExchangeSupport() && pDataObject->bOnDemand )
-    {
-        SAL_INFO( "sfx.config", "Data exchange in ItemsOnDemand is not desired!" );
-    }
 #endif
 
-    int nRet = SfxTabPage::LEAVE_PAGE;
+    DeactivateRC nRet = DeactivateRC::LeavePage;
 
-    if ( !pExampleSet && pPage->HasExchangeSupport() && pSet )
-        pExampleSet = new SfxItemSet( *pSet->GetPool(), pSet->GetRanges() );
+    if ( !m_pExampleSet && pPage->HasExchangeSupport() && m_pSet )
+        m_pExampleSet = new SfxItemSet( *m_pSet->GetPool(), m_pSet->GetRanges() );
 
-    if ( pSet )
+    if ( m_pSet )
     {
-        SfxItemSet aTmp( *pSet->GetPool(), pSet->GetRanges() );
+        SfxItemSet aTmp( *m_pSet->GetPool(), m_pSet->GetRanges() );
 
         if ( pPage->HasExchangeSupport() )
             nRet = pPage->DeactivatePage( &aTmp );
         else
             nRet = pPage->DeactivatePage( nullptr );
-        if ( ( SfxTabPage::LEAVE_PAGE & nRet ) == SfxTabPage::LEAVE_PAGE &&
-             aTmp.Count() )
+        if ( ( DeactivateRC::LeavePage & nRet ) == DeactivateRC::LeavePage &&
+             aTmp.Count() && m_pExampleSet)
         {
-            pExampleSet->Put( aTmp );
-            pOutSet->Put( aTmp );
+            m_pExampleSet->Put( aTmp );
+            m_pOutSet->Put( aTmp );
         }
     }
     else
     {
         if ( pPage->HasExchangeSupport() ) //!!!
         {
-            if ( !pExampleSet )
+            if ( !m_pExampleSet )
             {
                 SfxItemPool* pPool = pPage->GetItemSet().GetPool();
-                pExampleSet =
+                m_pExampleSet =
                     new SfxItemSet( *pPool, GetInputRanges( *pPool ) );
             }
-            nRet = pPage->DeactivatePage( pExampleSet );
+            nRet = pPage->DeactivatePage( m_pExampleSet );
         }
         else
             nRet = pPage->DeactivatePage( nullptr );
     }
 
-    if ( nRet & SfxTabPage::REFRESH_SET )
+    if ( nRet & DeactivateRC::RefreshSet )
     {
         RefreshInputSet();
         // Flag all Pages as to be initialized as new
 
-        for ( SfxTabDlgData_Impl::const_iterator it = pImpl->aData.begin(); it != pImpl->aData.end(); ++it )
+        for ( SfxTabDlgData_Impl::const_iterator it = m_pImpl->aData.begin(); it != m_pImpl->aData.end(); ++it )
         {
             Data_Impl* pObj = *it;
 
@@ -1262,14 +1193,10 @@ IMPL_LINK_TYPED( SfxTabDialog, DeactivatePageHdl, TabControl *, pTabCtrl, bool )
                 pObj->bRefresh = false;
         }
     }
-    if ( nRet & SfxTabPage::LEAVE_PAGE )
-        return true;
-    else
-        return false;
+    return static_cast<bool>(nRet & DeactivateRC::LeavePage);
 }
 
 
-
 void SfxTabDialog::ShowPage( sal_uInt16 nId )
 
 /*  [Description]
@@ -1282,7 +1209,21 @@ void SfxTabDialog::ShowPage( sal_uInt16 nId )
     ActivatePageHdl( m_pTabCtrl );
 }
 
+OString SfxTabDialog::GetScreenshotId() const
+{
+    SfxTabPage *pActiveTabPage = GetCurTabPage();
+    OString aScreenshotId = GetHelpId();
 
+    if ( pActiveTabPage )
+    {
+        vcl::Window* pToplevelBox = pActiveTabPage->GetWindow( GetWindowType::FirstChild );
+
+        if ( pToplevelBox )
+            aScreenshotId = pToplevelBox->GetHelpId();
+    }
+
+    return aScreenshotId;
+}
 
 const sal_uInt16* SfxTabDialog::GetInputRanges( const SfxItemPool& rPool )
 
@@ -1305,17 +1246,17 @@ const sal_uInt16* SfxTabDialog::GetInputRanges( const SfxItemPool& rPool )
 */
 
 {
-    if ( pSet )
+    if ( m_pSet )
     {
         SAL_WARN( "sfx.dialog", "Set already exists!" );
-        return pSet->GetRanges();
+        return m_pSet->GetRanges();
     }
 
-    if ( pRanges )
-        return pRanges;
+    if ( m_pRanges )
+        return m_pRanges;
     std::vector<sal_uInt16> aUS;
 
-    for ( SfxTabDlgData_Impl::const_iterator it = pImpl->aData.begin(); it != pImpl->aData.end(); ++it )
+    for ( SfxTabDlgData_Impl::const_iterator it = m_pImpl->aData.begin(); it != m_pImpl->aData.end(); ++it )
     {
         Data_Impl* pDataObject = *it;
 
@@ -1344,14 +1285,13 @@ const sal_uInt16* SfxTabDialog::GetInputRanges( const SfxItemPool& rPool )
         std::sort( aUS.begin(), aUS.end() );
     }
 
-    pRanges = new sal_uInt16[aUS.size() + 1];
-    std::copy( aUS.begin(), aUS.end(), pRanges );
-    pRanges[aUS.size()] = 0;
-    return pRanges;
+    m_pRanges = new sal_uInt16[aUS.size() + 1];
+    std::copy( aUS.begin(), aUS.end(), m_pRanges );
+    m_pRanges[aUS.size()] = 0;
+    return m_pRanges;
 }
 
 
-
 void SfxTabDialog::SetInputSet( const SfxItemSet* pInSet )
 
 /*  [Description]
@@ -1360,15 +1300,68 @@ void SfxTabDialog::SetInputSet( const SfxItemSet* pInSet )
 */
 
 {
-    bool bSet = ( pSet != nullptr );
-    delete pSet;
-    pSet = pInSet ? new SfxItemSet(*pInSet) : nullptr;
+    bool bSet = ( m_pSet != nullptr );
+    delete m_pSet;
+    m_pSet = pInSet ? new SfxItemSet(*pInSet) : nullptr;
 
-    if (!bSet && !pExampleSet && !pOutSet && pSet)
+    if (!bSet && !m_pExampleSet && !m_pOutSet && m_pSet)
     {
-        pExampleSet = new SfxItemSet( *pSet );
-        pOutSet = new SfxItemSet( *pSet->GetPool(), pSet->GetRanges() );
+        m_pExampleSet = new SfxItemSet( *m_pSet );
+        m_pOutSet = new SfxItemSet( *m_pSet->GetPool(), m_pSet->GetRanges() );
     }
 }
 
+FactoryFunction SfxTabDialog::GetUITestFactory() const
+{
+    return SfxTabDialogUIObject::create;
+}
+
+std::vector<OString> SfxTabDialog::getAllPageUIXMLDescriptions() const
+{
+    std::vector<OString> aRetval;
+
+    for (SfxTabDlgData_Impl::const_iterator it = m_pImpl->aData.begin(); it != m_pImpl->aData.end(); ++it)
+    {
+        SfxTabPage* pCandidate = GetTabPage((*it)->nId);
+
+        if (!pCandidate)
+        {
+            // force SfxTabPage creation
+            const_cast<SfxTabDialog*>(this)->ShowPage((*it)->nId);
+            pCandidate = GetTabPage((*it)->nId);
+        }
+
+        if (pCandidate)
+        {
+            // use UIXMLDescription (without '.ui', with '/')
+            aRetval.push_back(pCandidate->getUIFile());
+        }
+    }
+
+    return aRetval;
+}
+
+bool SfxTabDialog::selectPageByUIXMLDescription(const OString& rUIXMLDescription)
+{
+    for (SfxTabDlgData_Impl::const_iterator it = m_pImpl->aData.begin(); it != m_pImpl->aData.end(); ++it)
+    {
+        SfxTabPage* pCandidate = (*it)->pTabPage;
+
+        if (!pCandidate)
+        {
+            // force SfxTabPage creation
+            ShowPage((*it)->nId);
+            pCandidate = GetTabPage((*it)->nId);
+        }
+
+        if (pCandidate && pCandidate->getUIFile() == rUIXMLDescription)
+        {
+            ShowPage((*it)->nId);
+            return true;
+        }
+    }
+
+    return false;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
