@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <config_features.h>
 
 #include <sfx2/docmacromode.hxx>
 #include <sfx2/signaturestate.hxx>
@@ -27,7 +28,6 @@
 #include <com/sun/star/task/DocumentMacroConfirmationRequest.hpp>
 #include <com/sun/star/task/InteractionClassification.hpp>
 #include <com/sun/star/security/DocumentDigitalSignatures.hpp>
-#include <com/sun/star/script/XLibraryQueryExecutable.hpp>
 
 #include <comphelper/processfactory.hxx>
 #include <framework/interaction.hxx>
@@ -38,78 +38,71 @@
 #include <tools/diagnose_ex.h>
 #include <tools/urlobj.hxx>
 
-//........................................................................
+
 namespace sfx2
 {
-//........................................................................
+
 
     using ::com::sun::star::uno::Reference;
     using ::com::sun::star::task::XInteractionHandler;
     using ::com::sun::star::uno::Any;
     using ::com::sun::star::uno::Sequence;
-    using ::com::sun::star::task::XInteractionContinuation;
-    using ::com::sun::star::task::XInteractionRequest;
     using ::com::sun::star::task::DocumentMacroConfirmationRequest;
     using ::com::sun::star::task::ErrorCodeRequest;
     using ::com::sun::star::uno::Exception;
     using ::com::sun::star::security::DocumentDigitalSignatures;
     using ::com::sun::star::security::XDocumentDigitalSignatures;
-    using ::com::sun::star::security::DocumentSignatureInformation;
     using ::com::sun::star::embed::XStorage;
-    using ::com::sun::star::task::InteractionClassification_QUERY;
     using ::com::sun::star::document::XEmbeddedScripts;
-    using ::com::sun::star::uno::UNO_SET_THROW;
     using ::com::sun::star::script::XLibraryContainer;
-    using ::com::sun::star::script::XLibraryQueryExecutable;
     using ::com::sun::star::container::XNameAccess;
     using ::com::sun::star::uno::UNO_QUERY_THROW;
-    using ::com::sun::star::uno::UNO_QUERY;
 
     namespace MacroExecMode = ::com::sun::star::document::MacroExecMode;
 
-    //====================================================================
+
     //= DocumentMacroMode_Data
-    //====================================================================
+
     struct DocumentMacroMode_Data
     {
         IMacroDocumentAccess&       m_rDocumentAccess;
-        sal_Bool                    m_bMacroDisabledMessageShown;
-        sal_Bool                    m_bDocMacroDisabledMessageShown;
+        bool                    m_bMacroDisabledMessageShown;
+        bool                    m_bDocMacroDisabledMessageShown;
 
-        DocumentMacroMode_Data( IMacroDocumentAccess& rDocumentAccess )
+        explicit DocumentMacroMode_Data( IMacroDocumentAccess& rDocumentAccess )
             :m_rDocumentAccess( rDocumentAccess )
-            ,m_bMacroDisabledMessageShown( sal_False )
-            ,m_bDocMacroDisabledMessageShown( sal_False )
+            ,m_bMacroDisabledMessageShown( false )
+            ,m_bDocMacroDisabledMessageShown( false )
         {
         }
     };
 
-    //====================================================================
+
     //= helper
-    //====================================================================
+
     namespace
     {
-        //................................................................
-        void lcl_showGeneralSfxErrorOnce( const Reference< XInteractionHandler >& rxHandler, const sal_Int32 nSfxErrorCode, sal_Bool& rbAlreadyShown )
+
+        void lcl_showGeneralSfxErrorOnce( const Reference< XInteractionHandler >& rxHandler, ErrCode nSfxErrorCode, bool& rbAlreadyShown )
         {
             if ( rbAlreadyShown )
                 return;
 
             ErrorCodeRequest aErrorCodeRequest;
-            aErrorCodeRequest.ErrCode = nSfxErrorCode;
+            aErrorCodeRequest.ErrCode = sal_uInt32(nSfxErrorCode);
 
-            SfxMedium::CallApproveHandler( rxHandler, makeAny( aErrorCodeRequest ), sal_False );
-            rbAlreadyShown = sal_True;
+            SfxMedium::CallApproveHandler( rxHandler, makeAny( aErrorCodeRequest ), false );
+            rbAlreadyShown = true;
         }
 
-        //................................................................
-        void lcl_showMacrosDisabledError( const Reference< XInteractionHandler >& rxHandler, sal_Bool& rbAlreadyShown )
+
+        void lcl_showMacrosDisabledError( const Reference< XInteractionHandler >& rxHandler, bool& rbAlreadyShown )
         {
             lcl_showGeneralSfxErrorOnce( rxHandler, ERRCODE_SFX_MACROS_SUPPORT_DISABLED, rbAlreadyShown );
         }
 
-        //................................................................
-        void lcl_showDocumentMacrosDisabledError( const Reference< XInteractionHandler >& rxHandler, sal_Bool& rbAlreadyShown )
+
+        void lcl_showDocumentMacrosDisabledError( const Reference< XInteractionHandler >& rxHandler, bool& rbAlreadyShown )
         {
 #ifdef MACOSX
             lcl_showGeneralSfxErrorOnce( rxHandler, ERRCODE_SFX_DOCUMENT_MACRO_DISABLED_MAC, rbAlreadyShown );
@@ -118,53 +111,42 @@ namespace sfx2
 #endif
         }
 
-        //................................................................
-        sal_Bool lcl_showMacroWarning( const Reference< XInteractionHandler >& rxHandler,
+
+        bool lcl_showMacroWarning( const Reference< XInteractionHandler >& rxHandler,
             const OUString& rDocumentLocation )
         {
             DocumentMacroConfirmationRequest aRequest;
             aRequest.DocumentURL = rDocumentLocation;
-            return SfxMedium::CallApproveHandler( rxHandler, makeAny( aRequest ), sal_True );
+            return SfxMedium::CallApproveHandler( rxHandler, makeAny( aRequest ), true );
         }
     }
 
-    //====================================================================
     //= DocumentMacroMode
-    //====================================================================
-    //--------------------------------------------------------------------
     DocumentMacroMode::DocumentMacroMode( IMacroDocumentAccess& rDocumentAccess )
-        :m_pData( new DocumentMacroMode_Data( rDocumentAccess ) )
+        :m_xData( new DocumentMacroMode_Data( rDocumentAccess ) )
     {
     }
 
-    //--------------------------------------------------------------------
-    DocumentMacroMode::~DocumentMacroMode()
+    bool DocumentMacroMode::allowMacroExecution()
     {
+        m_xData->m_rDocumentAccess.setCurrentMacroExecMode( MacroExecMode::ALWAYS_EXECUTE_NO_WARN );
+        return true;
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool DocumentMacroMode::allowMacroExecution()
+    bool DocumentMacroMode::disallowMacroExecution()
     {
-        m_pData->m_rDocumentAccess.setCurrentMacroExecMode( MacroExecMode::ALWAYS_EXECUTE_NO_WARN );
-        return sal_True;
+        m_xData->m_rDocumentAccess.setCurrentMacroExecMode( MacroExecMode::NEVER_EXECUTE );
+        return false;
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool DocumentMacroMode::disallowMacroExecution()
+    bool DocumentMacroMode::adjustMacroMode( const Reference< XInteractionHandler >& rxInteraction )
     {
-        m_pData->m_rDocumentAccess.setCurrentMacroExecMode( MacroExecMode::NEVER_EXECUTE );
-        return sal_False;
-    }
-
-    //--------------------------------------------------------------------
-    sal_Bool DocumentMacroMode::adjustMacroMode( const Reference< XInteractionHandler >& rxInteraction )
-    {
-        sal_uInt16 nMacroExecutionMode = m_pData->m_rDocumentAccess.getCurrentMacroExecMode();
+        sal_uInt16 nMacroExecutionMode = m_xData->m_rDocumentAccess.getCurrentMacroExecMode();
 
         if ( SvtSecurityOptions().IsMacroDisabled() )
         {
             // no macro should be executed at all
-            lcl_showMacrosDisabledError( rxInteraction, m_pData->m_bMacroDisabledMessageShown );
+            lcl_showMacrosDisabledError( rxInteraction, m_xData->m_bMacroDisabledMessageShown );
             return disallowMacroExecution();
         }
 
@@ -209,23 +191,21 @@ namespace sfx2
         }
 
         if ( nMacroExecutionMode == MacroExecMode::NEVER_EXECUTE )
-            return sal_False;
+            return false;
 
         if ( nMacroExecutionMode == MacroExecMode::ALWAYS_EXECUTE_NO_WARN )
-            return sal_True;
+            return true;
 
         try
         {
-            OUString sReferrer( m_pData->m_rDocumentAccess.getDocumentLocation() );
-
             // get document location from medium name and check whether it is a trusted one
-            // the service is created ohne document version, since it is not of interest here
+            // the service is created without document version, since it is not of interest here
             Reference< XDocumentDigitalSignatures > xSignatures(DocumentDigitalSignatures::createDefault(::comphelper::getProcessComponentContext()));
-            INetURLObject aURLReferer( sReferrer );
+            INetURLObject aURLReferer( m_xData->m_rDocumentAccess.getDocumentLocation() );
 
             OUString aLocation;
             if ( aURLReferer.removeSegment() )
-                aLocation = aURLReferer.GetMainURL( INetURLObject::NO_DECODE );
+                aLocation = aURLReferer.GetMainURL( INetURLObject::DecodeMechanism::NONE );
 
             if ( !aLocation.isEmpty() && xSignatures->isLocationTrusted( aLocation ) )
             {
@@ -235,7 +215,7 @@ namespace sfx2
             // at this point it is clear that the document is not in the secure location
             if ( nMacroExecutionMode == MacroExecMode::FROM_LIST_NO_WARN )
             {
-                lcl_showDocumentMacrosDisabledError( rxInteraction, m_pData->m_bDocMacroDisabledMessageShown );
+                lcl_showDocumentMacrosDisabledError( rxInteraction, m_xData->m_bDocMacroDisabledMessageShown );
                 return disallowMacroExecution();
             }
 
@@ -243,15 +223,11 @@ namespace sfx2
             if ( nMacroExecutionMode != MacroExecMode::FROM_LIST )
             {
                 // the trusted macro check will also retrieve the signature state ( small optimization )
-                sal_Bool bHasTrustedMacroSignature = m_pData->m_rDocumentAccess.hasTrustedScriptingSignature( nMacroExecutionMode != MacroExecMode::FROM_LIST_AND_SIGNED_NO_WARN );
+                bool bHasTrustedMacroSignature = m_xData->m_rDocumentAccess.hasTrustedScriptingSignature( nMacroExecutionMode != MacroExecMode::FROM_LIST_AND_SIGNED_NO_WARN );
 
-                sal_uInt16 nSignatureState = m_pData->m_rDocumentAccess.getScriptingSignatureState();
-                if ( nSignatureState == SIGNATURESTATE_SIGNATURES_BROKEN )
+                SignatureState nSignatureState = m_xData->m_rDocumentAccess.getScriptingSignatureState();
+                if ( nSignatureState == SignatureState::BROKEN )
                 {
-                    // the signature is broken, no macro execution
-                    if ( nMacroExecutionMode != MacroExecMode::FROM_LIST_AND_SIGNED_NO_WARN )
-                        m_pData->m_rDocumentAccess.showBrokenSignatureWarning( rxInteraction );
-
                     return disallowMacroExecution();
                 }
                 else if ( bHasTrustedMacroSignature )
@@ -259,8 +235,8 @@ namespace sfx2
                     // there is trusted macro signature, allow macro execution
                     return allowMacroExecution();
                 }
-                else if ( nSignatureState == SIGNATURESTATE_SIGNATURES_OK
-                       || nSignatureState == SIGNATURESTATE_SIGNATURES_NOTVALIDATED )
+                else if ( nSignatureState == SignatureState::OK
+                       || nSignatureState == SignatureState::NOTVALIDATED )
                 {
                     // there is valid signature, but it is not from the trusted author
                     return disallowMacroExecution();
@@ -273,7 +249,7 @@ namespace sfx2
                 )
             {
                 if  ( nMacroExecutionMode == MacroExecMode::FROM_LIST_AND_SIGNED_WARN )
-                    lcl_showDocumentMacrosDisabledError( rxInteraction, m_pData->m_bDocMacroDisabledMessageShown );
+                    lcl_showDocumentMacrosDisabledError( rxInteraction, m_xData->m_bDocMacroDisabledMessageShown );
 
                 return disallowMacroExecution();
             }
@@ -290,11 +266,11 @@ namespace sfx2
         }
 
         // conformation is required
-        sal_Bool bSecure = sal_False;
+        bool bSecure = false;
 
         if ( eAutoConfirm == eNoAutoConfirm )
         {
-            OUString sReferrer( m_pData->m_rDocumentAccess.getDocumentLocation() );
+            OUString sReferrer( m_xData->m_rDocumentAccess.getDocumentLocation() );
 
             OUString aSystemFileURL;
             if ( osl::FileBase::getSystemPathFromFileURL( sReferrer, aSystemFileURL ) == osl::FileBase::E_None )
@@ -308,16 +284,16 @@ namespace sfx2
         return ( bSecure ? allowMacroExecution() : disallowMacroExecution() );
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool DocumentMacroMode::isMacroExecutionDisallowed() const
+
+    bool DocumentMacroMode::isMacroExecutionDisallowed() const
     {
-        return m_pData->m_rDocumentAccess.getCurrentMacroExecMode() == MacroExecMode::NEVER_EXECUTE;
+        return m_xData->m_rDocumentAccess.getCurrentMacroExecMode() == MacroExecMode::NEVER_EXECUTE;
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool DocumentMacroMode::containerHasBasicMacros( const Reference< XLibraryContainer >& xContainer )
+
+    bool DocumentMacroMode::containerHasBasicMacros( const Reference< XLibraryContainer >& xContainer )
     {
-        sal_Bool bHasMacroLib = sal_False;
+        bool bHasMacroLib = false;
         try
         {
             if ( xContainer.is() )
@@ -327,28 +303,28 @@ namespace sfx2
                 // if there are libraries except the "Standard" library
                 // we assume that they are not empty (because they have been created by the user)
                 if ( !xContainer->hasElements() )
-                    bHasMacroLib = sal_False;
+                    bHasMacroLib = false;
                 else
                 {
-                    OUString aStdLibName( "Standard" );
-                    OUString aVBAProject( "VBAProject" );
+                    const OUString aStdLibName( "Standard" );
+                    const OUString aVBAProject( "VBAProject" );
                     Sequence< OUString > aElements = xContainer->getElementNames();
                     if ( aElements.getLength() )
                     {
                         sal_Int32 nElements = aElements.getLength();
                         for( sal_Int32 i = 0; i < nElements; ++i )
                         {
-                            OUString aElement = aElements[i];
+                            const OUString aElement = aElements[i];
                             if( aElement == aStdLibName || aElement == aVBAProject )
                             {
                                 Reference < XNameAccess > xLib;
                                 Any aAny = xContainer->getByName( aElement );
                                 aAny >>= xLib;
                                 if ( xLib.is() && xLib->hasElements() )
-                                    return sal_True;
+                                    return true;
                             }
                             else
-                                return sal_True;
+                                return true;
                         }
                     }
                 }
@@ -361,14 +337,14 @@ namespace sfx2
         return bHasMacroLib;
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool DocumentMacroMode::hasMacroLibrary() const
+
+    bool DocumentMacroMode::hasMacroLibrary() const
     {
-        sal_Bool bHasMacroLib = sal_False;
-#ifndef DISABLE_SCRIPTING
+        bool bHasMacroLib = false;
+#if HAVE_FEATURE_SCRIPTING
         try
         {
-            Reference< XEmbeddedScripts > xScripts( m_pData->m_rDocumentAccess.getEmbeddedDocumentScripts() );
+            Reference< XEmbeddedScripts > xScripts( m_xData->m_rDocumentAccess.getEmbeddedDocumentScripts() );
             Reference< XLibraryContainer > xContainer;
             if ( xScripts.is() )
                 xContainer.set( xScripts->getBasicLibraries(), UNO_QUERY_THROW );
@@ -383,10 +359,10 @@ namespace sfx2
         return bHasMacroLib;
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool DocumentMacroMode::storageHasMacros( const Reference< XStorage >& rxStorage )
+
+    bool DocumentMacroMode::storageHasMacros( const Reference< XStorage >& rxStorage )
     {
-        sal_Bool bHasMacros = sal_False;
+        bool bHasMacros = false;
         if ( rxStorage.is() )
         {
             try
@@ -410,10 +386,10 @@ namespace sfx2
         return bHasMacros;
     }
 
-    //--------------------------------------------------------------------
-    sal_Bool DocumentMacroMode::checkMacrosOnLoading( const Reference< XInteractionHandler >& rxInteraction )
+
+    bool DocumentMacroMode::checkMacrosOnLoading( const Reference< XInteractionHandler >& rxInteraction )
     {
-        sal_Bool bAllow = sal_False;
+        bool bAllow = false;
         if ( SvtSecurityOptions().IsMacroDisabled() )
         {
             // no macro should be executed at all
@@ -421,7 +397,7 @@ namespace sfx2
         }
         else
         {
-            if ( m_pData->m_rDocumentAccess.documentStorageHasMacros() || hasMacroLibrary() )
+            if ( m_xData->m_rDocumentAccess.documentStorageHasMacros() || hasMacroLibrary() )
             {
                 bAllow = adjustMacroMode( rxInteraction );
             }
@@ -434,8 +410,8 @@ namespace sfx2
         return bAllow;
     }
 
-//........................................................................
+
 } // namespace sfx2
-//........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
