@@ -277,16 +277,16 @@ uno::Sequence< beans::PropertyValue > SAL_CALL SfxPrintHelper::getPrinter()
     uno::Sequence< beans::PropertyValue > aPrinter(8);
 
     aPrinter.getArray()[7].Name = "CanSetPaperSize";
-    aPrinter.getArray()[7].Value <<= ( pPrinter->HasSupport( PrinterSupport::SetPaperSize ) );
+    aPrinter.getArray()[7].Value <<= pPrinter->HasSupport( PrinterSupport::SetPaperSize );
 
     aPrinter.getArray()[6].Name = "CanSetPaperFormat";
-    aPrinter.getArray()[6].Value <<= ( pPrinter->HasSupport( PrinterSupport::SetPaper ) );
+    aPrinter.getArray()[6].Value <<= pPrinter->HasSupport( PrinterSupport::SetPaper );
 
     aPrinter.getArray()[5].Name = "CanSetPaperOrientation";
-    aPrinter.getArray()[5].Value <<= ( pPrinter->HasSupport( PrinterSupport::SetOrientation ) );
+    aPrinter.getArray()[5].Value <<= pPrinter->HasSupport( PrinterSupport::SetOrientation );
 
     aPrinter.getArray()[4].Name = "IsBusy";
-    aPrinter.getArray()[4].Value <<= ( pPrinter->IsPrinting() );
+    aPrinter.getArray()[4].Value <<= pPrinter->IsPrinting();
 
     aPrinter.getArray()[3].Name = "PaperSize";
     awt::Size aSize = impl_Size_Object2Struct(pPrinter->GetPaperSize() );
@@ -345,7 +345,7 @@ void SfxPrintHelper::impl_setPrinter(const uno::Sequence< beans::PropertyValue >
 
             if ( aPrinterName != pPrinter->GetName() )
             {
-                pPrinter = VclPtr<SfxPrinter>::Create( pPrinter->GetOptions().Clone(), aPrinterName );
+                pPrinter = VclPtr<SfxPrinter>::Create( std::unique_ptr<SfxItemSet>(pPrinter->GetOptions().Clone()), aPrinterName );
                 nChangeFlags = SfxPrinterChangeFlags::PRINTER;
             }
             break;
@@ -404,10 +404,7 @@ void SfxPrintHelper::impl_setPrinter(const uno::Sequence< beans::PropertyValue >
             {
                 throw css::lang::IllegalArgumentException();
             }
-            else
-            {
-                aSetPaperSize = impl_Size_Struct2Object(aTempSize);
-            }
+            aSetPaperSize = impl_Size_Struct2Object(aTempSize);
         }
 
         // PrinterTray-Property
@@ -435,7 +432,7 @@ void SfxPrintHelper::impl_setPrinter(const uno::Sequence< beans::PropertyValue >
     {
         // Bug 56929 - MapMode of 100mm which recalculated when
         // the device is set. Additionally only set if they were really changed.
-        aSetPaperSize = pPrinter->LogicToPixel( aSetPaperSize, MapUnit::Map100thMM );
+        aSetPaperSize = pPrinter->LogicToPixel(aSetPaperSize, MapMode(MapUnit::Map100thMM));
         if( aSetPaperSize != pPrinter->GetPaperSizePixel() )
         {
             pPrinter->SetPaperSizeUser( pPrinter->PixelToLogic( aSetPaperSize ) );
@@ -539,12 +536,12 @@ class ImplUCBPrintWatcher : public ::osl::Thread
                 if (aSplitter.removeSegment() && !sFileName.isEmpty())
                 {
                     ::ucbhelper::Content aSource(
-                            OUString((*ppTempFile)->GetURL()),
+                            (*ppTempFile)->GetURL(),
                             css::uno::Reference< css::ucb::XCommandEnvironment >(),
                             comphelper::getProcessComponentContext());
 
                     ::ucbhelper::Content aTarget(
-                            OUString(aSplitter.GetMainURL(INetURLObject::DecodeMechanism::NONE)),
+                            aSplitter.GetMainURL(INetURLObject::DecodeMechanism::NONE),
                             css::uno::Reference< css::ucb::XCommandEnvironment >(),
                             comphelper::getProcessComponentContext());
 
@@ -640,7 +637,7 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
                 // reasons. Otherwhise we break to much external code ...
                 // We try to convert it to a file URL. If its possible
                 // we put the system path to the item set and let vcl work with it.
-                // No ucb or thread will be necessary then. In case it couldnt be
+                // No ucb or thread will be necessary then. In case it couldn't be
                 // converted it's not an URL nor a system path. Then we can't accept
                 // this parameter and have to throw an exception.
                 const OUString& sSystemPath(sTemp);
@@ -687,7 +684,7 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
 
                 //FIXME: does it work?
                 aCheckedArgs[nProps].Name = "LocalFileName";
-                aCheckedArgs[nProps++].Value <<= OUString( pUCBPrintTempFile->GetFileName() );
+                aCheckedArgs[nProps++].Value <<= pUCBPrintTempFile->GetFileName();
                 sUcbUrl = sURL;
             }
         }
@@ -698,7 +695,6 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
             sal_Int32 nCopies = 0;
             if ( !( rProp.Value >>= nCopies ) )
                 throw css::lang::IllegalArgumentException();
-
             aCheckedArgs[nProps].Name = rProp.Name;
             aCheckedArgs[nProps++].Value <<= nCopies;
         }
@@ -708,26 +704,20 @@ void SAL_CALL SfxPrintHelper::print(const uno::Sequence< beans::PropertyValue >&
         else if ( rProp.Name == "Collate" || rProp.Name == "Sort" )
         {
             bool bTemp;
-            if ( rProp.Value >>= bTemp )
-            {
-                aCheckedArgs[nProps].Name = "Collate";
-                aCheckedArgs[nProps++].Value <<= bTemp;
-            }
-            else
+            if ( !(rProp.Value >>= bTemp) )
                 throw css::lang::IllegalArgumentException();
+            aCheckedArgs[nProps].Name = "Collate";
+            aCheckedArgs[nProps++].Value <<= bTemp;
         }
 
         // Pages-Property
         else if ( rProp.Name == "Pages" )
         {
             OUString sTemp;
-            if( rProp.Value >>= sTemp )
-            {
-                aCheckedArgs[nProps].Name = rProp.Name;
-                aCheckedArgs[nProps++].Value <<= sTemp;
-            }
-            else
+            if( !(rProp.Value >>= sTemp) )
                 throw css::lang::IllegalArgumentException();
+            aCheckedArgs[nProps].Name = rProp.Name;
+            aCheckedArgs[nProps++].Value <<= sTemp;
         }
 
         // MonitorVisible
