@@ -20,9 +20,11 @@
 #include <sfx2/sidebar/ResourceManager.hxx>
 #include <sfx2/sidebar/Tools.hxx>
 
+#include <officecfg/Office/UI/Sidebar.hxx>
 #include <unotools/confignode.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/namedvaluecollection.hxx>
+#include <comphelper/sequence.hxx>
 #include <comphelper/types.hxx>
 
 #include <rtl/ustrbuf.hxx>
@@ -98,6 +100,7 @@ ResourceManager::ResourceManager()
 {
     ReadDeckList();
     ReadPanelList();
+    ReadLastActive();
 }
 
 ResourceManager::~ResourceManager()
@@ -133,7 +136,7 @@ std::shared_ptr<DeckDescriptor> ResourceManager::ImplGetDeckDescriptor(const OUS
 
         if (rDeck->mbExperimental && !maMiscOptions.IsExperimentalMode())
             continue;
-        if (rDeck->msId.equals(rsDeckId))
+        if (rDeck->msId == rsDeckId)
             return rDeck;
     }
     return nullptr;
@@ -151,7 +154,7 @@ std::shared_ptr<PanelDescriptor> ResourceManager::ImplGetPanelDescriptor(const O
     {
         const std::shared_ptr<PanelDescriptor>& rPanel = *iPanel;
 
-        if (rPanel->msId.equals(rsPanelId))
+        if (rPanel->msId == rsPanelId)
             return rPanel;
     }
     return nullptr;
@@ -190,9 +193,7 @@ const ResourceManager::DeckContextDescriptorContainer& ResourceManager::GetMatch
                                              && rDeckDescriptor.mbIsEnabled;
 
 
-        aOrderedIds.insert(::std::multimap<sal_Int32,DeckContextDescriptor>::value_type(
-                rDeckDescriptor.mnOrderIndex,
-                aDeckContextDescriptor));
+        aOrderedIds.emplace(rDeckDescriptor.mnOrderIndex, aDeckContextDescriptor);
     }
 
     std::multimap<sal_Int32,DeckContextDescriptor>::const_iterator iId;
@@ -221,7 +222,7 @@ const ResourceManager::PanelContextDescriptorContainer& ResourceManager::GetMatc
         const PanelDescriptor& rPanelDescriptor (*rPanel);
         if (rPanelDescriptor.mbExperimental && !maMiscOptions.IsExperimentalMode())
             continue;
-        if ( ! rPanelDescriptor.msDeckId.equals(sDeckId))
+        if ( rPanelDescriptor.msDeckId != sDeckId )
             continue;
 
         const ContextList::Entry* pEntry = rPanelDescriptor.maContextList.GetMatch(rContext);
@@ -233,9 +234,7 @@ const ResourceManager::PanelContextDescriptorContainer& ResourceManager::GetMatc
         aPanelContextDescriptor.msMenuCommand = pEntry->msMenuCommand;
         aPanelContextDescriptor.mbIsInitiallyVisible = pEntry->mbIsInitiallyVisible;
         aPanelContextDescriptor.mbShowForReadOnlyDocuments = rPanelDescriptor.mbShowForReadOnlyDocuments;
-        aOrderedIds.insert(std::multimap<sal_Int32, PanelContextDescriptor>::value_type(
-                                                    rPanelDescriptor.mnOrderIndex,
-                                                    aPanelContextDescriptor));
+        aOrderedIds.emplace(rPanelDescriptor.mnOrderIndex, aPanelContextDescriptor);
     }
 
     std::multimap<sal_Int32,PanelContextDescriptor>::const_iterator iId;
@@ -247,11 +246,24 @@ const ResourceManager::PanelContextDescriptorContainer& ResourceManager::GetMatc
     return rPanelIds;
 }
 
+const OUString& ResourceManager::GetLastActiveDeck( const Context& rContext )
+{
+    if( maLastActiveDecks.find( rContext.msApplication ) == maLastActiveDecks.end())
+        return maLastActiveDecks["any"];
+    else
+        return maLastActiveDecks[rContext.msApplication];
+}
+
+void ResourceManager::SetLastActiveDeck( const Context& rContext, const OUString &rsDeckId )
+{
+    maLastActiveDecks[rContext.msApplication] = rsDeckId;
+}
+
 void ResourceManager::ReadDeckList()
 {
     const utl::OConfigurationTreeRoot aDeckRootNode(
                                         comphelper::getProcessComponentContext(),
-                                        OUString("org.openoffice.Office.UI.Sidebar/Content/DeckList"),
+                                        "org.openoffice.Office.UI.Sidebar/Content/DeckList",
                                         false);
     if (!aDeckRootNode.isValid())
         return;
@@ -311,7 +323,7 @@ void ResourceManager::SaveDeckSettings(const DeckDescriptor* pDeckDesc)
 {
     const utl::OConfigurationTreeRoot aDeckRootNode(
                                     comphelper::getProcessComponentContext(),
-                                    OUString("org.openoffice.Office.UI.Sidebar/Content/DeckList"),
+                                    "org.openoffice.Office.UI.Sidebar/Content/DeckList",
                                     true);
     if (!aDeckRootNode.isValid())
         return;
@@ -322,17 +334,35 @@ void ResourceManager::SaveDeckSettings(const DeckDescriptor* pDeckDesc)
 
     utl::OConfigurationNode aDeckNode (aDeckRootNode.openNode(pDeckDesc->msNodeName));
 
-    aDeckNode.setNodeValue("Title", makeAny(pDeckDesc->msTitle));
-    aDeckNode.setNodeValue("OrderIndex", makeAny(pDeckDesc->mnOrderIndex));
-    aDeckNode.setNodeValue("ContextList", makeAny( sContextList ));
+    css::uno::Any aTitle(makeAny(pDeckDesc->msTitle));
+    css::uno::Any aOrder(makeAny(pDeckDesc->mnOrderIndex));
+    css::uno::Any aContextList(makeAny(sContextList));
 
-    aDeckRootNode.commit();
+    bool bChanged = false;
+    if (aTitle != aDeckNode.getNodeValue("Title"))
+    {
+        aDeckNode.setNodeValue("Title", aTitle);
+        bChanged = true;
+    }
+    if (aOrder != aDeckNode.getNodeValue("OrderIndex"))
+    {
+        aDeckNode.setNodeValue("OrderIndex", aOrder);
+        bChanged = true;
+    }
+    if (aContextList != aDeckNode.getNodeValue("ContextList"))
+    {
+        aDeckNode.setNodeValue("ContextList", aContextList);
+        bChanged = true;
+    }
+
+    if (bChanged)
+        aDeckRootNode.commit();
 
     // save panel settings
 
     const utl::OConfigurationTreeRoot aPanelRootNode(
                                     comphelper::getProcessComponentContext(),
-                                    OUString("org.openoffice.Office.UI.Sidebar/Content/PanelList"),
+                                    "org.openoffice.Office.UI.Sidebar/Content/PanelList",
                                     true);
 
     if (!aPanelRootNode.isValid())
@@ -343,10 +373,11 @@ void ResourceManager::SaveDeckSettings(const DeckDescriptor* pDeckDesc)
 
     SharedPanelContainer rPanels = pDeckDesc->mpDeck->GetPanels();
 
+    bChanged = false;
     for ( SharedPanelContainer::iterator iPanel(rPanels.begin()), iEnd(rPanels.end());
               iPanel!=iEnd; ++iPanel)
     {
-        Panel* aPanel = *iPanel;
+        VclPtr<Panel> const & aPanel = *iPanel;
         OUString panelId = aPanel->GetId();
         std::shared_ptr<PanelDescriptor> xPanelDesc = GetPanelDescriptor(panelId);
 
@@ -354,13 +385,43 @@ void ResourceManager::SaveDeckSettings(const DeckDescriptor* pDeckDesc)
 
         utl::OConfigurationNode aPanelNode (aPanelRootNode.openNode(xPanelDesc->msNodeName));
 
-        aPanelNode.setNodeValue("Title", makeAny(xPanelDesc->msTitle));
-        aPanelNode.setNodeValue("OrderIndex", makeAny(xPanelDesc->mnOrderIndex));
-        aPanelNode.setNodeValue("ContextList", makeAny( sPanelContextList ));
+        aTitle <<= xPanelDesc->msTitle;
+        aOrder <<= xPanelDesc->mnOrderIndex;
+        aContextList <<= sPanelContextList;
 
+        if (aTitle != aPanelNode.getNodeValue("Title"))
+        {
+            aPanelNode.setNodeValue("Title", aTitle);
+            bChanged = true;
+        }
+        if (aOrder != aPanelNode.getNodeValue("OrderIndex"))
+        {
+            aPanelNode.setNodeValue("OrderIndex", aOrder);
+            bChanged = true;
+        }
+        if (aContextList != aPanelNode.getNodeValue("ContextList"))
+        {
+            aPanelNode.setNodeValue("ContextList", aContextList);
+            bChanged = true;
+        }
     }
 
-     aPanelRootNode.commit();
+    if (bChanged)
+        aPanelRootNode.commit();
+}
+
+void ResourceManager::SaveLastActiveDeck(const Context& rContext, const OUString& rActiveDeck)
+{
+    maLastActiveDecks[rContext.msApplication] = rActiveDeck;
+
+    std::set<OUString> aLastActiveDecks;
+    for ( auto const & rEntry : maLastActiveDecks )
+        aLastActiveDecks.insert( rEntry.first + "," +  rEntry.second);
+
+    std::shared_ptr<comphelper::ConfigurationChanges> cfgWriter( comphelper::ConfigurationChanges::create() );
+
+    officecfg::Office::UI::Sidebar::Content::LastActiveDeck::set(comphelper::containerToSequence(aLastActiveDecks), cfgWriter);
+    cfgWriter->commit();
 
 }
 
@@ -368,7 +429,7 @@ void ResourceManager::ReadPanelList()
 {
     const utl::OConfigurationTreeRoot aPanelRootNode(
                                         comphelper::getProcessComponentContext(),
-                                        OUString("org.openoffice.Office.UI.Sidebar/Content/PanelList"),
+                                        "org.openoffice.Office.UI.Sidebar/Content/PanelList",
                                         false);
     if (!aPanelRootNode.isValid())
         return;
@@ -405,6 +466,29 @@ void ResourceManager::ReadPanelList()
     }
 }
 
+void ResourceManager::ReadLastActive()
+{
+    Sequence <OUString> aLastActive (officecfg::Office::UI::Sidebar::Content::LastActiveDeck::get());
+
+    for (auto& rDeckInfo : aLastActive)
+    {
+        sal_Int32 nCharIdx = rDeckInfo.lastIndexOf(',');
+        if ( nCharIdx <= 0 || (nCharIdx == rDeckInfo.getLength() - 1) )
+        {
+            SAL_WARN("sfx.sidebar", "Expecting 2 values separated by comma");
+            continue;
+        }
+
+        const OUString sApplicationName = rDeckInfo.copy( 0, nCharIdx );
+        vcl::EnumContext::Application eApplication (vcl::EnumContext::GetApplicationEnum(sApplicationName));
+        const OUString sLastUsed = rDeckInfo.copy( nCharIdx + 1 );
+
+        // guard against garbage in place of application
+        if (eApplication != vcl::EnumContext::Application::NONE)
+            maLastActiveDecks.insert( std::make_pair(sApplicationName, sLastUsed ) );
+    }
+}
+
 void ResourceManager::ReadContextList (
                         const utl::OConfigurationNode& rParentNode,
                         ContextList& rContextList,
@@ -466,42 +550,42 @@ void ResourceManager::ReadContextList (
         // application name may result in more than one value (eg
         // DrawImpress will result in two enums, one for Draw and one
         // for Impress).
-        std::vector<EnumContext::Application> aApplications;
-        EnumContext::Application eApplication (EnumContext::GetApplicationEnum(sApplicationName));
+        std::vector<vcl::EnumContext::Application> aApplications;
+        vcl::EnumContext::Application eApplication (vcl::EnumContext::GetApplicationEnum(sApplicationName));
 
-        if (eApplication == EnumContext::Application_None
-            && !sApplicationName.equals(EnumContext::GetApplicationName(EnumContext::Application_None)))
+        if (eApplication == vcl::EnumContext::Application::NONE
+            && sApplicationName != vcl::EnumContext::GetApplicationName(vcl::EnumContext::Application::NONE))
         {
             // Handle some special names: abbreviations that make
             // context descriptions more readable.
             if (sApplicationName == "Writer")
-                aApplications.push_back(EnumContext::Application_Writer);
+                aApplications.push_back(vcl::EnumContext::Application::Writer);
             else if (sApplicationName == "Calc")
-                aApplications.push_back(EnumContext::Application_Calc);
+                aApplications.push_back(vcl::EnumContext::Application::Calc);
             else if (sApplicationName == "Draw")
-                aApplications.push_back(EnumContext::Application_Draw);
+                aApplications.push_back(vcl::EnumContext::Application::Draw);
             else if (sApplicationName == "Impress")
-                aApplications.push_back(EnumContext::Application_Impress);
+                aApplications.push_back(vcl::EnumContext::Application::Impress);
             else if (sApplicationName == "Chart")
-                aApplications.push_back(EnumContext::Application_Chart);
+                aApplications.push_back(vcl::EnumContext::Application::Chart);
             else if (sApplicationName == "DrawImpress")
             {
                 // A special case among the special names:  it is
                 // common to use the same context descriptions for
                 // both Draw and Impress.  This special case helps to
                 // avoid duplication in the .xcu file.
-                aApplications.push_back(EnumContext::Application_Draw);
-                aApplications.push_back(EnumContext::Application_Impress);
+                aApplications.push_back(vcl::EnumContext::Application::Draw);
+                aApplications.push_back(vcl::EnumContext::Application::Impress);
             }
             else if (sApplicationName == "WriterVariants")
             {
                 // Another special case for all Writer variants.
-                aApplications.push_back(EnumContext::Application_Writer);
-                aApplications.push_back(EnumContext::Application_WriterGlobal);
-                aApplications.push_back(EnumContext::Application_WriterWeb);
-                aApplications.push_back(EnumContext::Application_WriterXML);
-                aApplications.push_back(EnumContext::Application_WriterForm);
-                aApplications.push_back(EnumContext::Application_WriterReport);
+                aApplications.push_back(vcl::EnumContext::Application::Writer);
+                aApplications.push_back(vcl::EnumContext::Application::WriterGlobal);
+                aApplications.push_back(vcl::EnumContext::Application::WriterWeb);
+                aApplications.push_back(vcl::EnumContext::Application::WriterXML);
+                aApplications.push_back(vcl::EnumContext::Application::WriterForm);
+                aApplications.push_back(vcl::EnumContext::Application::WriterReport);
             }
             else
             {
@@ -516,8 +600,8 @@ void ResourceManager::ReadContextList (
         }
 
         // Setup the actual context enum.
-        const EnumContext::Context eContext (EnumContext::GetContextEnum(sContextName));
-        if (eContext == EnumContext::Context_Unknown)
+        const vcl::EnumContext::Context eContext (vcl::EnumContext::GetContextEnum(sContextName));
+        if (eContext == vcl::EnumContext::Context::Unknown)
         {
             SAL_WARN("sfx.sidebar", "context name " << sContextName << " not recognized");
             continue;
@@ -538,15 +622,15 @@ void ResourceManager::ReadContextList (
 
 
         // Add context descriptors.
-        std::vector<EnumContext::Application>::const_iterator iApplication;
+        std::vector<vcl::EnumContext::Application>::const_iterator iApplication;
         for (iApplication = aApplications.begin(); iApplication != aApplications.end(); ++iApplication)
         {
-            if (*iApplication != EnumContext::Application_None)
+            if (*iApplication != vcl::EnumContext::Application::NONE)
             {
                 rContextList.AddContextDescription(
                     Context(
-                        EnumContext::GetApplicationName(*iApplication),
-                        EnumContext::GetContextName(eContext)),
+                        vcl::EnumContext::GetApplicationName(*iApplication),
+                        vcl::EnumContext::GetContextName(eContext)),
                     bIsInitiallyVisible,
                     sMenuCommand);
             }
@@ -607,7 +691,7 @@ void ResourceManager::ReadLegacyAddons (const Reference<frame::XController>& rxC
         rDeckDescriptor.msHelpText = rDeckDescriptor.msTitle;
         rDeckDescriptor.mbIsEnabled = true;
         rDeckDescriptor.mnOrderIndex = 100000 + nReadIndex;
-        rDeckDescriptor.maContextList.AddContextDescription(Context(sModuleName, OUString("any")), true, OUString());
+        rDeckDescriptor.maContextList.AddContextDescription(Context(sModuleName, "any"), true, OUString());
 
         maPanels.push_back(std::make_shared<PanelDescriptor>());
         PanelDescriptor& rPanelDescriptor(*maPanels.back());
@@ -622,7 +706,7 @@ void ResourceManager::ReadLegacyAddons (const Reference<frame::XController>& rxC
         rPanelDescriptor.mnOrderIndex = 100000 + nReadIndex;
         rPanelDescriptor.mbShowForReadOnlyDocuments = false;
         rPanelDescriptor.mbWantsCanvas = false;
-        rPanelDescriptor.maContextList.AddContextDescription(Context(sModuleName, OUString("any")), true, OUString());
+        rPanelDescriptor.maContextList.AddContextDescription(Context(sModuleName, "any"), true, OUString());
     }
 }
 
@@ -636,7 +720,7 @@ void ResourceManager::StorePanelExpansionState (
     {
         const std::shared_ptr<PanelDescriptor>& rPanel = *iPanel;
 
-        if (rPanel->msId.equals(rsPanelId))
+        if (rPanel->msId == rsPanelId)
         {
             ContextList::Entry* pEntry(rPanel->maContextList.GetMatch(rContext));
             if (pEntry != nullptr)
@@ -719,7 +803,10 @@ void ResourceManager::UpdateModel(const css::uno::Reference<css::frame::XModel>&
         for (SharedPanelContainer::const_iterator it = rContainer.begin(); it != rContainer.end(); ++it)
         {
             css::uno::Reference<css::ui::XUpdateModel> xPanel((*it)->GetPanelComponent(), css::uno::UNO_QUERY);
-            xPanel->updateModel(xModel);
+            if (xPanel.is()) // tdf#108814 interface is optional
+            {
+                xPanel->updateModel(xModel);
+            }
         }
     }
 }
