@@ -17,16 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "global.hxx"
+#include <global.hxx>
 #include "classfactory.hxx"
-#include "infotips.hxx"
-#include "propsheets.hxx"
-#include "columninfo.hxx"
-#ifdef __MINGW32__
-#include <algorithm>
-#endif
-#include "thumbviewer.hxx"
-#include "shlxthdl.hxx"
+#include <infotips.hxx>
+#include <propsheets.hxx>
+#include <columninfo.hxx>
+#include <thumbviewer.hxx>
+#include <shlxthdl.hxx>
 
 
 long CClassFactory::s_ServerLocks = 0;
@@ -51,7 +48,7 @@ CClassFactory::~CClassFactory()
 
 HRESULT STDMETHODCALLTYPE CClassFactory::QueryInterface(REFIID riid, void __RPC_FAR *__RPC_FAR *ppvObject)
 {
-    *ppvObject = 0;
+    *ppvObject = nullptr;
 
     if (IID_IUnknown == riid || IID_IClassFactory == riid)
     {
@@ -90,10 +87,10 @@ HRESULT STDMETHODCALLTYPE CClassFactory::CreateInstance(
             REFIID riid,
             void __RPC_FAR *__RPC_FAR *ppvObject)
 {
-    if ((pUnkOuter != NULL))
+    if (pUnkOuter != nullptr)
         return CLASS_E_NOAGGREGATION;
 
-    IUnknown* pUnk = 0;
+    IUnknown* pUnk = nullptr;
 
     if (CLSID_PROPERTYSHEET_HANDLER == m_Clsid)
         pUnk = static_cast<IShellExtInit*>(new CPropertySheet());
@@ -107,7 +104,7 @@ HRESULT STDMETHODCALLTYPE CClassFactory::CreateInstance(
     else if (CLSID_THUMBVIEWER_HANDLER == m_Clsid)
         pUnk = static_cast<IExtractImage*>(new CThumbviewer());
 
-    if (0 == pUnk)
+    if (nullptr == pUnk)
     {
         return E_OUTOFMEMORY;
     }
