@@ -17,25 +17,23 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "config.hxx"
-#include "global.hxx"
+#include <config.hxx>
+#include <global.hxx>
 
-#include "propsheets.hxx"
-#include "utilities.hxx"
-#include "resource.h"
+#include <propsheets.hxx>
+#include <utilities.hxx>
+#include <resource.h>
 #include "listviewbuilder.hxx"
 
 #if defined _MSC_VER
 #pragma warning(push, 1)
 #endif
 #include <shellapi.h>
-#ifdef _WIN32_WINNT_WINBLUE
-#include <VersionHelpers.h>
-#endif
 #if defined _MSC_VER
 #pragma warning(pop)
 #endif
 
+#include <memory>
 #include <string>
 #include <vector>
 #include <utility>
@@ -56,14 +54,14 @@
 CPropertySheet::CPropertySheet(long RefCnt) :
     m_RefCnt(RefCnt)
 {
-    OutputDebugStringFormat("CPropertySheet::CTor [%d], [%d]", m_RefCnt, g_DllRefCnt );
+    OutputDebugStringFormatW(L"CPropertySheet::CTor [%d], [%d]", m_RefCnt, g_DllRefCnt );
     InterlockedIncrement(&g_DllRefCnt);
 }
 
 
 CPropertySheet::~CPropertySheet()
 {
-    OutputDebugStringFormat("CPropertySheet::DTor [%d], [%d]", m_RefCnt, g_DllRefCnt );
+    OutputDebugStringFormatW(L"CPropertySheet::DTor [%d], [%d]", m_RefCnt, g_DllRefCnt );
     InterlockedDecrement(&g_DllRefCnt);
 }
 
@@ -74,9 +72,9 @@ CPropertySheet::~CPropertySheet()
 HRESULT STDMETHODCALLTYPE CPropertySheet::QueryInterface(
     REFIID riid, void __RPC_FAR *__RPC_FAR *ppvObject)
 {
-    *ppvObject = 0;
+    *ppvObject = nullptr;
 
-    IUnknown* pUnk = 0;
+    IUnknown* pUnk = nullptr;
     if (IID_IUnknown == riid || IID_IShellExtInit == riid)
     {
         pUnk = static_cast<IShellExtInit*>(this);
@@ -98,14 +96,14 @@ HRESULT STDMETHODCALLTYPE CPropertySheet::QueryInterface(
 
 ULONG STDMETHODCALLTYPE CPropertySheet::AddRef()
 {
-    OutputDebugStringFormat("CPropertySheet::AddRef [%d]", m_RefCnt );
+    OutputDebugStringFormatW(L"CPropertySheet::AddRef [%d]", m_RefCnt );
     return InterlockedIncrement(&m_RefCnt);
 }
 
 
 ULONG STDMETHODCALLTYPE CPropertySheet::Release()
 {
-    OutputDebugStringFormat("CPropertySheet::Release [%d]", m_RefCnt );
+    OutputDebugStringFormatW(L"CPropertySheet::Release [%d]", m_RefCnt );
     long refcnt = InterlockedDecrement(&m_RefCnt);
 
     if (0 == refcnt)
@@ -124,35 +122,33 @@ HRESULT STDMETHODCALLTYPE CPropertySheet::Initialize(
     InitCommonControls();
 
     STGMEDIUM medium;
-    FORMATETC fe = {CF_HDROP, NULL, DVASPECT_CONTENT, -1, TYMED_HGLOBAL};
+    FORMATETC fe = {CF_HDROP, nullptr, DVASPECT_CONTENT, -1, TYMED_HGLOBAL};
 
     HRESULT hr = lpdobj->GetData(&fe, &medium);
 
     // save the file name
     if (SUCCEEDED(hr) &&
-        (1 == DragQueryFileA(
-            reinterpret_cast<HDROP>(medium.hGlobal),
+        (1 == DragQueryFileW(
+            static_cast<HDROP>(medium.hGlobal),
             0xFFFFFFFF,
-            NULL,
+            nullptr,
             0)))
     {
-        UINT size = DragQueryFile( reinterpret_cast<HDROP>(medium.hGlobal), 0, 0, 0 );
+        UINT size = DragQueryFileW( static_cast<HDROP>(medium.hGlobal), 0, nullptr, 0 );
         if ( size != 0 )
         {
-            TCHAR * buffer = new TCHAR[ size + 1 ];
-            UINT result_size = DragQueryFile( reinterpret_cast<HDROP>(medium.hGlobal),
-                                              0, buffer, size + 1 );
+            auto buffer = std::unique_ptr<WCHAR[]>(new WCHAR[ size + 1 ]);
+            UINT result_size = DragQueryFileW( static_cast<HDROP>(medium.hGlobal),
+                                               0, buffer.get(), size + 1 );
             if ( result_size != 0 )
             {
-                std::wstring fname = getShortPathName( buffer );
-                std::string fnameA = WStringToString( fname );
+                std::wstring fname = getShortPathName( buffer.get() );
                 ZeroMemory( m_szFileName, sizeof( m_szFileName ) );
-                strncpy( m_szFileName, fnameA.c_str(), ( sizeof( m_szFileName ) - 1 ) );
+                wcsncpy( m_szFileName, fname.c_str(), ( SAL_N_ELEMENTS( m_szFileName ) - 1 ) );
                 hr = S_OK;
             }
             else
                 hr = E_INVALIDARG;
-            delete [] buffer;
         }
         else
             hr = E_INVALIDARG;
@@ -171,19 +167,6 @@ HRESULT STDMETHODCALLTYPE CPropertySheet::Initialize(
 
 HRESULT STDMETHODCALLTYPE CPropertySheet::AddPages(LPFNADDPROPSHEETPAGE lpfnAddPage, LPARAM lParam)
 {
-// the Win32 SDK 8.1 deprecates GetVersionEx()
-#ifdef _WIN32_WINNT_WINBLUE
-    bool bIsVistaOrLater = IsWindowsVistaOrGreater() ? true : false;
-#else
-    // Get OS version (we don't need the summary page on Windows Vista or later)
-    OSVERSIONINFO sInfoOS;
-
-    ZeroMemory( &sInfoOS, sizeof(OSVERSIONINFO) );
-    sInfoOS.dwOSVersionInfoSize = sizeof( OSVERSIONINFO );
-    GetVersionEx( &sInfoOS );
-    bool bIsVistaOrLater = (sInfoOS.dwMajorVersion >= 6);
-#endif
-
     std::wstring proppage_header;
 
     PROPSHEETPAGE psp;
@@ -192,33 +175,11 @@ HRESULT STDMETHODCALLTYPE CPropertySheet::AddPages(LPFNADDPROPSHEETPAGE lpfnAddP
     // add the summary property page
     psp.dwSize      = sizeof(PROPSHEETPAGE);
     psp.dwFlags     = PSP_DEFAULT | PSP_USETITLE | PSP_USECALLBACK;
-    psp.hInstance   = GetModuleHandle(MODULE_NAME);
+    psp.hInstance   = GetModuleHandleW(MODULE_NAME);
     psp.lParam      = reinterpret_cast<LPARAM>(this);
     psp.pfnCallback = reinterpret_cast<LPFNPSPCALLBACK>(CPropertySheet::PropPageSummaryCallback);
 
-    HPROPSHEETPAGE hPage = NULL;
-
-    if ( !bIsVistaOrLater )
-    {
-        proppage_header = GetResString(IDS_PROPPAGE_SUMMARY_TITLE);
-
-        psp.pszTemplate = MAKEINTRESOURCE(IDD_PROPPAGE_SUMMARY);
-        psp.pszTitle    = proppage_header.c_str();
-        psp.pfnDlgProc  = reinterpret_cast<DLGPROC>(CPropertySheet::PropPageSummaryProc);
-
-        hPage = CreatePropertySheetPage(&psp);
-
-        // keep this instance alive, will be released when the
-        // the page is about to be destroyed in the callback function
-
-        if (hPage)
-        {
-            if (lpfnAddPage(hPage, lParam))
-                AddRef();
-            else
-                DestroyPropertySheetPage(hPage);
-        }
-    }
+    HPROPSHEETPAGE hPage = nullptr;
 
     // add the statistics property page
     proppage_header = GetResString(IDS_PROPPAGE_STATISTICS_TITLE);
@@ -237,9 +198,7 @@ HRESULT STDMETHODCALLTYPE CPropertySheet::AddPages(LPFNADDPROPSHEETPAGE lpfnAddP
             DestroyPropertySheetPage(hPage);
     }
 
-    // always return success else
-    // no property sheet will be
-    // displayed at all
+    // always return success else no property sheet will be displayed at all
     return NOERROR;
 }
 
@@ -257,8 +216,7 @@ UINT CALLBACK CPropertySheet::PropPageSummaryCallback(
     CPropertySheet* pImpl =
         reinterpret_cast<CPropertySheet*>(ppsp->lParam);
 
-    // release this instance, acquired
-    // in the AddPages method
+    // release this instance, acquired in the AddPages method
     if (PSPCB_RELEASE == uMsg)
     {
         pImpl->Release();
@@ -307,10 +265,10 @@ void CPropertySheet::InitPropPageSummary(HWND hwnd, LPPROPSHEETPAGE /*lppsp*/)
     {
         CMetaInfoReader metaInfo(m_szFileName);
 
-        SetWindowText(GetDlgItem(hwnd,IDC_TITLE),    metaInfo.getTagData( META_INFO_TITLE ).c_str() );
-        SetWindowText(GetDlgItem(hwnd,IDC_AUTHOR),   metaInfo.getTagData( META_INFO_AUTHOR ).c_str() );
-        SetWindowText(GetDlgItem(hwnd,IDC_SUBJECT),  metaInfo.getTagData( META_INFO_SUBJECT ).c_str() );
-        SetWindowText(GetDlgItem(hwnd,IDC_KEYWORDS), metaInfo.getTagData( META_INFO_KEYWORDS ).c_str() );
+        SetWindowTextW(GetDlgItem(hwnd,IDC_TITLE),    metaInfo.getTagData( META_INFO_TITLE ).c_str() );
+        SetWindowTextW(GetDlgItem(hwnd,IDC_AUTHOR),   metaInfo.getTagData( META_INFO_AUTHOR ).c_str() );
+        SetWindowTextW(GetDlgItem(hwnd,IDC_SUBJECT),  metaInfo.getTagData( META_INFO_SUBJECT ).c_str() );
+        SetWindowTextW(GetDlgItem(hwnd,IDC_KEYWORDS), metaInfo.getTagData( META_INFO_KEYWORDS ).c_str() );
 
         // comments read from meta.xml use "\n" for return, but this will not displayable in Edit control, add
         // "\r" before "\n" to form "\r\n" in order to display return in Edit control.
@@ -321,7 +279,7 @@ void CPropertySheet::InitPropPageSummary(HWND hwnd, LPPROPSHEETPAGE /*lppsp*/)
             tempStr.insert(itor, L"\r");
             itor = tempStr.find(L"\n", itor + 2);
         }
-        SetWindowText(GetDlgItem(hwnd,IDC_COMMENTS), tempStr.c_str());
+        SetWindowTextW(GetDlgItem(hwnd,IDC_COMMENTS), tempStr.c_str());
     }
     catch (const std::exception&)
     {
@@ -329,8 +287,6 @@ void CPropertySheet::InitPropPageSummary(HWND hwnd, LPPROPSHEETPAGE /*lppsp*/)
 }
 
 
-/**
-*/
 void CPropertySheet::InitPropPageStatistics(HWND hwnd, LPPROPSHEETPAGE /*lppsp*/)
 {
     try
