@@ -18,16 +18,13 @@
  */
 
 
-// must be first
-#include <canvas/debug.hxx>
-#include <canvas/verbosetrace.hxx>
 #include <com/sun/star/animations/AnimationColorSpace.hpp>
 
-#include "coloranimation.hxx"
-#include "hslcoloranimation.hxx"
+#include <coloranimation.hxx>
+#include <hslcoloranimation.hxx>
 #include "animationcolornode.hxx"
-#include "animationfactory.hxx"
-#include "activitiesfactory.hxx"
+#include <animationfactory.hxx>
+#include <activitiesfactory.hxx>
 
 using namespace com::sun::star;
 
@@ -44,7 +41,7 @@ namespace {
 class HSLWrapper : public HSLColorAnimation
 {
 public:
-    HSLWrapper( const ColorAnimationSharedPtr& rAnimation )
+    explicit HSLWrapper( const ColorAnimationSharedPtr& rAnimation )
         : mpAnimation( rAnimation )
     {
         ENSURE_OR_THROW(
@@ -53,26 +50,26 @@ public:
     }
 
     virtual void prefetch( const AnimatableShapeSharedPtr&,
-                           const ShapeAttributeLayerSharedPtr& )
+                           const ShapeAttributeLayerSharedPtr& ) override
     {}
 
     virtual void start( const AnimatableShapeSharedPtr&     rShape,
-                        const ShapeAttributeLayerSharedPtr& rAttrLayer )
+                        const ShapeAttributeLayerSharedPtr& rAttrLayer ) override
     {
         mpAnimation->start( rShape, rAttrLayer );
     }
 
-    virtual void end()
+    virtual void end() override
     {
         mpAnimation->end();
     }
 
-    virtual bool operator()( const HSLColor& rColor )
+    virtual bool operator()( const HSLColor& rColor ) override
     {
         return (*mpAnimation)( RGBColor( rColor ) );
     }
 
-    virtual HSLColor getUnderlyingValue() const
+    virtual HSLColor getUnderlyingValue() const override
     {
         return HSLColor( mpAnimation->getUnderlyingValue() );
     }
