@@ -17,11 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "screenupdater.hxx"
-#include "listenercontainer.hxx"
+#include <screenupdater.hxx>
+#include <listenercontainer.hxx>
 
-#include <boost/shared_ptr.hpp>
-#include <boost/mem_fn.hpp>
+#include <osl/diagnose.h>
+
+#include <functional>
+#include <memory>
 #include <vector>
 #include <algorithm>
 
@@ -29,9 +31,9 @@ namespace {
     class UpdateLock : public ::slideshow::internal::ScreenUpdater::UpdateLock
     {
     public:
-        UpdateLock (::slideshow::internal::ScreenUpdater& rUpdater, const bool bStartLocked);
-        virtual ~UpdateLock (void);
-        virtual void Activate (void) SAL_OVERRIDE;
+        explicit UpdateLock (::slideshow::internal::ScreenUpdater& rUpdater);
+        virtual ~UpdateLock();
+        virtual void Activate() override;
     private:
         ::slideshow::internal::ScreenUpdater& mrUpdater;
         bool mbIsActivated;
@@ -97,8 +99,7 @@ namespace internal
     void ScreenUpdater::notifyUpdate( const UnoViewSharedPtr& rView,
                                       bool                    bViewClobbered )
     {
-        mpImpl->maViewUpdateRequests.push_back(
-            std::make_pair(rView, bViewClobbered) );
+        mpImpl->maViewUpdateRequests.emplace_back(rView, bViewClobbered );
 
         if( bViewClobbered )
             mpImpl->mbViewClobbered = true;
@@ -123,32 +124,30 @@ namespace internal
         // any ViewUpdate-triggered updates?
         const bool bViewUpdatesNeeded(
             mpImpl->maUpdaters.apply(
-                boost::mem_fn(&ViewUpdate::needsUpdate)) );
+                std::mem_fn(&ViewUpdate::needsUpdate)) );
 
         if( bViewUpdatesNeeded )
         {
             mpImpl->maUpdaters.applyAll(
-                boost::mem_fn((bool (ViewUpdate::*)())&ViewUpdate::update) );
+                std::mem_fn((bool (ViewUpdate::*)())&ViewUpdate::update) );
         }
 
         if( bViewUpdatesNeeded ||
             mpImpl->mbUpdateAllRequest )
         {
             // unconditionally update all views
-            std::for_each( mpImpl->mrViewContainer.begin(),
-                           mpImpl->mrViewContainer.end(),
-                           mpImpl->mbViewClobbered ?
-                           boost::mem_fn(&View::paintScreen) :
-                           boost::mem_fn(&View::updateScreen) );
+            for( const auto& pView : mpImpl->mrViewContainer )
+            {
+                if( mpImpl->mbViewClobbered )
+                    pView->paintScreen();
+                else
+                    pView->updateScreen();
+            }
         }
         else if( !mpImpl->maViewUpdateRequests.empty() )
         {
             // update notified views only
-            UpdateRequestVector::const_iterator aIter(
-                mpImpl->maViewUpdateRequests.begin() );
-            const UpdateRequestVector::const_iterator aEnd(
-                mpImpl->maViewUpdateRequests.end() );
-            while( aIter != aEnd )
+            for( const auto& rViewUpdateRequest : mpImpl->maViewUpdateRequests )
             {
                 // TODO(P1): this is O(n^2) in the number of views, if
                 // lots of views notify updates.
@@ -157,15 +156,13 @@ namespace internal
                 UnoViewVector::const_iterator aFoundView;
                 if( (aFoundView=std::find(mpImpl->mrViewContainer.begin(),
                                           aEndOfViews,
-                                          aIter->first)) != aEndOfViews )
+                                          rViewUpdateRequest.first)) != aEndOfViews )
                 {
-                    if( aIter->second )
+                    if( rViewUpdateRequest.second )
                         (*aFoundView)->paintScreen(); // force-paint
                     else
                         (*aFoundView)->updateScreen(); // update changes only
                 }
-
-                ++aIter;
             }
         }
 
@@ -193,18 +190,17 @@ namespace internal
         // TODO(F2): This will interfere with other updates, since it
         // happens out-of-sync with main animation loop. Might cause
         // artifacts.
-        std::for_each( mpImpl->mrViewContainer.begin(),
-                       mpImpl->mrViewContainer.end(),
-                       boost::mem_fn(&View::updateScreen) );
+        for( auto const& pView : mpImpl->mrViewContainer )
+            pView->updateScreen();
     }
 
-    void ScreenUpdater::lockUpdates (void)
+    void ScreenUpdater::lockUpdates()
     {
         ++mpImpl->mnLockCount;
         OSL_ASSERT(mpImpl->mnLockCount>0);
     }
 
-    void ScreenUpdater::unlockUpdates (void)
+    void ScreenUpdater::unlockUpdates()
     {
         OSL_ASSERT(mpImpl->mnLockCount>0);
         if (mpImpl->mnLockCount > 0)
@@ -215,9 +211,9 @@ namespace internal
         }
     }
 
-    ::boost::shared_ptr<ScreenUpdater::UpdateLock> ScreenUpdater::createLock (const bool bStartLocked)
+    ::std::shared_ptr<ScreenUpdater::UpdateLock> ScreenUpdater::createLock()
     {
-        return ::boost::shared_ptr<ScreenUpdater::UpdateLock>(new ::UpdateLock(*this, bStartLocked));
+        return ::std::shared_ptr<ScreenUpdater::UpdateLock>(new ::UpdateLock(*this));
     }
 
 
@@ -227,28 +223,21 @@ namespace internal
 namespace {
 
 UpdateLock::UpdateLock (
-    ::slideshow::internal::ScreenUpdater& rUpdater,
-    const bool bStartLocked)
+    ::slideshow::internal::ScreenUpdater& rUpdater)
     : mrUpdater(rUpdater),
       mbIsActivated(false)
 {
-    if (bStartLocked)
-        Activate();
 }
 
 
-
-
-UpdateLock::~UpdateLock (void)
+UpdateLock::~UpdateLock()
 {
     if (mbIsActivated)
         mrUpdater.unlockUpdates();
 }
 
 
-
-
-void UpdateLock::Activate (void)
+void UpdateLock::Activate()
 {
     if ( ! mbIsActivated)
     {
