@@ -37,29 +37,28 @@
 #include <com/sun/star/awt/Rectangle.hpp>
 #include <com/sun/star/presentation/ParagraphTarget.hpp>
 #include <com/sun/star/presentation/EffectNodeType.hpp>
-#include <com/sun/star/animations/XAnimationNodeSupplier.hpp>
 #include <com/sun/star/drawing/TextAnimationKind.hpp>
 
 #include <cppuhelper/exc_hlp.hxx>
 #include <comphelper/anytostring.hxx>
 
-#include "slide.hxx"
-#include "slideshowcontext.hxx"
+#include <slide.hxx>
+#include <slideshowcontext.hxx>
 #include "slideanimations.hxx"
-#include "doctreenode.hxx"
-#include "screenupdater.hxx"
-#include "cursormanager.hxx"
-#include "shapeimporter.hxx"
-#include "slideshowexceptions.hxx"
-#include "eventqueue.hxx"
-#include "activitiesqueue.hxx"
+#include <doctreenode.hxx>
+#include <screenupdater.hxx>
+#include <cursormanager.hxx>
+#include <shapeimporter.hxx>
+#include <slideshowexceptions.hxx>
+#include <eventqueue.hxx>
+#include <activitiesqueue.hxx>
 #include "layermanager.hxx"
 #include "shapemanagerimpl.hxx"
-#include "usereventqueue.hxx"
+#include <usereventqueue.hxx>
 #include "userpaintoverlay.hxx"
-#include "event.hxx"
+#include <event.hxx>
 #include "targetpropertiescreator.hxx"
-#include "tools.hxx"
+#include <tools.hxx>
 
 #include <iterator>
 #include <functional>
@@ -275,7 +274,7 @@ private:
 };
 
 
-void slideRenderer( SlideImpl* pSlide, const UnoViewSharedPtr& rView )
+void slideRenderer( SlideImpl const * pSlide, const UnoViewSharedPtr& rView )
 {
     // fully clear view content to background color
     rView->clearAll();
@@ -365,7 +364,7 @@ SlideImpl::SlideImpl( const uno::Reference< drawing::XDrawPage >&           xDra
 {
     // clone already existing views for slide bitmaps
     for( const auto& rView : rViewContainer )
-        this->viewAdded( rView );
+        viewAdded( rView );
 
     // register screen update (LayerManager needs to signal pending
     // updates)
@@ -582,9 +581,8 @@ SlideBitmapSharedPtr SlideImpl::getCurrentSlideBitmap( const UnoViewSharedPtr& r
 
 void SlideImpl::viewAdded( const UnoViewSharedPtr& rView )
 {
-    maSlideBitmaps.push_back(
-        std::make_pair( rView,
-                        VectorOfSlideBitmaps(SlideAnimationState_NUM_ENTRIES) ));
+    maSlideBitmaps.emplace_back( rView,
+                        VectorOfSlideBitmaps(SlideAnimationState_NUM_ENTRIES) );
 
     if( mpLayerManager )
         mpLayerManager->viewAdded( rView );
@@ -777,10 +775,7 @@ bool SlideImpl::implPrefetchShow()
     }
     catch( uno::Exception& )
     {
-        OSL_FAIL(
-            OUStringToOString(
-                comphelper::anyToString(cppu::getCaughtException()),
-                RTL_TEXTENCODING_UTF8).getStr() );
+        SAL_WARN( "slideshow", comphelper::anyToString(cppu::getCaughtException()) );
         // TODO(E2): Error handling. For now, bail out
     }
 
@@ -869,7 +864,7 @@ void SlideImpl::applyShapeAttributes(
             // not a shape target. Maybe a ParagraphTarget?
             presentation::ParagraphTarget aParaTarget;
 
-            if( (aProps[i].Target >>= aParaTarget) )
+            if( aProps[i].Target >>= aParaTarget )
             {
                 // yep, ParagraphTarget found - extract shape
                 // and index
@@ -1038,10 +1033,7 @@ bool SlideImpl::loadShapes()
             }
             catch( uno::Exception& )
             {
-                OSL_FAIL( OUStringToOString(
-                                comphelper::anyToString( cppu::getCaughtException() ),
-                                RTL_TEXTENCODING_UTF8 ).getStr() );
-
+                SAL_WARN( "slideshow", comphelper::anyToString( cppu::getCaughtException() ) );
                 return false;
             }
         }
@@ -1080,10 +1072,7 @@ bool SlideImpl::loadShapes()
     }
     catch( uno::Exception& )
     {
-        OSL_FAIL( OUStringToOString(
-                        comphelper::anyToString( cppu::getCaughtException() ),
-                        RTL_TEXTENCODING_UTF8 ).getStr() );
-
+        SAL_WARN( "slideshow", comphelper::anyToString( cppu::getCaughtException() ) );
         return false;
     }
 
