@@ -153,10 +153,6 @@ sub getproductblock
         {
             installer::exiter::exit_program("ERROR: Product $installer::globals::product not defined in $installer::globals::ziplistname", "getproductblock");
         }
-        elsif ($search eq $installer::globals::compiler )
-        {
-            installer::exiter::exit_program("ERROR: Compiler $installer::globals::compiler not defined in $installer::globals::pathfilename", "getproductblock");
-        }
         else    # this is not possible
         {
             installer::exiter::exit_program("ERROR: Unknown value for $search in getproductblock()", "getproductblock");
@@ -175,18 +171,14 @@ sub analyze_settings_block
     my ($blockref) = @_;
 
     my @newsettingsblock = ();
-    my $compilerstring = "";
     my $record = 1;
     my $counter = 0;
 
     # Allowed values in settings block:
     # "Settings", "Variables", "unix" (for destination path and logfile)
-    # Furthermore allowed values are $installer::globals::build (srx645) and $installer::globals::compiler (pro and nonpro (unxsols4.pro))
 
     # Comment line in settings block begin with "#" or ";"
 
-    $compilerstring = $installer::globals::compiler;
-
     for ( my $i = 0; $i <= $#{$blockref}; $i++ )
     {
         my $line = ${$blockref}[$i];
@@ -201,10 +193,9 @@ sub analyze_settings_block
             next;
         }
 
-        # complete blocks of unknows strings are not recorded
+        # complete blocks of unknown strings are not recorded
 
-        if ((!($line =~ /^\s*\Q$compilerstring\E\s*$/i)) &&
-            (!($line =~ /^\s*\Q$installer::globals::build\E\s*$/i)) &&
+        if ((!($line =~ /^\s*\Q$installer::globals::build\E\s*$/i)) &&
             (!($line =~ /^\s*\bSettings\b\s*$/i)) &&
             (!($line =~ /^\s*\bVariables\b\s*$/i)) &&
             (!($line =~ /^\s*\bunix\b\s*$/i)) &&
@@ -804,7 +795,6 @@ sub replace_variables_in_ziplist_variables
 sub overwrite_branding
 {
     my ($variableshashref) = @_;
-    $variableshashref->{'OOOVENDOR'} = $ENV{'OOO_VENDOR'} , if( defined $ENV{'OOO_VENDOR'}  && $ENV{'OOO_VENDOR'} ne "" );
     $variableshashref->{'PROGRESSBARCOLOR'} = $ENV{'PROGRESSBARCOLOR'} , if( defined $ENV{'PROGRESSBARCOLOR'}  && $ENV{'PROGRESSBARCOLOR'} ne "" );
     $variableshashref->{'PROGRESSSIZE'} = $ENV{'PROGRESSSIZE'} , if( defined $ENV{'PROGRESSSIZE'}  && $ENV{'PROGRESSSIZE'} ne "" );
     $variableshashref->{'PROGRESSPOSITION'} = $ENV{'PROGRESSPOSITION'} , if( defined $ENV{'PROGRESSPOSITION'}  && $ENV{'PROGRESSPOSITION'} ne "" );
@@ -834,7 +824,7 @@ sub add_variables_to_allvariableshashref
     }
 
     if ( $installer::globals::languagepack ) { $variableshashref->{'PRODUCTADDON'} = $installer::globals::languagepackaddon; }
-    elsif ( $installer::globals::helppack ) { $variableshashref->{'PRODUCTADDON'} = $installer::globals::helppackpackaddon; }
+    elsif ( $installer::globals::helppack ) { $variableshashref->{'PRODUCTADDON'} = $installer::globals::helppackaddon; }
     else { $variableshashref->{'PRODUCTADDON'} = ""; }
 
     my $localbuild = $installer::globals::build;
@@ -848,7 +838,6 @@ sub add_variables_to_allvariableshashref
     $variableshashref->{'PRODUCTMINOR'} = $localminor;
 
     $variableshashref->{'PRODUCTBUILDID'} = $installer::globals::buildid;
-    $variableshashref->{'SYSTEM_LIBEXTTEXTCAT_DATA'} = $ENV{'SYSTEM_LIBEXTTEXTCAT_DATA'} , if( defined $ENV{'SYSTEM_LIBEXTTEXTCAT_DATA'} && $ENV{'SYSTEM_LIBEXTTEXTCAT_DATA'} ne "" );
 }
 
 1;
