@@ -19,38 +19,112 @@
 
 #include <osl/diagnose.h>
 #include <vcl/svapp.hxx>
-#include <vcl/wrkwin.hxx>
 #include <vcl/virdev.hxx>
 
+#include <rect.hxx>
+#include <types.hxx>
+#include <smmod.hxx>
 
-#include "rect.hxx"
-#include "types.hxx"
-#include "utility.hxx"
-#include "smmod.hxx"
+#include <cassert>
+#include <unordered_set>
 
+namespace {
 
-
-
-
-// '\0' terminated Array with symbol, which should be treat as letters in
-// StarMath Font, (to get a normal (non-clipped) SmRect in contrast to the
-// other operators and symbols).
-static sal_Unicode const aMathAlpha[] =
+bool SmGetGlyphBoundRect(const vcl::RenderContext &rDev,
+                         const OUString &rText, tools::Rectangle &rRect)
+    // basically the same as 'GetTextBoundRect' (in class 'OutputDevice')
+    // but with a string as argument.
 {
-    MS_ALEPH,               MS_IM,                  MS_RE,
-    MS_WP,                  sal_Unicode(0xE070),    MS_EMPTYSET,
-    sal_Unicode(0x2113),    sal_Unicode(0xE0D6),    sal_Unicode(0x2107),
-    sal_Unicode(0x2127),    sal_Unicode(0x210A),    MS_HBAR,
-    MS_LAMBDABAR,           MS_SETN,                MS_SETZ,
-    MS_SETQ,                MS_SETR,                MS_SETC,
-    sal_Unicode(0x2373),    sal_Unicode(0xE0A5),    sal_Unicode(0x2112),
-    sal_Unicode(0x2130),    sal_Unicode(0x2131),
-    sal_Unicode('\0')
-};
+    // handle special case first
+    if (rText.isEmpty())
+    {
+        rRect.SetEmpty();
+        return true;
+    }
+
+    // get a device where 'OutputDevice::GetTextBoundRect' will be successful
+    OutputDevice *pGlyphDev;
+    if (rDev.GetOutDevType() != OUTDEV_PRINTER)
+        pGlyphDev = const_cast<OutputDevice *>(&rDev);
+    else
+    {
+        // since we format for the printer (where GetTextBoundRect will fail)
+        // we need a virtual device here.
+        pGlyphDev = &SM_MOD()->GetDefaultVirtualDev();
+    }
+
+    const FontMetric  aDevFM (rDev.GetFontMetric());
+
+    pGlyphDev->Push(PushFlags::FONT | PushFlags::MAPMODE);
+    vcl::Font aFnt(rDev.GetFont());
+    aFnt.SetAlignment(ALIGN_TOP);
+
+    // use scale factor when calling GetTextBoundRect to counter
+    // negative effects from antialiasing which may otherwise result
+    // in significant incorrect bounding rectangles for some characters.
+    Size aFntSize = aFnt.GetFontSize();
+
+    // Workaround to avoid HUGE font sizes and resulting problems
+    long nScaleFactor = 1;
+    while( aFntSize.Height() > 2000 * nScaleFactor )
+        nScaleFactor *= 2;
+
+    aFnt.SetFontSize( Size( aFntSize.Width() / nScaleFactor, aFntSize.Height() / nScaleFactor ) );
+    pGlyphDev->SetFont(aFnt);
+
+    long nTextWidth = rDev.GetTextWidth(rText);
+    Point aPoint;
+    tools::Rectangle   aResult (aPoint, Size(nTextWidth, rDev.GetTextHeight())),
+                aTmp;
+
+    bool bSuccess = pGlyphDev->GetTextBoundRect(aTmp, rText);
+    OSL_ENSURE( bSuccess, "GetTextBoundRect failed" );
+
+
+    if (!aTmp.IsEmpty())
+    {
+        aResult = tools::Rectangle(aTmp.Left() * nScaleFactor, aTmp.Top() * nScaleFactor,
+                            aTmp.Right() * nScaleFactor, aTmp.Bottom() * nScaleFactor);
+        if (&rDev != pGlyphDev) /* only when rDev is a printer... */
+        {
+            long nGDTextWidth  = pGlyphDev->GetTextWidth(rText);
+            if (nGDTextWidth != 0  &&
+                nTextWidth != nGDTextWidth)
+            {
+                aResult.Right() *= nTextWidth;
+                aResult.Right() /= nGDTextWidth * nScaleFactor;
+            }
+        }
+    }
+
+    // move rectangle to match possibly different baselines
+    // (because of different devices)
+    long nDelta = aDevFM.GetAscent() - pGlyphDev->GetFontMetric().GetAscent() * nScaleFactor;
+    aResult.Move(0, nDelta);
+
+    pGlyphDev->Pop();
+
+    rRect = aResult;
+    return bSuccess;
+}
 
 bool SmIsMathAlpha(const OUString &rText)
     // true iff symbol (from StarMath Font) should be treated as letter
 {
+    // Set of symbols, which should be treated as letters in StarMath Font
+    // (to get a normal (non-clipped) SmRect in contrast to the other operators
+    // and symbols).
+    static std::unordered_set<sal_Unicode> const aMathAlpha({
+        MS_ALEPH,               MS_IM,                  MS_RE,
+        MS_WP,                  u'\xE070',              MS_EMPTYSET,
+        u'\x2113',              u'\xE0D6',              u'\x2107',
+        u'\x2127',              u'\x210A',              MS_HBAR,
+        MS_LAMBDABAR,           MS_SETN,                MS_SETZ,
+        MS_SETQ,                MS_SETR,                MS_SETC,
+        u'\x2373',              u'\xE0A5',              u'\x2112',
+        u'\x2130',              u'\x2131'
+    });
+
     if (rText.isEmpty())
         return false;
 
@@ -58,57 +132,33 @@ bool SmIsMathAlpha(const OUString &rText)
     sal_Unicode cChar = rText[0];
 
     // is it a greek symbol?
-    if (sal_Unicode(0xE0AC) <= cChar  &&  cChar <= sal_Unicode(0xE0D4))
+    if (u'\xE0AC' <= cChar  &&  cChar <= u'\xE0D4')
         return true;
-    else
-    {
-        // appears it in 'aMathAlpha'?
-        const sal_Unicode *pChar = aMathAlpha;
-        while (*pChar  &&  *pChar != cChar)
-            pChar++;
-        return *pChar != '\0';
-    }
+    // or, does it appear in 'aMathAlpha'?
+    return aMathAlpha.find(cChar) != aMathAlpha.end();
 }
 
-
-
-
-// SmRect members
-
+}
 
 
 SmRect::SmRect()
     // constructs empty rectangle at (0, 0) with width and height 0.
+    : aTopLeft(0, 0)
+    , aSize(0, 0)
+    , nBaseline(0)
+    , nAlignT(0)
+    , nAlignM(0)
+    , nAlignB(0)
+    , nGlyphTop(0)
+    , nGlyphBottom(0)
+    , nItalicLeftSpace(0)
+    , nItalicRightSpace(0)
+    , nLoAttrFence(0)
+    , nHiAttrFence(0)
+    , nBorderWidth(0)
+    , bHasBaseline(false)
+    , bHasAlignInfo(false)
 {
-    OSL_ENSURE(aTopLeft == Point(0, 0), "Sm: ooops...");
-    OSL_ENSURE(aSize == Size(0, 0), "Sm: ooops...");
-
-    bHasBaseline = bHasAlignInfo = false;
-    nBaseline = nAlignT = nAlignM = nAlignB =
-    nGlyphTop = nGlyphBottom =
-    nItalicLeftSpace = nItalicRightSpace =
-    nLoAttrFence = nHiAttrFence = 0;
-    nBorderWidth = 0;
-}
-
-
-SmRect::SmRect(const SmRect &rRect)
-:   aTopLeft(rRect.aTopLeft),
-    aSize(rRect.aSize)
-{
-    bHasBaseline  = rRect.bHasBaseline;
-    nBaseline     = rRect.nBaseline;
-    nAlignT       = rRect.nAlignT;
-    nAlignM       = rRect.nAlignM;
-    nAlignB       = rRect.nAlignB;
-    nGlyphTop     = rRect.nGlyphTop;
-    nGlyphBottom  = rRect.nGlyphBottom;
-    nHiAttrFence  = rRect.nHiAttrFence;
-    nLoAttrFence  = rRect.nLoAttrFence;
-    bHasAlignInfo = rRect.bHasAlignInfo;
-    nItalicLeftSpace  = rRect.nItalicLeftSpace;
-    nItalicRightSpace = rRect.nItalicRightSpace;
-    nBorderWidth  = rRect.nBorderWidth;
 }
 
 
@@ -125,24 +175,23 @@ void SmRect::CopyAlignInfo(const SmRect &rRect)
 }
 
 
-void SmRect::BuildRect(const OutputDevice &rDev, const SmFormat *pFormat,
-                       const OUString &rText, sal_uInt16 nBorder)
+SmRect::SmRect(const OutputDevice &rDev, const SmFormat *pFormat,
+               const OUString &rText, sal_uInt16 nBorder)
+    // get rectangle fitting for drawing 'rText' on OutputDevice 'rDev'
+    : aTopLeft(0, 0)
+    , aSize(rDev.GetTextWidth(rText), rDev.GetTextHeight())
 {
-    OSL_ENSURE(aTopLeft == Point(0, 0), "Sm: Ooops...");
-
-    aSize = Size(rDev.GetTextWidth(rText), rDev.GetTextHeight());
-
     const FontMetric  aFM (rDev.GetFontMetric());
-    bool              bIsMath  = aFM.GetName().equalsIgnoreAsciiCase( FONTNAME_MATH );
+    bool              bIsMath  = aFM.GetFamilyName().equalsIgnoreAsciiCase( FONTNAME_MATH );
     bool              bAllowSmaller = bIsMath && !SmIsMathAlpha(rText);
-    const long        nFontHeight = rDev.GetFont().GetSize().Height();
+    const long        nFontHeight = rDev.GetFont().GetFontSize().Height();
 
     nBorderWidth  = nBorder;
     bHasAlignInfo = true;
     bHasBaseline  = true;
     nBaseline     = aFM.GetAscent();
-    nAlignT       = nBaseline - nFontHeight * 750L / 1000L;
-    nAlignM       = nBaseline - nFontHeight * 121L / 422L;
+    nAlignT       = nBaseline - nFontHeight * 750 / 1000;
+    nAlignM       = nBaseline - nFontHeight * 121 / 422;
         // that's where the horizontal bars of '+', '-', ... are
         // (1/3 of ascent over baseline)
         // (121 = 1/3 of 12pt ascent, 422 = 12pt fontheight)
@@ -150,7 +199,7 @@ void SmRect::BuildRect(const OutputDevice &rDev, const SmFormat *pFormat,
 
     // workaround for printer fonts with very small (possible 0 or even
     // negative(!)) leading
-    if (aFM.GetIntLeading() < 5  &&  rDev.GetOutDevType() == OUTDEV_PRINTER)
+    if (aFM.GetInternalLeading() < 5  &&  rDev.GetOutDevType() == OUTDEV_PRINTER)
     {
         OutputDevice    *pWindow = Application::GetDefaultDevice();
 
@@ -159,11 +208,11 @@ void SmRect::BuildRect(const OutputDevice &rDev, const SmFormat *pFormat,
         pWindow->SetMapMode(rDev.GetMapMode());
         pWindow->SetFont(rDev.GetFontMetric());
 
-        long  nDelta = pWindow->GetFontMetric().GetIntLeading();
+        long  nDelta = pWindow->GetFontMetric().GetInternalLeading();
         if (nDelta == 0)
         {   // this value approx. fits a Leading of 80 at a
             // Fontheight of 422 (12pt)
-            nDelta = nFontHeight * 8L / 43;
+            nDelta = nFontHeight * 8 / 43;
         }
         SetTop(GetTop() - nDelta);
 
@@ -171,7 +220,7 @@ void SmRect::BuildRect(const OutputDevice &rDev, const SmFormat *pFormat,
     }
 
     // get GlyphBoundRect
-    Rectangle  aGlyphRect;
+    tools::Rectangle  aGlyphRect;
     bool bSuccess = SmGetGlyphBoundRect(rDev, rText, aGlyphRect);
     if (!bSuccess)
         SAL_WARN("starmath", "Ooops... (Font missing?)");
@@ -185,8 +234,8 @@ void SmRect::BuildRect(const OutputDevice &rDev, const SmFormat *pFormat,
 
     long  nDist = 0;
     if (pFormat)
-        nDist = (rDev.GetFont().GetSize().Height()
-                * pFormat->GetDistance(DIS_ORNAMENTSIZE)) / 100L;
+        nDist = (rDev.GetFont().GetFontSize().Height()
+                * pFormat->GetDistance(DIS_ORNAMENTSIZE)) / 100;
 
     nHiAttrFence = aGlyphRect.TopLeft().Y() - 1 - nBorderWidth - nDist;
     nLoAttrFence = SmFromTo(GetAlignB(), GetBottom(), 0.0);
@@ -213,43 +262,23 @@ void SmRect::BuildRect(const OutputDevice &rDev, const SmFormat *pFormat,
 }
 
 
-void SmRect::Init(const OutputDevice &rDev, const SmFormat *pFormat,
-                  const OUString &rText, sal_uInt16 nEBorderWidth)
-    // get rectangle fitting for drawing 'rText' on OutputDevice 'rDev'
-{
-    BuildRect(rDev, pFormat, rText, nEBorderWidth);
-}
-
-
-SmRect::SmRect(const OutputDevice &rDev, const SmFormat *pFormat,
-               const OUString &rText, long nEBorderWidth)
-{
-    OSL_ENSURE( nEBorderWidth >= 0, "BorderWidth is negative" );
-    if (nEBorderWidth < 0)
-        nEBorderWidth = 0;
-    Init(rDev, pFormat, rText, (sal_uInt16) nEBorderWidth);
-}
-
-
 SmRect::SmRect(long nWidth, long nHeight)
     // this constructor should never be used for anything textlike because
     // it will not provide useful values for baseline, AlignT and AlignB!
     // It's purpose is to get a 'SmRect' for the horizontal line in fractions
     // as used in 'SmBinVerNode'.
-:   aSize(nWidth, nHeight)
+    : aTopLeft(0, 0)
+    , aSize(nWidth, nHeight)
+    , nBaseline(0)
+    , nItalicLeftSpace(0)
+    , nItalicRightSpace(0)
+    , nBorderWidth(0)
+    , bHasBaseline(false)
+    , bHasAlignInfo(true)
 {
-    OSL_ENSURE(aTopLeft == Point(0, 0), "Sm: ooops...");
-
-    bHasBaseline  = false;
-    bHasAlignInfo = true;
-    nBaseline     = 0;
-    nAlignT       = GetTop();
-    nAlignB       = GetBottom();
-    nAlignM       = (nAlignT + nAlignB) / 2;        // this is the default
-    nItalicLeftSpace = nItalicRightSpace = 0;
-    nGlyphTop    = nHiAttrFence  = GetTop();
-    nGlyphBottom = nLoAttrFence  = GetBottom();
-    nBorderWidth  = 0;
+    nAlignT = nGlyphTop    = nHiAttrFence = GetTop();
+    nAlignB = nGlyphBottom = nLoAttrFence = GetBottom();
+    nAlignM = (nAlignT + nAlignB) / 2;        // this is the default
 }
 
 
@@ -307,96 +336,95 @@ const Point SmRect::AlignTo(const SmRect &rRect, RectPos ePos,
 {   Point  aPos (GetTopLeft());
         // will become the topleft point of the new rectangle position
 
-    // set horizontal or vertical new rectangle position depending on
-    // 'ePos' is one of 'RP_LEFT', 'RP_RIGHT' or 'RP_TOP', 'RP_BOTTOM'
+    // set horizontal or vertical new rectangle position depending on ePos
     switch (ePos)
-    {   case RP_LEFT :
+    {   case RectPos::Left:
             aPos.X() = rRect.GetItalicLeft() - GetItalicRightSpace()
                        - GetWidth();
             break;
-        case RP_RIGHT :
+        case RectPos::Right:
             aPos.X() = rRect.GetItalicRight() + 1 + GetItalicLeftSpace();
             break;
-        case RP_TOP :
+        case RectPos::Top:
             aPos.Y() = rRect.GetTop() - GetHeight();
             break;
-        case RP_BOTTOM :
+        case RectPos::Bottom:
             aPos.Y() = rRect.GetBottom() + 1;
             break;
-        case RP_ATTRIBUT :
+        case RectPos::Attribute:
             aPos.X() = rRect.GetItalicCenterX() - GetItalicWidth() / 2
                        + GetItalicLeftSpace();
             break;
-        default :
-            SAL_WARN("starmath", "unknown case");
+        default:
+            assert(false);
     }
 
     // check if horizontal position is already set
-    if (ePos == RP_LEFT  ||  ePos == RP_RIGHT  ||  ePos == RP_ATTRIBUT)
+    if (ePos == RectPos::Left || ePos == RectPos::Right || ePos == RectPos::Attribute)
         // correct error in current vertical position
         switch (eVer)
-        {   case RVA_TOP :
+        {   case RectVerAlign::Top :
                 aPos.Y() += rRect.GetAlignT() - GetAlignT();
                 break;
-            case RVA_MID :
+            case RectVerAlign::Mid :
                 aPos.Y() += rRect.GetAlignM() - GetAlignM();
                 break;
-            case RVA_BASELINE :
+            case RectVerAlign::Baseline :
                 // align baselines if possible else align mid's
                 if (HasBaseline() && rRect.HasBaseline())
                     aPos.Y() += rRect.GetBaseline() - GetBaseline();
                 else
                     aPos.Y() += rRect.GetAlignM() - GetAlignM();
                 break;
-            case RVA_BOTTOM :
+            case RectVerAlign::Bottom :
                 aPos.Y() += rRect.GetAlignB() - GetAlignB();
                 break;
-            case RVA_CENTERY :
+            case RectVerAlign::CenterY :
                 aPos.Y() += rRect.GetCenterY() - GetCenterY();
                 break;
-            case RVA_ATTRIBUT_HI:
+            case RectVerAlign::AttributeHi:
                 aPos.Y() += rRect.GetHiAttrFence() - GetBottom();
                 break;
-            case RVA_ATTRIBUT_MID :
+            case RectVerAlign::AttributeMid :
                 aPos.Y() += SmFromTo(rRect.GetAlignB(), rRect.GetAlignT(), 0.4)
                             - GetCenterY();
                 break;
-            case RVA_ATTRIBUT_LO :
+            case RectVerAlign::AttributeLo :
                 aPos.Y() += rRect.GetLoAttrFence() - GetTop();
                 break;
         default :
-                SAL_WARN("starmath", "unknown case");
+                assert(false);
         }
 
     // check if vertical position is already set
-    if (ePos == RP_TOP  ||  ePos == RP_BOTTOM)
+    if (ePos == RectPos::Top || ePos == RectPos::Bottom)
         // correct error in current horizontal position
         switch (eHor)
-        {   case RHA_LEFT :
+        {   case RectHorAlign::Left:
                 aPos.X() += rRect.GetItalicLeft() - GetItalicLeft();
                 break;
-            case RHA_CENTER :
+            case RectHorAlign::Center:
                 aPos.X() += rRect.GetItalicCenterX() - GetItalicCenterX();
                 break;
-            case RHA_RIGHT :
+            case RectHorAlign::Right:
                 aPos.X() += rRect.GetItalicRight() - GetItalicRight();
                 break;
-            default :
-                SAL_WARN("starmath", "unknown case");
+            default:
+                assert(false);
         }
 
     return aPos;
 }
 
 
-SmRect & SmRect::Union(const SmRect &rRect)
+void SmRect::Union(const SmRect &rRect)
     // rectangle union of current one with 'rRect'. The result is to be the
     // smallest rectangles that covers the space of both rectangles.
     // (empty rectangles cover no space)
     //! Italic correction is NOT taken into account here!
 {
     if (rRect.IsEmpty())
-        return *this;
+        return;
 
     long  nL  = rRect.GetLeft(),
           nR  = rRect.GetRight(),
@@ -427,8 +455,6 @@ SmRect & SmRect::Union(const SmRect &rRect)
     SetBottom(nB);
     nGlyphTop    = nGT;
     nGlyphBottom = nGB;
-
-    return *this;
 }
 
 
@@ -451,29 +477,30 @@ SmRect & SmRect::ExtendBy(const SmRect &rRect, RectCopyMBL eCopyMode)
     if (!HasAlignInfo())
         CopyAlignInfo(rRect);
     else if (rRect.HasAlignInfo())
-    {   nAlignT = std::min(GetAlignT(), rRect.GetAlignT());
+    {
+        assert(HasAlignInfo());
+        nAlignT = std::min(GetAlignT(), rRect.GetAlignT());
         nAlignB = std::max(GetAlignB(), rRect.GetAlignB());
         nHiAttrFence = std::min(GetHiAttrFence(), rRect.GetHiAttrFence());
         nLoAttrFence = std::max(GetLoAttrFence(), rRect.GetLoAttrFence());
-        OSL_ENSURE(HasAlignInfo(), "Sm: ooops...");
 
         switch (eCopyMode)
-        {   case RCP_THIS:
+        {   case RectCopyMBL::This:
                 // already done
                 break;
-            case RCP_ARG:
+            case RectCopyMBL::Arg:
                 CopyMBL(rRect);
                 break;
-            case RCP_NONE:
-                ClearBaseline();
+            case RectCopyMBL::None:
+                bHasBaseline = false;
                 nAlignM = (nAlignT + nAlignB) / 2;
                 break;
-            case RCP_XOR:
+            case RectCopyMBL::Xor:
                 if (!HasBaseline())
                     CopyMBL(rRect);
                 break;
             default :
-                SAL_WARN("starmath", "unknown case");
+                assert(false);
         }
     }
 
@@ -481,7 +508,7 @@ SmRect & SmRect::ExtendBy(const SmRect &rRect, RectCopyMBL eCopyMode)
 }
 
 
-SmRect & SmRect::ExtendBy(const SmRect &rRect, RectCopyMBL eCopyMode,
+void SmRect::ExtendBy(const SmRect &rRect, RectCopyMBL eCopyMode,
                           long nNewAlignM)
     // as 'ExtendBy' but sets AlignM value to 'nNewAlignM'.
     // (this version will be used in 'SmBinVerNode' to provide means to
@@ -492,8 +519,6 @@ SmRect & SmRect::ExtendBy(const SmRect &rRect, RectCopyMBL eCopyMode,
 
     ExtendBy(rRect, eCopyMode);
     nAlignM = nNewAlignM;
-
-    return *this;
 }
 
 
@@ -593,83 +618,4 @@ SmRect SmRect::AsGlyphRect() const
     return aRect;
 }
 
-bool SmGetGlyphBoundRect(const vcl::RenderContext &rDev,
-                         const OUString &rText, Rectangle &rRect)
-    // basically the same as 'GetTextBoundRect' (in class 'OutputDevice')
-    // but with a string as argument.
-{
-    // handle special case first
-    if (rText.isEmpty())
-    {
-        rRect.SetEmpty();
-        return true;
-    }
-
-    // get a device where 'OutputDevice::GetTextBoundRect' will be successful
-    OutputDevice *pGlyphDev;
-    if (rDev.GetOutDevType() != OUTDEV_PRINTER)
-        pGlyphDev = const_cast<OutputDevice *>(&rDev);
-    else
-    {
-        // since we format for the printer (where GetTextBoundRect will fail)
-        // we need a virtual device here.
-        pGlyphDev = &SM_MOD()->GetDefaultVirtualDev();
-    }
-
-    const FontMetric  aDevFM (rDev.GetFontMetric());
-
-    pGlyphDev->Push(PushFlags::FONT | PushFlags::MAPMODE);
-    vcl::Font aFnt(rDev.GetFont());
-    aFnt.SetAlign(ALIGN_TOP);
-
-    // use scale factor when calling GetTextBoundRect to counter
-    // negative effects from antialiasing which may otherwise result
-    // in significant incorrect bounding rectangles for some characters.
-    Size aFntSize = aFnt.GetSize();
-
-    // Workaround to avoid HUGE font sizes and resulting problems
-    long nScaleFactor = 1;
-    while( aFntSize.Height() > 2000 * nScaleFactor )
-        nScaleFactor *= 2;
-
-    aFnt.SetSize( Size( aFntSize.Width() / nScaleFactor, aFntSize.Height() / nScaleFactor ) );
-    pGlyphDev->SetFont(aFnt);
-
-    long nTextWidth = rDev.GetTextWidth(rText);
-    Point aPoint;
-    Rectangle   aResult (aPoint, Size(nTextWidth, rDev.GetTextHeight())),
-                aTmp;
-
-    bool bSuccess = pGlyphDev->GetTextBoundRect(aTmp, rText);
-    OSL_ENSURE( bSuccess, "GetTextBoundRect failed" );
-
-
-    if (!aTmp.IsEmpty())
-    {
-        aResult = Rectangle(aTmp.Left() * nScaleFactor, aTmp.Top() * nScaleFactor,
-                            aTmp.Right() * nScaleFactor, aTmp.Bottom() * nScaleFactor);
-        if (&rDev != pGlyphDev) /* only when rDev is a printer... */
-        {
-            long nGDTextWidth  = pGlyphDev->GetTextWidth(rText);
-            if (nGDTextWidth != 0  &&
-                nTextWidth != nGDTextWidth)
-            {
-                aResult.Right() *= nTextWidth;
-                aResult.Right() /= nGDTextWidth * nScaleFactor;
-            }
-        }
-    }
-
-    // move rectangle to match possibly different baselines
-    // (because of different devices)
-    long nDelta = aDevFM.GetAscent() - pGlyphDev->GetFontMetric().GetAscent() * nScaleFactor;
-    aResult.Move(0, nDelta);
-
-    pGlyphDev->Pop();
-
-    rRect = aResult;
-    return bSuccess;
-}
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
