@@ -7,29 +7,27 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-
 #include "rtfexport.hxx"
 
-#include <rtl/ustring.hxx>
 #include <svtools/rtfkeywd.hxx>
 #include <filter/msfilter/rtfutil.hxx>
 
 SmRtfExport::SmRtfExport(const SmNode* pIn)
     : SmWordExportBase(pIn)
-      , m_pBuffer(0)
+    , m_pBuffer(nullptr)
+    , m_nEncoding(RTL_TEXTENCODING_DONTKNOW)
 {
 }
 
-bool SmRtfExport::ConvertFromStarMath(OStringBuffer& rBuffer, rtl_TextEncoding nEncoding)
+void SmRtfExport::ConvertFromStarMath(OStringBuffer& rBuffer, rtl_TextEncoding nEncoding)
 {
     if (!m_pTree)
-        return false;
+        return;
     m_pBuffer = &rBuffer;
     m_nEncoding = nEncoding;
     m_pBuffer->append("{" OOO_STRING_SVTOOLS_RTF_IGNORE LO_STRING_SVTOOLS_RTF_MOMATH " ");
     HandleNode(m_pTree, 0);
     m_pBuffer->append("}"); // moMath
-    return true;
 }
 
 // NOTE: This is still work in progress and unfinished, but it already covers a good
@@ -42,7 +40,7 @@ void SmRtfExport::HandleVerticalStack(const SmNode* pNode, int nLevel)
     for (int i = 0; i < size; ++i)
     {
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
-        HandleNode(pNode->GetSubNode( i ), nLevel + 1);
+        HandleNode(pNode->GetSubNode(i), nLevel + 1);
         m_pBuffer->append("}"); // me
     }
     m_pBuffer->append("}"); // meqArr
@@ -52,10 +50,10 @@ void SmRtfExport::HandleText(const SmNode* pNode, int /*nLevel*/)
 {
     m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MR " ");
 
-    if( pNode->GetToken().eType == TTEXT ) // literal text
+    if (pNode->GetToken().eType == TTEXT) // literal text
         m_pBuffer->append(LO_STRING_SVTOOLS_RTF_MNOR " ");
 
-    SmTextNode* pTemp=(SmTextNode* )pNode;
+    auto pTemp = static_cast<const SmTextNode*>(pNode);
     SAL_INFO("starmath.rtf", "Text: " << pTemp->GetText());
     for (sal_Int32 i = 0; i < pTemp->GetText().getLength(); i++)
     {
@@ -78,7 +76,7 @@ void SmRtfExport::HandleFractions(const SmNode* pNode, int nLevel, const char* t
         m_pBuffer->append("}"); // mtype
         m_pBuffer->append("}"); // mfPr
     }
-    OSL_ASSERT(pNode->GetNumSubNodes() == 3);
+    assert(pNode->GetNumSubNodes() == 3);
     m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MNUM " ");
     HandleNode(pNode->GetSubNode(0), nLevel + 1);
     m_pBuffer->append("}"); // mnum
@@ -116,7 +114,7 @@ void SmRtfExport::HandleAttribute(const SmAttributNode* pNode, int nLevel)
             m_pBuffer->append("}"); // mchr
             m_pBuffer->append("}"); // maccPr
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
-            HandleNode( pNode->Body(), nLevel + 1 );
+            HandleNode(pNode->Body(), nLevel + 1);
             m_pBuffer->append("}"); // me
             m_pBuffer->append("}"); // macc
             break;
@@ -126,11 +124,11 @@ void SmRtfExport::HandleAttribute(const SmAttributNode* pNode, int nLevel)
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MBAR " ");
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MBARPR " ");
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MPOS " ");
-            m_pBuffer->append((pNode->Attribute()->GetToken().eType == TUNDERLINE ) ? "bot" : "top");
+            m_pBuffer->append((pNode->Attribute()->GetToken().eType == TUNDERLINE) ? "bot" : "top");
             m_pBuffer->append("}"); // mpos
             m_pBuffer->append("}"); // mbarPr
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
-            HandleNode( pNode->Body(), nLevel + 1 );
+            HandleNode(pNode->Body(), nLevel + 1);
             m_pBuffer->append("}"); // me
             m_pBuffer->append("}"); // mbar
             break;
@@ -144,12 +142,12 @@ void SmRtfExport::HandleAttribute(const SmAttributNode* pNode, int nLevel)
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSTRIKEH " 1}");
             m_pBuffer->append("}"); // mborderBoxPr
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
-            HandleNode( pNode->Body(), nLevel + 1 );
+            HandleNode(pNode->Body(), nLevel + 1);
             m_pBuffer->append("}"); // me
             m_pBuffer->append("}"); // mborderBox
             break;
         default:
-            HandleAllSubNodes( pNode, nLevel );
+            HandleAllSubNodes(pNode, nLevel);
             break;
     }
 }
@@ -176,11 +174,12 @@ void SmRtfExport::HandleRoot(const SmRootNode* pNode, int nLevel)
     m_pBuffer->append("}"); // mrad
 }
 
-namespace {
+namespace
+{
 OString mathSymbolToString(const SmNode* node, rtl_TextEncoding nEncoding)
 {
-    assert(node->GetType() == NMATH || node->GetType() == NMATHIDENT);
-    const SmTextNode* txtnode = static_cast<const SmTextNode*>(node);
+    assert(node->GetType() == SmNodeType::Math || node->GetType() == SmNodeType::MathIdent);
+    auto txtnode = static_cast<const SmTextNode*>(node);
     if (txtnode->GetText().isEmpty())
         return OString();
     assert(txtnode->GetText().getLength() == 1);
@@ -196,6 +195,7 @@ void SmRtfExport::HandleOperator(const SmOperNode* pNode, int nLevel)
     switch (pNode->GetToken().eType)
     {
         case TINT:
+        case TINTD:
         case TIINT:
         case TIIINT:
         case TLINT:
@@ -205,7 +205,10 @@ void SmRtfExport::HandleOperator(const SmOperNode* pNode, int nLevel)
         case TCOPROD:
         case TSUM:
         {
-            const SmSubSupNode* subsup = pNode->GetSubNode(0)->GetType() == NSUBSUP ? static_cast<const SmSubSupNode*>(pNode->GetSubNode(0)) : 0;
+            const SmSubSupNode* subsup
+                = pNode->GetSubNode(0)->GetType() == SmNodeType::SubSup
+                      ? static_cast<const SmSubSupNode*>(pNode->GetSubNode(0))
+                      : nullptr;
             const SmNode* operation = subsup ? subsup->GetBody() : pNode->GetSubNode(0);
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MNARY " ");
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MNARYPR " ");
@@ -225,7 +228,7 @@ void SmRtfExport::HandleOperator(const SmOperNode* pNode, int nLevel)
                 HandleNode(subsup->GetSubSup(CSUB), nLevel + 1);
                 m_pBuffer->append("}"); // msub
             }
-            if (!subsup || !subsup->GetSubSup( CSUP ))
+            if (!subsup || !subsup->GetSubSup(CSUP))
                 m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSUP " }");
             else
             {
@@ -247,7 +250,10 @@ void SmRtfExport::HandleOperator(const SmOperNode* pNode, int nLevel)
             HandleNode(pNode->GetSymbol(), nLevel + 1);
             m_pBuffer->append("}"); // me
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MLIM " ");
-            if (const SmSubSupNode* subsup = pNode->GetSubNode(0)->GetType() == NSUBSUP ? static_cast<const SmSubSupNode*>( pNode->GetSubNode(0)) : 0)
+            if (const SmSubSupNode* subsup
+                = pNode->GetSubNode(0)->GetType() == SmNodeType::SubSup
+                      ? static_cast<const SmSubSupNode*>(pNode->GetSubNode(0))
+                      : nullptr)
                 if (subsup->GetSubSup(CSUB))
                     HandleNode(subsup->GetSubSup(CSUB), nLevel + 1);
             m_pBuffer->append("}"); // mlim
@@ -266,12 +272,13 @@ void SmRtfExport::HandleOperator(const SmOperNode* pNode, int nLevel)
 
 void SmRtfExport::HandleSubSupScriptInternal(const SmSubSupNode* pNode, int nLevel, int flags)
 {
-// rtf supports only a certain combination of sub/super scripts, but LO can have any,
-// so try to merge it using several tags if necessary
+    // rtf supports only a certain combination of sub/super scripts, but LO can have any,
+    // so try to merge it using several tags if necessary
     if (flags == 0) // none
         return;
     if ((flags & (1 << RSUP | 1 << RSUB)) == (1 << RSUP | 1 << RSUB))
-    { // m:sSubSup
+    {
+        // m:sSubSup
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSSUBSUP " ");
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
         flags &= ~(1 << RSUP | 1 << RSUB);
@@ -284,12 +291,13 @@ void SmRtfExport::HandleSubSupScriptInternal(const SmSubSupNode* pNode, int nLev
         HandleNode(pNode->GetSubSup(RSUB), nLevel + 1);
         m_pBuffer->append("}"); // msub
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSUP " ");
-        HandleNode(pNode->GetSubSup(RSUP ), nLevel + 1);
+        HandleNode(pNode->GetSubSup(RSUP), nLevel + 1);
         m_pBuffer->append("}"); // msup
         m_pBuffer->append("}"); // msubSup
     }
     else if ((flags & (1 << RSUB)) == 1 << RSUB)
-    { // m:sSub
+    {
+        // m:sSub
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSSUB " ");
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
         flags &= ~(1 << RSUB);
@@ -304,7 +312,8 @@ void SmRtfExport::HandleSubSupScriptInternal(const SmSubSupNode* pNode, int nLev
         m_pBuffer->append("}"); // msSub
     }
     else if ((flags & (1 << RSUP)) == 1 << RSUP)
-    { // m:sSup
+    {
+        // m:sSup
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSSUP " ");
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
         flags &= ~(1 << RSUP);
@@ -319,10 +328,11 @@ void SmRtfExport::HandleSubSupScriptInternal(const SmSubSupNode* pNode, int nLev
         m_pBuffer->append("}"); // msSup
     }
     else if ((flags & (1 << LSUP | 1 << LSUB)) == (1 << LSUP | 1 << LSUB))
-    { // m:sPre
+    {
+        // m:sPre
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSPRE " ");
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSUB " ");
-        HandleNode(pNode->GetSubSup(LSUB ), nLevel + 1);
+        HandleNode(pNode->GetSubSup(LSUB), nLevel + 1);
         m_pBuffer->append("}"); // msub
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSUP " ");
         HandleNode(pNode->GetSubSup(LSUP), nLevel + 1);
@@ -337,7 +347,8 @@ void SmRtfExport::HandleSubSupScriptInternal(const SmSubSupNode* pNode, int nLev
         m_pBuffer->append("}"); // msPre
     }
     else if ((flags & (1 << CSUB)) == (1 << CSUB))
-    { // m:limLow looks like a good element for central superscript
+    {
+        // m:limLow looks like a good element for central superscript
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MLIMLOW " ");
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
         flags &= ~(1 << CSUB);
@@ -352,7 +363,8 @@ void SmRtfExport::HandleSubSupScriptInternal(const SmSubSupNode* pNode, int nLev
         m_pBuffer->append("}"); // mlimLow
     }
     else if ((flags & (1 << CSUP)) == (1 << CSUP))
-    { // m:limUpp looks like a good element for central superscript
+    {
+        // m:limUpp looks like a good element for central superscript
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MLIMUPP " ");
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
         flags &= ~(1 << CSUP);
@@ -373,10 +385,10 @@ void SmRtfExport::HandleSubSupScriptInternal(const SmSubSupNode* pNode, int nLev
 void SmRtfExport::HandleMatrix(const SmMatrixNode* pNode, int nLevel)
 {
     m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MM " ");
-    for (int row = 0; row < pNode->GetNumRows(); ++row )
+    for (int row = 0; row < pNode->GetNumRows(); ++row)
     {
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MMR " ");
-        for (int col = 0; col < pNode->GetNumCols(); ++col )
+        for (int col = 0; col < pNode->GetNumCols(); ++col)
         {
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
             if (const SmNode* node = pNode->GetSubNode(row * pNode->GetNumCols() + col))
@@ -395,18 +407,20 @@ void SmRtfExport::HandleBrace(const SmBraceNode* pNode, int nLevel)
     m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MBEGCHR " ");
     m_pBuffer->append(mathSymbolToString(pNode->OpeningBrace(), m_nEncoding));
     m_pBuffer->append("}"); // mbegChr
-    std::vector< const SmNode* > subnodes;
-    if (pNode->Body()->GetType() == NBRACEBODY)
+    std::vector<const SmNode*> subnodes;
+    if (pNode->Body()->GetType() == SmNodeType::Bracebody)
     {
-        const SmBracebodyNode* body = static_cast<const SmBracebodyNode*>( pNode->Body());
+        auto body = static_cast<const SmBracebodyNode*>(pNode->Body());
         bool separatorWritten = false; // assume all separators are the same
         for (int i = 0; i < body->GetNumSubNodes(); ++i)
         {
             const SmNode* subnode = body->GetSubNode(i);
-            if (subnode->GetType() == NMATH || subnode->GetType() == NMATHIDENT)
-            { // do not write, but write what separator it is
-                const SmMathSymbolNode* math = static_cast<const SmMathSymbolNode*>(subnode);
-                if(!separatorWritten)
+            if (subnode->GetType() == SmNodeType::Math
+                || subnode->GetType() == SmNodeType::MathIdent)
+            {
+                // do not write, but write what separator it is
+                auto math = static_cast<const SmMathSymbolNode*>(subnode);
+                if (!separatorWritten)
                 {
                     m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MSEPCHR " ");
                     m_pBuffer->append(mathSymbolToString(math, m_nEncoding));
@@ -424,10 +438,10 @@ void SmRtfExport::HandleBrace(const SmBraceNode* pNode, int nLevel)
     m_pBuffer->append(mathSymbolToString(pNode->ClosingBrace(), m_nEncoding));
     m_pBuffer->append("}"); // mendChr
     m_pBuffer->append("}"); // mdPr
-    for (unsigned int i = 0; i < subnodes.size(); ++i)
+    for (const SmNode* subnode : subnodes)
     {
         m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
-        HandleNode(subnodes[ i ], nLevel + 1);
+        HandleNode(subnode, nLevel + 1);
         m_pBuffer->append("}"); // me
     }
     m_pBuffer->append("}"); // md
@@ -453,8 +467,12 @@ void SmRtfExport::HandleVerticalBrace(const SmVerticalBraceNode* pNode, int nLev
             m_pBuffer->append(mathSymbolToString(pNode->Brace(), m_nEncoding));
             m_pBuffer->append("}"); // mchr
             // TODO not sure if pos and vertJc are correct
-            m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MPOS " ").append(top ? "top" : "bot").append("}");
-            m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MVERTJC " ").append(top ? "bot" : "top").append("}");
+            m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MPOS " ")
+                .append(top ? "top" : "bot")
+                .append("}");
+            m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_MVERTJC " ")
+                .append(top ? "bot" : "top")
+                .append("}");
             m_pBuffer->append("}"); // mgroupChrPr
             m_pBuffer->append("{" LO_STRING_SVTOOLS_RTF_ME " ");
             HandleNode(pNode->Body(), nLevel + 1);
