@@ -17,21 +17,18 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <sot/factory.hxx>
+#include <sal/config.h>
+
 #include <svx/svxids.hrc>
 #include <svx/modctrl.hxx>
 #include <svx/zoomctrl.hxx>
 #include <svx/zoomsliderctrl.hxx>
 #include <sfx2/docfac.hxx>
 #include <svx/lboxctrl.hxx>
-#include <sfx2/docfile.hxx>
-#include <sfx2/docfilt.hxx>
 #include <sfx2/app.hxx>
-#include <sfx2/taskpane.hxx>
 
 #include <smdll.hxx>
 #include <document.hxx>
-#include <toolbox.hxx>
 #include <view.hxx>
 
 #include <ElementsDockingWindow.hxx>
@@ -39,6 +36,7 @@
 #include <starmath.hrc>
 
 #include <svx/xmlsecctrl.hxx>
+#include <o3tl/make_unique.hxx>
 
 namespace
 {
@@ -46,26 +44,26 @@ namespace
     {
     public:
         SmDLL();
-        ~SmDLL();
     };
 
     SmDLL::SmDLL()
     {
-        SmModule** ppShlPtr = (SmModule**) GetAppData(SHL_SM);
-        if ( *ppShlPtr )
+        if ( SfxApplication::GetModule(SfxToolsModule::Math) )    // Module already active
             return;
 
         SfxObjectFactory& rFactory = SmDocShell::Factory();
-        SmModule *pModule = new SmModule( &rFactory );
-        *ppShlPtr = pModule;
 
-        rFactory.SetDocumentServiceName( OUString("com.sun.star.formula.FormulaProperties") );
+        auto pUniqueModule = o3tl::make_unique<SmModule>(&rFactory);
+        SmModule* pModule = pUniqueModule.get();
+        SfxApplication::SetModule(SfxToolsModule::Math, std::move(pUniqueModule));
+
+        rFactory.SetDocumentServiceName( "com.sun.star.formula.FormulaProperties" );
 
         SmModule::RegisterInterface(pModule);
         SmDocShell::RegisterInterface(pModule);
         SmViewShell::RegisterInterface(pModule);
 
-        SmViewShell::RegisterFactory(1);
+        SmViewShell::RegisterFactory(SFX_INTERFACE_SFXAPP);
 
         SvxZoomStatusBarControl::RegisterControl(SID_ATTR_ZOOM, pModule);
         SvxZoomSliderControl::RegisterControl(SID_ATTR_ZOOMSLIDER, pModule);
@@ -74,22 +72,8 @@ namespace
         SvxUndoRedoControl::RegisterControl(SID_REDO, pModule);
         XmlSecStatusBarControl::RegisterControl(SID_SIGNATURE, pModule);
 
-        SmToolBoxWrapper::RegisterChildWindow(true);
         SmCmdBoxWrapper::RegisterChildWindow(true);
         SmElementsDockingWindowWrapper::RegisterChildWindow(true);
-
-        ::sfx2::TaskPaneWrapper::RegisterChildWindow(false, pModule);
-    }
-
-    SmDLL::~SmDLL()
-    {
-#if 0
-        // the SdModule must be destroyed
-        SmModule** ppShlPtr = (SmModule**) GetAppData(SHL_SM);
-        delete (*ppShlPtr);
-        (*ppShlPtr) = NULL;
-        *GetAppData(SHL_SM) = 0;
-#endif
     }
 
     struct theSmDLLInstance : public rtl::Static<SmDLL, theSmDLLInstance> {};
