@@ -17,21 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <sfx2/app.hxx>
-#include <vcl/virdev.hxx>
-#include <tools/tenccvt.hxx>
-#include <osl/thread.h>
-
-#include <tools/stream.hxx>
-
-#include "starmath.hrc"
-
-#include "utility.hxx"
-#include "dialog.hxx"
-#include "view.hxx"
-#include "smdll.hxx"
+#include <vcl/builderfactory.hxx>
 
+#include <strings.hrc>
 
+#include <utility.hxx>
+#include <dialog.hxx>
+#include <view.hxx>
 
 
 // return pointer to active SmViewShell, if this is not possible
@@ -41,13 +33,10 @@
 SmViewShell * SmGetActiveView()
 {
     SfxViewShell *pView = SfxViewShell::Current();
-    return PTR_CAST(SmViewShell, pView);
+    return  dynamic_cast<SmViewShell*>( pView);
 }
 
 
-
-
-
 /**************************************************************************/
 
 void SmFontPickList::Clear()
@@ -59,52 +48,57 @@ SmFontPickList& SmFontPickList::operator = (const SmFontPickList& rList)
 {
     Clear();
     nMaxItems = rList.nMaxItems;
-    for (sal_uInt16 nPos = 0; nPos < rList.aFontVec.size(); nPos++)
-        aFontVec.push_back( rList.aFontVec[nPos] );
+    for (const auto & nPos : rList.aFontVec)
+        aFontVec.push_back( nPos );
 
     return *this;
 }
 
-vcl::Font SmFontPickList::operator [] (sal_uInt16 nPos) const
-{
-    return aFontVec[nPos];
-}
-
 vcl::Font SmFontPickList::Get(sal_uInt16 nPos) const
 {
     return nPos < aFontVec.size() ? aFontVec[nPos] : vcl::Font();
 }
 
-bool SmFontPickList::CompareItem(const vcl::Font & rFirstFont, const vcl::Font & rSecondFont) const
+namespace {
+
+bool lcl_CompareItem(const vcl::Font & rFirstFont, const vcl::Font & rSecondFont)
 {
-  return rFirstFont.GetName() == rSecondFont.GetName() &&
-        rFirstFont.GetFamily()  == rSecondFont.GetFamily()  &&
-        rFirstFont.GetCharSet() == rSecondFont.GetCharSet() &&
-        rFirstFont.GetWeight()  == rSecondFont.GetWeight()  &&
-        rFirstFont.GetItalic()  == rSecondFont.GetItalic();
+  return rFirstFont.GetFamilyName() == rSecondFont.GetFamilyName() &&
+         rFirstFont.GetFamilyType() == rSecondFont.GetFamilyType() &&
+         rFirstFont.GetCharSet()    == rSecondFont.GetCharSet()    &&
+         rFirstFont.GetWeight()     == rSecondFont.GetWeight()     &&
+         rFirstFont.GetItalic()     == rSecondFont.GetItalic();
 }
 
-OUString SmFontPickList::GetStringItem(const vcl::Font &rFont)
+OUString lcl_GetStringItem(const vcl::Font &rFont)
 {
-    OUStringBuffer aString(rFont.GetName());
+    OUStringBuffer aString(rFont.GetFamilyName());
 
     if (IsItalic( rFont ))
     {
         aString.append(", ");
-        aString.append(SM_RESSTR(RID_FONTITALIC));
+        aString.append(SmResId(RID_FONTITALIC));
     }
     if (IsBold( rFont ))
     {
         aString.append(", ");
-        aString.append(SM_RESSTR(RID_FONTBOLD));
+        aString.append(SmResId(RID_FONTBOLD));
     }
 
     return aString.makeStringAndClear();
 }
 
+}
+
 void SmFontPickList::Insert(const vcl::Font &rFont)
 {
-    Remove(rFont);
+    for (size_t nPos = 0; nPos < aFontVec.size(); nPos++)
+        if (lcl_CompareItem( aFontVec[nPos], rFont))
+        {
+            aFontVec.erase( aFontVec.begin() + nPos );
+            break;
+        }
+
     aFontVec.push_front( rFont );
 
     if (aFontVec.size() > nMaxItems)
@@ -113,27 +107,6 @@ void SmFontPickList::Insert(const vcl::Font &rFont)
     }
 }
 
-void SmFontPickList::Update(const vcl::Font &rFont, const vcl::Font &rNewFont)
-{
-    for (sal_uInt16 nPos = 0; nPos < aFontVec.size(); nPos++)
-        if (CompareItem( aFontVec[nPos], rFont ))
-        {
-            aFontVec[nPos] = rNewFont;
-            break;
-        }
-}
-
-void SmFontPickList::Remove(const vcl::Font &rFont)
-{
-    for (sal_uInt16 nPos = 0; nPos < aFontVec.size(); nPos++)
-        if (CompareItem( aFontVec[nPos], rFont))
-        {
-            aFontVec.erase( aFontVec.begin() + nPos );
-            break;
-        }
-}
-
-
 void SmFontPickList::ReadFrom(const SmFontDialog& rDialog)
 {
     Insert(rDialog.GetFont());
@@ -147,10 +120,7 @@ void SmFontPickList::WriteTo(SmFontDialog& rDialog) const
 
 /**************************************************************************/
 
-extern "C" SAL_DLLPUBLIC_EXPORT vcl::Window* SAL_CALL makeSmFontPickListBox(vcl::Window* pParent, VclBuilder::stringmap &)
-{
-    return new SmFontPickListBox(pParent, WB_DROPDOWN);
-}
+VCL_BUILDER_FACTORY_ARGS(SmFontPickListBox, WB_DROPDOWN)
 
 SmFontPickListBox::SmFontPickListBox (vcl::Window* pParent, WinBits nBits) :
     SmFontPickList(4),
@@ -159,12 +129,11 @@ SmFontPickListBox::SmFontPickListBox (vcl::Window* pParent, WinBits nBits) :
     SetSelectHdl(LINK(this, SmFontPickListBox, SelectHdl));
 }
 
-IMPL_LINK( SmFontPickListBox, SelectHdl, ListBox *, /*pListBox*/ )
+IMPL_LINK_NOARG( SmFontPickListBox, SelectHdl, ListBox&, void )
 {
-    sal_uInt16  nPos;
     OUString aString;
 
-    nPos = GetSelectEntryPos();
+    const sal_Int32 nPos = GetSelectedEntryPos();
 
     if (nPos != 0)
     {
@@ -175,21 +144,17 @@ IMPL_LINK( SmFontPickListBox, SelectHdl, ListBox *, /*pListBox*/ )
     }
 
     SelectEntryPos(0);
-
-    return 0;
 }
 
 SmFontPickListBox& SmFontPickListBox::operator=(const SmFontPickList& rList)
 {
-    sal_uInt16 nPos;
+    *static_cast<SmFontPickList *>(this) = rList;
 
-    *(SmFontPickList *)this = rList;
+    for (decltype(aFontVec)::size_type nPos = 0; nPos < aFontVec.size(); nPos++)
+        InsertEntry(lcl_GetStringItem(aFontVec[nPos]), nPos);
 
-    for (nPos = 0; nPos < aFontVec.size(); nPos++)
-        InsertEntry(GetStringItem(aFontVec[nPos]), nPos);
-
-    if (aFontVec.size() > 0)
-        SelectEntry(GetStringItem(aFontVec.front()));
+    if (!aFontVec.empty())
+        SelectEntry(lcl_GetStringItem(aFontVec.front()));
 
     return *this;
 }
@@ -198,34 +163,15 @@ void SmFontPickListBox::Insert(const vcl::Font &rFont)
 {
     SmFontPickList::Insert(rFont);
 
-    RemoveEntry(GetStringItem(aFontVec.front()));
-    InsertEntry(GetStringItem(aFontVec.front()), 0);
-    SelectEntry(GetStringItem(aFontVec.front()));
+    RemoveEntry(lcl_GetStringItem(aFontVec.front()));
+    InsertEntry(lcl_GetStringItem(aFontVec.front()), 0);
+    SelectEntry(lcl_GetStringItem(aFontVec.front()));
 
     while (GetEntryCount() > nMaxItems)
         RemoveEntry(GetEntryCount() - 1);
-
-    return;
 }
 
 
-void SmFontPickListBox::Update(const vcl::Font &rFont, const vcl::Font &rNewFont)
-{
-    SmFontPickList::Update(rFont, rNewFont);
-
-    return;
-}
-
-
-void SmFontPickListBox::Remove(const vcl::Font &rFont)
-{
-    SmFontPickList::Remove(rFont);
-
-    return;
-}
-
-
-
 bool IsItalic( const vcl::Font &rFont )
 {
     FontItalic eItalic = rFont.GetItalic();
@@ -243,9 +189,9 @@ bool IsBold( const vcl::Font &rFont )
 
 void SmFace::Impl_Init()
 {
-    SetSize( GetSize() );
+    SetSize( GetFontSize() );
     SetTransparent( true );
-    SetAlign( ALIGN_BASELINE );
+    SetAlignment( ALIGN_BASELINE );
     SetColor( COL_AUTO );
 }
 
@@ -264,7 +210,7 @@ void SmFace::SetSize(const Size& rSize)
     //! bodies (eg stack{...} with many entries).
     //! Of course this is holds only if characters are used and not polygons.
 
-    Font::SetSize(aSize);
+    Font::SetFontSize(aSize);
 }
 
 
@@ -288,13 +234,12 @@ SmFace & operator *= (SmFace &rFace, const Fraction &rFrac)
     // scales the width and height of 'rFace' by 'rFrac' and returns a
     // reference to 'rFace'.
     // It's main use is to make scaling fonts look easier.
-{   const Size &rFaceSize = rFace.GetSize();
+{   const Size &rFaceSize = rFace.GetFontSize();
 
-    rFace.SetSize(Size(Fraction(rFaceSize.Width())  *= rFrac,
-                       Fraction(rFaceSize.Height()) *= rFrac));
+    rFace.SetSize(Size(long(rFaceSize.Width() * rFrac),
+                       long(rFaceSize.Height() * rFrac)));
     return rFace;
 }
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
