@@ -26,6 +26,7 @@
 
 #include <rtl/string.hxx>
 #include <rtl/ustrbuf.hxx>
+#include <osl/diagnose.h>
 
 #include <com/sun/star/security/RuntimePermission.hpp>
 #include <com/sun/star/security/AllPermission.hpp>
@@ -39,14 +40,14 @@
 using namespace ::std;
 using namespace ::osl;
 using namespace ::com::sun::star;
-using namespace ::com::sun::star::uno;
+using namespace css::uno;
 
 namespace stoc_sec
 {
 
 
 static inline sal_Int32 makeMask(
-    OUString const & items, char const * const * strings ) SAL_THROW(())
+    OUString const & items, char const * const * strings )
 {
     sal_Int32 mask = 0;
 
@@ -69,12 +70,7 @@ static inline sal_Int32 makeMask(
 #if OSL_DEBUG_LEVEL > 0
         if (! strings[ nPos ])
         {
-            OUStringBuffer buf( 48 );
-            buf.append( "### ignoring unknown socket action: " );
-            buf.append( item );
-            OString str( OUStringToOString(
-                buf.makeStringAndClear(), RTL_TEXTENCODING_ASCII_US ) );
-            OSL_TRACE( "%s", str.getStr() );
+            SAL_WARN("stoc", "ignoring unknown socket action: " << item );
         }
 #endif
     }
@@ -83,7 +79,7 @@ static inline sal_Int32 makeMask(
 }
 
 static inline OUString makeStrings(
-    sal_Int32 mask, char const * const * strings ) SAL_THROW(())
+    sal_Int32 mask, char const * const * strings )
 {
     OUStringBuffer buf( 48 );
     while (mask)
@@ -91,7 +87,7 @@ static inline OUString makeStrings(
         if (0x80000000 & mask)
         {
             buf.appendAscii( *strings );
-            if (mask << 1) // more items following
+            if ((mask << 1) != 0) // more items following
                 buf.append( ',' );
         }
         mask = (mask << 1);
@@ -101,8 +97,6 @@ static inline OUString makeStrings(
 }
 
 
-
-
 class SocketPermission : public Permission
 {
     static char const * s_actions [];
@@ -116,23 +110,21 @@ class SocketPermission : public Permission
     mutable bool m_resolvedHost;
     bool m_wildCardHost;
 
-    inline bool resolveHost() const SAL_THROW(());
+    inline bool resolveHost() const;
 
 public:
     SocketPermission(
         connection::SocketPermission const & perm,
-        ::rtl::Reference< Permission > const & next = ::rtl::Reference< Permission >() )
-        SAL_THROW(());
-    virtual bool implies( Permission const & perm ) const SAL_THROW(()) SAL_OVERRIDE;
-    virtual OUString toString() const SAL_THROW(()) SAL_OVERRIDE;
+        ::rtl::Reference< Permission > const & next = ::rtl::Reference< Permission >() );
+    virtual bool implies( Permission const & perm ) const override;
+    virtual OUString toString() const override;
 };
 
-char const * SocketPermission::s_actions [] = { "accept", "connect", "listen", "resolve", 0 };
+char const * SocketPermission::s_actions [] = { "accept", "connect", "listen", "resolve", nullptr };
 
 SocketPermission::SocketPermission(
     connection::SocketPermission const & perm,
     ::rtl::Reference< Permission > const & next )
-    SAL_THROW(())
     : Permission( SOCKET, next )
     , m_actions( makeMask( perm.Actions, s_actions ) )
     , m_host( perm.Host )
@@ -165,13 +157,13 @@ SocketPermission::SocketPermission(
         else // A-B
         {
             m_lowerPort = m_host.copy( colon +1, minus - colon -1 ).toInt32();
-            m_upperPort = m_host.copy( minus +1, m_host.getLength() -minus -1 ).toInt32();
+            m_upperPort = m_host.copy( minus +1 ).toInt32();
         }
         m_host = m_host.copy( 0, colon );
     }
 }
 
-inline bool SocketPermission::resolveHost() const SAL_THROW(())
+inline bool SocketPermission::resolveHost() const
 {
     if (m_resolveErr)
         return false;
@@ -197,7 +189,7 @@ inline bool SocketPermission::resolveHost() const SAL_THROW(())
     return m_resolvedHost;
 }
 
-bool SocketPermission::implies( Permission const & perm ) const SAL_THROW(())
+bool SocketPermission::implies( Permission const & perm ) const
 {
     // check type
     if (SOCKET != perm.m_type)
@@ -236,10 +228,10 @@ bool SocketPermission::implies( Permission const & perm ) const SAL_THROW(())
         return false;
     if (! demanded.resolveHost())
         return false;
-    return m_ip.equals( demanded.m_ip );
+    return m_ip == demanded.m_ip;
 }
 
-OUString SocketPermission::toString() const SAL_THROW(())
+OUString SocketPermission::toString() const
 {
     OUStringBuffer buf( 48 );
     // host
@@ -272,8 +264,6 @@ OUString SocketPermission::toString() const SAL_THROW(())
 }
 
 
-
-
 class FilePermission : public Permission
 {
     static char const * s_actions [];
@@ -285,17 +275,16 @@ class FilePermission : public Permission
 public:
     FilePermission(
         io::FilePermission const & perm,
-        ::rtl::Reference< Permission > const & next = ::rtl::Reference< Permission >() )
-        SAL_THROW(());
-    virtual bool implies( Permission const & perm ) const SAL_THROW(()) SAL_OVERRIDE;
-    virtual OUString toString() const SAL_THROW(()) SAL_OVERRIDE;
+        ::rtl::Reference< Permission > const & next = ::rtl::Reference< Permission >() );
+    virtual bool implies( Permission const & perm ) const override;
+    virtual OUString toString() const override;
 };
 
-char const * FilePermission::s_actions [] = { "read", "write", "execute", "delete", 0 };
+char const * FilePermission::s_actions [] = { "read", "write", "execute", "delete", nullptr };
 
-static OUString const & getWorkingDir() SAL_THROW(())
+static OUString const & getWorkingDir()
 {
-    static OUString * s_workingDir = 0;
+    static OUString * s_workingDir = nullptr;
     if (! s_workingDir)
     {
         OUString workingDir;
@@ -314,7 +303,6 @@ static OUString const & getWorkingDir() SAL_THROW(())
 FilePermission::FilePermission(
     io::FilePermission const & perm,
     ::rtl::Reference< Permission > const & next )
-    SAL_THROW(())
     : Permission( FILE, next )
     , m_actions( makeMask( perm.Actions, s_actions ) )
     , m_url( perm.URL )
@@ -356,7 +344,7 @@ FilePermission::FilePermission(
     }
 }
 
-bool FilePermission::implies( Permission const & perm ) const SAL_THROW(())
+bool FilePermission::implies( Permission const & perm ) const
 {
     // check type
     if (FILE != perm.m_type)
@@ -377,14 +365,13 @@ bool FilePermission::implies( Permission const & perm ) const SAL_THROW(())
     if (m_url.equalsIgnoreAsciiCase( demanded.m_url ))
         return true;
 #else
-    if (m_url.equals( demanded.m_url ))
+    if (m_url == demanded.m_url )
         return true;
 #endif
     if (m_url.getLength() > demanded.m_url.getLength())
         return false;
     // check /- wildcard: all files and recursive in that path
-    if (1 < m_url.getLength() &&
-        0 == ::rtl_ustr_ascii_compare_WithLength( m_url.getStr() + m_url.getLength() - 2, 2, "/-" ))
+    if (m_url.endsWith("/-"))
     {
         // demanded url must start with granted path (including path trailing path sep)
         sal_Int32 len = m_url.getLength() -1;
@@ -397,8 +384,7 @@ bool FilePermission::implies( Permission const & perm ) const SAL_THROW(())
 #endif
     }
     // check /* wildcard: all files in that path (not recursive!)
-    if (1 < m_url.getLength() &&
-        0 == ::rtl_ustr_ascii_compare_WithLength( m_url.getStr() + m_url.getLength() - 2, 2, "/*" ))
+    if (m_url.endsWith("/*"))
     {
         // demanded url must start with granted path (including path trailing path sep)
         sal_Int32 len = m_url.getLength() -1;
@@ -415,7 +401,7 @@ bool FilePermission::implies( Permission const & perm ) const SAL_THROW(())
     return false;
 }
 
-OUString FilePermission::toString() const SAL_THROW(())
+OUString FilePermission::toString() const
 {
     OUStringBuffer buf( 48 );
     // url
@@ -429,25 +415,22 @@ OUString FilePermission::toString() const SAL_THROW(())
 }
 
 
-
-
 class RuntimePermission : public Permission
 {
     OUString m_name;
 
 public:
-    inline RuntimePermission(
+    RuntimePermission(
         security::RuntimePermission const & perm,
         ::rtl::Reference< Permission > const & next = ::rtl::Reference< Permission >() )
-        SAL_THROW(())
         : Permission( RUNTIME, next )
         , m_name( perm.Name )
         {}
-    virtual bool implies( Permission const & perm ) const SAL_THROW(()) SAL_OVERRIDE;
-    virtual OUString toString() const SAL_THROW(()) SAL_OVERRIDE;
+    virtual bool implies( Permission const & perm ) const override;
+    virtual OUString toString() const override;
 };
 
-bool RuntimePermission::implies( Permission const & perm ) const SAL_THROW(())
+bool RuntimePermission::implies( Permission const & perm ) const
 {
     // check type
     if (RUNTIME != perm.m_type)
@@ -455,10 +438,10 @@ bool RuntimePermission::implies( Permission const & perm ) const SAL_THROW(())
     RuntimePermission const & demanded = static_cast< RuntimePermission const & >( perm );
 
     // check name
-    return m_name.equals( demanded.m_name );
+    return m_name == demanded.m_name;
 }
 
-OUString RuntimePermission::toString() const SAL_THROW(())
+OUString RuntimePermission::toString() const
 {
     OUStringBuffer buf( 48 );
     buf.append( "com.sun.star.security.RuntimePermission (name=\"" );
@@ -468,24 +451,19 @@ OUString RuntimePermission::toString() const SAL_THROW(())
 }
 
 
-
-
-bool AllPermission::implies( Permission const & ) const SAL_THROW(())
+bool AllPermission::implies( Permission const & ) const
 {
     return true;
 }
 
-OUString AllPermission::toString() const SAL_THROW(())
+OUString AllPermission::toString() const
 {
     return OUString("com.sun.star.security.AllPermission");
 }
 
 
-
-
 PermissionCollection::PermissionCollection(
     Sequence< Any > const & permissions, PermissionCollection const & addition )
-    SAL_THROW( (RuntimeException) )
     : m_head( addition.m_head )
 {
     Any const * perms = permissions.getConstArray();
@@ -495,38 +473,34 @@ PermissionCollection::PermissionCollection(
         Type const & perm_type = perm.getValueType();
 
         // supported permission types
-        if (perm_type.equals( ::getCppuType( (io::FilePermission const *)0 ) ))
+        if (perm_type.equals( cppu::UnoType<io::FilePermission>::get()))
         {
             m_head = new FilePermission(
-                *reinterpret_cast< io::FilePermission const * >( perm.pData ), m_head );
+                *static_cast< io::FilePermission const * >( perm.pData ), m_head );
         }
-        else if (perm_type.equals( ::getCppuType( (connection::SocketPermission const *)0 ) ))
+        else if (perm_type.equals( cppu::UnoType<connection::SocketPermission>::get()))
         {
             m_head = new SocketPermission(
-                *reinterpret_cast< connection::SocketPermission const * >( perm.pData ), m_head );
+                *static_cast< connection::SocketPermission const * >( perm.pData ), m_head );
         }
-        else if (perm_type.equals( ::getCppuType( (security::RuntimePermission const *)0 ) ))
+        else if (perm_type.equals( cppu::UnoType<security::RuntimePermission>::get()))
         {
             m_head = new RuntimePermission(
-                *reinterpret_cast< security::RuntimePermission const * >( perm.pData ), m_head );
+                *static_cast< security::RuntimePermission const * >( perm.pData ), m_head );
         }
-        else if (perm_type.equals( ::getCppuType( (security::AllPermission const *)0 ) ))
+        else if (perm_type.equals( cppu::UnoType<security::AllPermission>::get()))
         {
             m_head = new AllPermission( m_head );
         }
         else
         {
-            OUStringBuffer buf( 48 );
-            buf.append( "checking for unsupported permission type: " );
-            buf.append( perm_type.getTypeName() );
-            throw RuntimeException(
-                buf.makeStringAndClear(), Reference< XInterface >() );
+            throw RuntimeException( "checking for unsupported permission type: " + perm_type.getTypeName() );
         }
     }
 }
 #ifdef __DIAGNOSE
 
-Sequence< OUString > PermissionCollection::toStrings() const SAL_THROW(())
+Sequence< OUString > PermissionCollection::toStrings() const
 {
     vector< OUString > strings;
     strings.reserve( 8 );
@@ -534,13 +508,12 @@ Sequence< OUString > PermissionCollection::toStrings() const SAL_THROW(())
     {
         strings.push_back( perm->toString() );
     }
-    return Sequence< OUString >(
-        strings.empty() ? 0 : &strings[ 0 ], strings.size() );
+    return Sequence< OUString >( strings.data(), strings.size() );
 }
 #endif
 
-inline static bool __implies(
-    ::rtl::Reference< Permission > const & head, Permission const & demanded ) SAL_THROW(())
+inline static bool implies(
+    ::rtl::Reference< Permission > const & head, Permission const & demanded )
 {
     for ( Permission * perm = head.get(); perm; perm = perm->m_next.get() )
     {
@@ -554,7 +527,6 @@ inline static bool __implies(
 
 static void demanded_diag(
     Permission const & perm )
-    SAL_THROW(())
 {
     OUStringBuffer buf( 48 );
     buf.append( "demanding " );
@@ -562,34 +534,30 @@ static void demanded_diag(
     buf.append( " => ok." );
     OString str(
         OUStringToOString( buf.makeStringAndClear(), RTL_TEXTENCODING_ASCII_US ) );
-    OSL_TRACE( "%s", str.getStr() );
+    SAL_INFO("stoc",( "%s", str.getStr() );
 }
 #endif
 
 static void throwAccessControlException(
     Permission const & perm, Any const & demanded_perm )
-    SAL_THROW( (security::AccessControlException) )
 {
-    OUStringBuffer buf( 48 );
-    buf.append( "access denied: " );
-    buf.append( perm.toString() );
     throw security::AccessControlException(
-        buf.makeStringAndClear(), Reference< XInterface >(), demanded_perm );
+        "access denied: " + perm.toString(),
+        Reference< XInterface >(), demanded_perm );
 }
 
 void PermissionCollection::checkPermission( Any const & perm ) const
-    SAL_THROW( (RuntimeException) )
 {
     Type const & demanded_type = perm.getValueType();
 
     // supported permission types
     // stack object of SimpleReferenceObject are ok, as long as they are not
     // assigned to a ::rtl::Reference<> (=> delete this)
-    if (demanded_type.equals( ::getCppuType( (io::FilePermission const *)0 ) ))
+    if (demanded_type.equals( cppu::UnoType<io::FilePermission>::get()))
     {
         FilePermission demanded(
-            *reinterpret_cast< io::FilePermission const * >( perm.pData ) );
-        if (__implies( m_head, demanded ))
+            *static_cast< io::FilePermission const * >( perm.pData ) );
+        if (implies( m_head, demanded ))
         {
 #ifdef __DIAGNOSE
             demanded_diag( demanded );
@@ -598,11 +566,11 @@ void PermissionCollection::checkPermission( Any const & perm ) const
         }
         throwAccessControlException( demanded, perm );
     }
-    else if (demanded_type.equals( ::getCppuType( (connection::SocketPermission const *)0 ) ))
+    else if (demanded_type.equals( cppu::UnoType<connection::SocketPermission>::get()))
     {
         SocketPermission demanded(
-            *reinterpret_cast< connection::SocketPermission const * >( perm.pData ) );
-        if (__implies( m_head, demanded ))
+            *static_cast< connection::SocketPermission const * >( perm.pData ) );
+        if (implies( m_head, demanded ))
         {
 #ifdef __DIAGNOSE
             demanded_diag( demanded );
@@ -611,11 +579,11 @@ void PermissionCollection::checkPermission( Any const & perm ) const
         }
         throwAccessControlException( demanded, perm );
     }
-    else if (demanded_type.equals( ::getCppuType( (security::RuntimePermission const *)0 ) ))
+    else if (demanded_type.equals( cppu::UnoType<security::RuntimePermission>::get()))
     {
         RuntimePermission demanded(
-            *reinterpret_cast< security::RuntimePermission const * >( perm.pData ) );
-        if (__implies( m_head, demanded ))
+            *static_cast< security::RuntimePermission const * >( perm.pData ) );
+        if (implies( m_head, demanded ))
         {
 #ifdef __DIAGNOSE
             demanded_diag( demanded );
@@ -624,10 +592,10 @@ void PermissionCollection::checkPermission( Any const & perm ) const
         }
         throwAccessControlException( demanded, perm );
     }
-    else if (demanded_type.equals( ::getCppuType( (security::AllPermission const *)0 ) ))
+    else if (demanded_type.equals( cppu::UnoType<security::AllPermission>::get()))
     {
         AllPermission demanded;
-        if (__implies( m_head, demanded ))
+        if (implies( m_head, demanded ))
         {
 #ifdef __DIAGNOSE
             demanded_diag( demanded );
@@ -638,11 +606,7 @@ void PermissionCollection::checkPermission( Any const & perm ) const
     }
     else
     {
-        OUStringBuffer buf( 48 );
-        buf.append( "checking for unsupported permission type: " );
-        buf.append( demanded_type.getTypeName() );
-        throw RuntimeException(
-            buf.makeStringAndClear(), Reference< XInterface >() );
+        throw RuntimeException( "checking for unsupported permission type: " + demanded_type.getTypeName() );
     }
 }
 
