@@ -19,51 +19,18 @@
 
 #include "storbase.hxx"
 
-#include "boost/noncopyable.hpp"
-#include "sal/types.h"
-#include "rtl/alloc.h"
-#include "rtl/ref.hxx"
-#include "osl/diagnose.h"
+#include <sal/types.h>
+#include <rtl/alloc.h>
+#include <rtl/ref.hxx>
+#include <osl/diagnose.h>
 
-#include "store/types.h"
+#include <store/types.h>
 #include "object.hxx"
 
 #include <stdio.h>
 
 using namespace store;
 
-/*========================================================================
- *
- * SharedCount::Allocator.
- *
- *======================================================================*/
-SharedCount::Allocator &
-SharedCount::Allocator::get()
-{
-    static Allocator g_aSharedCountAllocator;
-    return g_aSharedCountAllocator;
-}
-
-SharedCount::Allocator::Allocator()
-{
-    m_cache = rtl_cache_create (
-        "store_shared_count_cache",
-        sizeof(long),
-        0, // objalign
-        0, // constructor
-        0, // destructor
-        0, // reclaim
-        0, // userarg
-        0, // default source
-        0  // flags
-        );
-}
-
-SharedCount::Allocator::~Allocator()
-{
-    rtl_cache_destroy (m_cache), m_cache = 0;
-}
-
 /*========================================================================
  *
  * PageData::Allocator_Impl (default allocator).
@@ -74,20 +41,22 @@ namespace store
 
 class PageData::Allocator_Impl :
     public store::OStoreObject,
-    public store::PageData::Allocator,
-    private boost::noncopyable
+    public store::PageData::Allocator
 {
 public:
     /** Construction (two phase).
      */
     Allocator_Impl();
 
+    Allocator_Impl(const Allocator_Impl&) = delete;
+    Allocator_Impl& operator=(const Allocator_Impl&) = delete;
+
     storeError initialize (sal_uInt16 nPageSize);
 
 protected:
     /** Destruction.
      */
-    virtual ~Allocator_Impl();
+    virtual ~Allocator_Impl() override;
 
 private:
     /** Representation.
@@ -97,24 +66,24 @@ private:
 
     /** PageData::Allocator implementation.
      */
-    virtual void allocate_Impl (void ** ppPage, sal_uInt16 * pnSize) SAL_OVERRIDE;
-    virtual void deallocate_Impl (void * pPage) SAL_OVERRIDE;
+    virtual void allocate_Impl (void ** ppPage, sal_uInt16 * pnSize) override;
+    virtual void deallocate_Impl (void * pPage) override;
 };
 
 } // namespace store
 
 PageData::Allocator_Impl::Allocator_Impl()
-    : m_page_cache(0), m_page_size(0)
+    : m_page_cache(nullptr), m_page_size(0)
 {}
 
 storeError
 PageData::Allocator_Impl::initialize (sal_uInt16 nPageSize)
 {
     char name[RTL_CACHE_NAME_LENGTH + 1];
-    sal_Size size = sal::static_int_cast< sal_Size >(nPageSize);
-    (void) snprintf (name, sizeof(name), "store_page_alloc_%" SAL_PRIuUINTPTR, size);
+    std::size_t size = sal::static_int_cast<std::size_t>(nPageSize);
+    (void) snprintf (name, sizeof(name), "store_page_alloc_%" SAL_PRI_SIZET "u", size);
 
-    m_page_cache = rtl_cache_create (name, size, 0, 0, 0, 0, 0, 0, 0);
+    m_page_cache = rtl_cache_create (name, size, 0, nullptr, nullptr, nullptr, nullptr, nullptr, 0);
     if (!m_page_cache)
         return store_E_OutOfMemory;
 
@@ -124,19 +93,23 @@ PageData::Allocator_Impl::initialize (sal_uInt16 nPageSize)
 
 PageData::Allocator_Impl::~Allocator_Impl()
 {
-    rtl_cache_destroy(m_page_cache), m_page_cache = 0;
+    rtl_cache_destroy(m_page_cache);
+    m_page_cache = nullptr;
 }
 
 void PageData::Allocator_Impl::allocate_Impl (void ** ppPage, sal_uInt16 * pnSize)
 {
-    OSL_PRECOND((ppPage != 0) && (pnSize != 0), "contract violation");
-    if ((ppPage != 0) && (pnSize != 0))
-        *ppPage = rtl_cache_alloc(m_page_cache), *pnSize = m_page_size;
+    OSL_PRECOND((ppPage != nullptr) && (pnSize != nullptr), "contract violation");
+    if ((ppPage != nullptr) && (pnSize != nullptr))
+    {
+        *ppPage = rtl_cache_alloc(m_page_cache);
+        *pnSize = m_page_size;
+    }
 }
 
 void PageData::Allocator_Impl::deallocate_Impl (void * pPage)
 {
-    OSL_PRECOND(pPage != 0, "contract violation");
+    OSL_PRECOND(pPage != nullptr, "contract violation");
     rtl_cache_free(m_page_cache, pPage);
 }
 
