@@ -17,21 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
 #include "storbios.hxx"
 
-#include "sal/types.h"
-#include "sal/macros.h"
-#include "sal/log.hxx"
+#include <sal/types.h>
+#include <sal/macros.h>
+#include <sal/log.hxx>
 
-#include "rtl/alloc.h"
-#include "rtl/ref.hxx"
+#include <rtl/alloc.h>
+#include <rtl/ref.hxx>
 
-#include "osl/diagnose.h"
-#include "osl/mutex.hxx"
+#include <osl/diagnose.h>
+#include <osl/mutex.hxx>
 
-#include "store/types.h"
+#include <store/types.h>
 #include "object.hxx"
 #include "lockbyte.hxx"
 #include "storcach.hxx"
@@ -195,7 +195,7 @@ struct SuperBlockPage
 
     /** save.
      */
-    storeError save (OStorePageBIOS & rBIOS, sal_uInt32 nSize = theSize)
+    storeError save (OStorePageBIOS const & rBIOS, sal_uInt32 nSize = theSize)
     {
         m_aSuperOne.guard();
         m_aSuperTwo = m_aSuperOne;
@@ -205,20 +205,20 @@ struct SuperBlockPage
     /** Page allocation.
      */
     storeError unusedHead (
-        OStorePageBIOS & rBIOS,
+        OStorePageBIOS const & rBIOS,
         PageData &       rPageHead);
 
     storeError unusedPop (
-        OStorePageBIOS & rBIOS,
+        OStorePageBIOS const & rBIOS,
         PageData const & rPageHead);
 
     storeError unusedPush (
-        OStorePageBIOS & rBIOS,
+        OStorePageBIOS const & rBIOS,
         sal_uInt32       nAddr);
 
     /** verify (with repair).
      */
-    storeError verify (OStorePageBIOS & rBIOS);
+    storeError verify (OStorePageBIOS const & rBIOS);
 };
 
 } // namespace store
@@ -231,7 +231,7 @@ struct SuperBlockPage
 /*
  * unusedHead(): get freelist head (alloc page, step 1).
  */
-storeError SuperBlockPage::unusedHead (OStorePageBIOS & rBIOS, PageData & rPageHead)
+storeError SuperBlockPage::unusedHead (OStorePageBIOS const & rBIOS, PageData & rPageHead)
 {
     storeError eErrCode = verify (rBIOS);
     if (eErrCode != store_E_None)
@@ -274,7 +274,7 @@ storeError SuperBlockPage::unusedHead (OStorePageBIOS & rBIOS, PageData & rPageH
 /*
  * unusedPop(): pop freelist head (alloc page, step 2).
  */
-storeError SuperBlockPage::unusedPop (OStorePageBIOS & rBIOS, PageData const & rPageHead)
+storeError SuperBlockPage::unusedPop (OStorePageBIOS const & rBIOS, PageData const & rPageHead)
 {
     sal_uInt32 const nAddr = rPageHead.m_aUnused.location();
     OSL_PRECOND(nAddr != STORE_PAGE_NULL, "store::SuperBlock::unusedPop(): page not free");
@@ -290,7 +290,7 @@ storeError SuperBlockPage::unusedPop (OStorePageBIOS & rBIOS, PageData const & r
 /*
  * unusedPush(): push new freelist head.
  */
-storeError SuperBlockPage::unusedPush (OStorePageBIOS & rBIOS, sal_uInt32 nAddr)
+storeError SuperBlockPage::unusedPush (OStorePageBIOS const & rBIOS, sal_uInt32 nAddr)
 {
     storeError eErrCode = verify (rBIOS);
     if (eErrCode != store_E_None)
@@ -320,7 +320,7 @@ storeError SuperBlockPage::unusedPush (OStorePageBIOS & rBIOS, sal_uInt32 nAddr)
 /*
  * verify (with repair).
  */
-storeError SuperBlockPage::verify (OStorePageBIOS & rBIOS)
+storeError SuperBlockPage::verify (OStorePageBIOS const & rBIOS)
 {
     // Verify 1st copy.
     storeError eErrCode = m_aSuperOne.verify();
@@ -373,7 +373,7 @@ storeError SuperBlockPage::verify (OStorePageBIOS & rBIOS)
         else
         {
             // Double Failure.
-            OSL_TRACE("OStoreSuperBlockPage::verify(): double failure.");
+            SAL_WARN("store", "OStoreSuperBlockPage::verify(): double failure.");
         }
     }
 
@@ -688,7 +688,7 @@ void OStorePageBIOS::cleanup_Impl()
  * Low Level: Precond: initialized, exclusive access.
  */
 storeError OStorePageBIOS::read (
-    sal_uInt32 nAddr, void *pData, sal_uInt32 nSize)
+    sal_uInt32 nAddr, void *pData, sal_uInt32 nSize) const
 {
     // Check precond.
     if (!m_xLockBytes.is())
@@ -703,7 +703,7 @@ storeError OStorePageBIOS::read (
  * Low Level: Precond: initialized, writeable, exclusive access.
  */
 storeError OStorePageBIOS::write (
-    sal_uInt32 nAddr, const void *pData, sal_uInt32 nSize)
+    sal_uInt32 nAddr, const void *pData, sal_uInt32 nSize) const
 {
     // Check precond.
     if (!m_xLockBytes.is())
@@ -874,7 +874,7 @@ storeError OStorePageBIOS::loadObjectAt (OStorePageObject & rPage, sal_uInt32 nA
  * loadObjectAt_Impl.
  * Internal: Precond: initialized, readable, exclusive access.
  */
-storeError OStorePageBIOS::loadObjectAt_Impl (OStorePageObject & rPage, sal_uInt32 nAddr)
+storeError OStorePageBIOS::loadObjectAt_Impl (OStorePageObject & rPage, sal_uInt32 nAddr) const
 {
     storeError eErrCode = m_xCache->lookupPageAt (rPage.get(), nAddr);
     if (eErrCode != store_E_NotExists)
@@ -920,7 +920,7 @@ storeError OStorePageBIOS::saveObjectAt (OStorePageObject & rPage, sal_uInt32 nA
  * saveObjectAt_Impl.
  * Internal: Precond: initialized, writeable, exclusive access.
  */
-storeError OStorePageBIOS::saveObjectAt_Impl (OStorePageObject & rPage, sal_uInt32 nAddr)
+storeError OStorePageBIOS::saveObjectAt_Impl (OStorePageObject & rPage, sal_uInt32 nAddr) const
 {
     // Guard page (incl. set location).
     storeError eErrCode = rPage.guard (nAddr);
