@@ -17,9 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <svgio/svgreader/svgmarkernode.hxx>
-
-//////////////////////////////////////////////////////////////////////////////
+#include <svgmarkernode.hxx>
 
 namespace svgio
 {
@@ -31,7 +29,7 @@ namespace svgio
         :   SvgNode(SVGTokenMarker, rDocument, pParent),
             aPrimitives(),
             maSvgStyleAttributes(*this),
-            mpViewBox(0),
+            mpViewBox(nullptr),
             maSvgAspectRatio(),
             maRefX(0),
             maRefY(0),
@@ -45,13 +43,11 @@ namespace svgio
 
         SvgMarkerNode::~SvgMarkerNode()
         {
-            if(mpViewBox) delete mpViewBox;
         }
 
         const SvgStyleAttributes* SvgMarkerNode::getSvgStyleAttributes() const
         {
-            static rtl::OUString aClassStr(rtl::OUString::createFromAscii("marker"));
-            return checkForCssStyle(aClassStr, maSvgStyleAttributes);
+            return checkForCssStyle("marker", maSvgStyleAttributes);
         }
 
         void SvgMarkerNode::parseAttribute(const OUString& rTokenName, SVGToken aSVGToken, const OUString& aContent)
@@ -60,14 +56,14 @@ namespace svgio
             SvgNode::parseAttribute(rTokenName, aSVGToken, aContent);
 
             // read style attributes
-            maSvgStyleAttributes.parseStyleAttribute(rTokenName, aSVGToken, aContent);
+            maSvgStyleAttributes.parseStyleAttribute(aSVGToken, aContent, false);
 
             // parse own
             switch(aSVGToken)
             {
                 case SVGTokenStyle:
                 {
-                    maSvgStyleAttributes.readStyle(aContent);
+                    readLocalCssStyle(aContent);
                     break;
                 }
                 case SVGTokenViewBox:
@@ -82,7 +78,7 @@ namespace svgio
                 }
                 case SVGTokenPreserveAspectRatio:
                 {
-                    setSvgAspectRatio(readSvgAspectRatio(aContent));
+                    maSvgAspectRatio = readSvgAspectRatio(aContent);
                     break;
                 }
                 case SVGTokenRefX:
@@ -91,7 +87,7 @@ namespace svgio
 
                     if(readSingleNumber(aContent, aNum))
                     {
-                        setRefX(aNum);
+                        maRefX = aNum;
                     }
                     break;
                 }
@@ -101,7 +97,7 @@ namespace svgio
 
                     if(readSingleNumber(aContent, aNum))
                     {
-                        setRefY(aNum);
+                        maRefY = aNum;
                     }
                     break;
                 }
@@ -109,13 +105,11 @@ namespace svgio
                 {
                     if(!aContent.isEmpty())
                     {
-                        static OUString aStrStrokeWidth(OUString::createFromAscii("strokeWidth"));
-
-                        if(aContent.match(aStrStrokeWidth, 0))
+                        if(aContent.startsWith("strokeWidth"))
                         {
                             setMarkerUnits(strokeWidth);
                         }
-                        else if(aContent.match(commonStrings::aStrUserSpaceOnUse, 0))
+                        else if(aContent.match(commonStrings::aStrUserSpaceOnUse))
                         {
                             setMarkerUnits(userSpaceOnUse);
                         }
@@ -130,7 +124,7 @@ namespace svgio
                     {
                         if(aNum.isPositive())
                         {
-                            setMarkerWidth(aNum);
+                            maMarkerWidth = aNum;
                         }
                     }
                     break;
@@ -143,7 +137,7 @@ namespace svgio
                     {
                         if(aNum.isPositive())
                         {
-                            setMarkerHeight(aNum);
+                            maMarkerHeight = aNum;
                         }
                     }
                     break;
@@ -154,11 +148,9 @@ namespace svgio
 
                     if(nLen)
                     {
-                        static OUString aStrAuto(OUString::createFromAscii("auto"));
-
-                        if(aContent.match(aStrAuto, 0))
+                        if(aContent.startsWith("auto"))
                         {
-                            setOrientAuto(true);
+                            mbOrientAuto = true;
                         }
                         else
                         {
@@ -180,9 +172,9 @@ namespace svgio
             }
         }
 
-        const drawinglayer::primitive2d::Primitive2DSequence& SvgMarkerNode::getMarkerPrimitives() const
+        const drawinglayer::primitive2d::Primitive2DContainer& SvgMarkerNode::getMarkerPrimitives() const
         {
-            if(!aPrimitives.hasElements() && Display_none != getDisplay())
+            if(aPrimitives.empty() && Display_none != getDisplay())
             {
                 decomposeSvgNode(const_cast< SvgMarkerNode* >(this)->aPrimitives, true);
             }
@@ -205,7 +197,4 @@ namespace svgio
     } // end of namespace svgreader
 } // end of namespace svgio
 
-//////////////////////////////////////////////////////////////////////////////
-// eof
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
