@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <svl/style.hxx>
 
 #include <com/sun/star/lang/XComponent.hpp>
@@ -26,7 +27,7 @@
 #include <osl/diagnose.h>
 #include <comphelper/processfactory.hxx>
 #include <unotools/intlwrapper.hxx>
-#include <svl/smplhint.hxx>
+#include <svl/hint.hxx>
 #include <svl/poolitem.hxx>
 #include <svl/itemset.hxx>
 #include <svl/itempool.hxx>
@@ -35,6 +36,7 @@
 #include <unotools/syslocale.hxx>
 #include <algorithm>
 #include <comphelper/servicehelper.hxx>
+#include <o3tl/make_unique.hxx>
 
 #include <string.h>
 
@@ -53,43 +55,38 @@ public:
 
     sal_uInt32 mnStyles;
     sal_uInt32 mnPools;
-}
-aDbgStyleSheetReferences;
+};
 
+static DbgStyleSheetReferences aDbgStyleSheetReferences;
 #endif
 
-TYPEINIT0(SfxStyleSheetBase)
 
-TYPEINIT3(SfxStyleSheet, SfxStyleSheetBase, SfxListener, SfxBroadcaster)
-
-SfxStyleSheetHintExtended::SfxStyleSheetHintExtended
+SfxStyleSheetModifiedHint::SfxStyleSheetModifiedHint
 (
-    sal_uInt16          nAction,        // SfxStyleSheetHintId::... (see above)
     const OUString&     rOldName,
     SfxStyleSheetBase&  rStyleSheet     // Remains with the caller
 )
-:   SfxStyleSheetHint( nAction, rStyleSheet ),
+:   SfxStyleSheetHint( SfxHintId::StyleSheetModified, rStyleSheet ),
     aName( rOldName )
 {}
 
 
 SfxStyleSheetHint::SfxStyleSheetHint
 (
-    sal_uInt16              nAction,    // SfxStyleSheetHintId::... (see above)
+    SfxHintId           nAction,
     SfxStyleSheetBase&  rStyleSheet     // Remains with the caller
 )
-:   pStyleSh( &rStyleSheet ),
-    nHint( nAction )
+:   SfxHint(nAction), pStyleSh( &rStyleSheet )
 {}
 
 
 class SfxStyleSheetBasePool_Impl
 {
 private:
-    SfxStyleSheetBasePool_Impl(const SfxStyleSheetBasePool_Impl&) SAL_DELETED_FUNCTION;
-    SfxStyleSheetBasePool_Impl& operator=(const SfxStyleSheetBasePool_Impl&) SAL_DELETED_FUNCTION;
+    SfxStyleSheetBasePool_Impl(const SfxStyleSheetBasePool_Impl&) = delete;
+    SfxStyleSheetBasePool_Impl& operator=(const SfxStyleSheetBasePool_Impl&) = delete;
 public:
-    SfxStyleSheetIteratorPtr pIter;
+    std::shared_ptr<SfxStyleSheetIterator> pIter;
 
     /** This member holds the indexed style sheets.
      *
@@ -110,7 +107,7 @@ SfxStyleSheetBase::SfxStyleSheetBase( const OUString& rName, SfxStyleSheetBasePo
     , aName( rName )
     , aParent()
     , aFollow( rName )
-    , pSet( NULL )
+    , pSet( nullptr )
     , nMask(mask)
     , nHelpId( 0 )
     , bMySet( false )
@@ -140,7 +137,7 @@ SfxStyleSheetBase::SfxStyleSheetBase( const SfxStyleSheetBase& r )
     if( r.pSet )
         pSet = bMySet ? new SfxItemSet( *r.pSet ) : r.pSet;
     else
-        pSet = NULL;
+        pSet = nullptr;
 }
 
 SfxStyleSheetBase::~SfxStyleSheetBase()
@@ -152,7 +149,7 @@ SfxStyleSheetBase::~SfxStyleSheetBase()
     if( bMySet )
     {
         delete pSet;
-        pSet = 0;
+        pSet = nullptr;
     }
 }
 
@@ -188,13 +185,12 @@ bool SfxStyleSheetBase::SetName(const OUString& rName, bool bReIndexNow)
         if (bReIndexNow)
             pPool->Reindex();
         pPool->SetSearchMask(eTmpFam, nTmpMask);
-        pPool->Broadcast( SfxStyleSheetHintExtended(
-            SfxStyleSheetHintId::MODIFIED, aOldName, *this ) );
+        pPool->Broadcast( SfxStyleSheetModifiedHint( aOldName, *this ) );
     }
     return true;
 }
 
-OUString SfxStyleSheetBase::GetDisplayName() const
+OUString const & SfxStyleSheetBase::GetDisplayName() const
 {
     if( maDisplayName.isEmpty() )
     {
@@ -237,14 +233,14 @@ bool SfxStyleSheetBase::SetParent( const OUString& rName )
         }
         aParent = rName;
     }
-    pPool->Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::MODIFIED, *this ) );
+    pPool->Broadcast( SfxStyleSheetHint( SfxHintId::StyleSheetModified, *this ) );
     return true;
 }
 
 void SfxStyleSheetBase::SetHidden( bool hidden )
 {
     bHidden = hidden;
-    pPool->Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::MODIFIED, *this ) );
+    pPool->Broadcast( SfxStyleSheetHint( SfxHintId::StyleSheetModified, *this ) );
 }
 
 /**
@@ -261,12 +257,12 @@ bool SfxStyleSheetBase::SetFollow( const OUString& rName )
     {
         if( !pPool->Find( rName, nFamily ) )
         {
-            SAL_WARN( "svl", "StyleSheet-Follow not found" );
+            SAL_WARN( "svl.items", "StyleSheet-Follow not found" );
             return false;
         }
         aFollow = rName;
     }
-    pPool->Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::MODIFIED, *this ) );
+    pPool->Broadcast( SfxStyleSheetHint( SfxHintId::StyleSheetModified, *this ) );
     return true;
 }
 
@@ -284,6 +280,11 @@ SfxItemSet& SfxStyleSheetBase::GetItemSet()
     return *pSet;
 }
 
+std::unique_ptr<SfxItemSet> SfxStyleSheetBase::GetItemSetForPreview()
+{
+    return o3tl::make_unique<SfxItemSet>(GetItemSet());
+}
+
 /**
  * Set help file and ID and return it
  */
@@ -337,28 +338,20 @@ bool SfxStyleSheetBase::IsUsed() const
 /**
  * Return set attributes
  */
-OUString SfxStyleSheetBase::GetDescription()
-{
-    return GetDescription( SFX_MAPUNIT_CM );
-}
-
-/**
- * Return set attributes
- */
-OUString SfxStyleSheetBase::GetDescription( SfxMapUnit eMetric )
+OUString SfxStyleSheetBase::GetDescription( MapUnit eMetric )
 {
     SfxItemIter aIter( GetItemSet() );
     OUString aDesc;
     const SfxPoolItem* pItem = aIter.FirstItem();
 
-    IntlWrapper aIntlWrapper( SvtSysLocale().GetLanguageTag() );
+    IntlWrapper aIntlWrapper(SvtSysLocale().GetUILanguageTag());
     while ( pItem )
     {
         OUString aItemPresentation;
 
         if ( !IsInvalidItem( pItem ) &&
              pPool->GetPool().GetPresentation(
-                *pItem, eMetric, aItemPresentation, &aIntlWrapper ) )
+                *pItem, eMetric, aItemPresentation, aIntlWrapper ) )
         {
             if ( !aDesc.isEmpty() && !aItemPresentation.isEmpty() )
                 aDesc += " + ";
@@ -375,23 +368,23 @@ SfxStyleFamily SfxStyleSheetIterator::GetSearchFamily() const
     return nSearchFamily;
 }
 
-inline bool SfxStyleSheetIterator::IsTrivialSearch()
+inline bool SfxStyleSheetIterator::IsTrivialSearch() const
 {
     return (( nMask & SFXSTYLEBIT_ALL_VISIBLE ) == SFXSTYLEBIT_ALL_VISIBLE) &&
-        (GetSearchFamily() == SFX_STYLE_FAMILY_ALL);
+        (GetSearchFamily() == SfxStyleFamily::All);
 }
 
 namespace {
 
-struct DoesStyleMatchStyleSheetPredicate SAL_FINAL : public svl::StyleSheetPredicate
+struct DoesStyleMatchStyleSheetPredicate final : public svl::StyleSheetPredicate
 {
-    DoesStyleMatchStyleSheetPredicate(SfxStyleSheetIterator *it)
-            : mIterator(it) {;}
+    explicit DoesStyleMatchStyleSheetPredicate(SfxStyleSheetIterator *it)
+            : mIterator(it) {}
 
     bool
-    Check(const SfxStyleSheetBase& styleSheet) SAL_OVERRIDE
+    Check(const SfxStyleSheetBase& styleSheet) override
     {
-        bool bMatchFamily = ((mIterator->GetSearchFamily() == SFX_STYLE_FAMILY_ALL) ||
+        bool bMatchFamily = ((mIterator->GetSearchFamily() == SfxStyleFamily::All) ||
                 ( styleSheet.GetFamily() == mIterator->GetSearchFamily() ));
 
         bool bUsed = mIterator->SearchUsed() && styleSheet.IsUsed( );
@@ -414,7 +407,7 @@ struct DoesStyleMatchStyleSheetPredicate SAL_FINAL : public svl::StyleSheetPredi
 
 SfxStyleSheetIterator::SfxStyleSheetIterator(SfxStyleSheetBasePool *pBase,
                                              SfxStyleFamily eFam, sal_uInt16 n)
-    : pAktStyle(NULL)
+    : pAktStyle(nullptr)
     , nAktPosition(0)
 {
     pBasePool=pBase;
@@ -438,33 +431,33 @@ sal_uInt16 SfxStyleSheetIterator::Count()
     sal_uInt16 n = 0;
     if( IsTrivialSearch())
     {
-        n = (sal_uInt16) pBasePool->pImp->mxIndexedStyleSheets->GetNumberOfStyleSheets();
+        n = (sal_uInt16) pBasePool->pImpl->mxIndexedStyleSheets->GetNumberOfStyleSheets();
     }
     else if(nMask == SFXSTYLEBIT_ALL)
     {
-        n = static_cast<sal_uInt16>(pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetPositionsByFamily(nSearchFamily).size());
+        n = static_cast<sal_uInt16>(pBasePool->pImpl->mxIndexedStyleSheets->GetStyleSheetPositionsByFamily(nSearchFamily).size());
     }
     else
     {
         DoesStyleMatchStyleSheetPredicate predicate(this);
-        n = pBasePool->pImp->mxIndexedStyleSheets->GetNumberOfStyleSheetsWithPredicate(predicate);
+        n = pBasePool->pImpl->mxIndexedStyleSheets->GetNumberOfStyleSheetsWithPredicate(predicate);
     }
     return n;
 }
 
 SfxStyleSheetBase* SfxStyleSheetIterator::operator[](sal_uInt16 nIdx)
 {
-    SfxStyleSheetBase* retval = NULL;
+    SfxStyleSheetBase* retval = nullptr;
     if( IsTrivialSearch())
     {
-        retval = pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(nIdx).get();
+        retval = pBasePool->pImpl->mxIndexedStyleSheets->GetStyleSheetByPosition(nIdx).get();
         nAktPosition = nIdx;
     }
     else if(nMask == SFXSTYLEBIT_ALL)
     {
         rtl::Reference< SfxStyleSheetBase > ref =
-        pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(
-                pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetPositionsByFamily(nSearchFamily).at(nIdx))
+        pBasePool->pImpl->mxIndexedStyleSheets->GetStyleSheetByPosition(
+                pBasePool->pImpl->mxIndexedStyleSheets->GetStyleSheetPositionsByFamily(nSearchFamily).at(nIdx))
                 ;
         retval = ref.get();
         nAktPosition = nIdx;
@@ -473,15 +466,15 @@ SfxStyleSheetBase* SfxStyleSheetIterator::operator[](sal_uInt16 nIdx)
     {
         DoesStyleMatchStyleSheetPredicate predicate(this);
         rtl::Reference< SfxStyleSheetBase > ref =
-                pBasePool->pImp->mxIndexedStyleSheets->GetNthStyleSheetThatMatchesPredicate(nIdx, predicate);
-        if (ref.get() != NULL)
+                pBasePool->pImpl->mxIndexedStyleSheets->GetNthStyleSheetThatMatchesPredicate(nIdx, predicate);
+        if (ref.get() != nullptr)
         {
-            nAktPosition = pBasePool->pImp->mxIndexedStyleSheets->FindStyleSheetPosition(*ref);
+            nAktPosition = pBasePool->pImpl->mxIndexedStyleSheets->FindStyleSheetPosition(*ref);
             retval = ref.get();
         }
     }
 
-    if (retval == NULL)
+    if (retval == nullptr)
     {
         OSL_FAIL("Incorrect index");
     }
@@ -495,46 +488,46 @@ SfxStyleSheetBase* SfxStyleSheetIterator::First()
         return operator[](0);
     }
     else {
-        return NULL;
+        return nullptr;
     }
 }
 
 
 SfxStyleSheetBase* SfxStyleSheetIterator::Next()
 {
-    SfxStyleSheetBase* retval = NULL;
+    SfxStyleSheetBase* retval = nullptr;
 
     if ( IsTrivialSearch() )
     {
-        unsigned nStyleSheets = pBasePool->pImp->mxIndexedStyleSheets->GetNumberOfStyleSheets();
+        unsigned nStyleSheets = pBasePool->pImpl->mxIndexedStyleSheets->GetNumberOfStyleSheets();
         unsigned newPosition = nAktPosition +1;
         if (nStyleSheets > newPosition)
         {
             nAktPosition = newPosition;
-            retval = pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(nAktPosition).get();
+            retval = pBasePool->pImpl->mxIndexedStyleSheets->GetStyleSheetByPosition(nAktPosition).get();
         }
     }
     else if(nMask == SFXSTYLEBIT_ALL)
     {
         unsigned newPosition = nAktPosition +1;
         const std::vector<unsigned>& familyVector =
-            pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetPositionsByFamily(nSearchFamily);
+            pBasePool->pImpl->mxIndexedStyleSheets->GetStyleSheetPositionsByFamily(nSearchFamily);
         if (familyVector.size() > newPosition)
         {
             nAktPosition = newPosition;
             unsigned stylePosition = familyVector.at(newPosition);
-            retval = pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(stylePosition).get();
+            retval = pBasePool->pImpl->mxIndexedStyleSheets->GetStyleSheetByPosition(stylePosition).get();
         }
     }
     else
     {
         DoesStyleMatchStyleSheetPredicate predicate(this);
         rtl::Reference< SfxStyleSheetBase > ref =
-                pBasePool->pImp->mxIndexedStyleSheets->GetNthStyleSheetThatMatchesPredicate(
+                pBasePool->pImpl->mxIndexedStyleSheets->GetNthStyleSheetThatMatchesPredicate(
                         0, predicate, nAktPosition+1);
         retval = ref.get();
-        if (retval != NULL) {
-            nAktPosition = pBasePool->pImp->mxIndexedStyleSheets->FindStyleSheetPosition(*ref);
+        if (retval != nullptr) {
+            nAktPosition = pBasePool->pImpl->mxIndexedStyleSheets->FindStyleSheetPosition(*ref);
         }
     }
     pAktStyle = retval;
@@ -546,14 +539,14 @@ SfxStyleSheetBase* SfxStyleSheetIterator::Find(const OUString& rStr)
     DoesStyleMatchStyleSheetPredicate predicate(this);
 
     std::vector<unsigned> positions =
-            pBasePool->pImp->mxIndexedStyleSheets->FindPositionsByNameAndPredicate(rStr, predicate,
-                    svl::IndexedStyleSheets::RETURN_FIRST);
+            pBasePool->pImpl->mxIndexedStyleSheets->FindPositionsByNameAndPredicate(rStr, predicate,
+                    svl::IndexedStyleSheets::SearchBehavior::ReturnFirst);
     if (positions.empty()) {
-        return NULL;
+        return nullptr;
     }
 
     unsigned pos = positions.front();
-    SfxStyleSheetBase* pStyle = pBasePool->pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(pos).get();
+    SfxStyleSheetBase* pStyle = pBasePool->pImpl->mxIndexedStyleSheets->GetStyleSheetByPosition(pos).get();
     nAktPosition = pos;
     pAktStyle = pStyle;
     return pAktStyle;
@@ -569,31 +562,20 @@ sal_uInt16 SfxStyleSheetIterator::GetSearchMask() const
 }
 
 
-void SfxStyleSheetBasePool::Replace( SfxStyleSheetBase& rSource, SfxStyleSheetBase& rTarget )
-{
-    rTarget.SetFollow( rSource.GetFollow() );
-    rTarget.SetParent( rSource.GetParent() );
-    SfxItemSet& rSourceSet = rSource.GetItemSet();
-    SfxItemSet& rTargetSet = rTarget.GetItemSet();
-    rTargetSet.Intersect( rSourceSet );
-    rTargetSet.Put( rSourceSet );
-}
-
 SfxStyleSheetIterator& SfxStyleSheetBasePool::GetIterator_Impl()
 {
-    if( !pImp->pIter || (pImp->pIter->GetSearchMask() != nMask) || (pImp->pIter->GetSearchFamily() != nSearchFamily) )
+    if( !pImpl->pIter || (pImpl->pIter->GetSearchMask() != nMask) || (pImpl->pIter->GetSearchFamily() != nSearchFamily) )
     {
-        pImp->pIter = CreateIterator( nSearchFamily, nMask );
+        pImpl->pIter = CreateIterator( nSearchFamily, nMask );
     }
 
-    return *pImp->pIter;
+    return *pImpl->pIter;
 }
 
 SfxStyleSheetBasePool::SfxStyleSheetBasePool( SfxItemPool& r ) :
-    pImp(new SfxStyleSheetBasePool_Impl),
-    aAppName(r.GetName()),
+    pImpl(new SfxStyleSheetBasePool_Impl),
     rPool(r),
-    nSearchFamily(SFX_STYLE_FAMILY_PARA),
+    nSearchFamily(SfxStyleFamily::Para),
     nMask(SFXSTYLEBIT_ALL)
 {
 #ifdef DBG_UTIL
@@ -604,8 +586,7 @@ SfxStyleSheetBasePool::SfxStyleSheetBasePool( SfxItemPool& r ) :
 SfxStyleSheetBasePool::SfxStyleSheetBasePool( const SfxStyleSheetBasePool& r ) :
     SfxBroadcaster( r ),
     comphelper::OWeakTypeObject(),
-    pImp(new SfxStyleSheetBasePool_Impl),
-    aAppName(r.aAppName),
+    pImpl(new SfxStyleSheetBasePool_Impl),
     rPool(r.rPool),
     nSearchFamily(r.nSearchFamily),
     nMask( r.nMask )
@@ -623,9 +604,8 @@ SfxStyleSheetBasePool::~SfxStyleSheetBasePool()
     aDbgStyleSheetReferences.mnPools--;
 #endif
 
-    Broadcast( SfxSimpleHint(SFX_HINT_DYING) );
+    Broadcast( SfxHint(SfxHintId::Dying) );
     Clear();
-    delete pImp;
 }
 
 bool SfxStyleSheetBasePool::SetParent(SfxStyleFamily eFam, const OUString& rStyle, const OUString& rParent)
@@ -646,13 +626,13 @@ void SfxStyleSheetBasePool::SetSearchMask(SfxStyleFamily eFam, sal_uInt16 n)
 }
 
 
-SfxStyleSheetIteratorPtr SfxStyleSheetBasePool::CreateIterator
+std::shared_ptr<SfxStyleSheetIterator> SfxStyleSheetBasePool::CreateIterator
 (
  SfxStyleFamily eFam,
  sal_uInt16 mask
 )
 {
-    return SfxStyleSheetIteratorPtr(new SfxStyleSheetIterator(this,eFam,mask));
+    return std::make_shared<SfxStyleSheetIterator>(this,eFam,mask);
 }
 
 SfxStyleSheetBase* SfxStyleSheetBasePool::Create
@@ -672,7 +652,7 @@ SfxStyleSheetBase* SfxStyleSheetBasePool::Create( const SfxStyleSheetBase& r )
 
 SfxStyleSheetBase& SfxStyleSheetBasePool::Make( const OUString& rName, SfxStyleFamily eFam, sal_uInt16 mask)
 {
-    OSL_ENSURE( eFam != SFX_STYLE_FAMILY_ALL, "svl::SfxStyleSheetBasePool::Make(), FamilyAll is not a allowed Familie" );
+    OSL_ENSURE( eFam != SfxStyleFamily::All, "svl::SfxStyleSheetBasePool::Make(), FamilyAll is not a allowed Familie" );
 
     SfxStyleSheetIterator aIter(this, eFam, mask);
     rtl::Reference< SfxStyleSheetBase > xStyle( aIter.Find( rName ) );
@@ -682,7 +662,7 @@ SfxStyleSheetBase& SfxStyleSheetBasePool::Make( const OUString& rName, SfxStyleF
     {
         xStyle = Create( rName, eFam, mask );
         StoreStyleSheet(xStyle);
-        Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::CREATED, *xStyle.get() ) );
+        Broadcast( SfxStyleSheetHint( SfxHintId::StyleSheetCreated, *xStyle.get() ) );
     }
     return *xStyle.get();
 }
@@ -691,7 +671,7 @@ SfxStyleSheetBase& SfxStyleSheetBasePool::Make( const OUString& rName, SfxStyleF
  * Helper function: If a template with this name exists it is created
  * anew. All templates that have this template as a parent are reconnected.
  */
-SfxStyleSheetBase& SfxStyleSheetBasePool::Add( const SfxStyleSheetBase& rSheet )
+void SfxStyleSheetBasePool::Add( const SfxStyleSheetBase& rSheet )
 {
     SfxStyleSheetIterator aIter(this, rSheet.GetFamily(), nMask);
     SfxStyleSheetBase* pOld = aIter.Find( rSheet.GetName() );
@@ -699,9 +679,8 @@ SfxStyleSheetBase& SfxStyleSheetBasePool::Add( const SfxStyleSheetBase& rSheet )
         Remove( pOld );
     }
     rtl::Reference< SfxStyleSheetBase > xNew( Create( rSheet ) );
-    pImp->mxIndexedStyleSheets->AddStyleSheet(xNew);
-    Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::CHANGED, *xNew.get() ) );
-    return *xNew.get();
+    pImpl->mxIndexedStyleSheets->AddStyleSheet(xNew);
+    Broadcast( SfxStyleSheetHint( SfxHintId::StyleSheetChanged, *xNew.get() ) );
 }
 
 SfxStyleSheetBasePool& SfxStyleSheetBasePool::operator=( const SfxStyleSheetBasePool& r )
@@ -717,10 +696,10 @@ SfxStyleSheetBasePool& SfxStyleSheetBasePool::operator=( const SfxStyleSheetBase
 namespace {
 struct AddStyleSheetCallback : svl::StyleSheetCallback
 {
-    AddStyleSheetCallback(SfxStyleSheetBasePool *pool)
-    : mPool(pool) {;}
+    explicit AddStyleSheetCallback(SfxStyleSheetBasePool *pool)
+    : mPool(pool) {}
 
-    void DoIt(const SfxStyleSheetBase& ssheet) SAL_OVERRIDE
+    void DoIt(const SfxStyleSheetBase& ssheet) override
     {
         mPool->Add(ssheet);
     }
@@ -734,7 +713,7 @@ SfxStyleSheetBasePool& SfxStyleSheetBasePool::operator+=( const SfxStyleSheetBas
     if( &r != this )
     {
         AddStyleSheetCallback callback(this);
-        pImp->mxIndexedStyleSheets->ApplyToAllStyleSheets(callback);
+        pImpl->mxIndexedStyleSheets->ApplyToAllStyleSheets(callback);
     }
     return *this;
 }
@@ -773,7 +752,7 @@ void SfxStyleSheetBasePool::Remove( SfxStyleSheetBase* p )
     {
         // Reference to keep p alive until after Broadcast call!
         rtl::Reference<SfxStyleSheetBase> xP(p);
-        bool bWasRemoved = pImp->mxIndexedStyleSheets->RemoveStyleSheet(xP);
+        bool bWasRemoved = pImpl->mxIndexedStyleSheets->RemoveStyleSheet(xP);
         if( bWasRemoved )
         {
             // Adapt all styles which have this style as parant
@@ -784,15 +763,15 @@ void SfxStyleSheetBasePool::Remove( SfxStyleSheetBase* p )
             // this works well under normal conditions (checked breaking and counting
             // on SfxStyleSheetBase constructors and destructors)
 
-            // com::sun::star::uno::Reference< com::sun::star::lang::XComponent > xComp( static_cast< ::cppu::OWeakObject* >((*aIter).get()), com::sun::star::uno::UNO_QUERY );
+            // css::uno::Reference< css::lang::XComponent > xComp( static_cast< ::cppu::OWeakObject* >((*aIter).get()), css::uno::UNO_QUERY );
             // if( xComp.is() ) try
             // {
             //  xComp->dispose();
             // }
-            // catch( com::sun::star::uno::Exception& )
+            // catch( css::uno::Exception& )
             // {
             // }
-            Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::ERASED, *p ) );
+            Broadcast( SfxStyleSheetHint( SfxHintId::StyleSheetErased, *p ) );
         }
     }
 }
@@ -812,31 +791,30 @@ void SfxStyleSheetBasePool::Insert( SfxStyleSheetBase* p )
     }
 #endif
     StoreStyleSheet(rtl::Reference< SfxStyleSheetBase >( p ) );
-    Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::CREATED, *p ) );
+    Broadcast( SfxStyleSheetHint( SfxHintId::StyleSheetCreated, *p ) );
 }
 
 namespace
 {
 
-struct StyleSheetDisposerFunctor SAL_FINAL : public svl::StyleSheetDisposer
+struct StyleSheetDisposerFunctor final : public svl::StyleSheetDisposer
 {
-    StyleSheetDisposerFunctor(SfxStyleSheetBasePool* pool)
-            : mPool(pool) {;}
+    explicit StyleSheetDisposerFunctor(SfxStyleSheetBasePool* pool)
+            : mPool(pool) {}
 
     void
-    Dispose(rtl::Reference<SfxStyleSheetBase> styleSheet) SAL_OVERRIDE
+    Dispose(rtl::Reference<SfxStyleSheetBase> styleSheet) override
     {
         cppu::OWeakObject* weakObject = static_cast< ::cppu::OWeakObject* >(styleSheet.get());
-        com::sun::star::uno::Reference< com::sun::star::lang::XComponent >
-            xComp( weakObject, com::sun::star::uno::UNO_QUERY );
+        css::uno::Reference< css::lang::XComponent > xComp( weakObject, css::uno::UNO_QUERY );
         if( xComp.is() ) try
         {
             xComp->dispose();
         }
-        catch( com::sun::star::uno::Exception& )
+        catch( css::uno::Exception& )
         {
         }
-        mPool->Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::ERASED, *styleSheet.get() ) );
+        mPool->Broadcast( SfxStyleSheetHint( SfxHintId::StyleSheetErased, *styleSheet.get() ) );
     }
 
     SfxStyleSheetBasePool* mPool;
@@ -847,7 +825,7 @@ struct StyleSheetDisposerFunctor SAL_FINAL : public svl::StyleSheetDisposer
 void SfxStyleSheetBasePool::Clear()
 {
     StyleSheetDisposerFunctor cleanup(this);
-    pImp->mxIndexedStyleSheets->Clear(cleanup);
+    pImpl->mxIndexedStyleSheets->Clear(cleanup);
 }
 
 void SfxStyleSheetBasePool::ChangeParent(const OUString& rOld,
@@ -855,7 +833,7 @@ void SfxStyleSheetBasePool::ChangeParent(const OUString& rOld,
                                          bool bVirtual)
 {
     const sal_uInt16 nTmpMask = GetSearchMask();
-    SetSearchMask(GetSearchFamily(), SFXSTYLEBIT_ALL);
+    SetSearchMask(GetSearchFamily());
     for( SfxStyleSheetBase* p = First(); p; p = Next() )
     {
         if( p->GetParent() == rOld )
@@ -873,10 +851,6 @@ void SfxStyleSheetBase::Load( SvStream&, sal_uInt16 )
 {
 }
 
-void SfxStyleSheetBase::Store( SvStream& )
-{
-}
-
 SfxStyleSheet::SfxStyleSheet(const OUString &rName,
                              const SfxStyleSheetBasePool& r_Pool,
                              SfxStyleFamily eFam,
@@ -895,7 +869,7 @@ SfxStyleSheet::SfxStyleSheet(const SfxStyleSheet& rStyle)
 
 SfxStyleSheet::~SfxStyleSheet()
 {
-    Broadcast( SfxStyleSheetHint( SfxStyleSheetHintId::INDESTRUCTION, *this ) );
+    Broadcast( SfxStyleSheetHint( SfxHintId::StyleSheetInDestruction, *this ) );
 }
 
 
@@ -909,14 +883,14 @@ bool SfxStyleSheet::SetParent( const OUString& rName )
         // Remove from notification chain of the old parent if applicable
         if(!aOldParent.isEmpty())
         {
-            SfxStyleSheet *pParent = static_cast<SfxStyleSheet *>(pPool->Find(aOldParent, nFamily, SFXSTYLEBIT_ALL));
+            SfxStyleSheet *pParent = static_cast<SfxStyleSheet *>(pPool->Find(aOldParent, nFamily));
             if(pParent)
                 EndListening(*pParent);
         }
         // Add to the notification chain of the new parent
         if(!aParent.isEmpty())
         {
-            SfxStyleSheet *pParent = static_cast<SfxStyleSheet *>(pPool->Find(aParent, nFamily, SFXSTYLEBIT_ALL));
+            SfxStyleSheet *pParent = static_cast<SfxStyleSheet *>(pPool->Find(aParent, nFamily));
             if(pParent)
                 StartListening(*pParent);
         }
@@ -951,16 +925,16 @@ SfxStyleSheetBase* SfxStyleSheetPool::Create( const OUString& rName,
 }
 
 SfxUnoStyleSheet::SfxUnoStyleSheet( const OUString& _rName, const SfxStyleSheetBasePool& _rPool, SfxStyleFamily _eFamily, sal_uInt16 _nMaske )
-: ::cppu::ImplInheritanceHelper2< SfxStyleSheet, ::com::sun::star::style::XStyle, ::com::sun::star::lang::XUnoTunnel >( _rName, _rPool, _eFamily, _nMaske )
+: cppu::ImplInheritanceHelper<SfxStyleSheet, css::style::XStyle, css::lang::XUnoTunnel>(_rName, _rPool, _eFamily, _nMaske)
 {
 }
 
-SfxUnoStyleSheet* SfxUnoStyleSheet::getUnoStyleSheet( const ::com::sun::star::uno::Reference< ::com::sun::star::style::XStyle >& xStyle )
+SfxUnoStyleSheet* SfxUnoStyleSheet::getUnoStyleSheet( const css::uno::Reference< css::style::XStyle >& xStyle )
 {
     SfxUnoStyleSheet* pRet = dynamic_cast< SfxUnoStyleSheet* >( xStyle.get() );
     if( !pRet )
     {
-        ::com::sun::star::uno::Reference< ::com::sun::star::lang::XUnoTunnel > xUT( xStyle, ::com::sun::star::uno::UNO_QUERY );
+        css::uno::Reference< css::lang::XUnoTunnel > xUT( xStyle, css::uno::UNO_QUERY );
         if( xUT.is() )
             pRet = reinterpret_cast<SfxUnoStyleSheet*>(sal::static_int_cast<sal_uIntPtr>(xUT->getSomething( SfxUnoStyleSheet::getIdentifier())));
     }
@@ -970,7 +944,7 @@ SfxUnoStyleSheet* SfxUnoStyleSheet::getUnoStyleSheet( const ::com::sun::star::un
 /**
  * XUnoTunnel
  */
-::sal_Int64 SAL_CALL SfxUnoStyleSheet::getSomething( const ::com::sun::star::uno::Sequence< ::sal_Int8 >& rId ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+::sal_Int64 SAL_CALL SfxUnoStyleSheet::getSomething( const css::uno::Sequence< ::sal_Int8 >& rId )
 {
     if( rId.getLength() == 16 && 0 == memcmp( getIdentifier().getConstArray(), rId.getConstArray(), 16 ) )
     {
@@ -983,9 +957,9 @@ SfxUnoStyleSheet* SfxUnoStyleSheet::getUnoStyleSheet( const ::com::sun::star::un
 }
 
 void
-SfxStyleSheetBasePool::StoreStyleSheet(rtl::Reference< SfxStyleSheetBase > xStyle)
+SfxStyleSheetBasePool::StoreStyleSheet(const rtl::Reference< SfxStyleSheetBase >& xStyle)
 {
-    pImp->mxIndexedStyleSheets->AddStyleSheet(xStyle);
+    pImpl->mxIndexedStyleSheets->AddStyleSheet(xStyle);
 }
 
 namespace
@@ -993,7 +967,7 @@ namespace
     class theSfxUnoStyleSheetIdentifier : public rtl::Static< UnoTunnelIdInit, theSfxUnoStyleSheetIdentifier > {};
 }
 
-const ::com::sun::star::uno::Sequence< ::sal_Int8 >& SfxUnoStyleSheet::getIdentifier()
+const css::uno::Sequence< ::sal_Int8 >& SfxUnoStyleSheet::getIdentifier()
 {
     return theSfxUnoStyleSheetIdentifier::get().getSeq();
 }
@@ -1001,19 +975,19 @@ const ::com::sun::star::uno::Sequence< ::sal_Int8 >& SfxUnoStyleSheet::getIdenti
 void
 SfxStyleSheetBasePool::Reindex()
 {
-    pImp->mxIndexedStyleSheets->Reindex();
+    pImpl->mxIndexedStyleSheets->Reindex();
 }
 
 const svl::IndexedStyleSheets&
 SfxStyleSheetBasePool::GetIndexedStyleSheets() const
 {
-    return *pImp->mxIndexedStyleSheets;
+    return *pImpl->mxIndexedStyleSheets;
 }
 
 rtl::Reference<SfxStyleSheetBase>
 SfxStyleSheetBasePool::GetStyleSheetByPositionInIndex(unsigned pos)
 {
-    return pImp->mxIndexedStyleSheets->GetStyleSheetByPosition(pos);
+    return pImpl->mxIndexedStyleSheets->GetStyleSheetByPosition(pos);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
