@@ -25,10 +25,16 @@
 #include <set>
 #include <string.h>
 
+#include <com/sun/star/io/IOException.hpp>
+#include <com/sun/star/io/XInputStream.hpp>
+#include <com/sun/star/io/XOutputStream.hpp>
+#include <com/sun/star/io/XSeekable.hpp>
+
+#include <osl/diagnose.h>
 #include <rtl/alloc.h>
+#include <cppuhelper/queryinterface.hxx>
 #include <svl/instrm.hxx>
 #include <svl/outstrm.hxx>
-#include <svl/strmadpt.hxx>
 
 using namespace com::sun::star;
 
@@ -48,6 +54,7 @@ private:
         sal_uInt32 m_nOffset;
         sal_Int8 m_aBuffer[1];
     };
+    static const sal_uInt32 m_nPageSize = 1000;
 
     std::multiset< sal_uInt32 > m_aMarks;
     Page * m_pFirstPage;
@@ -56,19 +63,13 @@ private:
     sal_Int8 * m_pReadBuffer;
     sal_uInt32 m_nReadBufferSize;
     sal_uInt32 m_nReadBufferFilled;
-    sal_uInt32 m_nPageSize;
-    sal_uInt32 m_nMinPages;
-    sal_uInt32 m_nMaxPages;
     sal_uInt32 m_nPages;
     bool m_bEOF;
 
-    bool remove(Page * pPage);
+    void remove(Page * pPage);
 
 public:
-    inline SvDataPipe_Impl(sal_uInt32 nThePageSize = 1000,
-                           sal_uInt32 nTheMinPages = 100,
-                           sal_uInt32 nTheMaxPages
-                               = std::numeric_limits< sal_uInt32 >::max());
+    inline SvDataPipe_Impl();
 
     ~SvDataPipe_Impl();
 
@@ -76,37 +77,26 @@ public:
 
     sal_uInt32 read();
 
-    void clearReadBuffer() { m_pReadBuffer = 0; }
+    void clearReadBuffer() { m_pReadBuffer = nullptr; }
 
-    sal_uInt32 write(sal_Int8 const * pBuffer, sal_uInt32 nSize);
+    void write(sal_Int8 const * pBuffer, sal_uInt32 nSize);
 
     void setEOF() { m_bEOF = true; }
 
     inline bool isEOF() const;
 
-    bool addMark(sal_uInt32 nPosition);
-    bool removeMark(sal_uInt32 nPosition);
-
-    inline sal_uInt32 getReadPosition() const;
-
     SeekResult setReadPosition(sal_uInt32 nPosition);
 };
 
-SvDataPipe_Impl::SvDataPipe_Impl(sal_uInt32 nThePageSize,
-                                 sal_uInt32 nTheMinPages,
-                                 sal_uInt32 nTheMaxPages):
-    m_pFirstPage(0),
-    m_pReadPage(0),
-    m_pWritePage(0),
-    m_pReadBuffer(0),
-    m_nPageSize(std::min< sal_uInt32 >(
-                    std::max< sal_uInt32 >(nThePageSize, sal_uInt32(1)),
-                    sal_uInt32(std::numeric_limits< sal_uInt32 >::max()
-                                   - sizeof (Page) + 1))),
-    m_nMinPages(std::max< sal_uInt32 >(nTheMinPages, sal_uInt32(1))),
-    m_nMaxPages(std::max< sal_uInt32 >(nTheMaxPages, sal_uInt32(1))),
-    m_nPages(0),
-    m_bEOF(false)
+SvDataPipe_Impl::SvDataPipe_Impl()
+    : m_pFirstPage( nullptr )
+    , m_pReadPage( nullptr )
+    , m_pWritePage( nullptr )
+    , m_pReadBuffer( nullptr )
+    , m_nReadBufferSize( 0 )
+    , m_nReadBufferFilled( 0 )
+    , m_nPages( 0 )
+    , m_bEOF( false )
 {}
 
 inline void SvDataPipe_Impl::setReadBuffer(sal_Int8 * pBuffer,
@@ -123,305 +113,9 @@ inline bool SvDataPipe_Impl::isEOF() const
            && (!m_pReadPage || m_pReadPage->m_pRead == m_pReadPage->m_pEnd);
 }
 
-inline sal_uInt32 SvDataPipe_Impl::getReadPosition() const
-{
-    return m_pReadPage == 0 ? 0 :
-                              m_pReadPage->m_nOffset
-                                  + (m_pReadPage->m_pRead
-                                         - m_pReadPage->m_aBuffer);
-}
 
-//
-//  SvOutputStreamOpenLockBytes
-//
 
-TYPEINIT1(SvOutputStreamOpenLockBytes, SvOpenLockBytes)
-
-// virtual
-ErrCode SvOutputStreamOpenLockBytes::ReadAt(sal_uLong, void *, sal_uLong, sal_uLong *)
-    const
-{
-    return ERRCODE_IO_CANTREAD;
-}
-
-// virtual
-ErrCode SvOutputStreamOpenLockBytes::WriteAt(sal_uLong nPos, void const * pBuffer,
-                                             sal_uLong nCount, sal_uLong * pWritten)
-{
-    if (nPos != m_nPosition)
-        return ERRCODE_IO_CANTWRITE;
-    return FillAppend(pBuffer, nCount, pWritten);
-}
-
-// virtual
-ErrCode SvOutputStreamOpenLockBytes::Flush() const
-{
-    if (!m_xOutputStream.is())
-        return ERRCODE_IO_CANTWRITE;
-    try
-    {
-        m_xOutputStream->flush();
-    }
-    catch (const io::IOException&)
-    {
-        return ERRCODE_IO_CANTWRITE;
-    }
-    return ERRCODE_NONE;
-}
-
-// virtual
-ErrCode SvOutputStreamOpenLockBytes::SetSize(sal_uLong)
-{
-    return ERRCODE_IO_NOTSUPPORTED;
-}
-
-// virtual
-ErrCode SvOutputStreamOpenLockBytes::Stat(SvLockBytesStat * pStat,
-                                          SvLockBytesStatFlag) const
-{
-    if (pStat)
-        pStat->nSize = m_nPosition;
-    return ERRCODE_NONE;
-}
-
-// virtual
-ErrCode SvOutputStreamOpenLockBytes::FillAppend(void const * pBuffer,
-                                                sal_uLong nCount,
-                                                sal_uLong * pWritten)
-{
-    if (!m_xOutputStream.is())
-        return ERRCODE_IO_CANTWRITE;
-    if (nCount > 0
-        && nCount > std::numeric_limits< sal_uLong >::max() - m_nPosition)
-    {
-        nCount = std::numeric_limits< sal_uLong >::max() - m_nPosition;
-        if (nCount == 0)
-            return ERRCODE_IO_CANTWRITE;
-    }
-    try
-    {
-        m_xOutputStream->
-            writeBytes(uno::Sequence< sal_Int8 >(
-                           static_cast< sal_Int8 const * >(pBuffer), nCount));
-    }
-    catch (const io::IOException&)
-    {
-        return ERRCODE_IO_CANTWRITE;
-    }
-    m_nPosition += nCount;
-    if (pWritten)
-        *pWritten = nCount;
-    return ERRCODE_NONE;
-}
-
-// virtual
-sal_uLong SvOutputStreamOpenLockBytes::Tell() const
-{
-    return m_nPosition;
-}
-
-// virtual
-sal_uLong SvOutputStreamOpenLockBytes::Seek(sal_uLong)
-{
-    return m_nPosition;
-}
-
-// virtual
-void SvOutputStreamOpenLockBytes::Terminate()
-{
-    if (m_xOutputStream.is())
-    {
-        try
-        {
-            m_xOutputStream->closeOutput();
-        }
-        catch (const io::IOException&)
-        {
-        }
-    }
-}
-
-//
-//  SvLockBytesInputStream
-//
-
-// virtual
-uno::Any SAL_CALL SvLockBytesInputStream::queryInterface(uno::Type const &
-                                                             rType)
-    throw (uno::RuntimeException)
-{
-    uno::Any
-        aReturn(cppu::queryInterface(rType,
-                                     static_cast< io::XInputStream * >(this),
-                                     static_cast< io::XSeekable * >(this)));
-    return aReturn.hasValue() ? aReturn : OWeakObject::queryInterface(rType);
-}
-
-// virtual
-void SAL_CALL SvLockBytesInputStream::acquire() throw ()
-{
-    OWeakObject::acquire();
-}
-
-// virtual
-void SAL_CALL SvLockBytesInputStream::release() throw ()
-{
-    OWeakObject::release();
-}
-
-// virtual
-sal_Int32 SAL_CALL
-SvLockBytesInputStream::readBytes(uno::Sequence< sal_Int8 > & rData,
-                                  sal_Int32 nBytesToRead)
-    throw (io::IOException, uno::RuntimeException)
-{
-    OSL_ASSERT(m_nPosition >= 0);
-    if (!m_xLockBytes.Is())
-        throw io::NotConnectedException();
-    if (
-         nBytesToRead < 0 ||
-         (
-          static_cast<sal_uInt64>(m_nPosition) > SAL_MAX_SIZE &&
-          nBytesToRead > 0
-         )
-       )
-    {
-        throw io::IOException();
-    }
-    rData.realloc(nBytesToRead);
-    sal_Int32 nSize = 0;
-    while (nSize < nBytesToRead)
-    {
-        sal_Size nCount;
-        ErrCode nError = m_xLockBytes->ReadAt(static_cast<sal_Size>(
-                                                  m_nPosition),
-                                              rData.getArray() + nSize,
-                                              nBytesToRead - nSize, &nCount);
-        if (nError != ERRCODE_NONE && nError != ERRCODE_IO_PENDING)
-            throw io::IOException();
-        m_nPosition += nCount;
-        nSize += nCount;
-        if (nError == ERRCODE_NONE && nCount == 0)
-            break;
-    }
-    rData.realloc(nSize);
-    return nSize;
-}
-
-// virtual
-sal_Int32 SAL_CALL
-SvLockBytesInputStream::readSomeBytes(uno::Sequence< sal_Int8 > & rData,
-                                      sal_Int32 nMaxBytesToRead)
-    throw (io::IOException, uno::RuntimeException)
-{
-    OSL_ASSERT(m_nPosition >= 0);
-    if (!m_xLockBytes.Is())
-        throw io::NotConnectedException();
-    if (static_cast<sal_uInt64>(m_nPosition) > SAL_MAX_SIZE
-        && nMaxBytesToRead > 0)
-        throw io::IOException();
-    rData.realloc(nMaxBytesToRead);
-    sal_Size nCount = 0;
-    if (nMaxBytesToRead > 0)
-    {
-        ErrCode nError;
-        do
-        {
-            nError = m_xLockBytes->ReadAt(static_cast<sal_Size>(m_nPosition),
-                                          rData.getArray(),
-                                          nMaxBytesToRead < 0 ?
-                                              0 : nMaxBytesToRead,
-                                          &nCount);
-            if (nError != ERRCODE_NONE && nError != ERRCODE_IO_PENDING)
-                throw io::IOException();
-            m_nPosition += nCount;
-        }
-        while (nCount == 0 && nError == ERRCODE_IO_PENDING);
-    }
-    rData.realloc(sal_Int32(nCount));
-    return sal_Int32(nCount);
-}
-
-// virtual
-void SAL_CALL SvLockBytesInputStream::skipBytes(sal_Int32 nBytesToSkip)
-    throw (io::IOException, uno::RuntimeException)
-{
-    if (!m_xLockBytes.Is())
-        throw io::NotConnectedException();
-    if (nBytesToSkip < 0)
-        throw io::IOException();
-    if (nBytesToSkip > SAL_MAX_INT64 - m_nPosition)
-        throw io::BufferSizeExceededException();
-    m_nPosition += nBytesToSkip;
-}
-
-// virtual
-sal_Int32 SAL_CALL SvLockBytesInputStream::available()
-    throw (io::IOException, uno::RuntimeException)
-{
-    OSL_ASSERT(m_nPosition >= 0);
-    if (!m_xLockBytes.Is())
-        throw io::NotConnectedException();
-    SvLockBytesStat aStat;
-    if (m_xLockBytes->Stat(&aStat, SVSTATFLAG_DEFAULT) != ERRCODE_NONE)
-        throw io::IOException();
-    return aStat.nSize <= static_cast<sal_uInt64>(m_nPosition) ?
-               0 :
-           static_cast<sal_Size>(aStat.nSize - m_nPosition) <=
-                   static_cast<sal_uInt32>(SAL_MAX_INT32) ?
-               static_cast<sal_Int32>(aStat.nSize - m_nPosition) :
-               SAL_MAX_INT32;
-}
-
-// virtual
-void SAL_CALL SvLockBytesInputStream::closeInput()
-    throw (io::IOException, uno::RuntimeException)
-{
-    if (!m_xLockBytes.Is())
-        throw io::NotConnectedException();
-    m_xLockBytes = 0;
-}
-
-// virtual
-void SAL_CALL SvLockBytesInputStream::seek(sal_Int64 nLocation)
-    throw (lang::IllegalArgumentException, io::IOException,
-           uno::RuntimeException)
-{
-    if (nLocation < 0)
-        throw lang::IllegalArgumentException();
-    if (!m_xLockBytes.Is())
-        throw io::NotConnectedException();
-    m_nPosition = nLocation;
-}
-
-// virtual
-sal_Int64 SAL_CALL SvLockBytesInputStream::getPosition()
-    throw (io::IOException, uno::RuntimeException)
-{
-    if (!m_xLockBytes.Is())
-        throw io::NotConnectedException();
-    return m_nPosition;
-}
-
-// virtual
-sal_Int64 SAL_CALL SvLockBytesInputStream::getLength()
-    throw (io::IOException, uno::RuntimeException)
-{
-    if (!m_xLockBytes.Is())
-        throw io::NotConnectedException();
-    SvLockBytesStat aStat;
-    if (m_xLockBytes->Stat(&aStat, SVSTATFLAG_DEFAULT) != ERRCODE_NONE)
-        throw io::IOException();
-#if SAL_TYPES_SIZEOFPOINTER > 4 // avoid warnings if sal_Size < sal_Int64
-    if (aStat.nSize > static_cast<sal_uInt64>(SAL_MAX_INT64))
-        throw io::IOException();
-#endif
-    return aStat.nSize;
-}
-
-//
 //  SvInputStream
-//
 
 bool SvInputStream::open()
 {
@@ -434,8 +128,7 @@ bool SvInputStream::open()
             SetError(ERRCODE_IO_INVALIDDEVICE);
             return false;
         }
-        m_xSeekable
-            = uno::Reference< io::XSeekable >(m_xStream, uno::UNO_QUERY);
+        m_xSeekable.set(m_xStream, uno::UNO_QUERY);
         if (!m_xSeekable.is())
             m_pPipe = new SvDataPipe_Impl;
     }
@@ -443,13 +136,15 @@ bool SvInputStream::open()
 }
 
 // virtual
-sal_uLong SvInputStream::GetData(void * pData, sal_uLong nSize)
+std::size_t SvInputStream::GetData(void * pData, std::size_t const nSize)
 {
     if (!open())
     {
         SetError(ERRCODE_IO_CANTREAD);
         return 0;
     }
+    // check if a truncated STREAM_SEEK_TO_END was passed
+    assert(m_nSeekedFrom != SAL_MAX_UINT32);
     sal_uInt32 nRead = 0;
     if (m_xSeekable.is())
     {
@@ -470,8 +165,8 @@ sal_uLong SvInputStream::GetData(void * pData, sal_uLong nSize)
         {
             sal_Int32 nRemain
                 = sal_Int32(
-                    std::min(sal_uLong(nSize - nRead),
-                             sal_uLong(std::numeric_limits< sal_Int32 >::max())));
+                    std::min(std::size_t(nSize - nRead),
+                             std::size_t(std::numeric_limits<sal_Int32>::max())));
             if (nRemain == 0)
                 break;
             uno::Sequence< sal_Int8 > aBuffer;
@@ -507,8 +202,8 @@ sal_uLong SvInputStream::GetData(void * pData, sal_uLong nSize)
                 sal_Int32 nRemain
                     = sal_Int32(
                         std::min(
-                            sal_uLong(nSize - nRead),
-                            sal_uLong(std::numeric_limits< sal_Int32 >::max())));
+                            std::size_t(nSize - nRead),
+                            std::size_t(std::numeric_limits<sal_Int32>::max())));
                 if (nRemain == 0)
                     break;
                 uno::Sequence< sal_Int8 > aBuffer;
@@ -537,7 +232,7 @@ sal_uLong SvInputStream::GetData(void * pData, sal_uLong nSize)
 }
 
 // virtual
-sal_uLong SvInputStream::PutData(void const *, sal_uLong)
+std::size_t SvInputStream::PutData(void const *, std::size_t)
 {
     SetError(ERRCODE_IO_NOTSUPPORTED);
     return 0;
@@ -548,8 +243,10 @@ void SvInputStream::FlushData()
 {}
 
 // virtual
-sal_uLong SvInputStream::SeekPos(sal_uLong nPos)
+sal_uInt64 SvInputStream::SeekPos(sal_uInt64 const nPos)
 {
+    // check if a truncated STREAM_SEEK_TO_END was passed
+    assert(nPos != SAL_MAX_UINT32);
     if (open())
     {
         if (nPos == STREAM_SEEK_TO_END)
@@ -565,7 +262,7 @@ sal_uLong SvInputStream::SeekPos(sal_uLong nPos)
                             < STREAM_SEEK_TO_END)
                         {
                             m_nSeekedFrom = Tell();
-                            return sal_uLong(nLength);
+                            return sal_uInt64(nLength);
                         }
                     }
                     catch (const io::IOException&)
@@ -615,17 +312,14 @@ sal_uLong SvInputStream::SeekPos(sal_uLong nPos)
 }
 
 // virtual
-void SvInputStream::SetSize(sal_uLong)
+void SvInputStream::SetSize(sal_uInt64)
 {
     SetError(ERRCODE_IO_NOTSUPPORTED);
 }
 
-SvInputStream::SvInputStream(
-        com::sun::star::uno::Reference< com::sun::star::io::XInputStream >
-                const &
-            rTheStream):
+SvInputStream::SvInputStream( css::uno::Reference< css::io::XInputStream > const & rTheStream):
     m_xStream(rTheStream),
-    m_pPipe(0),
+    m_pPipe(nullptr),
     m_nSeekedFrom(STREAM_SEEK_TO_END)
 {
     SetBufferSize(0);
@@ -647,52 +341,30 @@ SvInputStream::~SvInputStream()
     delete m_pPipe;
 }
 
-// virtual
-sal_uInt16 SvInputStream::IsA() const
-{
-    return 0;
-}
-
-// virtual
-void SvInputStream::AddMark(sal_uLong nPos)
-{
-    if (open() && m_pPipe)
-        m_pPipe->addMark(nPos);
-}
-
-// virtual
-void SvInputStream::RemoveMark(sal_uLong nPos)
-{
-    if (open() && m_pPipe)
-        m_pPipe->removeMark(nPos);
-}
-
-//
 //  SvOutputStream
-//
 
 // virtual
-sal_uLong SvOutputStream::GetData(void *, sal_uLong)
+std::size_t SvOutputStream::GetData(void *, std::size_t)
 {
     SetError(ERRCODE_IO_NOTSUPPORTED);
     return 0;
 }
 
 // virtual
-sal_uLong SvOutputStream::PutData(void const * pData, sal_uLong nSize)
+std::size_t SvOutputStream::PutData(void const * pData, std::size_t nSize)
 {
     if (!m_xStream.is())
     {
         SetError(ERRCODE_IO_CANTWRITE);
         return 0;
     }
-    sal_uLong nWritten = 0;
+    std::size_t nWritten = 0;
     for (;;)
     {
         sal_Int32 nRemain
             = sal_Int32(
-                std::min(sal_uLong(nSize - nWritten),
-                         sal_uLong(std::numeric_limits< sal_Int32 >::max())));
+                std::min(std::size_t(nSize - nWritten),
+                         std::size_t(std::numeric_limits<sal_Int32>::max())));
         if (nRemain == 0)
             break;
         try
@@ -713,7 +385,7 @@ sal_uLong SvOutputStream::PutData(void const * pData, sal_uLong nSize)
 }
 
 // virtual
-sal_uLong SvOutputStream::SeekPos(sal_uLong)
+sal_uInt64 SvOutputStream::SeekPos(sal_uInt64)
 {
     SetError(ERRCODE_IO_NOTSUPPORTED);
     return 0;
@@ -737,7 +409,7 @@ void SvOutputStream::FlushData()
 }
 
 // virtual
-void SvOutputStream::SetSize(sal_uLong)
+void SvOutputStream::SetSize(sal_uInt64)
 {
     SetError(ERRCODE_IO_NOTSUPPORTED);
 }
@@ -764,17 +436,11 @@ SvOutputStream::~SvOutputStream()
     }
 }
 
-// virtual
-sal_uInt16 SvOutputStream::IsA() const
-{
-    return 0;
-}
 
-//
 //  SvDataPipe_Impl
-//
 
-bool SvDataPipe_Impl::remove(Page * pPage)
+
+void SvDataPipe_Impl::remove(Page * pPage)
 {
     if (
         pPage != m_pFirstPage ||
@@ -785,25 +451,23 @@ bool SvDataPipe_Impl::remove(Page * pPage)
         )
        )
     {
-        return false;
+        return;
     }
 
     m_pFirstPage = m_pFirstPage->m_pNext;
 
-    if (m_nPages <= m_nMinPages)
-        return true;
+    if (m_nPages <= 100) // min pages
+        return;
 
     pPage->m_pPrev->m_pNext = pPage->m_pNext;
     pPage->m_pNext->m_pPrev = pPage->m_pPrev;
     rtl_freeMemory(pPage);
     --m_nPages;
-
-    return true;
 }
 
 SvDataPipe_Impl::~SvDataPipe_Impl()
 {
-    if (m_pFirstPage != 0)
+    if (m_pFirstPage != nullptr)
         for (Page * pPage = m_pFirstPage;;)
         {
             Page * pNext = pPage->m_pNext;
@@ -816,7 +480,7 @@ SvDataPipe_Impl::~SvDataPipe_Impl()
 
 sal_uInt32 SvDataPipe_Impl::read()
 {
-    if (m_pReadBuffer == 0 || m_nReadBufferSize == 0 || m_pReadPage == 0)
+    if (m_pReadBuffer == nullptr || m_nReadBufferSize == 0 || m_pReadPage == nullptr)
         return 0;
 
     sal_uInt32 nSize = m_nReadBufferSize;
@@ -852,12 +516,12 @@ sal_uInt32 SvDataPipe_Impl::read()
     return nSize - nRemain;
 }
 
-sal_uInt32 SvDataPipe_Impl::write(sal_Int8 const * pBuffer, sal_uInt32 nSize)
+void SvDataPipe_Impl::write(sal_Int8 const * pBuffer, sal_uInt32 nSize)
 {
     if (nSize == 0)
-        return 0;
+        return;
 
-    if (m_pWritePage == 0)
+    if (m_pWritePage == nullptr)
     {
         m_pFirstPage
             = static_cast< Page * >(rtl_allocateMemory(sizeof (Page)
@@ -876,7 +540,7 @@ sal_uInt32 SvDataPipe_Impl::write(sal_Int8 const * pBuffer, sal_uInt32 nSize)
 
     sal_uInt32 nRemain = nSize;
 
-    if (m_pReadBuffer != 0 && m_pReadPage == m_pWritePage
+    if (m_pReadBuffer != nullptr && m_pReadPage == m_pWritePage
         && m_pReadPage->m_pRead == m_pWritePage->m_pEnd)
     {
         sal_uInt32 nBlock = std::min(nRemain,
@@ -924,7 +588,7 @@ sal_uInt32 SvDataPipe_Impl::write(sal_Int8 const * pBuffer, sal_uInt32 nSize)
 
             if (m_pWritePage->m_pNext == m_pFirstPage)
             {
-                if (m_nPages == m_nMaxPages)
+                if (m_nPages == std::numeric_limits< sal_uInt32 >::max())
                     break;
 
                 Page * pNew
@@ -946,32 +610,12 @@ sal_uInt32 SvDataPipe_Impl::write(sal_Int8 const * pBuffer, sal_uInt32 nSize)
             m_pWritePage->m_pRead = m_pWritePage->m_aBuffer;
             m_pWritePage->m_pEnd = m_pWritePage->m_aBuffer;
         }
-
-    return nSize - nRemain;
-}
-
-bool SvDataPipe_Impl::addMark(sal_uInt32 nPosition)
-{
-    if (m_pFirstPage != 0 && m_pFirstPage->m_nOffset > nPosition)
-        return false;
-    m_aMarks.insert(nPosition);
-    return true;
-}
-
-bool SvDataPipe_Impl::removeMark(sal_uInt32 nPosition)
-{
-    std::multiset< sal_uInt32 >::iterator t = m_aMarks.find(nPosition);
-    if (t == m_aMarks.end())
-        return false;
-    m_aMarks.erase(t);
-    while (remove(m_pFirstPage)) ;
-    return true;
 }
 
 SvDataPipe_Impl::SeekResult SvDataPipe_Impl::setReadPosition(sal_uInt32
                                                                  nPosition)
 {
-    if (m_pFirstPage == 0)
+    if (m_pFirstPage == nullptr)
         return nPosition == 0 ? SEEK_OK : SEEK_PAST_END;
 
     if (nPosition
