@@ -22,7 +22,6 @@
 #include <unotools/configitem.hxx>
 #include <vcl/print.hxx>
 #include <com/sun/star/uno/Any.hxx>
-#include <com/sun/star/uno/Sequence.hxx>
 
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
@@ -37,42 +36,42 @@
 
 #include <sal/macros.h>
 
-static sal_uInt16 aDPIArray[] = { 72, 96, 150, 200, 300, 600 };
+static const sal_uInt16 aDPIArray[] = { 72, 96, 150, 200, 300, 600 };
 
 #define DPI_COUNT (SAL_N_ELEMENTS(aDPIArray))
 
-#define ROOTNODE_START                                  OUString("Office.Common/Print/Option")
-#define ROOTNODE_PRINTOPTION                            OUString("org.openoffice.Office.Common/Print/Option")
+#define ROOTNODE_START                                  "Office.Common/Print/Option"
+#define ROOTNODE_PRINTOPTION                            "org.openoffice.Office.Common/Print/Option"
 
-#define PROPERTYNAME_REDUCETRANSPARENCY                 OUString("ReduceTransparency")
-#define PROPERTYNAME_REDUCEDTRANSPARENCYMODE            OUString("ReducedTransparencyMode")
-#define PROPERTYNAME_REDUCEGRADIENTS                    OUString("ReduceGradients")
-#define PROPERTYNAME_REDUCEDGRADIENTMODE                OUString("ReducedGradientMode")
-#define PROPERTYNAME_REDUCEDGRADIENTSTEPCOUNT           OUString("ReducedGradientStepCount")
-#define PROPERTYNAME_REDUCEBITMAPS                      OUString("ReduceBitmaps")
-#define PROPERTYNAME_REDUCEDBITMAPMODE                  OUString("ReducedBitmapMode")
-#define PROPERTYNAME_REDUCEDBITMAPRESOLUTION            OUString("ReducedBitmapResolution")
-#define PROPERTYNAME_REDUCEDBITMAPINCLUDESTRANSPARENCY  OUString("ReducedBitmapIncludesTransparency")
-#define PROPERTYNAME_CONVERTTOGREYSCALES                OUString("ConvertToGreyscales")
-#define PROPERTYNAME_PDFASSTANDARDPRINTJOBFORMAT        OUString("PDFAsStandardPrintJobFormat")
+#define PROPERTYNAME_REDUCETRANSPARENCY                 "ReduceTransparency"
+#define PROPERTYNAME_REDUCEDTRANSPARENCYMODE            "ReducedTransparencyMode"
+#define PROPERTYNAME_REDUCEGRADIENTS                    "ReduceGradients"
+#define PROPERTYNAME_REDUCEDGRADIENTMODE                "ReducedGradientMode"
+#define PROPERTYNAME_REDUCEDGRADIENTSTEPCOUNT           "ReducedGradientStepCount"
+#define PROPERTYNAME_REDUCEBITMAPS                      "ReduceBitmaps"
+#define PROPERTYNAME_REDUCEDBITMAPMODE                  "ReducedBitmapMode"
+#define PROPERTYNAME_REDUCEDBITMAPRESOLUTION            "ReducedBitmapResolution"
+#define PROPERTYNAME_REDUCEDBITMAPINCLUDESTRANSPARENCY  "ReducedBitmapIncludesTransparency"
+#define PROPERTYNAME_CONVERTTOGREYSCALES                "ConvertToGreyscales"
+#define PROPERTYNAME_PDFASSTANDARDPRINTJOBFORMAT        "PDFAsStandardPrintJobFormat"
 
 using namespace ::utl;
 using namespace ::osl;
 using namespace ::com::sun::star::uno;
 
-static SvtPrintOptions_Impl*   pPrinterOptionsDataContainer = NULL;
-static SvtPrintOptions_Impl*   pPrintFileOptionsDataContainer = NULL;
+static SvtPrintOptions_Impl*   pPrinterOptionsDataContainer = nullptr;
+static SvtPrintOptions_Impl*   pPrintFileOptionsDataContainer = nullptr;
 
-SvtPrintOptions_Impl*   SvtPrinterOptions::m_pStaticDataContainer = NULL;
+SvtPrintOptions_Impl*   SvtPrinterOptions::m_pStaticDataContainer = nullptr;
 sal_Int32               SvtPrinterOptions::m_nRefCount = 0;
 
-SvtPrintOptions_Impl*   SvtPrintFileOptions::m_pStaticDataContainer = NULL;
+SvtPrintOptions_Impl*   SvtPrintFileOptions::m_pStaticDataContainer = nullptr;
 sal_Int32               SvtPrintFileOptions::m_nRefCount = 0;
 
 class SvtPrintOptions_Impl
 {
 public:
-     SvtPrintOptions_Impl( const OUString& rConfigRoot );
+    explicit SvtPrintOptions_Impl( const OUString& rConfigRoot );
     ~SvtPrintOptions_Impl();
 
     bool        IsReduceTransparency() const ;
@@ -120,11 +119,11 @@ SvtPrintOptions_Impl::SvtPrintOptions_Impl(const OUString& rConfigRoot)
 {
     try
     {
-        m_xCfg = css::uno::Reference< css::container::XNameAccess >(
+        m_xCfg.set(
             ::comphelper::ConfigurationHelper::openConfig(
-            comphelper::getProcessComponentContext(),
-            ROOTNODE_PRINTOPTION,
-            ::comphelper::ConfigurationHelper::E_STANDARD),
+                comphelper::getProcessComponentContext(),
+                ROOTNODE_PRINTOPTION,
+                ::comphelper::EConfigurationModes::Standard),
             css::uno::UNO_QUERY);
 
         if (m_xCfg.is())
@@ -139,7 +138,7 @@ SvtPrintOptions_Impl::SvtPrintOptions_Impl(const OUString& rConfigRoot)
     {
         m_xNode.clear();
         m_xCfg.clear();
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 }
 
@@ -157,7 +156,7 @@ bool SvtPrintOptions_Impl::IsReduceTransparency() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return bRet;
@@ -177,7 +176,7 @@ sal_Int16 SvtPrintOptions_Impl::GetReducedTransparencyMode() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return  nRet;
@@ -199,7 +198,7 @@ bool SvtPrintOptions_Impl::IsReduceGradients() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return bRet;
@@ -221,7 +220,7 @@ sal_Int16 SvtPrintOptions_Impl::GetReducedGradientMode() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return nRet;
@@ -243,7 +242,7 @@ sal_Int16 SvtPrintOptions_Impl::GetReducedGradientStepCount() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return nRet;
@@ -265,7 +264,7 @@ bool SvtPrintOptions_Impl::IsReduceBitmaps() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return bRet;
@@ -287,7 +286,7 @@ sal_Int16 SvtPrintOptions_Impl::GetReducedBitmapMode() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return nRet;
@@ -309,7 +308,7 @@ sal_Int16 SvtPrintOptions_Impl::GetReducedBitmapResolution() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return  nRet;
@@ -331,7 +330,7 @@ bool SvtPrintOptions_Impl::IsReducedBitmapIncludesTransparency() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return  bRet;
@@ -353,7 +352,7 @@ bool SvtPrintOptions_Impl::IsConvertToGreyscales() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return  bRet;
@@ -376,7 +375,7 @@ bool SvtPrintOptions_Impl::IsPDFAsStandardPrintJobFormat() const
     }
     catch (const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return  bRet;
@@ -466,7 +465,7 @@ void SvtPrintOptions_Impl::impl_setValue (const OUString& sProp, bool bNew )
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 }
 
@@ -494,12 +493,12 @@ void SvtPrintOptions_Impl::impl_setValue (const OUString& sProp,
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 }
 
 SvtBasePrintOptions::SvtBasePrintOptions()
-    : m_pDataContainer(NULL)
+    : m_pDataContainer(nullptr)
 {
 }
 
@@ -509,24 +508,9 @@ SvtBasePrintOptions::~SvtBasePrintOptions()
 
 Mutex& SvtBasePrintOptions::GetOwnStaticMutex()
 {
-    // Initialize static mutex only for one time!
-    static Mutex* pMutex = NULL;
-    // If these method first called (Mutex not already exist!) ...
-    if( pMutex == NULL )
-    {
-        // ... we must create a new one. Protect follow code with the global mutex -
-        // It must be - we create a static variable!
-        MutexGuard aGuard( Mutex::getGlobalMutex() );
-        // We must check our pointer again - because it can be that another instance of our class will be fastr then these!
-        if( pMutex == NULL )
-        {
-            // Create the new mutex and set it for return on static variable.
-            static Mutex aMutex;
-            pMutex = &aMutex;
-        }
-    }
-    // Return new created or already existing mutex object.
-    return *pMutex;
+    static Mutex ourMutex;
+
+    return ourMutex;
 }
 
 bool SvtBasePrintOptions::IsReduceTransparency() const
@@ -717,12 +701,12 @@ SvtPrinterOptions::SvtPrinterOptions()
     // Increase our refcount ...
     ++m_nRefCount;
     // ... and initialize our data container only if it not already!
-    if( m_pStaticDataContainer == NULL )
+    if( m_pStaticDataContainer == nullptr )
     {
         OUString aRootPath( ROOTNODE_START );
         m_pStaticDataContainer = new SvtPrintOptions_Impl( aRootPath += "/Printer" );
         pPrinterOptionsDataContainer = m_pStaticDataContainer;
-        svtools::ItemHolder2::holdConfigItem(E_PRINTOPTIONS);
+        svtools::ItemHolder2::holdConfigItem(EItem::PrintOptions);
     }
 
     SetDataContainer( m_pStaticDataContainer );
@@ -739,8 +723,8 @@ SvtPrinterOptions::~SvtPrinterOptions()
     if( m_nRefCount <= 0 )
     {
         delete m_pStaticDataContainer;
-        m_pStaticDataContainer = NULL;
-        pPrinterOptionsDataContainer = NULL;
+        m_pStaticDataContainer = nullptr;
+        pPrinterOptionsDataContainer = nullptr;
     }
 }
 
@@ -751,13 +735,13 @@ SvtPrintFileOptions::SvtPrintFileOptions()
     // Increase our refcount ...
     ++m_nRefCount;
     // ... and initialize our data container only if it not already!
-    if( m_pStaticDataContainer == NULL )
+    if( m_pStaticDataContainer == nullptr )
     {
         OUString aRootPath( ROOTNODE_START );
         m_pStaticDataContainer = new SvtPrintOptions_Impl( aRootPath += "/File" );
         pPrintFileOptionsDataContainer = m_pStaticDataContainer;
 
-        svtools::ItemHolder2::holdConfigItem(E_PRINTFILEOPTIONS);
+        svtools::ItemHolder2::holdConfigItem(EItem::PrintFileOptions);
     }
 
     SetDataContainer( m_pStaticDataContainer );
@@ -774,8 +758,8 @@ SvtPrintFileOptions::~SvtPrintFileOptions()
     if( m_nRefCount <= 0 )
     {
         delete m_pStaticDataContainer;
-        m_pStaticDataContainer = NULL;
-        pPrintFileOptionsDataContainer = NULL;
+        m_pStaticDataContainer = nullptr;
+        pPrintFileOptionsDataContainer = nullptr;
     }
 }
 
