@@ -17,17 +17,18 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <svtools/svtabbx.hxx>
 #include <svtools/headbar.hxx>
 #include <svtools/svtresid.hxx>
 #include <svtools/svlbitm.hxx>
-#include <svtools/svtools.hrc>
+#include <svtools/strings.hrc>
 #include <svtools/treelistentry.hxx>
 #include <vcl/builderfactory.hxx>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
-#include "svtaccessiblefactory.hxx"
-
+#include <svtaccessiblefactory.hxx>
+#include <o3tl/make_unique.hxx>
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::accessibility;
 
@@ -39,36 +40,36 @@ using namespace ::com::sun::star::accessibility;
 void SvTabListBox::SetTabs()
 {
     SvTreeListBox::SetTabs();
-    if( nTabCount )
+    if( !nTabCount )
+        return;
+
+    DBG_ASSERT(pTabList,"TabList ?");
+
+    // The tree listbox has now inserted its tabs into the list. Now we
+    // fluff up the list with additional tabs and adjust the rightmost tab
+    // of the tree listbox.
+
+    // Picking the rightmost tab.
+    // HACK for the explorer! If ViewParent != 0, the first tab of the tree
+    // listbox is calculated by the tre listbox itself! This behavior is
+    // necessary for ButtonsOnRoot, as the explorer does not know in this
+    // case, which additional offset it need to add to the tabs in this mode
+    // -- the tree listbox knows that, though!
+    /*
+    if( !pViewParent )
     {
-        DBG_ASSERT(pTabList,"TabList ?");
+    SvLBoxTab* pFirstTab = (SvLBoxTab*)aTabs.GetObject( aTabs.Count()-1 );
+    pFirstTab->SetPos( pTabList[0].GetPos() );
+    pFirstTab->nFlags &= ~MYTABMASK;
+    pFirstTab->nFlags |= pTabList[0].nFlags;
+    }
+    */
 
-        // The tree listbox has now inserted its tabs into the list. Now we
-        // fluff up the list with additional tabs and adjust the rightmost tab
-        // of the tree listbox.
-
-        // Picking the rightmost tab.
-        // HACK for the explorer! If ViewParent != 0, the first tab of the tree
-        // listbox is calculated by the tre listbox itself! This behavior is
-        // necessary for ButtonsOnRoot, as the explorer does not know in this
-        // case, which additional offset it need to add to the tabs in this mode
-        // -- the tree listbox knows that, though!
-        /*
-        if( !pViewParent )
-        {
-        SvLBoxTab* pFirstTab = (SvLBoxTab*)aTabs.GetObject( aTabs.Count()-1 );
-        pFirstTab->SetPos( pTabList[0].GetPos() );
-        pFirstTab->nFlags &= ~MYTABMASK;
-        pFirstTab->nFlags |= pTabList[0].nFlags;
-        }
-        */
-
-        // append all other tabs to the list
-        for( sal_uInt16 nCurTab = 1; nCurTab < nTabCount; nCurTab++ )
-        {
-            SvLBoxTab* pTab = pTabList+nCurTab;
-            AddTab( pTab->GetPos(), pTab->nFlags );
-        }
+    // append all other tabs to the list
+    for( sal_uInt16 nCurTab = 1; nCurTab < nTabCount; nCurTab++ )
+    {
+        SvLBoxTab* pTab = pTabList+nCurTab;
+        AddTab( pTab->GetPos(), pTab->nFlags );
     }
 }
 
@@ -83,8 +84,7 @@ void SvTabListBox::InitEntry(SvTreeListEntry* pEntry, const OUString& rStr,
     for( sal_uInt16 nToken = 0; nToken < nCount; nToken++ )
     {
         const OUString aToken = GetToken(aCurEntry, nIndex);
-        std::unique_ptr<SvLBoxString> pStr(new SvLBoxString(pEntry, 0, aToken));
-        pEntry->AddItem(std::move(pStr));
+        pEntry->AddItem(o3tl::make_unique<SvLBoxString>(aToken));
     }
 }
 SvTabListBox::SvTabListBox( vcl::Window* pParent, WinBits nBits )
@@ -92,18 +92,10 @@ SvTabListBox::SvTabListBox( vcl::Window* pParent, WinBits nBits )
 {
     pTabList = nullptr;
     nTabCount = 0;
-    pViewParent = nullptr;
     SetHighlightRange();    // select full width
 }
 
-VCL_BUILDER_DECL_FACTORY(SvTabListBox)
-{
-    WinBits nWinStyle = WB_TABSTOP;
-    OString sBorder = VclBuilder::extractCustomProperty(rMap);
-    if (!sBorder.isEmpty())
-        nWinStyle |= WB_BORDER;
-    rRet = VclPtr<SvTabListBox>::Create(pParent, nWinStyle);
-}
+VCL_BUILDER_FACTORY_CONSTRUCTOR(SvTabListBox, WB_TABSTOP)
 
 SvTabListBox::~SvTabListBox()
 {
@@ -133,7 +125,7 @@ void SvTabListBox::SetTabs(const long* pTabs, MapUnit eMapUnit)
     nTabCount = nCount;
 
     MapMode aMMSource( eMapUnit );
-    MapMode aMMDest( MAP_PIXEL );
+    MapMode aMMDest( MapUnit::MapPixel );
 
     pTabs++;
     for( sal_uInt16 nIdx = 0; nIdx < nCount; nIdx++, pTabs++ )
@@ -152,19 +144,19 @@ void SvTabListBox::SetTabs(const long* pTabs, MapUnit eMapUnit)
 void SvTabListBox::SetTab( sal_uInt16 nTab,long nValue,MapUnit eMapUnit )
 {
     DBG_ASSERT(nTab<nTabCount,"Invalid Tab-Pos");
-    if( nTab < nTabCount )
-    {
-        DBG_ASSERT(pTabList,"TabList?");
-        MapMode aMMSource( eMapUnit );
-        MapMode aMMDest( MAP_PIXEL );
-        Size aSize( nValue, 0 );
-        aSize = LogicToLogic( aSize, &aMMSource, &aMMDest );
-        nValue = aSize.Width();
-        pTabList[ nTab ].SetPos( nValue );
-        SvTreeListBox::nTreeFlags |= SvTreeFlags::RECALCTABS;
-        if( IsUpdateMode() )
-            Invalidate();
-    }
+    if( nTab >= nTabCount )
+        return;
+
+    DBG_ASSERT(pTabList,"TabList?");
+    MapMode aMMSource( eMapUnit );
+    MapMode aMMDest( MapUnit::MapPixel );
+    Size aSize( nValue, 0 );
+    aSize = LogicToLogic( aSize, &aMMSource, &aMMDest );
+    nValue = aSize.Width();
+    pTabList[ nTab ].SetPos( nValue );
+    SvTreeListBox::nTreeFlags |= SvTreeFlags::RECALCTABS;
+    if( IsUpdateMode() )
+        Invalidate();
 }
 
 SvTreeListEntry* SvTabListBox::InsertEntry( const OUString& rText, SvTreeListEntry* pParent,
@@ -264,7 +256,7 @@ OUString SvTabListBox::GetEntryText( SvTreeListEntry* pEntry, sal_uInt16 nCol )
         while( nCur < nCount )
         {
             const SvLBoxItem& rStr = pEntry->GetItem( nCur );
-            if (rStr.GetType() == SV_ITEM_ID_LBOXSTRING)
+            if (rStr.GetType() == SvLBoxItemType::String)
             {
                 if( nCol == 0xffff )
                 {
@@ -313,7 +305,7 @@ void SvTabListBox::SetEntryText(const OUString& rStr, SvTreeListEntry* pEntry, s
     for (sal_uInt16 nCur = 0; nCur < nCount; ++nCur)
     {
         SvLBoxItem& rBoxItem = pEntry->GetItem( nCur );
-        if (rBoxItem.GetType() == SV_ITEM_ID_LBOXSTRING)
+        if (rBoxItem.GetType() == SvLBoxItemType::String)
         {
             if (!nCol || nCol==0xFFFF)
             {
@@ -330,9 +322,8 @@ void SvTabListBox::SetEntryText(const OUString& rStr, SvTreeListEntry* pEntry, s
     }
     GetModel()->InvalidateEntry( pEntry );
 
-    TabListBoxEventData* pData = new TabListBoxEventData( pEntry, nTextColumn, sOldText );
-    CallEventListeners( VCLEVENT_TABLECELL_NAMECHANGED, pData );
-    delete pData;
+    std::unique_ptr<TabListBoxEventData> pData( new TabListBoxEventData( pEntry, nTextColumn, sOldText ) );
+    CallEventListeners( VclEventId::TableCellNameChanged, pData.get() );
 }
 
 OUString SvTabListBox::GetCellText( sal_uLong nPos, sal_uInt16 nCol ) const
@@ -343,7 +334,7 @@ OUString SvTabListBox::GetCellText( sal_uLong nPos, sal_uInt16 nCol ) const
     if (pEntry && pEntry->ItemCount() > static_cast<size_t>(nCol+1))
     {
         const SvLBoxItem& rStr = pEntry->GetItem( nCol + 1 );
-        if (rStr.GetType() == SV_ITEM_ID_LBOXSTRING)
+        if (rStr.GetType() == SvLBoxItemType::String)
             aResult = static_cast<const SvLBoxString&>(rStr).GetText();
     }
     return aResult;
@@ -378,11 +369,6 @@ sal_uLong SvTabListBox::GetEntryPos( const SvTreeListEntry* pEntry ) const
     return 0xffffffff;
 }
 
-void SvTabListBox::Resize()
-{
-    SvTreeListBox::Resize();
-}
-
 // static
 OUString SvTabListBox::GetToken( const OUString &sStr, sal_Int32& nIndex )
 {
@@ -401,7 +387,7 @@ OUString SvTabListBox::GetTabEntryText( sal_uLong nPos, sal_uInt16 nCol ) const
         while( nCur < nCount )
         {
             const SvLBoxItem& rBoxItem = pEntry->GetItem( nCur );
-            if (rBoxItem.GetType() == SV_ITEM_ID_LBOXSTRING)
+            if (rBoxItem.GetType() == SvLBoxItemType::String)
             {
                 if ( nCol == 0xffff )
                 {
@@ -415,7 +401,7 @@ OUString SvTabListBox::GetTabEntryText( sal_uLong nPos, sal_uInt16 nCol ) const
                     {
                         OUString sRet = static_cast<const SvLBoxString&>(rBoxItem).GetText();
                         if ( sRet.isEmpty() )
-                            sRet = SVT_RESSTR( STR_SVT_ACC_EMPTY_FIELD );
+                            sRet = SvtResId( STR_SVT_ACC_EMPTY_FIELD );
                         return sRet;
                     }
                     --nCol;
@@ -520,11 +506,11 @@ SvHeaderTabListBox::~SvHeaderTabListBox()
 
 void SvHeaderTabListBox::dispose()
 {
-    delete m_pImpl;
+    m_pImpl.reset();
     SvTabListBox::dispose();
 }
 
-void SvHeaderTabListBox::Paint( vcl::RenderContext& rRenderContext, const Rectangle& rRect )
+void SvHeaderTabListBox::Paint( vcl::RenderContext& rRenderContext, const tools::Rectangle& rRect )
 {
     if (m_bFirstPaint)
     {
@@ -544,16 +530,16 @@ void SvHeaderTabListBox::InitHeaderBar( HeaderBar* pHeaderBar )
 
 bool SvHeaderTabListBox::IsItemChecked( SvTreeListEntry* pEntry, sal_uInt16 nCol )
 {
-    SvButtonState eState = SV_BUTTON_UNCHECKED;
+    SvButtonState eState = SvButtonState::Unchecked;
     SvLBoxButton& rItem = static_cast<SvLBoxButton&>( pEntry->GetItem( nCol + 1 ) );
 
-    if (rItem.GetType() == SV_ITEM_ID_LBOXBUTTON)
+    if (rItem.GetType() == SvLBoxItemType::Button)
     {
         SvItemStateFlags nButtonFlags = rItem.GetButtonFlags();
         eState = SvLBoxButtonData::ConvertToButtonState( nButtonFlags );
     }
 
-    return ( eState == SV_BUTTON_CHECKED );
+    return ( eState == SvButtonState::Checked );
 }
 
 SvTreeListEntry* SvHeaderTabListBox::InsertEntryToColumn(
@@ -597,7 +583,7 @@ sal_uLong SvHeaderTabListBox::Insert( SvTreeListEntry* pEntry, sal_uLong nRootPo
     return nPos;
 }
 
-void SvHeaderTabListBox::RemoveEntry( SvTreeListEntry* _pEntry )
+void SvHeaderTabListBox::RemoveEntry( SvTreeListEntry const * _pEntry )
 {
     GetModel()->Remove( _pEntry );
     m_aAccessibleChildren.clear();
@@ -609,12 +595,12 @@ void SvHeaderTabListBox::Clear()
     m_aAccessibleChildren.clear();
 }
 
-IMPL_LINK_NOARG_TYPED(SvHeaderTabListBox, ScrollHdl_Impl, SvTreeListBox*, void)
+IMPL_LINK_NOARG(SvHeaderTabListBox, ScrollHdl_Impl, SvTreeListBox*, void)
 {
     m_pImpl->m_pHeaderBar->SetOffset( -GetXOffset() );
 }
 
-IMPL_LINK_NOARG_TYPED(SvHeaderTabListBox, CreateAccessibleHdl_Impl, HeaderBar*, void)
+IMPL_LINK_NOARG(SvHeaderTabListBox, CreateAccessibleHdl_Impl, HeaderBar*, void)
 {
     vcl::Window* pParent = m_pImpl->m_pHeaderBar->GetAccessibleParentWindow();
     DBG_ASSERT( pParent, "SvHeaderTabListBox..CreateAccessibleHdl_Impl - accessible parent not found" );
@@ -654,7 +640,7 @@ bool SvHeaderTabListBox::IsCellCheckBox( long _nRow, sal_uInt16 _nColumn, TriSta
         if ( nItemCount > ( _nColumn + 1 ) )
         {
             SvLBoxItem& rItem = pEntry->GetItem( _nColumn + 1 );
-            if (rItem.GetType() == SV_ITEM_ID_LBOXBUTTON)
+            if (rItem.GetType() == SvLBoxItemType::Button)
             {
                 bRet = true;
                 _rState = ( ( static_cast<SvLBoxButton&>(rItem).GetButtonFlags() & SvItemStateFlags::UNCHECKED ) == SvItemStateFlags::NONE )
@@ -706,12 +692,12 @@ sal_uInt16 SvHeaderTabListBox::GetCurrColumn() const
 
 OUString SvHeaderTabListBox::GetRowDescription( sal_Int32 _nRow ) const
 {
-    return OUString( GetEntryText( _nRow ) );
+    return GetEntryText( _nRow );
 }
 
 OUString SvHeaderTabListBox::GetColumnDescription( sal_uInt16 _nColumn ) const
 {
-    return OUString( m_pImpl->m_pHeaderBar->GetItemText( m_pImpl->m_pHeaderBar->GetItemId( _nColumn ) ) );
+    return m_pImpl->m_pHeaderBar->GetItemText( m_pImpl->m_pHeaderBar->GetItemId( _nColumn ) );
 }
 
 bool SvHeaderTabListBox::HasRowHeader() const
@@ -742,11 +728,6 @@ void SvHeaderTabListBox::SelectAll()
     SvTreeListBox::SelectAll(true);
 }
 
-void SvHeaderTabListBox::SelectAll( bool bSelect, bool bPaint )
-{
-    // overwritten just to disambiguate the SelectAll() from the base' class SelectAll( bool, bool )
-    SvTabListBox::SelectAll( bSelect, bPaint );
-}
 void SvHeaderTabListBox::SelectRow( long _nRow, bool _bSelect, bool )
 {
     Select( GetEntry( _nRow ), _bSelect );
@@ -795,9 +776,9 @@ OUString SvHeaderTabListBox::GetAccessibleCellText( long _nRow, sal_uInt16 _nCol
     return GetTabEntryText(_nRow, _nColumnPos);
 }
 
-Rectangle SvHeaderTabListBox::calcHeaderRect( bool _bIsColumnBar, bool _bOnScreen )
+tools::Rectangle SvHeaderTabListBox::calcHeaderRect( bool _bIsColumnBar, bool _bOnScreen )
 {
-    Rectangle aRect;
+    tools::Rectangle aRect;
     if ( _bIsColumnBar )
     {
         vcl::Window* pParent = nullptr;
@@ -809,36 +790,36 @@ Rectangle SvHeaderTabListBox::calcHeaderRect( bool _bIsColumnBar, bool _bOnScree
     return aRect;
 }
 
-Rectangle SvHeaderTabListBox::calcTableRect( bool _bOnScreen )
+tools::Rectangle SvHeaderTabListBox::calcTableRect( bool _bOnScreen )
 {
     vcl::Window* pParent = nullptr;
     if ( !_bOnScreen )
         pParent = GetAccessibleParentWindow();
 
-    Rectangle aRect( GetWindowExtentsRelative( pParent ) );
+    tools::Rectangle aRect( GetWindowExtentsRelative( pParent ) );
     return aRect;
 }
 
-Rectangle SvHeaderTabListBox::GetFieldRectPixelAbs( sal_Int32 _nRow, sal_uInt16 _nColumn, bool _bIsHeader, bool _bOnScreen )
+tools::Rectangle SvHeaderTabListBox::GetFieldRectPixelAbs( sal_Int32 _nRow, sal_uInt16 _nColumn, bool _bIsHeader, bool _bOnScreen )
 {
     DBG_ASSERT( !_bIsHeader || 0 == _nRow, "invalid parameters" );
-    Rectangle aRect;
+    tools::Rectangle aRect;
     SvTreeListEntry* pEntry = GetEntry( _nRow );
     if ( pEntry )
     {
         aRect = _bIsHeader ? calcHeaderRect( true, false ) : GetBoundingRect( pEntry );
         Point aTopLeft = aRect.TopLeft();
         DBG_ASSERT( m_pImpl->m_pHeaderBar->GetItemCount() > _nColumn, "invalid column" );
-        Rectangle aItemRect = m_pImpl->m_pHeaderBar->GetItemRect( m_pImpl->m_pHeaderBar->GetItemId( _nColumn ) );
+        tools::Rectangle aItemRect = m_pImpl->m_pHeaderBar->GetItemRect( m_pImpl->m_pHeaderBar->GetItemId( _nColumn ) );
         aTopLeft.X() = aItemRect.Left();
         Size aSize = aItemRect.GetSize();
-        aRect = Rectangle( aTopLeft, aSize );
+        aRect = tools::Rectangle( aTopLeft, aSize );
         vcl::Window* pParent = nullptr;
         if ( !_bOnScreen )
             pParent = GetAccessibleParentWindow();
         aTopLeft = aRect.TopLeft();
         aTopLeft += GetWindowExtentsRelative( pParent ).TopLeft();
-        aRect = Rectangle( aTopLeft, aRect.GetSize() );
+        aRect = tools::Rectangle( aTopLeft, aRect.GetSize() );
     }
 
     return aRect;
@@ -1014,7 +995,7 @@ OUString SvHeaderTabListBox::GetAccessibleObjectDescription( ::svt::AccessibleBr
             sal_Int32 nRow = _nPos / nColumnCount;
             sal_uInt16 nColumn  = static_cast< sal_uInt16 >( _nPos % nColumnCount );
 
-            OUString aText( SVT_RESSTR(STR_SVT_ACC_DESC_TABLISTBOX) );
+            OUString aText( SvtResId(STR_SVT_ACC_DESC_TABLISTBOX) );
             aText = aText.replaceFirst( sVar1, OUString::number( nRow ) );
             OUString sColHeader = m_pImpl->m_pHeaderBar->GetItemText( m_pImpl->m_pHeaderBar->GetItemId( nColumn ) );
             if ( sColHeader.isEmpty() )
@@ -1109,12 +1090,12 @@ void SvHeaderTabListBox::GrabTableFocus()
     GrabFocus();
 }
 
-bool SvHeaderTabListBox::GetGlyphBoundRects( const Point& rOrigin, const OUString& rStr, int nIndex, int nLen, int nBase, MetricVector& rVector )
+bool SvHeaderTabListBox::GetGlyphBoundRects( const Point& rOrigin, const OUString& rStr, int nIndex, int nLen, MetricVector& rVector )
 {
-    return Control::GetGlyphBoundRects( rOrigin, rStr, nIndex, nLen, nBase, rVector );
+    return Control::GetGlyphBoundRects( rOrigin, rStr, nIndex, nLen, rVector );
 }
 
-Rectangle SvHeaderTabListBox::GetWindowExtentsRelative( vcl::Window *pRelativeWindow ) const
+tools::Rectangle SvHeaderTabListBox::GetWindowExtentsRelative( vcl::Window *pRelativeWindow ) const
 {
     return Control::GetWindowExtentsRelative( pRelativeWindow );
 }
@@ -1124,9 +1105,9 @@ void SvHeaderTabListBox::GrabFocus()
     Control::GrabFocus();
 }
 
-Reference< XAccessible > SvHeaderTabListBox::GetAccessible( bool bCreate )
+Reference< XAccessible > SvHeaderTabListBox::GetAccessible()
 {
-    return Control::GetAccessible( bCreate );
+    return Control::GetAccessible();
 }
 
 vcl::Window* SvHeaderTabListBox::GetAccessibleParentWindow() const
@@ -1160,9 +1141,9 @@ Reference< XAccessible > SvHeaderTabListBox::CreateAccessible()
     return xAccessible;
 }
 
-Rectangle SvHeaderTabListBox::GetFieldCharacterBounds(sal_Int32,sal_Int32,sal_Int32)
+tools::Rectangle SvHeaderTabListBox::GetFieldCharacterBounds(sal_Int32,sal_Int32,sal_Int32)
 {
-    Rectangle aRect;
+    tools::Rectangle aRect;
     return aRect;
 }
 
@@ -1170,7 +1151,7 @@ sal_Int32 SvHeaderTabListBox::GetFieldIndexAtPoint(sal_Int32 _nRow,sal_Int32 _nC
 {
     OUString sText = GetAccessibleCellText( _nRow, static_cast< sal_uInt16 >( _nColumnPos ) );
     MetricVector aRects;
-    if ( GetGlyphBoundRects(Point(0,0), sText, 0, sText.getLength(), 0, aRects) )
+    if ( GetGlyphBoundRects(Point(0,0), sText, 0, sText.getLength(), aRects) )
     {
         for (MetricVector::iterator aIter = aRects.begin(); aIter != aRects.end(); ++aIter)
         {
