@@ -26,7 +26,6 @@ namespace svt
 {
 
 
-
     //= FileURLBox
 
 
@@ -76,7 +75,7 @@ namespace svt
         return SvtURLBox::PreNotify(_rNEvt);
     }
 
-    bool FileURLBox::Notify( NotifyEvent& _rNEvt )
+    bool FileURLBox::EventNotify( NotifyEvent& _rNEvt )
     {
         if (_rNEvt.GetType() == MouseNotifyEvent::KEYINPUT)
         {
@@ -85,13 +84,13 @@ namespace svt
                 &&  ( IsInDropDown()                                             )
                 )
             {
-                bool bReturn = SvtURLBox::Notify(_rNEvt);
+                bool bReturn = SvtURLBox::EventNotify(_rNEvt);
                 DisplayURL( m_sPreservedText );
                 return bReturn;
             }
         }
 
-        return SvtURLBox::Notify(_rNEvt);
+        return SvtURLBox::EventNotify(_rNEvt);
     }
 
 }   // namespace svt
