@@ -26,7 +26,7 @@
 
 #include <svtools/ruler.hxx>
 #include <svtools/svtresid.hxx>
-#include <svtools/svtools.hrc>
+#include <svtools/strings.hrc>
 #include <svtools/colorcfg.hxx>
 
 #include <memory>
@@ -88,9 +88,6 @@ private:
 
 public:
     ImplRulerData();
-    ~ImplRulerData();
-
-    ImplRulerData& operator=( const ImplRulerData& rData );
 };
 
 ImplRulerData::ImplRulerData() :
@@ -111,85 +108,19 @@ ImplRulerData::ImplRulerData() :
 {
 }
 
-ImplRulerData::~ImplRulerData()
-{}
-
-ImplRulerData& ImplRulerData::operator=( const ImplRulerData& rData )
-{
-    if( this == &rData )
-        return *this;
-
-    nNullVirOff       = rData.nNullVirOff;
-    nRulVirOff        = rData.nRulVirOff;
-    nRulWidth         = rData.nRulWidth;
-    nPageOff          = rData.nPageOff;
-    nPageWidth        = rData.nPageWidth;
-    nNullOff          = rData.nNullOff;
-    nMargin1          = rData.nMargin1;
-    nMargin2          = rData.nMargin2;
-    nLeftFrameMargin  = rData.nLeftFrameMargin;
-    nRightFrameMargin = rData.nRightFrameMargin;
-    nMargin1Style     = rData.nMargin1Style;
-    nMargin2Style     = rData.nMargin2Style;
-    bAutoPageWidth    = rData.bAutoPageWidth;
-    bTextRTL          = rData.bTextRTL;
-
-    if ( !rData.pLines.empty() )
-    {
-        pLines.resize(rData.pLines.size());
-        std::copy(rData.pLines.begin(), rData.pLines.end(), pLines.begin());
-    }
-    else
-    {
-        pLines.clear();
-    }
-
-    if ( !rData.pBorders.empty() )
-    {
-        pBorders.resize(rData.pBorders.size());
-        std::copy(rData.pBorders.begin(), rData.pBorders.end(), pBorders.begin());
-    }
-    else
-    {
-        pBorders.clear();
-    }
-
-    if ( !rData.pIndents.empty() )
-    {
-        pIndents.resize(rData.pIndents.size());
-        std::copy(rData.pIndents.begin(), rData.pIndents.end(), pIndents.begin());
-    }
-    else
-    {
-        pIndents.clear();
-    }
-
-    if ( !rData.pTabs.empty() )
-    {
-        pTabs.resize(rData.pTabs.size());
-        std::copy(rData.pTabs.begin(), rData.pTabs.end(), pTabs.begin());
-    }
-    else
-    {
-        pTabs.clear();
-    }
-
-    return *this;
-}
-
 static const RulerUnitData aImplRulerUnitTab[RULER_UNIT_COUNT] =
 {
-{ MAP_100TH_MM,        100,    25.0,    25.0,     50.0,    100.0,  " mm"    }, // MM
-{ MAP_100TH_MM,       1000,   100.0,   500.0,   1000.0,   1000.0,  " cm"    }, // CM
-{ MAP_MM,             1000,    10.0,   250.0,    500.0,   1000.0,  " m"     }, // M
-{ MAP_CM,           100000, 12500.0, 25000.0,  50000.0, 100000.0,  " km"    }, // KM
-{ MAP_1000TH_INCH,    1000,    62.5,   125.0,    500.0,   1000.0,  "\""     }, // INCH
-{ MAP_100TH_INCH,     1200,   120.0,   120.0,    600.0,   1200.0,  "'"      }, // FOOT
-{ MAP_10TH_INCH,    633600, 63360.0, 63360.0, 316800.0, 633600.0,  " miles" }, // MILE
-{ MAP_POINT,             1,    12.0,    12.0,     12.0,     36.0,  " pt"    }, // POINT
-{ MAP_100TH_MM,        423,   423.0,   423.0,    423.0,    846.0,  " pi"    }, // PICA
-{ MAP_100TH_MM,        371,   371.0,   371.0,    371.0,    743.0,  " ch"    }, // CHAR
-{ MAP_100TH_MM,        551,   551.0,   551.0,    551.0,   1102.0,  " li"    }  // LINE
+{ MapUnit::Map100thMM,        100,    25.0,    25.0,     50.0,    100.0,  " mm"    }, // MM
+{ MapUnit::Map100thMM,       1000,   100.0,   500.0,   1000.0,   1000.0,  " cm"    }, // CM
+{ MapUnit::MapMM,             1000,    10.0,   250.0,    500.0,   1000.0,  " m"     }, // M
+{ MapUnit::MapCM,           100000, 12500.0, 25000.0,  50000.0, 100000.0,  " km"    }, // KM
+{ MapUnit::Map1000thInch,    1000,    62.5,   125.0,    500.0,   1000.0,  "\""     }, // INCH
+{ MapUnit::Map100thInch,     1200,   120.0,   120.0,    600.0,   1200.0,  "'"      }, // FOOT
+{ MapUnit::Map10thInch,    633600, 63360.0, 63360.0, 316800.0, 633600.0,  " miles" }, // MILE
+{ MapUnit::MapPoint,             1,    12.0,    12.0,     12.0,     36.0,  " pt"    }, // POINT
+{ MapUnit::Map100thMM,        423,   423.0,   423.0,    423.0,    846.0,  " pc"    }, // PICA
+{ MapUnit::Map100thMM,        371,   371.0,   371.0,    371.0,    743.0,  " ch"    }, // CHAR
+{ MapUnit::Map100thMM,        551,   551.0,   551.0,    551.0,   1102.0,  " li"    }  // LINE
 };
 
 static RulerTabData ruler_tab =
@@ -214,12 +145,12 @@ static RulerTabData ruler_tab =
 
 void Ruler::ImplInit( WinBits nWinBits )
 {
-    // Default WinBits setzen
+    // Set default WinBits
     if ( !(nWinBits & WB_VERT) )
     {
         nWinBits |= WB_HORZ;
 
-        // --- RTL --- no UI mirroring for horizontal rulers, because
+        // RTL: no UI mirroring for horizontal rulers, because
         // the document is also not mirrored
         EnableRTL( false );
     }
@@ -240,8 +171,6 @@ void Ruler::ImplInit( WinBits nWinBits )
     mnDragSize      = RulerDragSize::Move;  // Did size change at dragging
     mnDragModifier  = 0;                    // Modifier key at dragging
     mnExtraStyle    = 0;                    // Style of Extra field
-    mnExtraClicks   = 0;                    // No. of clicks for Extra field
-    mnExtraModifier = 0;                    // Modifier key at click in extra field
     mnCharWidth     = 371;
     mnLineHeight    = 551;
     mbCalc          = true;                 // Should recalculate page width
@@ -260,7 +189,6 @@ void Ruler::ImplInit( WinBits nWinBits )
     mnUnitIndex     = RULER_UNIT_CM;
     meUnit          = FUNIT_CM;
     maZoom          = Fraction( 1, 1 );
-    meSourceUnit    = MAP_100TH_MM;
 
     // Recalculate border widths
     if ( nWinBits & WB_BORDER )
@@ -272,7 +200,7 @@ void Ruler::ImplInit( WinBits nWinBits )
     ImplInitSettings( true, true, true );
 
     // Setup the default size
-    Rectangle aRect;
+    tools::Rectangle aRect;
     GetTextBoundRect( aRect, "0123456789" );
     long nDefHeight = aRect.GetHeight() + RULER_OFF * 2 + ruler_tab.textoff * 2 + mnBorderWidth;
 
@@ -282,14 +210,13 @@ void Ruler::ImplInit( WinBits nWinBits )
     else
         aDefSize.Width() = nDefHeight;
     SetOutputSizePixel( aDefSize );
-    SetType(WINDOW_RULER);
-    pAccContext = nullptr;
+    SetType(WindowType::RULER);
 }
 
 Ruler::Ruler( vcl::Window* pParent, WinBits nWinStyle ) :
     Window( pParent, nWinStyle & WB_3DLOOK ),
     maVirDev( VclPtr<VirtualDevice>::Create(*this) ),
-    maMapMode( MAP_100TH_MM ),
+    maMapMode( MapUnit::Map100thMM ),
     mpSaveData(new ImplRulerData),
     mpData(nullptr),
     mpDragData(new ImplRulerData)
@@ -334,11 +261,7 @@ void Ruler::dispose()
     mpSaveData = nullptr;
     delete mpDragData;
     mpDragData = nullptr;
-    if( pAccContext )
-    {
-        pAccContext->release();
-        pAccContext = nullptr;
-    }
+    mxAccContext.clear();
     Window::dispose();
 }
 
@@ -381,14 +304,14 @@ void Ruler::ImplVDrawRect(vcl::RenderContext& rRenderContext, long nX1, long nY1
     }
 
     if ( mnWinStyle & WB_HORZ )
-        rRenderContext.DrawRect(Rectangle(nX1, nY1, nX2, nY2));
+        rRenderContext.DrawRect(tools::Rectangle(nX1, nY1, nX2, nY2));
     else
-        rRenderContext.DrawRect(Rectangle(nY1, nX1, nY2, nX2));
+        rRenderContext.DrawRect(tools::Rectangle(nY1, nX1, nY2, nX2));
 }
 
 void Ruler::ImplVDrawText(vcl::RenderContext& rRenderContext, long nX, long nY, const OUString& rText, long nMin, long nMax)
 {
-    Rectangle aRect;
+    tools::Rectangle aRect;
     rRenderContext.GetTextBoundRect(aRect, rText);
 
     long nShiftX = ( aRect.GetWidth() / 2 ) + aRect.Left();
@@ -406,61 +329,61 @@ void Ruler::ImplVDrawText(vcl::RenderContext& rRenderContext, long nX, long nY,
 void Ruler::ImplInvertLines(vcl::RenderContext& rRenderContext)
 {
     // Position lines
-    if (!mpData->pLines.empty() && mbActive && !mbDrag && !mbFormat && !(mnUpdateFlags & RULER_UPDATE_LINES) )
+    if (!(!mpData->pLines.empty() && mbActive && !mbDrag && !mbFormat && !(mnUpdateFlags & RULER_UPDATE_LINES)) )
+        return;
+
+    long nNullWinOff = mpData->nNullVirOff + mnVirOff;
+    long nRulX1      = mpData->nRulVirOff  + mnVirOff;
+    long nRulX2      = nRulX1 + mpData->nRulWidth;
+    long nY          = (RULER_OFF * 2) + mnVirHeight - 1;
+
+    // Calculate rectangle
+    tools::Rectangle aRect;
+    if (mnWinStyle & WB_HORZ)
+        aRect.Bottom() = nY;
+    else
+        aRect.Right() = nY;
+
+    // Draw lines
+    for (RulerLine & rLine : mpData->pLines)
     {
-        long nNullWinOff = mpData->nNullVirOff + mnVirOff;
-        long nRulX1      = mpData->nRulVirOff  + mnVirOff;
-        long nRulX2      = nRulX1 + mpData->nRulWidth;
-        long nY          = (RULER_OFF * 2) + mnVirHeight - 1;
-
-        // Calculate rectangle
-        Rectangle aRect;
-        if (mnWinStyle & WB_HORZ)
-            aRect.Bottom() = nY;
-        else
-            aRect.Right() = nY;
-
-        // Draw lines
-        for (RulerLine & rLine : mpData->pLines)
+        const long n = rLine.nPos + nNullWinOff;
+        if ((n >= nRulX1) && (n < nRulX2))
         {
-            const long n = rLine.nPos + nNullWinOff;
-            if ((n >= nRulX1) && (n < nRulX2))
+            if (mnWinStyle & WB_HORZ )
             {
-                if (mnWinStyle & WB_HORZ )
-                {
-                    aRect.Left()   = n;
-                    aRect.Right()  = n;
-                }
-                else
-                {
-                    aRect.Top()    = n;
-                    aRect.Bottom() = n;
-                }
-                Rectangle aTempRect = aRect;
-
-                if (mnWinStyle & WB_HORZ)
-                    aTempRect.Bottom() = RULER_OFF - 1;
-                else
-                    aTempRect.Right() = RULER_OFF - 1;
-
-                rRenderContext.Erase(aTempRect);
-
-                if (mnWinStyle & WB_HORZ)
-                {
-                    aTempRect.Bottom() = aRect.Bottom();
-                    aTempRect.Top()    = aTempRect.Bottom() - RULER_OFF + 1;
-                }
-                else
-                {
-                    aTempRect.Right()  = aRect.Right();
-                    aTempRect.Left()   = aTempRect.Right() - RULER_OFF + 1;
-                }
-                rRenderContext.Erase(aTempRect);
-                Invert(aRect);
+                aRect.Left()   = n;
+                aRect.Right()  = n;
             }
+            else
+            {
+                aRect.Top()    = n;
+                aRect.Bottom() = n;
+            }
+            tools::Rectangle aTempRect = aRect;
+
+            if (mnWinStyle & WB_HORZ)
+                aTempRect.Bottom() = RULER_OFF - 1;
+            else
+                aTempRect.Right() = RULER_OFF - 1;
+
+            rRenderContext.Erase(aTempRect);
+
+            if (mnWinStyle & WB_HORZ)
+            {
+                aTempRect.Bottom() = aRect.Bottom();
+                aTempRect.Top()    = aTempRect.Bottom() - RULER_OFF + 1;
+            }
+            else
+            {
+                aTempRect.Right()  = aRect.Right();
+                aTempRect.Left()   = aTempRect.Right() - RULER_OFF + 1;
+            }
+            rRenderContext.Erase(aTempRect);
+            Invert(aRect);
         }
-        mnUpdateFlags = 0;
     }
+    mnUpdateFlags = 0;
 }
 
 void Ruler::ImplDrawTicks(vcl::RenderContext& rRenderContext, long nMin, long nMax, long nStart, long nTop, long nBottom)
@@ -574,118 +497,118 @@ void Ruler::ImplDrawTicks(vcl::RenderContext& rRenderContext, long nMin, long nM
         rRenderContext.SetLineColor(rRenderContext.GetSettings().GetStyleSettings().GetShadowColor());
     }
 
-    if (!bNoTicks)
+    if (bNoTicks)
+        return;
+
+    long n = 0;
+    double nTick = 0.0;
+    double nTick3 = 0;
+
+    if ((mnUnitIndex != RULER_UNIT_CHAR) && (mnUnitIndex != RULER_UNIT_LINE))
     {
-        long n = 0;
-        double nTick = 0.0;
-        double nTick3 = 0;
+        nTick2 = aImplRulerUnitTab[mnUnitIndex].nTick2;
+        nTick3 = aImplRulerUnitTab[mnUnitIndex].nTick3;
+    }
 
-        if ((mnUnitIndex != RULER_UNIT_CHAR) && (mnUnitIndex != RULER_UNIT_LINE))
+    Size nTickGapSize;
+
+    nTickGapSize = rRenderContext.LogicToPixel(Size(nTickCount, nTickCount), maMapMode);
+    long nTickGap1 = mnWinStyle & WB_HORZ ? nTickGapSize.Width() : nTickGapSize.Height();
+    nTickGapSize = rRenderContext.LogicToPixel(Size(nTick2, nTick2), maMapMode);
+    long nTickGap2 = mnWinStyle & WB_HORZ ? nTickGapSize.Width() : nTickGapSize.Height();
+    nTickGapSize = rRenderContext.LogicToPixel(Size(nTick3, nTick3), maMapMode);
+    long nTickGap3 = mnWinStyle & WB_HORZ ? nTickGapSize.Width() : nTickGapSize.Height();
+
+    while (((nStart - n) >= nMin) || ((nStart + n) <= nMax))
+    {
+        // Null point
+        if (nTick == 0.0)
         {
-            nTick2 = aImplRulerUnitTab[mnUnitIndex].nTick2;
-            nTick3 = aImplRulerUnitTab[mnUnitIndex].nTick3;
-        }
-
-        Size nTickGapSize;
-
-        nTickGapSize = rRenderContext.LogicToPixel(Size(nTickCount, nTickCount), maMapMode);
-        long nTickGap1 = mnWinStyle & WB_HORZ ? nTickGapSize.Width() : nTickGapSize.Height();
-        nTickGapSize = rRenderContext.LogicToPixel(Size(nTick2, nTick2), maMapMode);
-        long nTickGap2 = mnWinStyle & WB_HORZ ? nTickGapSize.Width() : nTickGapSize.Height();
-        nTickGapSize = rRenderContext.LogicToPixel(Size(nTick3, nTick3), maMapMode);
-        long nTickGap3 = mnWinStyle & WB_HORZ ? nTickGapSize.Width() : nTickGapSize.Height();
-
-        while (((nStart - n) >= nMin) || ((nStart + n) <= nMax))
-        {
-            // Null point
-            if (nTick == 0.0)
+            if (nStart > nMin)
             {
-                if (nStart > nMin)
+                // 0 is only painted when Margin1 is not equal to zero
+                if ((mpData->nMargin1Style & RulerMarginStyle::Invisible) || (mpData->nMargin1 != 0))
                 {
-                    // 0 is only painted when Margin1 is not equal to zero
-                    if ((mpData->nMargin1Style & RulerMarginStyle::Invisible) || (mpData->nMargin1 != 0))
-                    {
-                        aNumString = "0";
-                        ImplVDrawText(rRenderContext, nStart, nCenter, aNumString);
-                    }
+                    aNumString = "0";
+                    ImplVDrawText(rRenderContext, nStart, nCenter, aNumString);
                 }
             }
+        }
+        else
+        {
+            aPixSize = rRenderContext.LogicToPixel(Size(nTick, nTick), maMapMode);
+
+            if (mnWinStyle & WB_HORZ)
+                n = aPixSize.Width();
+            else
+                n = aPixSize.Height();
+
+            // Tick4 - Output (Text)
+            double aStep = (nTick / nTick4);
+            double aRest = std::abs(aStep - std::floor(aStep));
+            double nAcceptanceDelta = 0.0001;
+
+            if (aRest < nAcceptanceDelta)
+            {
+                if ((mnUnitIndex == RULER_UNIT_CHAR) || (mnUnitIndex == RULER_UNIT_LINE))
+                    aNumString = OUString::number(nTick / nTickUnit);
+                else
+                    aNumString = OUString::number(nTick / aImplRulerUnitTab[mnUnitIndex].nTickUnit);
+
+                long nHorizontalLocation = nStart + n;
+                ImplVDrawText(rRenderContext, nHorizontalLocation, nCenter, aNumString, nMin, nMax);
+
+                if (nMin < nHorizontalLocation && nHorizontalLocation < nMax)
+                {
+                    ImplVDrawRect(rRenderContext, nHorizontalLocation, nBottom, nHorizontalLocation + DPIOffset, nBottom - 1 * nScale);
+                    ImplVDrawRect(rRenderContext, nHorizontalLocation, nTop,    nHorizontalLocation + DPIOffset, nTop + 1 * nScale);
+                }
+
+                nHorizontalLocation = nStart - n;
+                ImplVDrawText(rRenderContext, nHorizontalLocation, nCenter, aNumString, nMin, nMax);
+
+                if (nMin < nHorizontalLocation && nHorizontalLocation < nMax)
+                {
+                    ImplVDrawRect(rRenderContext, nHorizontalLocation, nBottom,
+                                                  nHorizontalLocation + DPIOffset, nBottom - 1 * nScale);
+                    ImplVDrawRect(rRenderContext, nHorizontalLocation, nTop,
+                                                  nHorizontalLocation + DPIOffset, nTop + 1 * nScale);
+                }
+            }
+            // Tick/Tick2 - Output (Strokes)
             else
             {
-                aPixSize = rRenderContext.LogicToPixel(Size(nTick, nTick), maMapMode);
-
-                if (mnWinStyle & WB_HORZ)
-                    n = aPixSize.Width();
-                else
-                    n = aPixSize.Height();
-
-                // Tick4 - Output (Text)
-                double aStep = (nTick / nTick4);
-                double aRest = std::abs(aStep - std::floor(aStep));
-                double nAcceptanceDelta = 0.0001;
+                long nTickLength = nTickLength1;
 
+                aStep = (nTick / nTick2);
+                aRest = std::abs(aStep - std::floor(aStep));
                 if (aRest < nAcceptanceDelta)
+                    nTickLength = nTickLength2;
+
+                aStep = (nTick / nTick3);
+                aRest = std::abs(aStep - std::floor(aStep));
+                if (aRest < nAcceptanceDelta )
+                    nTickLength = nTickLength3;
+
+                if ((nTickLength == nTickLength1 && nTickGap1 > 6) ||
+                    (nTickLength == nTickLength2 && nTickGap2 > 6) ||
+                    (nTickLength == nTickLength3 && nTickGap3 > 6))
                 {
-                    if ((mnUnitIndex == RULER_UNIT_CHAR) || (mnUnitIndex == RULER_UNIT_LINE))
-                        aNumString = OUString::number(nTick / nTickUnit);
-                    else
-                        aNumString = OUString::number(nTick / aImplRulerUnitTab[mnUnitIndex].nTickUnit);
+                    long nT1 = nCenter - (nTickLength / 2.0);
+                    long nT2 = nT1 + nTickLength - 1;
+                    long nT;
 
-                    long nHorizontalLocation = nStart + n;
-                    ImplVDrawText(rRenderContext, nHorizontalLocation, nCenter, aNumString, nMin, nMax);
+                    nT = nStart + n;
 
-                    if (nMin < nHorizontalLocation && nHorizontalLocation < nMax)
-                    {
-                        ImplVDrawRect(rRenderContext, nHorizontalLocation, nBottom, nHorizontalLocation + DPIOffset, nBottom - 1 * nScale);
-                        ImplVDrawRect(rRenderContext, nHorizontalLocation, nTop,    nHorizontalLocation + DPIOffset, nTop + 1 * nScale);
-                    }
-
-                    nHorizontalLocation = nStart - n;
-                    ImplVDrawText(rRenderContext, nHorizontalLocation, nCenter, aNumString, nMin, nMax);
-
-                    if (nMin < nHorizontalLocation && nHorizontalLocation < nMax)
-                    {
-                        ImplVDrawRect(rRenderContext, nHorizontalLocation, nBottom,
-                                                      nHorizontalLocation + DPIOffset, nBottom - 1 * nScale);
-                        ImplVDrawRect(rRenderContext, nHorizontalLocation, nTop,
-                                                      nHorizontalLocation + DPIOffset, nTop + 1 * nScale);
-                    }
-                }
-                // Tick/Tick2 - Output (Strokes)
-                else
-                {
-                    long nTickLength = nTickLength1;
-
-                    aStep = (nTick / nTick2);
-                    aRest = std::abs(aStep - std::floor(aStep));
-                    if (aRest < nAcceptanceDelta)
-                        nTickLength = nTickLength2;
-
-                    aStep = (nTick / nTick3);
-                    aRest = std::abs(aStep - std::floor(aStep));
-                    if (aRest < nAcceptanceDelta )
-                        nTickLength = nTickLength3;
-
-                    if ((nTickLength == nTickLength1 && nTickGap1 > 6) ||
-                        (nTickLength == nTickLength2 && nTickGap2 > 6) ||
-                        (nTickLength == nTickLength3 && nTickGap3 > 6))
-                    {
-                        long nT1 = nCenter - (nTickLength / 2.0);
-                        long nT2 = nT1 + nTickLength - 1;
-                        long nT;
-
-                        nT = nStart + n;
-
-                        if (nT < nMax)
-                            ImplVDrawRect(rRenderContext, nT, nT1, nT + DPIOffset, nT2);
-                        nT = nStart - n;
-                        if (nT > nMin)
-                            ImplVDrawRect(rRenderContext, nT, nT1, nT + DPIOffset, nT2);
-                    }
+                    if (nT < nMax)
+                        ImplVDrawRect(rRenderContext, nT, nT1, nT + DPIOffset, nT2);
+                    nT = nStart - n;
+                    if (nT > nMin)
+                        ImplVDrawRect(rRenderContext, nT, nT1, nT + DPIOffset, nT2);
                 }
             }
-            nTick += nTickCount;
         }
+        nTick += nTickCount;
     }
 }
 
@@ -697,9 +620,8 @@ void Ruler::ImplDrawBorders(vcl::RenderContext& rRenderContext, long nMin, long
     long    n2;
     long    nTemp1;
     long    nTemp2;
-    sal_uInt32  i;
 
-    for (i = 0; i < mpData->pBorders.size(); i++)
+    for (std::vector<RulerBorder>::size_type i = 0; i < mpData->pBorders.size(); i++)
     {
         if (mpData->pBorders[i].nStyle & RulerBorderStyle::Invisible)
             continue;
@@ -802,14 +724,13 @@ void Ruler::ImplDrawIndent(vcl::RenderContext& rRenderContext, const tools::Poly
 
 void Ruler::ImplDrawIndents(vcl::RenderContext& rRenderContext, long nMin, long nMax, long nVirTop, long nVirBottom)
 {
-    sal_uInt32  j;
     long n;
     long nIndentHeight = (mnVirHeight / 2) - 1;
     long nIndentWidth2 = nIndentHeight-3;
 
     tools::Polygon aPoly(5);
 
-    for (j = 0; j < mpData->pIndents.size(); j++)
+    for (std::vector<RulerIndent>::size_type j = 0; j < mpData->pIndents.size(); j++)
     {
         if (mpData->pIndents[j].bInvisible)
             continue;
@@ -820,13 +741,7 @@ void Ruler::ImplDrawIndents(vcl::RenderContext& rRenderContext, long nMin, long
 
         if ((n >= nMin) && (n <= nMax))
         {
-            if (nIndentStyle == RulerIndentStyle::Border)
-            {
-                const StyleSettings& rStyleSettings = rRenderContext.GetSettings().GetStyleSettings();
-                rRenderContext.SetLineColor(rStyleSettings.GetShadowColor());
-                ImplVDrawLine(rRenderContext, n, nVirTop + 1, n, nVirBottom - 1);
-            }
-            else if (nIndentStyle == RulerIndentStyle::Bottom)
+            if (nIndentStyle == RulerIndentStyle::Bottom)
             {
                 aPoly.SetPoint(Point(n + 0, nVirBottom - nIndentHeight), 0);
                 aPoly.SetPoint(Point(n - nIndentWidth2, nVirBottom - 3), 1);
@@ -853,19 +768,16 @@ void Ruler::ImplDrawIndents(vcl::RenderContext& rRenderContext, long nMin, long
                     aPoly[i] = aSet;
                 }
             }
-            if (RulerIndentStyle::Border != nIndentStyle)
+            bool bIsHit = false;
+            if(mxCurrentHitTest.get() != nullptr && mxCurrentHitTest->eType == RulerType::Indent)
             {
-                bool bIsHit = false;
-                if(mxCurrentHitTest.get() != nullptr && mxCurrentHitTest->eType == RulerType::Indent)
-                {
-                    bIsHit = mxCurrentHitTest->nAryPos == j;
-                }
-                else if(mbDrag && meDragType == RulerType::Indent)
-                {
-                    bIsHit = mnDragAryPos == j;
-                }
-                ImplDrawIndent(rRenderContext, aPoly, bIsHit);
+                bIsHit = mxCurrentHitTest->nAryPos == j;
             }
+            else if(mbDrag && meDragType == RulerType::Indent)
+            {
+                bIsHit = mnDragAryPos == j;
+            }
+            ImplDrawIndent(rRenderContext, aPoly, bIsHit);
         }
     }
 }
@@ -888,22 +800,22 @@ static void ImplCenterTabPos(Point& rPos, sal_uInt16 nTabStyle)
     }
 }
 
-static void lcl_RotateRect_Impl(Rectangle& rRect, const long nReference, bool bRightAligned)
+static void lcl_RotateRect_Impl(tools::Rectangle& rRect, const long nReference, bool bRightAligned)
 {
-    if (!rRect.IsEmpty())
-    {
-        Rectangle aTmp(rRect);
-        rRect.Top()    = aTmp.Left();
-        rRect.Bottom() = aTmp.Right();
-        rRect.Left()   = aTmp.Top();
-        rRect.Right()  = aTmp.Bottom();
+    if (rRect.IsEmpty())
+        return;
 
-        if (bRightAligned)
-        {
-            long nRef = 2 * nReference;
-            rRect.Left() = nRef - rRect.Left();
-            rRect.Right() = nRef - rRect.Right();
-        }
+    tools::Rectangle aTmp(rRect);
+    rRect.Top()    = aTmp.Left();
+    rRect.Bottom() = aTmp.Right();
+    rRect.Left()   = aTmp.Top();
+    rRect.Right()  = aTmp.Bottom();
+
+    if (bRightAligned)
+    {
+        long nRef = 2 * nReference;
+        rRect.Left() = nRef - rRect.Left();
+        rRect.Right() = nRef - rRect.Right();
     }
 }
 
@@ -921,9 +833,9 @@ static void ImplDrawRulerTab(vcl::RenderContext& rRenderContext, const Point& rP
     // drawn become asymmetric due to the +1 offsets
     sal_uInt16 DPIOffset = rRenderContext.GetDPIScaleFactor() - 1;
 
-    Rectangle aRect1;
-    Rectangle aRect2;
-    Rectangle aRect3;
+    tools::Rectangle aRect1;
+    tools::Rectangle aRect2;
+    tools::Rectangle aRect3;
 
     aRect3.SetEmpty();
 
@@ -1147,7 +1059,7 @@ void Ruler::ImplCalc()
     mbCalc = false;
 }
 
-void Ruler::ImplFormat(vcl::RenderContext& rRenderContext)
+void Ruler::ImplFormat(vcl::RenderContext const & rRenderContext)
 {
     // if already formatted, don't do it again
     if (!mbFormat)
@@ -1368,36 +1280,36 @@ void Ruler::ImplDraw(vcl::RenderContext& rRenderContext)
         ImplFormat(rRenderContext);
     }
 
-    if (IsReallyVisible())
+    if (!IsReallyVisible())
+        return;
+
+    // output the ruler to the virtual device
+    Point aOffPos;
+    Size aVirDevSize = maVirDev->GetOutputSizePixel();
+
+    if (mnWinStyle & WB_HORZ)
     {
-        // output the ruler to the virtual device
-        Point aOffPos;
-        Size aVirDevSize = maVirDev->GetOutputSizePixel();
+        aOffPos.X() = mnVirOff;
+        if (mpData->bTextRTL)
+            aVirDevSize.Width() -= maExtraRect.GetWidth();
 
-        if (mnWinStyle & WB_HORZ)
-        {
-            aOffPos.X() = mnVirOff;
-            if (mpData->bTextRTL)
-                aVirDevSize.Width() -= maExtraRect.GetWidth();
-
-            aOffPos.Y() = RULER_OFF;
-        }
-        else
-        {
-            aOffPos.X() = RULER_OFF;
-            aOffPos.Y() = mnVirOff;
-        }
-        rRenderContext.DrawOutDev(aOffPos, aVirDevSize, Point(), aVirDevSize, *maVirDev.get());
-
-        // redraw positionlines
-        ImplInvertLines(rRenderContext);
+        aOffPos.Y() = RULER_OFF;
     }
+    else
+    {
+        aOffPos.X() = RULER_OFF;
+        aOffPos.Y() = mnVirOff;
+    }
+    rRenderContext.DrawOutDev(aOffPos, aVirDevSize, Point(), aVirDevSize, *maVirDev.get());
+
+    // redraw positionlines
+    ImplInvertLines(rRenderContext);
 }
 
 void Ruler::ImplDrawExtra(vcl::RenderContext& rRenderContext)
 {
     const StyleSettings& rStyleSettings = rRenderContext.GetSettings().GetStyleSettings();
-    Rectangle aRect = maExtraRect;
+    tools::Rectangle aRect = maExtraRect;
     bool bEraseRect = false;
 
     aRect.Left()   += 2;
@@ -1515,7 +1427,6 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
 
     // test if outside
     nX -= mnVirOff;
-    long nXTemp = nX;
     if ( (nX < mpData->nRulVirOff - nXExtraOff) ||
          (nX > mpData->nRulVirOff + mpData->nRulWidth + nXExtraOff) ||
          (nY < 0) ||
@@ -1531,7 +1442,7 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
     pHitTest->eType = RulerType::DontKnow;
 
     // first test the tabs
-    Rectangle aRect;
+    tools::Rectangle aRect;
     if ( !mpData->pTabs.empty() )
     {
         aRect.Bottom()  = nHitBottom;
@@ -1615,14 +1526,6 @@ bool Ruler::ImplHitTest( const Point& rPos, RulerSelection* pHitTest,
         }
     }
 
-    // everything left and right is outside and don't take this into account
-    if ( (nXTemp < mpData->nRulVirOff) || (nXTemp > mpData->nRulVirOff+mpData->nRulWidth) )
-    {
-        pHitTest->nPos = 0;
-        pHitTest->eType = RulerType::Outside;
-        return false;
-    }
-
     // test the borders
     int nBorderTolerance = 1;
     if(pHitTest->bExpandTest)
@@ -1841,7 +1744,7 @@ bool Ruler::ImplDocHitTest( const Point& rPos, RulerType eDragType,
     return false;
 }
 
-bool Ruler::ImplStartDrag( RulerSelection* pHitTest, sal_uInt16 nModifier )
+bool Ruler::ImplStartDrag( RulerSelection const * pHitTest, sal_uInt16 nModifier )
 {
     // don't trigger drag if a border that was clicked can not be changed
     if ( (pHitTest->eType == RulerType::Border) &&
@@ -1986,68 +1889,64 @@ void Ruler::ImplEndDrag()
 
 void Ruler::MouseButtonDown( const MouseEvent& rMEvt )
 {
-    if ( rMEvt.IsLeft() && !IsTracking() )
+    if ( !(rMEvt.IsLeft() && !IsTracking()) )
+        return;
+
+    Point   aMousePos = rMEvt.GetPosPixel();
+    sal_uInt16  nMouseClicks = rMEvt.GetClicks();
+    sal_uInt16  nMouseModifier = rMEvt.GetModifier();
+
+    // update ruler
+    if ( mbFormat )
     {
-        Point   aMousePos = rMEvt.GetPosPixel();
-        sal_uInt16  nMouseClicks = rMEvt.GetClicks();
-        sal_uInt16  nMouseModifier = rMEvt.GetModifier();
+        Invalidate(InvalidateFlags::NoErase);
+    }
 
-        // update ruler
-        if ( mbFormat )
-        {
-            Invalidate(InvalidateFlags::NoErase);
-        }
+    if ( maExtraRect.IsInside( aMousePos ) )
+    {
+        ExtraDown();
+    }
+    else
+    {
+        std::unique_ptr<RulerSelection> pHitTest(new RulerSelection);
+        bool bHitTestResult = ImplHitTest(aMousePos, pHitTest.get());
 
-        if ( maExtraRect.IsInside( aMousePos ) )
+        if ( nMouseClicks == 1 )
         {
-            mnExtraClicks = nMouseClicks;
-            mnExtraModifier = nMouseModifier;
-            ExtraDown();
-            mnExtraClicks = 0;
-            mnExtraModifier = 0;
-        }
-        else
-        {
-            std::unique_ptr<RulerSelection> pHitTest(new RulerSelection);
-            bool bHitTestResult = ImplHitTest(aMousePos, pHitTest.get());
-
-            if ( nMouseClicks == 1 )
+            if ( bHitTestResult )
             {
-                if ( bHitTestResult )
-                {
-                    ImplStartDrag( pHitTest.get(), nMouseModifier );
-                }
-                else
-                {
-                    // calculate position inside of ruler area
-                    if ( pHitTest->eType == RulerType::DontKnow )
-                    {
-                        mnDragPos = pHitTest->nPos;
-                        Click();
-                        mnDragPos = 0;
-
-                        // call HitTest again as a click, for example, could set a new tab
-                        if ( ImplHitTest(aMousePos, pHitTest.get()) )
-                            ImplStartDrag(pHitTest.get(), nMouseModifier);
-                    }
-                }
+                ImplStartDrag( pHitTest.get(), nMouseModifier );
             }
             else
             {
-                if (bHitTestResult)
+                // calculate position inside of ruler area
+                if ( pHitTest->eType == RulerType::DontKnow )
                 {
-                    mnDragPos    = pHitTest->nPos;
-                    mnDragAryPos = pHitTest->nAryPos;
+                    mnDragPos = pHitTest->nPos;
+                    Click();
+                    mnDragPos = 0;
+
+                    // call HitTest again as a click, for example, could set a new tab
+                    if ( ImplHitTest(aMousePos, pHitTest.get()) )
+                        ImplStartDrag(pHitTest.get(), nMouseModifier);
                 }
-                meDragType = pHitTest->eType;
-
-                DoubleClick();
-
-                meDragType      = RulerType::DontKnow;
-                mnDragPos       = 0;
-                mnDragAryPos    = 0;
             }
         }
+        else
+        {
+            if (bHitTestResult)
+            {
+                mnDragPos    = pHitTest->nPos;
+                mnDragAryPos = pHitTest->nAryPos;
+            }
+            meDragType = pHitTest->eType;
+
+            DoubleClick();
+
+            meDragType      = RulerType::DontKnow;
+            mnDragPos       = 0;
+            mnDragAryPos    = 0;
+        }
     }
 }
 
@@ -2125,7 +2024,7 @@ void Ruler::Tracking( const TrackingEvent& rTEvt )
         ImplDrag( rTEvt.GetMouseEvent().GetPosPixel() );
 }
 
-void Ruler::Paint(vcl::RenderContext& rRenderContext, const Rectangle&)
+void Ruler::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&)
 {
     ImplDraw(rRenderContext);
 
@@ -2187,8 +2086,8 @@ void Ruler::Resize()
             Invalidate(InvalidateFlags::NoErase);
         else if ( mpData->bAutoPageWidth )
         {
-            // only at AutoPageWidth muss we redraw
-            Rectangle aRect;
+            // only at AutoPageWidth do we need to redraw
+            tools::Rectangle aRect;
 
             if ( mnWinStyle & WB_HORZ )
             {
@@ -2294,7 +2193,7 @@ void Ruler::Activate()
 {
     mbActive = true;
 
-    // update positionlies - draw is delayed
+    // update positionlines - draw is delayed
     mnUpdateFlags |= RULER_UPDATE_LINES;
     Invalidate(InvalidateFlags::NoErase);
 }
@@ -2448,52 +2347,52 @@ void Ruler::SetBorderPos( long nOff )
 
 void Ruler::SetUnit( FieldUnit eNewUnit )
 {
-    if ( meUnit != eNewUnit )
-    {
-        meUnit = eNewUnit;
-        switch ( meUnit )
-        {
-            case FUNIT_MM:
-                mnUnitIndex = RULER_UNIT_MM;
-                break;
-            case FUNIT_CM:
-                mnUnitIndex = RULER_UNIT_CM;
-                break;
-            case FUNIT_M:
-                mnUnitIndex = RULER_UNIT_M;
-                break;
-            case FUNIT_KM:
-                mnUnitIndex = RULER_UNIT_KM;
-                break;
-            case FUNIT_INCH:
-                mnUnitIndex = RULER_UNIT_INCH;
-                break;
-            case FUNIT_FOOT:
-                mnUnitIndex = RULER_UNIT_FOOT;
-                break;
-            case FUNIT_MILE:
-                mnUnitIndex = RULER_UNIT_MILE;
-                break;
-            case FUNIT_POINT:
-                mnUnitIndex = RULER_UNIT_POINT;
-                break;
-            case FUNIT_PICA:
-                mnUnitIndex = RULER_UNIT_PICA;
-                break;
-            case FUNIT_CHAR:
-                mnUnitIndex = RULER_UNIT_CHAR;
-                break;
-            case FUNIT_LINE:
-                mnUnitIndex = RULER_UNIT_LINE;
-                break;
-            default:
-                SAL_WARN( "svtools.control", "Ruler::SetUnit() - Wrong Unit" );
-                break;
-        }
+    if ( meUnit == eNewUnit )
+        return;
 
-        maMapMode.SetMapUnit( aImplRulerUnitTab[mnUnitIndex].eMapUnit );
-        ImplUpdate();
+    meUnit = eNewUnit;
+    switch ( meUnit )
+    {
+        case FUNIT_MM:
+            mnUnitIndex = RULER_UNIT_MM;
+            break;
+        case FUNIT_CM:
+            mnUnitIndex = RULER_UNIT_CM;
+            break;
+        case FUNIT_M:
+            mnUnitIndex = RULER_UNIT_M;
+            break;
+        case FUNIT_KM:
+            mnUnitIndex = RULER_UNIT_KM;
+            break;
+        case FUNIT_INCH:
+            mnUnitIndex = RULER_UNIT_INCH;
+            break;
+        case FUNIT_FOOT:
+            mnUnitIndex = RULER_UNIT_FOOT;
+            break;
+        case FUNIT_MILE:
+            mnUnitIndex = RULER_UNIT_MILE;
+            break;
+        case FUNIT_POINT:
+            mnUnitIndex = RULER_UNIT_POINT;
+            break;
+        case FUNIT_PICA:
+            mnUnitIndex = RULER_UNIT_PICA;
+            break;
+        case FUNIT_CHAR:
+            mnUnitIndex = RULER_UNIT_CHAR;
+            break;
+        case FUNIT_LINE:
+            mnUnitIndex = RULER_UNIT_LINE;
+            break;
+        default:
+            SAL_WARN( "svtools.control", "Ruler::SetUnit() - Wrong Unit" );
+            break;
     }
+
+    maMapMode.SetMapUnit( aImplRulerUnitTab[mnUnitIndex].eMapUnit );
+    ImplUpdate();
 }
 
 void Ruler::SetZoom( const Fraction& rNewZoom )
@@ -2524,6 +2423,7 @@ void Ruler::SetNullOffset( long nPos )
 {
     if ( mpData->nNullOff != nPos )
     {
+        mpData->nNullVirOff += nPos - mpData->nNullOff;
         mpData->nNullOff = nPos;
         ImplUpdate();
     }
@@ -2531,7 +2431,7 @@ void Ruler::SetNullOffset( long nPos )
 
 void Ruler::SetLeftFrameMargin( long nPos )
 {
-    if ( (mpData->nLeftFrameMargin != nPos) )
+    if ( mpData->nLeftFrameMargin != nPos )
     {
         mpData->nLeftFrameMargin  = nPos;
         ImplUpdate();
@@ -2540,7 +2440,7 @@ void Ruler::SetLeftFrameMargin( long nPos )
 
 void Ruler::SetRightFrameMargin( long nPos )
 {
-    if ( (mpData->nRightFrameMargin != nPos) )
+    if ( mpData->nRightFrameMargin != nPos )
     {
         mpData->nRightFrameMargin  = nPos;
         ImplUpdate();
@@ -2595,10 +2495,7 @@ void Ruler::SetLines( sal_uInt32 aLineArraySize, const RulerLine* pLineArray )
 
     // New values and new share issue
     bool bMustUpdate;
-    if ( IsReallyVisible() && IsUpdateMode() )
-        bMustUpdate = true;
-    else
-        bMustUpdate = false;
+    bMustUpdate = IsReallyVisible() && IsUpdateMode();
 
     // Delete old lines
     if ( bMustUpdate )
@@ -2772,7 +2669,7 @@ void Ruler::DrawTab(vcl::RenderContext& rRenderContext, const Color &rFillColor,
 
 void Ruler::SetTextRTL(bool bRTL)
 {
-    if(mpData->bTextRTL != (bool) bRTL)
+    if(mpData->bTextRTL != bRTL)
     {
         mpData->bTextRTL = bRTL;
         if ( IsReallyVisible() && IsUpdateMode() )
@@ -2836,10 +2733,9 @@ uno::Reference< XAccessible > Ruler::CreateAccessible()
         {
             aStr = SvtResId(STR_SVT_ACC_RULER_VERT_NAME);
         }
-        pAccContext = new SvtRulerAccessible( xAccParent, *this, aStr );
-        pAccContext->acquire();
-        this->SetAccessible(pAccContext);
-        return pAccContext;
+        mxAccContext = new SvtRulerAccessible( xAccParent, *this, aStr );
+        SetAccessible(mxAccContext.get());
+        return mxAccContext.get();
     }
     else
         return uno::Reference< XAccessible >();
