@@ -37,9 +37,6 @@ using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::ui::dialogs;
 
 
-// - ColorDialog -
-
-
 SvColorDialog::SvColorDialog( vcl::Window* pWindow )
 : mpParent( pWindow )
 , meMode( svtools::ColorPickerMode_SELECT )
@@ -56,17 +53,12 @@ void SvColorDialog::SetColor( const Color& rColor )
 }
 
 
-
-
-
-
 void SvColorDialog::SetMode( sal_Int16 eMode )
 {
     meMode = eMode;
 }
 
 
-
 short SvColorDialog::Execute()
 {
     short ret = 0;
@@ -84,7 +76,7 @@ short SvColorDialog::Execute()
         props[0].Name = sColor;
         props[0].Value <<= (sal_Int32) maColor.GetColor();
         props[1].Name = "Mode";
-        props[1].Value <<= (sal_Int16) meMode;
+        props[1].Value <<= meMode;
 
         xPropertyAccess->setPropertyValues( props );
 
@@ -95,7 +87,7 @@ short SvColorDialog::Execute()
             props = xPropertyAccess->getPropertyValues();
             for( sal_Int32 n = 0; n < props.getLength(); n++ )
             {
-                if( props[n].Name.equals( sColor ) )
+                if( props[n].Name == sColor )
                 {
                     sal_Int32 nColor = 0;
                     if( props[n].Value >>= nColor )
