@@ -22,12 +22,13 @@
 #include <algorithm>
 
 #include <officecfg/Office/Common.hxx>
+#include <osl/file.hxx>
 #include <tools/vcompat.hxx>
 #include <tools/fract.hxx>
 #include <tools/helpers.hxx>
 #include <unotools/ucbstreamhelper.hxx>
-#include <unotools/localfilehelper.hxx>
 #include <unotools/tempfile.hxx>
+#include <unotools/configmgr.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/cvtgrf.hxx>
 #include <vcl/metaact.hxx>
@@ -36,7 +37,7 @@
 
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 using com::sun::star::uno::Reference;
 using com::sun::star::uno::XInterface;
@@ -45,7 +46,7 @@ using com::sun::star::uno::Sequence;
 using com::sun::star::container::XNameContainer;
 using com::sun::star::beans::XPropertySet;
 
-GraphicManager* GraphicObject::mpGlobalMgr = NULL;
+GraphicManager* GraphicObject::mpGlobalMgr = nullptr;
 
 struct GrfSimpleCacheObj
 {
@@ -56,8 +57,6 @@ struct GrfSimpleCacheObj
                     maGraphic( rGraphic ), maAttr( rAttr ) {}
 };
 
-TYPEINIT1_AUTOFACTORY( GraphicObject, SvDataCopyStream );
-
 // unique increasing ID for being able to detect the GraphicObject with the
 // oldest last data changes
 static sal_uLong aIncrementingTimeOfLastDataChange = 1;
@@ -68,53 +67,57 @@ void GraphicObject::ImplAfterDataChange()
     mnDataChangeTimeStamp = aIncrementingTimeOfLastDataChange++;
 
     // check memory footprint of all GraphicObjects managed and evtl. take action
-    if (mpMgr)
-        mpMgr->ImplCheckSizeOfSwappedInGraphics(this);
+    mpGlobalMgr->ImplCheckSizeOfSwappedInGraphics(this);
 }
 
-GraphicObject::GraphicObject( const GraphicManager* pMgr ) :
-    maLink      (),
-    maUserData  ()
+GraphicObject::GraphicObject()
+    : mbAutoSwapped(false)
+    , mbIsInSwapIn(false)
+    , mbIsInSwapOut(false)
 {
-    ImplConstruct();
+    ImplEnsureGraphicManager();
     ImplAssignGraphicData();
-    ImplSetGraphicManager( pMgr );
+    mpGlobalMgr->ImplRegisterObj(*this, maGraphic, nullptr, nullptr);
 }
 
-GraphicObject::GraphicObject( const Graphic& rGraphic, const GraphicManager* pMgr ) :
-    maGraphic   ( rGraphic ),
-    maLink      (),
-    maUserData  ()
+GraphicObject::GraphicObject(const Graphic& rGraphic)
+    : maGraphic(rGraphic)
+    , mbAutoSwapped(false)
+    , mbIsInSwapIn(false)
+    , mbIsInSwapOut(false)
 {
-    ImplConstruct();
+    ImplEnsureGraphicManager();
     ImplAssignGraphicData();
-    ImplSetGraphicManager( pMgr );
+    mpGlobalMgr->ImplRegisterObj(*this, maGraphic, nullptr, nullptr);
 }
 
-GraphicObject::GraphicObject( const GraphicObject& rGraphicObj, const GraphicManager* pMgr ) :
-    SvDataCopyStream(),
-    maGraphic   ( rGraphicObj.GetGraphic() ),
-    maAttr      ( rGraphicObj.maAttr ),
-    maLink      ( rGraphicObj.maLink ),
-    maUserData  ( rGraphicObj.maUserData )
+GraphicObject::GraphicObject(const GraphicObject& rGraphicObj)
+    : maGraphic(rGraphicObj.GetGraphic())
+    , maAttr(rGraphicObj.maAttr)
+    , maPrefMapMode(rGraphicObj.maPrefMapMode)
+    , maLink(rGraphicObj.maLink)
+    , maUserData(rGraphicObj.maUserData)
+    , mbAutoSwapped(false)
+    , mbIsInSwapIn(false)
+    , mbIsInSwapOut(false)
 {
-    ImplConstruct();
     ImplAssignGraphicData();
-    ImplSetGraphicManager( pMgr, NULL, &rGraphicObj );
+    mpGlobalMgr->ImplRegisterObj(*this, maGraphic, nullptr, &rGraphicObj);
     if( rGraphicObj.HasUserData() && rGraphicObj.IsSwappedOut() )
         SetSwapState();
 }
 
-GraphicObject::GraphicObject( const OString& rUniqueID, const GraphicManager* pMgr ) :
-    maLink      (),
-    maUserData  ()
+GraphicObject::GraphicObject(const OString& rUniqueID)
+    : mbAutoSwapped(false)
+    , mbIsInSwapIn(false)
+    , mbIsInSwapOut(false)
 {
-    ImplConstruct();
+    ImplEnsureGraphicManager();
 
     // assign default properties
     ImplAssignGraphicData();
 
-    ImplSetGraphicManager( pMgr, &rUniqueID );
+    mpGlobalMgr->ImplRegisterObj(*this, maGraphic, &rUniqueID, nullptr);
 
     // update properties
     ImplAssignGraphicData();
@@ -122,32 +125,13 @@ GraphicObject::GraphicObject( const OString& rUniqueID, const GraphicManager* pM
 
 GraphicObject::~GraphicObject()
 {
-    if( mpMgr )
+    mpGlobalMgr->ImplUnregisterObj( *this );
+
+    if (!mpGlobalMgr->ImplHasObjects())
     {
-        mpMgr->ImplUnregisterObj( *this );
-
-        if( ( mpMgr == mpGlobalMgr ) && !mpGlobalMgr->ImplHasObjects() )
-            delete mpGlobalMgr, mpGlobalMgr = NULL;
+        delete mpGlobalMgr;
+        mpGlobalMgr = nullptr;
     }
-
-    delete mpSwapOutTimer;
-    delete mpSwapStreamHdl;
-    delete mpSimpleCache;
-}
-
-void GraphicObject::ImplConstruct()
-{
-    mpMgr = NULL;
-    mpSwapStreamHdl = NULL;
-    mpSwapOutTimer = NULL;
-    mpSimpleCache = NULL;
-    mnAnimationLoopCount = 0;
-    mbAutoSwapped = false;
-    mbIsInSwapIn = false;
-    mbIsInSwapOut = false;
-
-    // Init with a unique, increasing ID
-    mnDataChangeTimeStamp = aIncrementingTimeOfLastDataChange++;
 }
 
 void GraphicObject::ImplAssignGraphicData()
@@ -157,7 +141,6 @@ void GraphicObject::ImplAssignGraphicData()
     mnSizeBytes = maGraphic.GetSizeBytes();
     meType = maGraphic.GetType();
     mbTransparent = maGraphic.IsTransparent();
-    mbAlpha = maGraphic.IsAlpha();
     mbAnimated = maGraphic.IsAnimated();
     mbEPS = maGraphic.IsEPS();
     mnAnimationLoopCount = ( mbAnimated ? maGraphic.GetAnimationLoopCount() : 0 );
@@ -166,116 +149,100 @@ void GraphicObject::ImplAssignGraphicData()
     ImplAfterDataChange();
 }
 
-void GraphicObject::ImplSetGraphicManager( const GraphicManager* pMgr, const OString* pID, const GraphicObject* pCopyObj )
+void GraphicObject::ImplEnsureGraphicManager()
 {
-    if( !mpMgr || ( pMgr != mpMgr ) )
+    if (mpGlobalMgr)
+        return;
+
+    sal_uLong nCacheSize = 20000;
+    sal_uLong nMaxObjCacheSize = 20000;
+    sal_uLong nTimeoutSeconds = 20000;
+    if (!utl::ConfigManager::IsFuzzing())
     {
-        if( !pMgr && mpMgr && ( mpMgr == mpGlobalMgr ) )
-            return;
-        else
+        try
+        {
+            nCacheSize = officecfg::Office::Common::Cache::GraphicManager::TotalCacheSize::get();
+            nMaxObjCacheSize = officecfg::Office::Common::Cache::GraphicManager::ObjectCacheSize::get();
+            nTimeoutSeconds = officecfg::Office::Common::Cache::GraphicManager::ObjectReleaseTime::get();
+        }
+        catch (...)
         {
-            if( mpMgr )
-            {
-                mpMgr->ImplUnregisterObj( *this );
-
-                if( ( mpMgr == mpGlobalMgr ) && !mpGlobalMgr->ImplHasObjects() )
-                    delete mpGlobalMgr, mpGlobalMgr = NULL;
-            }
-
-            if( !pMgr )
-            {
-                if( !mpGlobalMgr )
-                {
-                    mpGlobalMgr = new GraphicManager(
-                        (officecfg::Office::Common::Cache::GraphicManager::
-                         TotalCacheSize::get()),
-                        (officecfg::Office::Common::Cache::GraphicManager::
-                         ObjectCacheSize::get()));
-                    mpGlobalMgr->SetCacheTimeout(
-                        officecfg::Office::Common::Cache::GraphicManager::
-                        ObjectReleaseTime::get());
-                }
-
-                mpMgr = mpGlobalMgr;
-            }
-            else
-                mpMgr = const_cast<GraphicManager*>(pMgr);
-
-            mpMgr->ImplRegisterObj( *this, maGraphic, pID, pCopyObj );
         }
     }
+    mpGlobalMgr = new GraphicManager(nCacheSize, nMaxObjCacheSize);
+    mpGlobalMgr->SetCacheTimeout(nTimeoutSeconds);
 }
 
 void GraphicObject::ImplAutoSwapIn()
 {
-    if( IsSwappedOut() )
+    if( !IsSwappedOut() )
+        return;
+
     {
+        mbIsInSwapIn = true;
+
+        if( maGraphic.SwapIn() )
+            mbAutoSwapped = false;
+        else
         {
-            mbIsInSwapIn = true;
+            SvStream* pStream = GetSwapStream();
 
-            if( maGraphic.SwapIn() )
-                mbAutoSwapped = false;
-            else
+            if( GRFMGR_AUTOSWAPSTREAM_NONE != pStream )
             {
-                SvStream* pStream = GetSwapStream();
-
-                if( GRFMGR_AUTOSWAPSTREAM_NONE != pStream )
+                if( GRFMGR_AUTOSWAPSTREAM_LINK == pStream )
                 {
-                    if( GRFMGR_AUTOSWAPSTREAM_LINK == pStream )
+                    if( HasLink() )
                     {
-                        if( HasLink() )
+                        OUString aURLStr;
+
+                        if( osl::FileBase::getFileURLFromSystemPath( GetLink(), aURLStr ) == osl::FileBase::E_None )
                         {
-                            OUString aURLStr;
+                            std::unique_ptr<SvStream> pIStm(::utl::UcbStreamHelper::CreateStream( aURLStr, StreamMode::READ ));
 
-                            if( ::utl::LocalFileHelper::ConvertPhysicalNameToURL( GetLink(), aURLStr ) )
+                            if( pIStm )
                             {
-                                boost::scoped_ptr<SvStream> pIStm(::utl::UcbStreamHelper::CreateStream( aURLStr, StreamMode::READ ));
-
-                                if( pIStm )
-                                {
-                                    ReadGraphic( *pIStm, maGraphic );
-                                    mbAutoSwapped = ( maGraphic.GetType() != GRAPHIC_NONE );
-                                }
+                                ReadGraphic( *pIStm, maGraphic );
+                                mbAutoSwapped = ( maGraphic.GetType() != GraphicType::NONE );
                             }
                         }
                     }
-                    else if( GRFMGR_AUTOSWAPSTREAM_TEMP == pStream )
-                        mbAutoSwapped = !maGraphic.SwapIn();
-                    else if( GRFMGR_AUTOSWAPSTREAM_LOADED == pStream )
-                        mbAutoSwapped = maGraphic.IsSwapOut();
-                    else
-                    {
-                        mbAutoSwapped = !maGraphic.SwapIn( pStream );
-                        delete pStream;
-                    }
                 }
+                else if( GRFMGR_AUTOSWAPSTREAM_TEMP == pStream )
+                    mbAutoSwapped = !maGraphic.SwapIn();
+                else if( GRFMGR_AUTOSWAPSTREAM_LOADED == pStream )
+                    mbAutoSwapped = maGraphic.IsSwapOut();
                 else
                 {
-                    DBG_ASSERT( ( GRAPHIC_NONE == meType ) || ( GRAPHIC_DEFAULT == meType ),
-                                "GraphicObject::ImplAutoSwapIn: could not get stream to swap in graphic! (=>KA)" );
+                    mbAutoSwapped = !maGraphic.SwapIn( pStream );
+                    delete pStream;
                 }
             }
-
-            mbIsInSwapIn = false;
-
-            if( !mbAutoSwapped && mpMgr )
-                mpMgr->ImplGraphicObjectWasSwappedIn( *this );
+            else
+            {
+                DBG_ASSERT( ( GraphicType::NONE == meType ) || ( GraphicType::Default == meType ),
+                            "GraphicObject::ImplAutoSwapIn: could not get stream to swap in graphic! (=>KA)" );
+            }
         }
-        ImplAssignGraphicData();
+
+        mbIsInSwapIn = false;
+
+        if (!mbAutoSwapped)
+            mpGlobalMgr->ImplGraphicObjectWasSwappedIn( *this );
     }
+    ImplAssignGraphicData();
 }
 
-bool GraphicObject::ImplGetCropParams( OutputDevice* pOut, Point& rPt, Size& rSz, const GraphicAttr* pAttr,
+bool GraphicObject::ImplGetCropParams( OutputDevice const * pOut, Point& rPt, Size& rSz, const GraphicAttr* pAttr,
                                        tools::PolyPolygon& rClipPolyPoly, bool& bRectClipRegion ) const
 {
     bool bRet = false;
 
-    if( GetType() != GRAPHIC_NONE )
+    if( GetType() != GraphicType::NONE )
     {
-        Polygon         aClipPoly( Rectangle( rPt, rSz ) );
-        const sal_uInt16    nRot10 = pAttr->GetRotation() % 3600;
+        tools::Polygon aClipPoly( tools::Rectangle( rPt, rSz ) );
+        const sal_uInt16 nRot10 = pAttr->GetRotation() % 3600;
         const Point     aOldOrigin( rPt );
-        const MapMode   aMap100( MAP_100TH_MM );
+        const MapMode   aMap100( MapUnit::Map100thMM );
         Size            aSize100;
         long            nTotalWidth, nTotalHeight;
 
@@ -289,7 +256,7 @@ bool GraphicObject::ImplGetCropParams( OutputDevice* pOut, Point& rPt, Size& rSz
 
         rClipPolyPoly = aClipPoly;
 
-        if( maGraphic.GetPrefMapMode() == MAP_PIXEL )
+        if (maGraphic.GetPrefMapMode().GetMapUnit() == MapUnit::MapPixel)
             aSize100 = Application::GetDefaultDevice()->PixelToLogic( maGraphic.GetPrefSize(), aMap100 );
         else
         {
@@ -320,7 +287,7 @@ bool GraphicObject::ImplGetCropParams( OutputDevice* pOut, Point& rPt, Size& rSz
 
             if( nRot10 )
             {
-                Polygon aOriginPoly( 1 );
+                tools::Polygon aOriginPoly( 1 );
 
                 aOriginPoly[ 0 ] = rPt;
                 aOriginPoly.Rotate( aOldOrigin, nRot10 );
@@ -338,10 +305,10 @@ GraphicObject& GraphicObject::operator=( const GraphicObject& rGraphicObj )
 {
     if( &rGraphicObj != this )
     {
-        mpMgr->ImplUnregisterObj( *this );
+        mpGlobalMgr->ImplUnregisterObj( *this );
 
-        delete mpSwapStreamHdl, mpSwapStreamHdl = NULL;
-        delete mpSimpleCache, mpSimpleCache = NULL;
+        maSwapStreamHdl = Link<const GraphicObject*, SvStream*>();
+        mxSimpleCache.reset();
 
         maGraphic = rGraphicObj.GetGraphic();
         maAttr = rGraphicObj.maAttr;
@@ -349,8 +316,7 @@ GraphicObject& GraphicObject::operator=( const GraphicObject& rGraphicObj )
         maUserData = rGraphicObj.maUserData;
         ImplAssignGraphicData();
         mbAutoSwapped = false;
-        mpMgr = rGraphicObj.mpMgr;
-        mpMgr->ImplRegisterObj( *this, maGraphic, NULL, &rGraphicObj );
+        mpGlobalMgr->ImplRegisterObj( *this, maGraphic, nullptr, &rGraphicObj );
         if( rGraphicObj.HasUserData() && rGraphicObj.IsSwappedOut() )
             SetSwapState();
     }
@@ -365,38 +331,18 @@ bool GraphicObject::operator==( const GraphicObject& rGraphicObj ) const
             ( rGraphicObj.GetLink() == GetLink() ) );
 }
 
-void GraphicObject::Load( SvStream& rIStm )
-{
-    ReadGraphicObject( rIStm, *this );
-}
-
-void GraphicObject::Save( SvStream& rOStm )
-{
-    WriteGraphicObject( rOStm, *this );
-}
-
-void GraphicObject::Assign( const SvDataCopyStream& rCopyStream )
-{
-    *this = static_cast<const GraphicObject&>(rCopyStream);
-}
-
 OString GraphicObject::GetUniqueID() const
 {
     if ( !IsInSwapIn() && IsEPS() )
         const_cast<GraphicObject*>(this)->FireSwapInRequest();
 
-    OString aRet;
-
-    if( mpMgr )
-        aRet = mpMgr->ImplGetUniqueID( *this );
-
-    return aRet;
+    return mpGlobalMgr->ImplGetUniqueID(*this);
 }
 
 SvStream* GraphicObject::GetSwapStream() const
 {
     if( HasSwapStreamHdl() )
-        return reinterpret_cast<SvStream*>( mpSwapStreamHdl->Call( const_cast<void*>(static_cast<const void*>(this)) ) );
+        return maSwapStreamHdl.Call( this );
     else
         return GRFMGR_AUTOSWAPSTREAM_NONE;
 }
@@ -405,8 +351,8 @@ void GraphicObject::SetAttr( const GraphicAttr& rAttr )
 {
     maAttr = rAttr;
 
-    if( mpSimpleCache && ( mpSimpleCache->maAttr != rAttr ) )
-        delete mpSimpleCache, mpSimpleCache = NULL;
+    if (mxSimpleCache && (mxSimpleCache->maAttr != rAttr))
+        mxSimpleCache.reset();
 }
 
 void GraphicObject::SetLink()
@@ -431,17 +377,11 @@ void GraphicObject::SetUserData( const OUString& rUserData )
         SetSwapState();
 }
 
-void GraphicObject::SetSwapStreamHdl()
-{
-    if( mpSwapStreamHdl )
-    {
-        delete mpSwapOutTimer, mpSwapOutTimer = NULL;
-        delete mpSwapStreamHdl, mpSwapStreamHdl = NULL;
-    }
-}
-
 static sal_uInt32 GetCacheTimeInMs()
 {
+    if (utl::ConfigManager::IsFuzzing())
+        return 20000;
+
     const sal_uInt32 nSeconds =
         officecfg::Office::Common::Cache::GraphicManager::ObjectReleaseTime::get(
             comphelper::getProcessComponentContext());
@@ -449,24 +389,26 @@ static sal_uInt32 GetCacheTimeInMs()
     return nSeconds * 1000;
 }
 
-void GraphicObject::SetSwapStreamHdl(const Link<>& rHdl)
+void GraphicObject::SetSwapStreamHdl(const Link<const GraphicObject*, SvStream*>& rHdl)
 {
-    delete mpSwapStreamHdl, mpSwapStreamHdl = new Link<>( rHdl );
+    maSwapStreamHdl = rHdl;
 
     sal_uInt32 const nSwapOutTimeout(GetCacheTimeInMs());
-    if( nSwapOutTimeout )
+    if (nSwapOutTimeout)
     {
-        if( !mpSwapOutTimer )
+        if (!mxSwapOutTimer)
         {
-            mpSwapOutTimer = new Timer;
-            mpSwapOutTimer->SetTimeoutHdl( LINK( this, GraphicObject, ImplAutoSwapOutHdl ) );
+            mxSwapOutTimer.reset(new Timer("svtools::GraphicObject mpSwapOutTimer"));
+            mxSwapOutTimer->SetInvokeHandler( LINK( this, GraphicObject, ImplAutoSwapOutHdl ) );
         }
 
-        mpSwapOutTimer->SetTimeout( nSwapOutTimeout );
-        mpSwapOutTimer->Start();
+        mxSwapOutTimer->SetTimeout( nSwapOutTimeout );
+        mxSwapOutTimer->Start();
     }
     else
-        delete mpSwapOutTimer, mpSwapOutTimer = NULL;
+    {
+        mxSwapOutTimer.reset();
+    }
 }
 
 void GraphicObject::FireSwapInRequest()
@@ -476,32 +418,25 @@ void GraphicObject::FireSwapInRequest()
 
 void GraphicObject::FireSwapOutRequest()
 {
-    ImplAutoSwapOutHdl( NULL );
+    ImplAutoSwapOutHdl( nullptr );
 }
 
-void GraphicObject::GraphicManagerDestroyed()
-{
-    // we're alive, but our manager doesn't live anymore ==> connect to default manager
-    mpMgr = NULL;
-    ImplSetGraphicManager( NULL );
-}
-
-bool GraphicObject::IsCached( OutputDevice* pOut, const Point& rPt, const Size& rSz,
+bool GraphicObject::IsCached( OutputDevice const * pOut, const Size& rSz,
                               const GraphicAttr* pAttr, GraphicManagerDrawFlags nFlags ) const
 {
     bool bRet;
 
     if( nFlags & GraphicManagerDrawFlags::CACHED )
     {
-        Point aPt( rPt );
+        Point aPt;
         Size aSz( rSz );
         if ( pAttr && pAttr->IsCropped() )
         {
             tools::PolyPolygon aClipPolyPoly;
-            bool        bRectClip;
+            bool bRectClip;
             ImplGetCropParams( pOut, aPt, aSz, pAttr, aClipPolyPoly, bRectClip );
         }
-        bRet = mpMgr->IsInCache( pOut, aPt, aSz, *this, ( pAttr ? *pAttr : GetAttr() ) );
+        bRet = mpGlobalMgr->IsInCache( pOut, aPt, aSz, *this, ( pAttr ? *pAttr : GetAttr() ) );
     }
     else
         bRet = false;
@@ -521,13 +456,13 @@ bool GraphicObject::Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz,
     bool bRet;
 
     // #i29534# Provide output rects for PDF writer
-    Rectangle           aCropRect;
+    tools::Rectangle           aCropRect;
 
     if( !( GraphicManagerDrawFlags::USE_DRAWMODE_SETTINGS & nFlags ) )
         pOut->SetDrawMode( nOldDrawMode & ~DrawModeFlags( DrawModeFlags::SettingsLine | DrawModeFlags::SettingsFill | DrawModeFlags::SettingsText | DrawModeFlags::SettingsGradient ) );
 
     // mirrored horizontically
-    if( aSz.Width() < 0L )
+    if( aSz.Width() < 0 )
     {
         aPt.X() += aSz.Width() + 1;
         aSz.Width() = -aSz.Width();
@@ -535,7 +470,7 @@ bool GraphicObject::Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz,
     }
 
     // mirrored vertically
-    if( aSz.Height() < 0L )
+    if( aSz.Height() < 0 )
     {
         aPt.Y() += aSz.Height() + 1;
         aSz.Height() = -aSz.Height();
@@ -566,7 +501,7 @@ bool GraphicObject::Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz,
         }
     }
 
-    bRet = mpMgr->DrawObj( pOut, aPt, aSz, *this, aAttr, nFlags, bCached );
+    bRet = mpGlobalMgr->DrawObj( pOut, aPt, aSz, *this, aAttr, nFlags, bCached );
 
     if( bCropped )
         pOut->Pop();
@@ -577,8 +512,8 @@ bool GraphicObject::Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz,
     // (code above needs to call GetGraphic twice)
     if( bCached )
     {
-        if( mpSwapOutTimer )
-            mpSwapOutTimer->Start();
+        if (mxSwapOutTimer)
+            mxSwapOutTimer->Start();
         else
             FireSwapOutRequest();
     }
@@ -586,11 +521,11 @@ bool GraphicObject::Draw( OutputDevice* pOut, const Point& rPt, const Size& rSz,
     return bRet;
 }
 
-bool GraphicObject::DrawTiled( OutputDevice* pOut, const Rectangle& rArea, const Size& rSize,
-                               const Size& rOffset, const GraphicAttr* pAttr, GraphicManagerDrawFlags nFlags, int nTileCacheSize1D )
+void GraphicObject::DrawTiled( OutputDevice* pOut, const tools::Rectangle& rArea, const Size& rSize,
+                               const Size& rOffset, GraphicManagerDrawFlags nFlags, int nTileCacheSize1D )
 {
-    if( pOut == NULL || rSize.Width() == 0 || rSize.Height() == 0 )
-        return false;
+    if( pOut == nullptr || rSize.Width() == 0 || rSize.Height() == 0 )
+        return;
 
     const MapMode   aOutMapMode( pOut->GetMapMode() );
     const MapMode   aMapMode( aOutMapMode.GetMapUnit(), Point(), aOutMapMode.GetScaleX(), aOutMapMode.GetScaleY() );
@@ -605,11 +540,11 @@ bool GraphicObject::DrawTiled( OutputDevice* pOut, const Rectangle& rArea, const
     while (((sal_Int64)rSize.Height() * nTileCacheSize1D) > SAL_MAX_UINT16)
         nTileCacheSize1D /= 2;
 
-    return ImplDrawTiled( pOut, rArea, aOutTileSize, rOffset, pAttr, nFlags, nTileCacheSize1D );
+    ImplDrawTiled( pOut, rArea, aOutTileSize, rOffset, nullptr, nFlags, nTileCacheSize1D );
 }
 
 bool GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const Size& rSz,
-                                    long nExtraData, const GraphicAttr* pAttr, GraphicManagerDrawFlags /*nFlags*/,
+                                    long nExtraData,
                                     OutputDevice* pFirstFrameOutDev )
 {
     bool bRet = false;
@@ -618,7 +553,7 @@ bool GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const
 
     if( !IsSwappedOut() )
     {
-        const GraphicAttr aAttr( pAttr ? *pAttr : GetAttr() );
+        const GraphicAttr aAttr( GetAttr() );
 
         if( mbAnimated )
         {
@@ -643,16 +578,13 @@ bool GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const
                 }
             }
 
-            if( !mpSimpleCache || ( mpSimpleCache->maAttr != aAttr ) || pFirstFrameOutDev )
+            if (!mxSimpleCache || (mxSimpleCache->maAttr != aAttr) || pFirstFrameOutDev)
             {
-                if( mpSimpleCache )
-                    delete mpSimpleCache;
-
-                mpSimpleCache = new GrfSimpleCacheObj( GetTransformedGraphic( &aAttr ), aAttr );
-                mpSimpleCache->maGraphic.SetAnimationNotifyHdl( GetAnimationNotifyHdl() );
+                mxSimpleCache.reset(new GrfSimpleCacheObj(GetTransformedGraphic(&aAttr), aAttr));
+                mxSimpleCache->maGraphic.SetAnimationNotifyHdl(GetGraphic().GetAnimationNotifyHdl());
             }
 
-            mpSimpleCache->maGraphic.StartAnimation( pOut, aPt, aSz, nExtraData, pFirstFrameOutDev );
+            mxSimpleCache->maGraphic.StartAnimation(pOut, aPt, aSz, nExtraData, pFirstFrameOutDev);
 
             if( bCropped )
                 pOut->Pop();
@@ -660,7 +592,7 @@ bool GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const
             bRet = true;
         }
         else
-            bRet = Draw( pOut, rPt, rSz, &aAttr, GraphicManagerDrawFlags::STANDARD );
+            bRet = Draw( pOut, rPt, rSz, &aAttr );
     }
 
     return bRet;
@@ -668,8 +600,8 @@ bool GraphicObject::StartAnimation( OutputDevice* pOut, const Point& rPt, const
 
 void GraphicObject::StopAnimation( OutputDevice* pOut, long nExtraData )
 {
-    if( mpSimpleCache )
-        mpSimpleCache->maGraphic.StopAnimation( pOut, nExtraData );
+    if (mxSimpleCache)
+        mxSimpleCache->maGraphic.StopAnimation(pOut, nExtraData);
 }
 
 const Graphic& GraphicObject::GetGraphic() const
@@ -680,36 +612,44 @@ const Graphic& GraphicObject::GetGraphic() const
     //fdo#50697 If we've been asked to provide the graphic, then reset
     //the cache timeout to start from now and not remain at the
     //time of creation
-    pThis->restartSwapOutTimer();
+    // restart SwapOut timer; this is like touching in a cache to reset to the full timeout value
+    if (pThis->mxSwapOutTimer && pThis->mxSwapOutTimer->IsActive())
+    {
+        pThis->mxSwapOutTimer->Stop();
+        pThis->mxSwapOutTimer->Start();
+    }
 
     return maGraphic;
 }
 
 void GraphicObject::SetGraphic( const Graphic& rGraphic, const GraphicObject* pCopyObj )
 {
-    mpMgr->ImplUnregisterObj( *this );
+    mpGlobalMgr->ImplUnregisterObj( *this );
 
-    if( mpSwapOutTimer )
-        mpSwapOutTimer->Stop();
+    if (mxSwapOutTimer)
+        mxSwapOutTimer->Stop();
 
     maGraphic = rGraphic;
     mbAutoSwapped = false;
     ImplAssignGraphicData();
     maLink.clear();
-    delete mpSimpleCache, mpSimpleCache = NULL;
+    mxSimpleCache.reset();
 
-    mpMgr->ImplRegisterObj( *this, maGraphic, 0, pCopyObj);
+    mpGlobalMgr->ImplRegisterObj( *this, maGraphic, nullptr, pCopyObj);
 
-    if( mpSwapOutTimer )
-        mpSwapOutTimer->Start();
+    if (mxSwapOutTimer)
+        mxSwapOutTimer->Start();
 
 
 }
 
 void GraphicObject::SetGraphic( const Graphic& rGraphic, const OUString& rLink )
 {
+    // in case we are called from a situation where rLink and maLink are the same thing,
+    // we need a copy because SetGraphic clears maLink
+    OUString sLinkCopy = rLink;
     SetGraphic( rGraphic );
-    maLink = rLink;
+    maLink = sLinkCopy;
 }
 
 Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMode& rDestMap, const GraphicAttr& rAttr ) const
@@ -721,18 +661,18 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
 
     // #104115# Convert the crop margins to graphic object mapmode
     const MapMode aMapGraph( aTransGraphic.GetPrefMapMode() );
-    const MapMode aMap100( MAP_100TH_MM );
+    const MapMode aMap100( MapUnit::Map100thMM );
 
     Size aCropLeftTop;
     Size aCropRightBottom;
 
-    if( GRAPHIC_GDIMETAFILE == eType )
+    if( GraphicType::GdiMetafile == eType )
     {
         GDIMetaFile aMtf( aTransGraphic.GetGDIMetaFile() );
 
-        if( aMapGraph == MAP_PIXEL )
+        if (aMapGraph.GetMapUnit() == MapUnit::MapPixel)
         {
-            // crops are in 1/100th mm -> to aMapGraph -> to MAP_PIXEL
+            // crops are in 1/100th mm -> to aMapGraph -> to MapUnit::MapPixel
             aCropLeftTop = Application::GetDefaultDevice()->LogicToPixel(
                 Size(rAttr.GetLeftCrop(), rAttr.GetTopCrop()),
                 aMap100);
@@ -761,7 +701,7 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
         {
             const MapMode aMtfMapMode( aMtf.GetPrefMapMode() );
 
-            Rectangle aClipRect( aMtfMapMode.GetOrigin().X() + aCropLeftTop.Width(),
+            tools::Rectangle aClipRect( aMtfMapMode.GetOrigin().X() + aCropLeftTop.Width(),
                                  aMtfMapMode.GetOrigin().Y() + aCropLeftTop.Height(),
                                  aMtfMapMode.GetOrigin().X() + aSrcSize.Width() - aCropRightBottom.Width(),
                                  aMtfMapMode.GetOrigin().Y() + aSrcSize.Height() - aCropRightBottom.Height() );
@@ -795,17 +735,17 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
 
         aTransGraphic = aMtf;
     }
-    else if( GRAPHIC_BITMAP == eType )
+    else if( GraphicType::Bitmap == eType )
     {
         BitmapEx aBitmapEx( aTransGraphic.GetBitmapEx() );
-        Rectangle aCropRect;
+        tools::Rectangle aCropRect;
 
         // convert crops to pixel
         if(rAttr.IsCropped())
         {
-            if( aMapGraph == MAP_PIXEL )
+            if (aMapGraph.GetMapUnit() == MapUnit::MapPixel)
             {
-                // crops are in 1/100th mm -> to MAP_PIXEL
+                // crops are in 1/100th mm -> to MapUnit::MapPixel
                 aCropLeftTop = Application::GetDefaultDevice()->LogicToPixel(
                     Size(rAttr.GetLeftCrop(), rAttr.GetTopCrop()),
                     aMap100);
@@ -815,7 +755,7 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
             }
             else
             {
-                // crops are in GraphicObject units -> to MAP_PIXEL
+                // crops are in GraphicObject units -> to MapUnit::MapPixel
                 aCropLeftTop = Application::GetDefaultDevice()->LogicToPixel(
                     Size(rAttr.GetLeftCrop(), rAttr.GetTopCrop()),
                     aMapGraph);
@@ -835,7 +775,7 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
                 && aSrcSizePixel.Width())
             {
                 // the size in pixels calculated from Graphic's internal MapMode (aTransGraphic.GetPrefMapMode())
-                // and it's internal size (aTransGraphic.GetPrefSize()) is different from it's real pixel size.
+                // and it's internal size (aTransGraphic.GetPrefSize()) is different from its real pixel size.
                 // This can be interpreted as this values to be set wrong, but needs to be corrected since e.g.
                 // existing cropping is calculated based on this logic values already.
                 // aBitmapEx.Scale(aSrcSizePixel);
@@ -855,7 +795,7 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
             }
 
             // setup crop rectangle in pixel
-            aCropRect = Rectangle( aCropLeftTop.Width(), aCropLeftTop.Height(),
+            aCropRect = tools::Rectangle( aCropLeftTop.Width(), aCropLeftTop.Height(),
                                  aSrcSizePixel.Width() - aCropRightBottom.Width(),
                                  aSrcSizePixel.Height() - aCropRightBottom.Height() );
         }
@@ -863,17 +803,16 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
         // #105641# Also crop animations
         if( aTransGraphic.IsAnimated() )
         {
-            sal_uInt16 nFrame;
             Animation aAnim( aTransGraphic.GetAnimation() );
 
-            for( nFrame=0; nFrame<aAnim.Count(); ++nFrame )
+            for( size_t nFrame=0; nFrame<aAnim.Count(); ++nFrame )
             {
                 AnimationBitmap aAnimBmp( aAnim.Get( nFrame ) );
 
-                if( !aCropRect.IsInside( Rectangle(aAnimBmp.aPosPix, aAnimBmp.aSizePix) ) )
+                if( !aCropRect.IsInside( tools::Rectangle(aAnimBmp.aPosPix, aAnimBmp.aSizePix) ) )
                 {
                     // setup actual cropping (relative to frame position)
-                    Rectangle aCropRectRel( aCropRect );
+                    tools::Rectangle aCropRectRel( aCropRect );
                     aCropRectRel.Move( -aAnimBmp.aPosPix.X(),
                                        -aAnimBmp.aPosPix.Y() );
 
@@ -910,7 +849,7 @@ Graphic GraphicObject::GetTransformedGraphic( const Size& rDestSize, const MapMo
                 Point aPosOffset( aCropLeftTop.Width() < 0 ? -aCropLeftTop.Width() : 0,
                                   aCropLeftTop.Height() < 0 ? -aCropLeftTop.Height() : 0 );
 
-                for( nFrame=0; nFrame<aAnim.Count(); ++nFrame )
+                for( size_t nFrame=0; nFrame<aAnim.Count(); ++nFrame )
                 {
                     AnimationBitmap aAnimBmp( aAnim.Get( nFrame ) );
 
@@ -951,7 +890,7 @@ Graphic GraphicObject::GetTransformedGraphic( const GraphicAttr* pAttr ) const /
     {
         if( aAttr.IsSpecialDrawMode() || aAttr.IsAdjusted() || aAttr.IsMirrored() || aAttr.IsRotated() || aAttr.IsTransparent() )
         {
-            if( GetType() == GRAPHIC_BITMAP )
+            if( GetType() == GraphicType::Bitmap )
             {
                 if( IsAnimated() )
                 {
@@ -976,7 +915,7 @@ Graphic GraphicObject::GetTransformedGraphic( const GraphicAttr* pAttr ) const /
         }
         else
         {
-            if( ( GetType() == GRAPHIC_BITMAP ) && IsAnimated() )
+            if( ( GetType() == GraphicType::Bitmap ) && IsAnimated() )
             {
                 Animation aAnimation( maGraphic.GetAnimation() );
                 aAnimation.SetLoopCount( mnAnimationLoopCount );
@@ -994,51 +933,64 @@ bool GraphicObject::SwapOut()
 {
     const bool bRet = !mbAutoSwapped && maGraphic.SwapOut();
 
-    if( bRet && mpMgr )
-        mpMgr->ImplGraphicObjectWasSwappedOut( *this );
+    if (bRet)
+        mpGlobalMgr->ImplGraphicObjectWasSwappedOut( *this );
 
     return bRet;
 }
 
 bool GraphicObject::SwapOut( SvStream* pOStm )
 {
-    bool bRet = !mbAutoSwapped;
-    // swap out as a link
-    if( pOStm == GRFMGR_AUTOSWAPSTREAM_LINK )
+    bool bRet = false;
+    try
     {
-        maGraphic.SwapOutAsLink();
+        bRet = !mbAutoSwapped;
+        // swap out as a link
+        if( pOStm == GRFMGR_AUTOSWAPSTREAM_LINK )
+        {
+            maGraphic.SwapOutAsLink();
+        }
+        else
+        {
+            bRet = bRet && maGraphic.SwapOut( pOStm );
+        }
+
+        if (bRet)
+            mpGlobalMgr->ImplGraphicObjectWasSwappedOut(*this);
     }
-    else
+    catch(...)
     {
-        bRet = bRet && maGraphic.SwapOut( pOStm );
+        SAL_WARN( "svtools", "GraphicObject::SwapIn exception");
     }
-
-    if( bRet && mpMgr )
-        mpMgr->ImplGraphicObjectWasSwappedOut( *this );
-
     return bRet;
 }
 
 bool GraphicObject::SwapIn()
 {
     bool bRet = false;
-
-    if( mbAutoSwapped )
+    try
     {
-        ImplAutoSwapIn();
-        bRet = true;
+        if( mbAutoSwapped )
+        {
+            ImplAutoSwapIn();
+            bRet = true;
+        }
+        else
+        {
+            bRet = maGraphic.SwapIn();
+
+            if (bRet)
+                mpGlobalMgr->ImplGraphicObjectWasSwappedIn(*this);
+        }
+
+        if( bRet )
+        {
+            ImplAssignGraphicData();
+        }
     }
-    else
+    catch (...)
     {
-        bRet = maGraphic.SwapIn();
-
-        if( bRet && mpMgr )
-            mpMgr->ImplGraphicObjectWasSwappedIn( *this );
-    }
-
-    if( bRet )
-    {
-        ImplAssignGraphicData();
+        SAL_WARN( "svtools", "GraphicObject::SwapIn exception");
     }
 
     return bRet;
@@ -1050,12 +1002,11 @@ void GraphicObject::SetSwapState()
     {
         mbAutoSwapped = true;
 
-        if( mpMgr )
-            mpMgr->ImplGraphicObjectWasSwappedOut( *this );
+        mpGlobalMgr->ImplGraphicObjectWasSwappedOut(*this);
     }
 }
 
-IMPL_LINK_NOARG_TYPED(GraphicObject, ImplAutoSwapOutHdl, Timer *, void)
+IMPL_LINK_NOARG(GraphicObject, ImplAutoSwapOutHdl, Timer *, void)
 {
     if( !IsSwappedOut() )
     {
@@ -1082,58 +1033,16 @@ IMPL_LINK_NOARG_TYPED(GraphicObject, ImplAutoSwapOutHdl, Timer *, void)
         mbIsInSwapOut = false;
     }
 
-    if( mpSwapOutTimer )
-        mpSwapOutTimer->Start();
-}
-
-SvStream& ReadGraphicObject( SvStream& rIStm, GraphicObject& rGraphicObj )
-{
-    VersionCompat   aCompat( rIStm, StreamMode::READ );
-    Graphic         aGraphic;
-    GraphicAttr     aAttr;
-    bool            bLink;
-
-    ReadGraphic( rIStm, aGraphic );
-    ReadGraphicAttr( rIStm, aAttr );
-    rIStm.ReadCharAsBool( bLink );
-
-    rGraphicObj.SetGraphic( aGraphic );
-    rGraphicObj.SetAttr( aAttr );
-
-    if( bLink )
-    {
-        OUString aLink = read_uInt16_lenPrefixed_uInt8s_ToOUString(rIStm, RTL_TEXTENCODING_UTF8);
-        rGraphicObj.SetLink(aLink);
-    }
-    else
-        rGraphicObj.SetLink();
-
-    rGraphicObj.SetSwapStreamHdl();
-
-    return rIStm;
-}
-
-SvStream& WriteGraphicObject( SvStream& rOStm, const GraphicObject& rGraphicObj )
-{
-    VersionCompat   aCompat( rOStm, StreamMode::WRITE, 1 );
-    const bool      bLink =  rGraphicObj.HasLink();
-
-    WriteGraphic( rOStm, rGraphicObj.GetGraphic() );
-    WriteGraphicAttr( rOStm, rGraphicObj.GetAttr() );
-    rOStm.WriteBool( bLink );
-
-    if( bLink )
-        write_uInt16_lenPrefixed_uInt8s_FromOUString(rOStm, rGraphicObj.GetLink(), RTL_TEXTENCODING_UTF8);
-
-    return rOStm;
+    if (mxSwapOutTimer)
+        mxSwapOutTimer->Start();
 }
 
 #define UNO_NAME_GRAPHOBJ_URLPREFIX "vnd.sun.star.GraphicObject:"
 
 GraphicObject GraphicObject::CreateGraphicObjectFromURL( const OUString &rURL )
 {
-    const OUString aURL( rURL ), aPrefix( UNO_NAME_GRAPHOBJ_URLPREFIX );
-    if( aURL.startsWith( aPrefix ) )
+    const OUString aPrefix( UNO_NAME_GRAPHOBJ_URLPREFIX );
+    if( rURL.startsWith( aPrefix ) )
     {
         // graphic manager url
         OString aUniqueID(OUStringToOString(rURL.copy(sizeof(UNO_NAME_GRAPHOBJ_URLPREFIX) - 1), RTL_TEXTENCODING_UTF8));
@@ -1142,9 +1051,9 @@ GraphicObject GraphicObject::CreateGraphicObjectFromURL( const OUString &rURL )
     else
     {
         Graphic     aGraphic;
-        if ( !aURL.isEmpty() )
+        if ( !rURL.isEmpty() )
         {
-            boost::scoped_ptr<SvStream> pStream(utl::UcbStreamHelper::CreateStream( aURL, StreamMode::READ ));
+            std::unique_ptr<SvStream> pStream(utl::UcbStreamHelper::CreateStream( rURL, StreamMode::READ ));
             if( pStream )
                 GraphicConverter::Import( *pStream, aGraphic );
         }
@@ -1193,12 +1102,12 @@ basegfx::B2DVector GraphicObject::calculateCropScaling(
     double fRightCrop,
     double fBottomCrop) const
 {
-    const MapMode aMapMode100thmm(MAP_100TH_MM);
+    const MapMode aMapMode100thmm(MapUnit::Map100thMM);
     Size aBitmapSize(GetPrefSize());
     double fFactorX(1.0);
     double fFactorY(1.0);
 
-    if(MAP_PIXEL == GetPrefMapMode().GetMapUnit())
+    if(MapUnit::MapPixel == GetPrefMapMode().GetMapUnit())
     {
         aBitmapSize = Application::GetDefaultDevice()->PixelToLogic(aBitmapSize, aMapMode100thmm);
     }
@@ -1223,14 +1132,5 @@ basegfx::B2DVector GraphicObject::calculateCropScaling(
     return basegfx::B2DVector(fFactorX,fFactorY);
 }
 
-// restart SwapOut timer
-void GraphicObject::restartSwapOutTimer() const
-{
-    if( mpSwapOutTimer && mpSwapOutTimer->IsActive() )
-    {
-        mpSwapOutTimer->Stop();
-        mpSwapOutTimer->Start();
-    }
-}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
