@@ -21,10 +21,15 @@
 #include <com/sun/star/beans/PropertyState.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/awt/Rectangle.hpp>
+#include <com/sun/star/awt/XDevice.hpp>
+#include <com/sun/star/graphic/XGraphic.hpp>
+#include <com/sun/star/graphic/XGraphicRenderer.hpp>
+#include <com/sun/star/lang/XServiceInfo.hpp>
 #include <com/sun/star/uno/XComponentContext.hpp>
-#include <osl/mutex.hxx>
+#include <tools/gen.hxx>
 #include <vcl/svapp.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
+#include <comphelper/propertysethelper.hxx>
 #include <comphelper/propertysetinfo.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <rtl/ref.hxx>
@@ -32,7 +37,6 @@
 #include <svtools/grfmgr.hxx>
 #include <comphelper/servicehelper.hxx>
 #include "graphic.hxx"
-#include "renderer.hxx"
 
 #define UNOGRAPHIC_DEVICE           1
 #define UNOGRAPHIC_DESTINATIONRECT  2
@@ -42,23 +46,56 @@ using namespace ::com::sun::star;
 
 namespace {
 
+class GraphicRendererVCL : public ::cppu::OWeakAggObject,
+                           public css::lang::XServiceInfo,
+                           public css::lang::XTypeProvider,
+                           public ::comphelper::PropertySetHelper,
+                           public css::graphic::XGraphicRenderer
+{
+    static rtl::Reference<::comphelper::PropertySetInfo> createPropertySetInfo();
+
+public:
+
+    GraphicRendererVCL();
+
+    // XInterface
+    virtual css::uno::Any SAL_CALL queryAggregation( const css::uno::Type & rType ) override;
+    virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type & rType ) override;
+    virtual void SAL_CALL acquire() throw() override;
+    virtual void SAL_CALL release() throw() override;
+
+    // XServiceInfo
+    virtual OUString SAL_CALL getImplementationName() override;
+    virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName ) override;
+    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() override;
+
+    // XTypeProvider
+    virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes(  ) override;
+    virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId(  ) override;
+
+    // PropertySetHelper
+    virtual void _setPropertyValues( const comphelper::PropertyMapEntry** ppEntries, const css::uno::Any* pValues ) override;
+    virtual void _getPropertyValues( const comphelper::PropertyMapEntry** ppEntries, css::uno::Any* pValue ) override;
+
+    // XGraphicRenderer
+    virtual void SAL_CALL render( const css::uno::Reference< css::graphic::XGraphic >& Graphic ) override;
+
+private:
+
+    css::uno::Reference< css::awt::XDevice > mxDevice;
+
+    VclPtr<OutputDevice>        mpOutDev;
+    tools::Rectangle                   maDestRect;
+    css::uno::Any               maRenderData;
+};
+
 GraphicRendererVCL::GraphicRendererVCL() :
     ::comphelper::PropertySetHelper( createPropertySetInfo() ),
     mpOutDev( nullptr )
 {
 }
 
-
-
-GraphicRendererVCL::~GraphicRendererVCL()
-    throw()
-{
-}
-
-
-
 uno::Any SAL_CALL GraphicRendererVCL::queryAggregation( const uno::Type & rType )
-    throw( uno::RuntimeException, std::exception )
 {
     uno::Any aAny;
 
@@ -75,21 +112,18 @@ uno::Any SAL_CALL GraphicRendererVCL::queryAggregation( const uno::Type & rType
     else if( rType == cppu::UnoType<graphic::XGraphicRenderer>::get())
         aAny <<= uno::Reference< graphic::XGraphicRenderer >(this);
     else
-        aAny <<= OWeakAggObject::queryAggregation( rType );
+        aAny = OWeakAggObject::queryAggregation( rType );
 
     return aAny;
 }
 
 
-
 uno::Any SAL_CALL GraphicRendererVCL::queryInterface( const uno::Type & rType )
-    throw( uno::RuntimeException, std::exception )
 {
     return OWeakAggObject::queryInterface( rType );
 }
 
 
-
 void SAL_CALL GraphicRendererVCL::acquire()
     throw()
 {
@@ -97,7 +131,6 @@ void SAL_CALL GraphicRendererVCL::acquire()
 }
 
 
-
 void SAL_CALL GraphicRendererVCL::release()
     throw()
 {
@@ -105,32 +138,25 @@ void SAL_CALL GraphicRendererVCL::release()
 }
 
 
-
 OUString SAL_CALL GraphicRendererVCL::getImplementationName()
-    throw( uno::RuntimeException, std::exception )
 {
     return OUString( "com.sun.star.comp.graphic.GraphicRendererVCL" );
 }
 
 sal_Bool SAL_CALL GraphicRendererVCL::supportsService( const OUString& ServiceName )
-    throw( uno::RuntimeException, std::exception )
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 
-
 uno::Sequence< OUString > SAL_CALL GraphicRendererVCL::getSupportedServiceNames()
-    throw( uno::RuntimeException, std::exception )
 {
     uno::Sequence<OUString> aSeq { "com.sun.star.graphic.GraphicRendererVCL" };
     return aSeq;
 }
 
 
-
 uno::Sequence< uno::Type > SAL_CALL GraphicRendererVCL::getTypes()
-    throw( uno::RuntimeException, std::exception )
 {
     uno::Sequence< uno::Type >  aTypes( 7 );
     uno::Type*                  pTypes = aTypes.getArray();
@@ -147,18 +173,13 @@ uno::Sequence< uno::Type > SAL_CALL GraphicRendererVCL::getTypes()
 }
 
 uno::Sequence< sal_Int8 > SAL_CALL GraphicRendererVCL::getImplementationId()
-    throw( uno::RuntimeException, std::exception )
 {
     return css::uno::Sequence<sal_Int8>();
 }
 
 
-
-::comphelper::PropertySetInfo* GraphicRendererVCL::createPropertySetInfo()
+rtl::Reference<::comphelper::PropertySetInfo> GraphicRendererVCL::createPropertySetInfo()
 {
-    SolarMutexGuard aGuard;
-    ::comphelper::PropertySetInfo*  pRet = new ::comphelper::PropertySetInfo();
-
     static ::comphelper::PropertyMapEntry const aEntries[] =
     {
         { OUString("Device"), UNOGRAPHIC_DEVICE, cppu::UnoType<uno::Any>::get(), 0, 0 },
@@ -167,19 +188,11 @@ uno::Sequence< sal_Int8 > SAL_CALL GraphicRendererVCL::getImplementationId()
         { OUString(), 0, css::uno::Type(), 0, 0 }
     };
 
-    pRet->acquire();
-    pRet->add( aEntries );
-
-    return pRet;
+    return rtl::Reference<::comphelper::PropertySetInfo>( new ::comphelper::PropertySetInfo(aEntries) );
 }
 
 
-
 void GraphicRendererVCL::_setPropertyValues( const comphelper::PropertyMapEntry** ppEntries, const uno::Any* pValues )
-    throw( beans::UnknownPropertyException,
-           beans::PropertyVetoException,
-           lang::IllegalArgumentException,
-              lang::WrappedTargetException )
 {
     SolarMutexGuard aGuard;
 
@@ -187,7 +200,7 @@ void GraphicRendererVCL::_setPropertyValues( const comphelper::PropertyMapEntry*
     {
         switch( (*ppEntries)->mnHandle )
         {
-            case( UNOGRAPHIC_DEVICE ):
+            case UNOGRAPHIC_DEVICE:
             {
                 uno::Reference< awt::XDevice > xDevice;
 
@@ -204,21 +217,21 @@ void GraphicRendererVCL::_setPropertyValues( const comphelper::PropertyMapEntry*
             }
             break;
 
-            case( UNOGRAPHIC_DESTINATIONRECT ):
+            case UNOGRAPHIC_DESTINATIONRECT:
             {
                 awt::Rectangle aAWTRect;
 
                 if( *pValues >>= aAWTRect )
                 {
-                    maDestRect = Rectangle( Point( aAWTRect.X, aAWTRect.Y ),
+                    maDestRect = tools::Rectangle( Point( aAWTRect.X, aAWTRect.Y ),
                                             Size( aAWTRect.Width, aAWTRect.Height ) );
                 }
             }
             break;
 
-            case( UNOGRAPHIC_RENDERDATA ):
+            case UNOGRAPHIC_RENDERDATA:
             {
-                *pValues >>= maRenderData;
+                 maRenderData = *pValues;
             }
             break;
         }
@@ -229,9 +242,7 @@ void GraphicRendererVCL::_setPropertyValues( const comphelper::PropertyMapEntry*
 }
 
 
-
 void GraphicRendererVCL::_getPropertyValues( const comphelper::PropertyMapEntry** ppEntries, uno::Any* pValues )
-    throw( beans::UnknownPropertyException, lang::WrappedTargetException )
 {
     SolarMutexGuard aGuard;
 
@@ -239,14 +250,14 @@ void GraphicRendererVCL::_getPropertyValues( const comphelper::PropertyMapEntry*
     {
         switch( (*ppEntries)->mnHandle )
         {
-            case( UNOGRAPHIC_DEVICE ):
+            case UNOGRAPHIC_DEVICE:
             {
                 if( mxDevice.is() )
                     *pValues <<= mxDevice;
             }
             break;
 
-            case( UNOGRAPHIC_DESTINATIONRECT ):
+            case UNOGRAPHIC_DESTINATIONRECT:
             {
                 const awt::Rectangle aAWTRect( maDestRect.Left(), maDestRect.Top(),
                                                maDestRect.GetWidth(), maDestRect.GetHeight() );
@@ -255,9 +266,9 @@ void GraphicRendererVCL::_getPropertyValues( const comphelper::PropertyMapEntry*
             }
             break;
 
-            case( UNOGRAPHIC_RENDERDATA ):
+            case UNOGRAPHIC_RENDERDATA:
             {
-                *pValues <<= maRenderData;
+                *pValues = maRenderData;
             }
             break;
         }
@@ -268,9 +279,7 @@ void GraphicRendererVCL::_getPropertyValues( const comphelper::PropertyMapEntry*
 }
 
 
-
 void SAL_CALL GraphicRendererVCL::render( const uno::Reference< graphic::XGraphic >& rxGraphic )
-    throw (uno::RuntimeException, std::exception)
 {
     if( mpOutDev && mxDevice.is() && rxGraphic.is() )
     {
