@@ -511,20 +511,20 @@ sal_Int64 SAL_CALL TransferableHelper::getSomething( const Sequence< sal_Int8 >&
 
 void TransferableHelper::ImplFlush()
 {
-    if( mxClipboard.is() )
-    {
-        Reference< XFlushableClipboard >    xFlushableClipboard( mxClipboard, UNO_QUERY );
-        SolarMutexReleaser aReleaser;
+    if( !mxClipboard.is() )
+        return;
 
-        try
-        {
-            if( xFlushableClipboard.is() )
-                 xFlushableClipboard->flushClipboard();
-        }
-        catch( const css::uno::Exception& )
-        {
-            OSL_FAIL( "Could not flush clipboard" );
-        }
+    Reference< XFlushableClipboard >    xFlushableClipboard( mxClipboard, UNO_QUERY );
+    SolarMutexReleaser aReleaser;
+
+    try
+    {
+        if( xFlushableClipboard.is() )
+             xFlushableClipboard->flushClipboard();
+    }
+    catch( const css::uno::Exception& )
+    {
+        OSL_FAIL( "Could not flush clipboard" );
     }
 }
 
@@ -561,30 +561,30 @@ void TransferableHelper::AddFormat( const DataFlavor& rFlavor )
         }
     }
 
-    if( bAdd )
+    if( !bAdd )
+        return;
+
+    DataFlavorEx   aFlavorEx;
+
+    aFlavorEx.MimeType = rFlavor.MimeType;
+    aFlavorEx.HumanPresentableName = rFlavor.HumanPresentableName;
+    aFlavorEx.DataType = rFlavor.DataType;
+    aFlavorEx.mnSotId = SotExchange::RegisterFormat( rFlavor );
+
+    if ((SotClipboardFormatId::OBJECTDESCRIPTOR == aFlavorEx.mnSotId) && mxObjDesc)
+        aFlavorEx.MimeType += ::ImplGetParameterString(*mxObjDesc);
+
+    maFormats.push_back(aFlavorEx);
+
+    if( SotClipboardFormatId::BITMAP == aFlavorEx.mnSotId )
     {
-        DataFlavorEx   aFlavorEx;
-
-        aFlavorEx.MimeType = rFlavor.MimeType;
-        aFlavorEx.HumanPresentableName = rFlavor.HumanPresentableName;
-        aFlavorEx.DataType = rFlavor.DataType;
-        aFlavorEx.mnSotId = SotExchange::RegisterFormat( rFlavor );
-
-        if ((SotClipboardFormatId::OBJECTDESCRIPTOR == aFlavorEx.mnSotId) && mxObjDesc)
-            aFlavorEx.MimeType += ::ImplGetParameterString(*mxObjDesc);
-
-        maFormats.push_back(aFlavorEx);
-
-        if( SotClipboardFormatId::BITMAP == aFlavorEx.mnSotId )
-        {
-            AddFormat( SotClipboardFormatId::PNG );
-            AddFormat( SotClipboardFormatId::BMP );
-        }
-        else if( SotClipboardFormatId::GDIMETAFILE == aFlavorEx.mnSotId )
-        {
-            AddFormat( SotClipboardFormatId::EMF );
-            AddFormat( SotClipboardFormatId::WMF );
-        }
+        AddFormat( SotClipboardFormatId::PNG );
+        AddFormat( SotClipboardFormatId::BMP );
+    }
+    else if( SotClipboardFormatId::GDIMETAFILE == aFlavorEx.mnSotId )
+    {
+        AddFormat( SotClipboardFormatId::EMF );
+        AddFormat( SotClipboardFormatId::WMF );
     }
 }
 
@@ -639,7 +639,7 @@ void TransferableHelper::ClearFormats()
 bool TransferableHelper::SetAny( const Any& rAny )
 {
     maAny = rAny;
-    return( maAny.hasValue() );
+    return maAny.hasValue();
 }
 
 
@@ -661,7 +661,7 @@ bool TransferableHelper::SetString( const OUString& rString, const DataFlavor& r
     else
         maAny <<= rString;
 
-    return( maAny.hasValue() );
+    return maAny.hasValue();
 }
 
 
@@ -689,7 +689,7 @@ bool TransferableHelper::SetBitmapEx( const BitmapEx& rBitmapEx, const DataFlavo
         maAny <<= Sequence< sal_Int8 >( static_cast< const sal_Int8* >( aMemStm.GetData() ), aMemStm.Seek( STREAM_SEEK_TO_END ) );
     }
 
-    return( maAny.hasValue() );
+    return maAny.hasValue();
 }
 
 
@@ -703,7 +703,7 @@ bool TransferableHelper::SetGDIMetaFile( const GDIMetaFile& rMtf )
         maAny <<= Sequence< sal_Int8 >( static_cast< const sal_Int8* >( aMemStm.GetData() ), aMemStm.Seek( STREAM_SEEK_TO_END ) );
     }
 
-    return( maAny.hasValue() );
+    return maAny.hasValue();
 }
 
 
@@ -719,7 +719,7 @@ bool TransferableHelper::SetGraphic( const Graphic& rGraphic )
         maAny <<= Sequence< sal_Int8 >( static_cast< const sal_Int8* >( aMemStm.GetData() ), aMemStm.Seek( STREAM_SEEK_TO_END ) );
     }
 
-    return( maAny.hasValue() );
+    return maAny.hasValue();
 }
 
 
@@ -731,7 +731,7 @@ bool TransferableHelper::SetImageMap( const ImageMap& rIMap )
     rIMap.Write( aMemStm );
     maAny <<= Sequence< sal_Int8 >( static_cast< const sal_Int8* >( aMemStm.GetData() ), aMemStm.Seek( STREAM_SEEK_TO_END ) );
 
-    return( maAny.hasValue() );
+    return maAny.hasValue();
 }
 
 
@@ -744,7 +744,7 @@ bool TransferableHelper::SetTransferableObjectDescriptor( const TransferableObje
     WriteTransferableObjectDescriptor( aMemStm, rDesc );
     maAny <<= Sequence< sal_Int8 >( static_cast< const sal_Int8* >( aMemStm.GetData() ), aMemStm.Tell() );
 
-    return( maAny.hasValue() );
+    return maAny.hasValue();
  }
 
 
@@ -772,7 +772,7 @@ bool TransferableHelper::SetINetBookmark( const INetBookmark& rBmk,
         break;
 
         case SotClipboardFormatId::STRING:
-            maAny <<= OUString( rBmk.GetURL() );
+            maAny <<= rBmk.GetURL();
             break;
 
         case SotClipboardFormatId::UNIFORMRESOURCELOCATOR:
@@ -833,7 +833,7 @@ bool TransferableHelper::SetINetBookmark( const INetBookmark& rBmk,
         break;
     }
 
-    return( maAny.hasValue() );
+    return maAny.hasValue();
 }
 
 
@@ -847,11 +847,11 @@ bool TransferableHelper::SetINetImage( const INetImage& rINtImg,
 
     maAny <<= Sequence< sal_Int8 >( static_cast< const sal_Int8* >( aMemStm.GetData() ), aMemStm.Seek( STREAM_SEEK_TO_END ) );
 
-    return( maAny.hasValue() );
+    return maAny.hasValue();
 }
 
 
-bool TransferableHelper::SetObject( void* pUserObject, SotClipboardFormatId nUserObjectId, const DataFlavor& rFlavor )
+bool TransferableHelper::SetObject( void* pUserObject, sal_uInt32 nUserObjectId, const DataFlavor& rFlavor )
 {
     tools::SvRef<SotStorageStream> xStm( new SotStorageStream( OUString() ) );
 
@@ -877,11 +877,11 @@ bool TransferableHelper::SetObject( void* pUserObject, SotClipboardFormatId nUse
             maAny <<= aSeq;
     }
 
-    return( maAny.hasValue() );
+    return maAny.hasValue();
 }
 
 
-bool TransferableHelper::WriteObject( tools::SvRef<SotStorageStream>&, void*, SotClipboardFormatId, const DataFlavor& )
+bool TransferableHelper::WriteObject( tools::SvRef<SotStorageStream>&, void*, sal_uInt32, const DataFlavor& )
 {
     OSL_FAIL( "TransferableHelper::WriteObject( ... ) not implemented" );
     return false;
@@ -918,19 +918,19 @@ void TransferableHelper::CopyToClipboard( vcl::Window *pWindow ) const
     if( xClipboard.is() )
         mxClipboard = xClipboard;
 
-    if( mxClipboard.is() && !mxTerminateListener.is() )
-    {
-        try
-        {
-            TransferableHelper*                 pThis = const_cast< TransferableHelper* >( this );
-            Reference< XDesktop2 > xDesktop = Desktop::create( ::comphelper::getProcessComponentContext() );
-            xDesktop->addTerminateListener( pThis->mxTerminateListener = new TerminateListener( *pThis ) );
+    if( !(mxClipboard.is() && !mxTerminateListener.is()) )
+        return;
 
-            mxClipboard->setContents( pThis, pThis );
-        }
-        catch( const css::uno::Exception& )
-        {
-        }
+    try
+    {
+        TransferableHelper*                 pThis = const_cast< TransferableHelper* >( this );
+        Reference< XDesktop2 > xDesktop = Desktop::create( ::comphelper::getProcessComponentContext() );
+        xDesktop->addTerminateListener( pThis->mxTerminateListener = new TerminateListener( *pThis ) );
+
+        mxClipboard->setContents( pThis, pThis );
+    }
+    catch( const css::uno::Exception& )
+    {
     }
 }
 
@@ -943,19 +943,19 @@ void TransferableHelper::CopyToSelection( vcl::Window *pWindow ) const
     if( pWindow )
         xSelection = pWindow->GetPrimarySelection();
 
-    if( xSelection.is() && !mxTerminateListener.is() )
-    {
-        try
-        {
-            TransferableHelper*                 pThis = const_cast< TransferableHelper* >( this );
-            Reference< XDesktop2 > xDesktop = Desktop::create( ::comphelper::getProcessComponentContext() );
-            xDesktop->addTerminateListener( pThis->mxTerminateListener = new TerminateListener( *pThis ) );
+    if( !(xSelection.is() && !mxTerminateListener.is()) )
+        return;
 
-            xSelection->setContents( pThis, pThis );
-        }
-        catch( const css::uno::Exception& )
-        {
-        }
+    try
+    {
+        TransferableHelper*                 pThis = const_cast< TransferableHelper* >( this );
+        Reference< XDesktop2 > xDesktop = Desktop::create( ::comphelper::getProcessComponentContext() );
+        xDesktop->addTerminateListener( pThis->mxTerminateListener = new TerminateListener( *pThis ) );
+
+        xSelection->setContents( pThis, pThis );
+    }
+    catch( const css::uno::Exception& )
+    {
     }
 }
 
@@ -967,38 +967,38 @@ void TransferableHelper::StartDrag( vcl::Window* pWindow, sal_Int8 nDnDSourceAct
     DBG_ASSERT( pWindow, "Window pointer is NULL" );
     Reference< XDragSource > xDragSource( pWindow->GetDragSource() );
 
-    if( xDragSource.is() )
-    {
-        /*
-         *    #96792# release mouse before actually starting DnD.
-         *    This is necessary for the X11 DnD implementation to work.
-         */
-        if( pWindow->IsMouseCaptured() )
-            pWindow->ReleaseMouse();
+    if( !xDragSource.is() )
+        return;
 
-        const Point aPt( pWindow->GetPointerPosPixel() );
+    /*
+     *    #96792# release mouse before actually starting DnD.
+     *    This is necessary for the X11 DnD implementation to work.
+     */
+    if( pWindow->IsMouseCaptured() )
+        pWindow->ReleaseMouse();
 
-        // On Mac OS X we are forced to execute 'startDrag' synchronously
-        // contrary to the XDragSource interface specification because
-        // we can receive drag events from the system only in the main
-        // thread
+    const Point aPt( pWindow->GetPointerPosPixel() );
+
+    // On Mac OS X we are forced to execute 'startDrag' synchronously
+    // contrary to the XDragSource interface specification because
+    // we can receive drag events from the system only in the main
+    // thread
 #if !defined(MACOSX)
-        SolarMutexReleaser aReleaser;
+    SolarMutexReleaser aReleaser;
 #endif
 
-        try
-        {
-            DragGestureEvent    aEvt;
-            aEvt.DragAction = DNDConstants::ACTION_COPY;
-            aEvt.DragOriginX = aPt.X();
-            aEvt.DragOriginY = aPt.Y();
-            aEvt.DragSource = xDragSource;
+    try
+    {
+        DragGestureEvent    aEvt;
+        aEvt.DragAction = DNDConstants::ACTION_COPY;
+        aEvt.DragOriginX = aPt.X();
+        aEvt.DragOriginY = aPt.Y();
+        aEvt.DragSource = xDragSource;
 
-            xDragSource->startDrag( aEvt, nDnDSourceActions, nDnDPointer, DND_IMAGE_NONE, this, this );
-        }
-        catch( const css::uno::Exception& )
-        {
-        }
+        xDragSource->startDrag( aEvt, nDnDSourceActions, nDnDPointer, DND_IMAGE_NONE, this, this );
+    }
+    catch( const css::uno::Exception& )
+    {
     }
 }
 
@@ -1308,17 +1308,17 @@ void TransferableDataHelper::InitFormats()
     maFormats.clear();
     mxObjDesc.reset(new TransferableObjectDescriptor);
 
-    if( mxTransfer.is() )
-    {
-        TransferableDataHelper::FillDataFlavorExVector(mxTransfer->getTransferDataFlavors(), maFormats);
+    if( !mxTransfer.is() )
+        return;
 
-        for (DataFlavorExVector::const_iterator aIter(maFormats.begin()), aEnd(maFormats.end()); aIter != aEnd; ++aIter)
+    TransferableDataHelper::FillDataFlavorExVector(mxTransfer->getTransferDataFlavors(), maFormats);
+
+    for (DataFlavorExVector::const_iterator aIter(maFormats.begin()), aEnd(maFormats.end()); aIter != aEnd; ++aIter)
+    {
+        if( SotClipboardFormatId::OBJECTDESCRIPTOR == aIter->mnSotId )
         {
-            if( SotClipboardFormatId::OBJECTDESCRIPTOR == aIter->mnSotId )
-            {
-                ImplSetParameterString(*mxObjDesc, *aIter);
-                break;
-            }
+            ImplSetParameterString(*mxObjDesc, *aIter);
+            break;
         }
     }
 }
@@ -1578,7 +1578,7 @@ bool TransferableDataHelper::GetBitmapEx( const DataFlavor& rFlavor, BitmapEx& r
             // it's a JPEG, import to BitmapEx
             GraphicFilter& rFilter = GraphicFilter::GetGraphicFilter();
             Graphic aGraphic;
-            if (rFilter.ImportGraphic(aGraphic, "", *xStm) == GRFILTER_OK)
+            if (rFilter.ImportGraphic(aGraphic, "", *xStm) == ERRCODE_NONE)
                 rBmpEx = aGraphic.GetBitmapEx();
         }
 
@@ -1618,16 +1618,16 @@ bool TransferableDataHelper::GetBitmapEx( const DataFlavor& rFlavor, BitmapEx& r
 
             if(MapUnit::MapPixel != aMapMode.GetMapUnit())
             {
-                const Size aSize(OutputDevice::LogicToLogic(rBmpEx.GetPrefSize(), aMapMode, MapUnit::Map100thMM));
+                const Size aSize(OutputDevice::LogicToLogic(rBmpEx.GetPrefSize(), aMapMode, MapMode(MapUnit::Map100thMM)));
 
                 // #i122388# This wrongly corrects in the given case; changing from 5000 100th mm to
                 // the described 50 cm (which is 50000 100th mm)
                 if((aSize.Width() > 50000) || (aSize.Height() > 50000))
                 {
-                    rBmpEx.SetPrefMapMode(MapUnit::MapPixel);
+                    rBmpEx.SetPrefMapMode(MapMode(MapUnit::MapPixel));
 
                     // #i122388# also adapt size by applying the mew MapMode
-                    const Size aNewSize(OutputDevice::LogicToLogic(aSize, MapUnit::Map100thMM, MapUnit::MapPixel));
+                    const Size aNewSize(OutputDevice::LogicToLogic(aSize, MapMode(MapUnit::Map100thMM), MapMode(MapUnit::MapPixel)));
                     rBmpEx.SetPrefSize(aNewSize);
                 }
             }
@@ -1819,8 +1819,8 @@ bool TransferableDataHelper::GetINetBookmark( const css::datatransfer::DataFlavo
     const SotClipboardFormatId nFormat = SotExchange::GetFormat( rFlavor );
     switch( nFormat )
     {
-        case( SotClipboardFormatId::SOLK ):
-        case( SotClipboardFormatId::UNIFORMRESOURCELOCATOR ):
+        case SotClipboardFormatId::SOLK:
+        case SotClipboardFormatId::UNIFORMRESOURCELOCATOR:
         {
             OUString aString;
             if( GetString( rFlavor, aString ) )
@@ -1866,7 +1866,7 @@ bool TransferableDataHelper::GetINetBookmark( const css::datatransfer::DataFlavo
         }
         break;
 
-        case( SotClipboardFormatId::NETSCAPE_BOOKMARK ):
+        case SotClipboardFormatId::NETSCAPE_BOOKMARK:
         {
             Sequence<sal_Int8> aSeq = GetSequence(rFlavor, OUString());
 
