@@ -20,7 +20,6 @@
 #include <svtools/unitconv.hxx>
 
 
-
 void SetFieldUnit( MetricField& rField, FieldUnit eUnit, bool bAll )
 {
     sal_Int64 nFirst    = rField.Denormalize( rField.GetFirst( FUNIT_TWIP ) );
@@ -80,27 +79,23 @@ void SetFieldUnit( MetricField& rField, FieldUnit eUnit, bool bAll )
 }
 
 
-
-void SetFieldUnit( MetricBox& rBox, FieldUnit eUnit, bool bAll )
+void SetFieldUnit( MetricBox& rBox, FieldUnit eUnit )
 {
     sal_Int64 nMin = rBox.Denormalize( rBox.GetMin( FUNIT_TWIP ) );
     sal_Int64 nMax = rBox.Denormalize( rBox.GetMax( FUNIT_TWIP ) );
 
-    if ( !bAll )
+    switch ( eUnit )
     {
-        switch ( eUnit )
-        {
-            case FUNIT_M:
-            case FUNIT_KM:
-                eUnit = FUNIT_CM;
-                break;
+        case FUNIT_M:
+        case FUNIT_KM:
+            eUnit = FUNIT_CM;
+            break;
 
-            case FUNIT_FOOT:
-            case FUNIT_MILE:
-                eUnit = FUNIT_INCH;
-                break;
-            default: ;//prevent warning
-        }
+        case FUNIT_FOOT:
+        case FUNIT_MILE:
+            eUnit = FUNIT_INCH;
+            break;
+        default: ;//prevent warning
     }
     rBox.SetUnit( eUnit );
 
@@ -109,25 +104,21 @@ void SetFieldUnit( MetricBox& rBox, FieldUnit eUnit, bool bAll )
     else
         rBox.SetDecimalDigits( 2 );
 
-    if ( !bAll )
-    {
-        rBox.SetMin( rBox.Normalize( nMin ), FUNIT_TWIP );
-        rBox.SetMax( rBox.Normalize( nMax ), FUNIT_TWIP );
-    }
+    rBox.SetMin( rBox.Normalize( nMin ), FUNIT_TWIP );
+    rBox.SetMax( rBox.Normalize( nMax ), FUNIT_TWIP );
 }
 
 
-void SetMetricValue( MetricField& rField, long nCoreValue, SfxMapUnit eUnit )
+void SetMetricValue( MetricField& rField, long nCoreValue, MapUnit eUnit )
 {
-    sal_Int64 nVal = OutputDevice::LogicToLogic( nCoreValue, (MapUnit)eUnit, MAP_100TH_MM );
+    sal_Int64 nVal = OutputDevice::LogicToLogic( nCoreValue, eUnit, MapUnit::Map100thMM );
     nVal = rField.Normalize( nVal );
     rField.SetValue( nVal, FUNIT_100TH_MM );
 
 }
 
 
-
-long GetCoreValue( const MetricField& rField, SfxMapUnit eUnit )
+long GetCoreValue( const MetricField& rField, MapUnit eUnit )
 {
     sal_Int64 nVal = rField.GetValue( FUNIT_100TH_MM );
     // avoid rounding issues
@@ -145,35 +136,34 @@ long GetCoreValue( const MetricField& rField, SfxMapUnit eUnit )
     }
     if( bRoundBefore )
         nVal = rField.Denormalize( nVal );
-    sal_Int64 nUnitVal = OutputDevice::LogicToLogic( static_cast<long>(nVal), MAP_100TH_MM, (MapUnit)eUnit );
+    sal_Int64 nUnitVal = OutputDevice::LogicToLogic( static_cast<long>(nVal), MapUnit::Map100thMM, eUnit );
     if( ! bRoundBefore )
         nUnitVal = rField.Denormalize( nUnitVal );
     return static_cast<long>(nUnitVal);
 }
 
 
-
-long CalcToUnit( float nIn, SfxMapUnit eUnit )
+long CalcToUnit( float nIn, MapUnit eUnit )
 {
-    // nIn ist in Points
+    // nIn is in Points
 
-    DBG_ASSERT( eUnit == SFX_MAPUNIT_TWIP       ||
-                eUnit == SFX_MAPUNIT_100TH_MM   ||
-                eUnit == SFX_MAPUNIT_10TH_MM    ||
-                eUnit == SFX_MAPUNIT_MM         ||
-                eUnit == SFX_MAPUNIT_CM, "this unit is not implemented" );
+    DBG_ASSERT( eUnit == MapUnit::MapTwip       ||
+                eUnit == MapUnit::Map100thMM   ||
+                eUnit == MapUnit::Map10thMM    ||
+                eUnit == MapUnit::MapMM         ||
+                eUnit == MapUnit::MapCM, "this unit is not implemented" );
 
     float nTmp = nIn;
 
-    if ( SFX_MAPUNIT_TWIP != eUnit )
+    if ( MapUnit::MapTwip != eUnit )
         nTmp = nIn * 10 / 567;
 
     switch ( eUnit )
     {
-        case SFX_MAPUNIT_100TH_MM:  nTmp *= 100; break;
-        case SFX_MAPUNIT_10TH_MM:   nTmp *= 10;  break;
-        case SFX_MAPUNIT_MM:                     break;
-        case SFX_MAPUNIT_CM:        nTmp /= 10;  break;
+        case MapUnit::Map100thMM:  nTmp *= 100; break;
+        case MapUnit::Map10thMM:   nTmp *= 10;  break;
+        case MapUnit::MapMM:                     break;
+        case MapUnit::MapCM:        nTmp /= 10;  break;
         default: ;//prevent warning
     }
 
@@ -184,53 +174,52 @@ long CalcToUnit( float nIn, SfxMapUnit eUnit )
 }
 
 
-
-long ItemToControl( long nIn, SfxMapUnit eItem, FieldUnit eCtrl )
+long ItemToControl( long nIn, MapUnit eItem, FieldUnit eCtrl )
 {
     long nOut = 0;
 
     switch ( eItem )
     {
-        case SFX_MAPUNIT_100TH_MM:
-        case SFX_MAPUNIT_10TH_MM:
-        case SFX_MAPUNIT_MM:
+        case MapUnit::Map100thMM:
+        case MapUnit::Map10thMM:
+        case MapUnit::MapMM:
         {
-            if ( eItem == SFX_MAPUNIT_10TH_MM )
+            if ( eItem == MapUnit::Map10thMM )
                 nIn /= 10;
-            else if ( eItem == SFX_MAPUNIT_100TH_MM )
+            else if ( eItem == MapUnit::Map100thMM )
                 nIn /= 100;
             nOut = TransformMetric( nIn, FUNIT_MM, eCtrl );
         }
         break;
 
-        case SFX_MAPUNIT_CM:
+        case MapUnit::MapCM:
         {
             nOut = TransformMetric( nIn, FUNIT_CM, eCtrl );
         }
         break;
 
-        case SFX_MAPUNIT_1000TH_INCH:
-        case SFX_MAPUNIT_100TH_INCH:
-        case SFX_MAPUNIT_10TH_INCH:
-        case SFX_MAPUNIT_INCH:
+        case MapUnit::Map1000thInch:
+        case MapUnit::Map100thInch:
+        case MapUnit::Map10thInch:
+        case MapUnit::MapInch:
         {
-            if ( eItem == SFX_MAPUNIT_10TH_INCH )
+            if ( eItem == MapUnit::Map10thInch )
                 nIn /= 10;
-            else if ( eItem == SFX_MAPUNIT_100TH_INCH )
+            else if ( eItem == MapUnit::Map100thInch )
                 nIn /= 100;
-            else if ( eItem == SFX_MAPUNIT_1000TH_INCH )
+            else if ( eItem == MapUnit::Map1000thInch )
                 nIn /= 1000;
             nOut = TransformMetric( nIn, FUNIT_INCH, eCtrl );
         }
         break;
 
-        case SFX_MAPUNIT_POINT:
+        case MapUnit::MapPoint:
         {
             nOut = TransformMetric( nIn, FUNIT_POINT, eCtrl );
         }
         break;
 
-        case SFX_MAPUNIT_TWIP:
+        case MapUnit::MapTwip:
         {
             nOut = TransformMetric( nIn, FUNIT_TWIP, eCtrl );
         }
@@ -241,36 +230,34 @@ long ItemToControl( long nIn, SfxMapUnit eItem, FieldUnit eCtrl )
 }
 
 
-
-long ControlToItem( long nIn, FieldUnit eCtrl, SfxMapUnit eItem )
+long ControlToItem( long nIn, FieldUnit eCtrl, MapUnit eItem )
 {
     return ItemToControl( nIn, eItem, eCtrl );
 }
 
 
-
-FieldUnit MapToFieldUnit( const SfxMapUnit eUnit )
+FieldUnit MapToFieldUnit( const MapUnit eUnit )
 {
     switch ( eUnit )
     {
-        case SFX_MAPUNIT_100TH_MM:
-        case SFX_MAPUNIT_10TH_MM:
-        case SFX_MAPUNIT_MM:
+        case MapUnit::Map100thMM:
+        case MapUnit::Map10thMM:
+        case MapUnit::MapMM:
             return FUNIT_MM;
 
-        case SFX_MAPUNIT_CM:
+        case MapUnit::MapCM:
             return FUNIT_CM;
 
-        case SFX_MAPUNIT_1000TH_INCH:
-        case SFX_MAPUNIT_100TH_INCH:
-        case SFX_MAPUNIT_10TH_INCH:
-        case SFX_MAPUNIT_INCH:
+        case MapUnit::Map1000thInch:
+        case MapUnit::Map100thInch:
+        case MapUnit::Map10thInch:
+        case MapUnit::MapInch:
             return FUNIT_INCH;
 
-        case SFX_MAPUNIT_POINT:
+        case MapUnit::MapPoint:
             return FUNIT_POINT;
 
-        case SFX_MAPUNIT_TWIP:
+        case MapUnit::MapTwip:
             return FUNIT_TWIP;
         default: ;//prevent warning
     }
@@ -278,36 +265,34 @@ FieldUnit MapToFieldUnit( const SfxMapUnit eUnit )
 }
 
 
-
-long CalcToPoint( long nIn, SfxMapUnit eUnit, sal_uInt16 nFactor )
+long CalcToPoint( long nIn, MapUnit eUnit, sal_uInt16 nFactor )
 {
-    DBG_ASSERT( eUnit == SFX_MAPUNIT_TWIP       ||
-                eUnit == SFX_MAPUNIT_100TH_MM   ||
-                eUnit == SFX_MAPUNIT_10TH_MM    ||
-                eUnit == SFX_MAPUNIT_MM         ||
-                eUnit == SFX_MAPUNIT_CM, "this unit is not implemented" );
+    DBG_ASSERT( eUnit == MapUnit::MapTwip       ||
+                eUnit == MapUnit::Map100thMM   ||
+                eUnit == MapUnit::Map10thMM    ||
+                eUnit == MapUnit::MapMM         ||
+                eUnit == MapUnit::MapCM, "this unit is not implemented" );
 
     long nRet = 0;
 
-    if ( SFX_MAPUNIT_TWIP == eUnit )
+    if ( MapUnit::MapTwip == eUnit )
         nRet = nIn;
     else
         nRet = nIn * 567;
 
     switch ( eUnit )
     {
-        case SFX_MAPUNIT_100TH_MM:  nRet /= 100; break;
-        case SFX_MAPUNIT_10TH_MM:   nRet /= 10;  break;
-        case SFX_MAPUNIT_MM:                     break;
-        case SFX_MAPUNIT_CM:        nRet *= 10;  break;
+        case MapUnit::Map100thMM:  nRet /= 100; break;
+        case MapUnit::Map10thMM:   nRet /= 10;  break;
+        case MapUnit::MapMM:                     break;
+        case MapUnit::MapCM:        nRet *= 10;  break;
         default: ;//prevent warning
     }
 
-    // ggf. aufrunden
-    if ( SFX_MAPUNIT_TWIP != eUnit )
+    // round up if necessary
+    if ( MapUnit::MapTwip != eUnit )
     {
-        long nMod = 10;
-        long nTmp = nRet % nMod;
+        long nTmp = nRet % 10;
 
         if ( nTmp >= 4 )
             nRet += 10 - nTmp;
@@ -317,7 +302,6 @@ long CalcToPoint( long nIn, SfxMapUnit eUnit, sal_uInt16 nFactor )
 }
 
 
-
 long CMToTwips( long nIn )
 {
     long nRet = 0;
@@ -328,7 +312,6 @@ long CMToTwips( long nIn )
 }
 
 
-
 long MMToTwips( long nIn )
 {
     long nRet = 0;
@@ -339,7 +322,6 @@ long MMToTwips( long nIn )
 }
 
 
-
 long InchToTwips( long nIn )
 {
     long nRet = 0;
@@ -350,7 +332,6 @@ long InchToTwips( long nIn )
 }
 
 
-
 long PointToTwips( long nIn )
 {
     long nRet = 0;
@@ -361,7 +342,6 @@ long PointToTwips( long nIn )
 }
 
 
-
 long PicaToTwips( long nIn )
 {
     long nRet = 0;
@@ -372,7 +352,6 @@ long PicaToTwips( long nIn )
 }
 
 
-
 long TwipsToCM( long nIn )
 {
     long nRet = nIn / 567;
@@ -380,7 +359,6 @@ long TwipsToCM( long nIn )
 }
 
 
-
 long InchToCM( long nIn )
 {
     long nRet = 0;
@@ -391,7 +369,6 @@ long InchToCM( long nIn )
 }
 
 
-
 long MMToCM( long nIn )
 {
     long nRet = nIn / 10;
@@ -399,7 +376,6 @@ long MMToCM( long nIn )
 }
 
 
-
 long PointToCM( long nIn )
 {
     long nRet = 0;
@@ -410,7 +386,6 @@ long PointToCM( long nIn )
 }
 
 
-
 long PicaToCM( long nIn)
 {
     long nRet = 0;
@@ -421,7 +396,6 @@ long PicaToCM( long nIn)
 }
 
 
-
 long TwipsToMM( long nIn )
 {
     long nRet = 0;
@@ -432,7 +406,6 @@ long TwipsToMM( long nIn )
 }
 
 
-
 long CMToMM( long nIn )
 {
     long nRet = 0;
@@ -443,7 +416,6 @@ long CMToMM( long nIn )
 }
 
 
-
 long InchToMM( long nIn )
 {
     long nRet = 0;
@@ -454,7 +426,6 @@ long InchToMM( long nIn )
 }
 
 
-
 long PointToMM( long nIn )
 {
     long nRet = 0;
@@ -465,7 +436,6 @@ long PointToMM( long nIn )
 }
 
 
-
 long PicaToMM( long nIn )
 {
     long nRet = 0;
@@ -476,7 +446,6 @@ long PicaToMM( long nIn )
 }
 
 
-
 long TwipsToInch( long nIn )
 {
     long nRet = nIn / 1440;
@@ -484,7 +453,6 @@ long TwipsToInch( long nIn )
 }
 
 
-
 long CMToInch( long nIn )
 {
     long nRet = 0;
@@ -495,7 +463,6 @@ long CMToInch( long nIn )
 }
 
 
-
 long MMToInch( long nIn )
 {
     long nRet = 0;
@@ -506,7 +473,6 @@ long MMToInch( long nIn )
 }
 
 
-
 long PointToInch( long nIn )
 {
     long nRet = nIn / 72;
@@ -514,7 +480,6 @@ long PointToInch( long nIn )
 }
 
 
-
 long PicaToInch( long nIn )
 {
     long nRet = nIn / 6;
@@ -522,7 +487,6 @@ long PicaToInch( long nIn )
 }
 
 
-
 long TwipsToPoint( long nIn )
 {
     long nRet = nIn / 20;
@@ -530,7 +494,6 @@ long TwipsToPoint( long nIn )
 }
 
 
-
 long InchToPoint( long nIn )
 {
     long nRet = 0;
@@ -541,7 +504,6 @@ long InchToPoint( long nIn )
 }
 
 
-
 long CMToPoint( long nIn )
 {
     long nRet = 0;
@@ -552,7 +514,6 @@ long CMToPoint( long nIn )
 }
 
 
-
 long MMToPoint( long nIn )
 {
     long nRet = 0;
@@ -563,7 +524,6 @@ long MMToPoint( long nIn )
 }
 
 
-
 long PicaToPoint( long nIn )
 {
     long nRet = nIn / 12;
@@ -571,7 +531,6 @@ long PicaToPoint( long nIn )
 }
 
 
-
 long TwipsToPica( long nIn )
 {
     long nRet = nIn / 240;
@@ -579,7 +538,6 @@ long TwipsToPica( long nIn )
 }
 
 
-
 long InchToPica( long nIn )
 {
     long nRet = 0;
@@ -590,7 +548,6 @@ long InchToPica( long nIn )
 }
 
 
-
 long PointToPica( long nIn )
 {
     long nRet = 0;
@@ -601,7 +558,6 @@ long PointToPica( long nIn )
 }
 
 
-
 long CMToPica( long nIn )
 {
     long nRet = 0;
@@ -612,7 +568,6 @@ long CMToPica( long nIn )
 }
 
 
-
 long MMToPica( long nIn )
 {
     long nRet = 0;
@@ -623,14 +578,13 @@ long MMToPica( long nIn )
 }
 
 
-
 long Nothing( long nIn )
 {
     long nRet = nIn;
     return nRet;
 }
 
-FUNC_CONVERT ConvertTable[6][6] =
+FUNC_CONVERT const ConvertTable[6][6] =
 {
 //  CM,         MM          INCH         POINT        PICAS=32     TWIPS
     { Nothing,  CMToMM,     CMToInch,    CMToPoint,   CMToPica,    CMToTwips },
@@ -642,7 +596,6 @@ FUNC_CONVERT ConvertTable[6][6] =
 };
 
 
-
 long TransformMetric( long nVal, FieldUnit aOld, FieldUnit aNew )
 {
     if ( aOld == FUNIT_NONE   || aNew == FUNIT_NONE ||
