@@ -36,13 +36,12 @@ const int MAX_TOKEN_LEN = 128;
 #define RTF_ISALPHA( c ) rtl::isAsciiAlpha(c)
 
 SvRTFParser::SvRTFParser( SvStream& rIn, sal_uInt8 nStackSize )
-    : SvParser( rIn, nStackSize )
+    : SvParser<int>( rIn, nStackSize )
     , nOpenBrakets(0)
     , eCodeSet(RTL_TEXTENCODING_MS_1252)
-    , eUNICodeSet(RTL_TEXTENCODING_MS_1252)    // default ist ANSI-CodeSet
     , nUCharOverread(1)
 {
-    // default ist ANSI-CodeSet
+    // default is ANSI-CodeSet
     SetSrcEncoding( RTL_TEXTENCODING_MS_1252 );
     bRTF_InTextRead = false;
 }
@@ -52,9 +51,7 @@ SvRTFParser::~SvRTFParser()
 }
 
 
-
-
-int SvRTFParser::_GetNextToken()
+int SvRTFParser::GetNextToken_()
 {
     int nRet = 0;
     do {
@@ -63,7 +60,7 @@ int SvRTFParser::_GetNextToken()
         {
         case '\\':
             {
-                // control charaters
+                // control characters
                 nNextCh = GetNextChar();
                 switch( nNextCh )
                 {
@@ -131,12 +128,12 @@ int SvRTFParser::_GetNextToken()
                         // possible numeric parameter
                         if( RTF_ISDIGIT( nNextCh ) )
                         {
-                            nTokenValue = 0;
+                            OUStringBuffer aNumber;
                             do {
-                                nTokenValue *= 10;
-                                nTokenValue += nNextCh - '0';
+                                aNumber.append(static_cast<sal_Unicode>(nNextCh));
                                 nNextCh = GetNextChar();
                             } while( RTF_ISDIGIT( nNextCh ) );
+                            nTokenValue = aNumber.toString().toInt32();
                             if( bNegValue )
                                 nTokenValue = -nTokenValue;
                             bTokenHasValue=true;
@@ -162,9 +159,11 @@ int SvRTFParser::_GetNextToken()
                             if( 0 <= nTokenValue )
                             {
                                 nUCharOverread = (sal_uInt8)nTokenValue;
-                                //cmc: other ifdef breaks #i3584
-                                aParserStates.top().
-                                    nUCharOverread = nUCharOverread;
+                                if (!aParserStates.empty())
+                                {
+                                    //cmc: other ifdef breaks #i3584
+                                    aParserStates.top().nUCharOverread = nUCharOverread;
+                                }
                             }
                             aToken.clear(); // #i47831# erase token to prevent the token from being treated as text
                             // read next token
@@ -175,10 +174,10 @@ int SvRTFParser::_GetNextToken()
                             if (!_inSkipGroup) {
                             // UPR - overread the group with the ansi
                             //       information
-                            while( '{' != _GetNextToken() )
+                            while( '{' != GetNextToken_() )
                                 ;
                             SkipGroup();
-                            _GetNextToken();  // overread the last bracket
+                            GetNextToken_();  // overread the last bracket
                             nRet = 0;
                             }
                             break;
@@ -193,7 +192,7 @@ int SvRTFParser::_GetNextToken()
                                 // can be also \{, \}, \'88
                                 for( sal_uInt8 m = 0; m < nUCharOverread; ++m )
                                 {
-                                    sal_Unicode cAnsi = nNextCh;
+                                    sal_uInt32 cAnsi = nNextCh;
                                     while( 0xD == cAnsi )
                                         cAnsi = GetNextChar();
                                     while( 0xA == cAnsi )
@@ -211,10 +210,10 @@ int SvRTFParser::_GetNextToken()
                             break;
                         }
                     }
-                    else if( SVPAR_PENDING != eState )
+                    else if( SvParserState::Pending != eState )
                     {
                         // Bug 34631 - "\ " read on - Blank as character
-                        // eState = SVPAR_ERROR;
+                        // eState = SvParserState::Error;
                         bNextCh = false;
                     }
                     break;
@@ -223,7 +222,7 @@ int SvRTFParser::_GetNextToken()
             break;
 
         case sal_Unicode(EOF):
-            eState = SVPAR_ACCEPTED;
+            eState = SvParserState::Accepted;
             nRet = nNextCh;
             break;
 
@@ -281,7 +280,7 @@ int SvRTFParser::_GetNextToken()
         if( bNextCh )
             nNextCh = GetNextChar();
 
-    } while( !nRet && SVPAR_WORKING == eState );
+    } while( !nRet && SvParserState::Working == eState );
     return nRet;
 }
 
@@ -306,8 +305,9 @@ sal_Unicode SvRTFParser::GetHexValue()
     return nHexVal;
 }
 
-void SvRTFParser::ScanText( const sal_Unicode cBreak )
+void SvRTFParser::ScanText()
 {
+    const sal_Unicode cBreak = 0;
     OUStringBuffer aStrBuffer;
     bool bContinue = true;
     while( bContinue && IsParserWorking() && aStrBuffer.getLength() < MAX_STRING_LEN)
@@ -335,19 +335,25 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
                             aByteString.append(c);
 
                             bool bBreak = false;
+                            bool bEOF = false;
                             sal_Char nSlash = '\\';
                             while (!bBreak)
                             {
-                                wchar_t __next=GetNextChar();
-                                if (__next>0xFF) // fix for #i43933# and #i35653#
+                                auto next = GetNextChar();
+                                if (sal_Unicode(EOF) == next)
+                                {
+                                    bEOF = true;
+                                    break;
+                                }
+                                if (next>0xFF) // fix for #i43933# and #i35653#
                                 {
                                     if (!aByteString.isEmpty())
                                         aStrBuffer.append( OStringToOUString(aByteString.makeStringAndClear(), GetSrcEncoding()) );
-                                    aStrBuffer.append((sal_Unicode)__next);
+                                    aStrBuffer.append((sal_Unicode)next);
 
                                     continue;
                                 }
-                                nSlash = (sal_Char)__next;
+                                nSlash = (sal_Char)next;
                                 while (nSlash == 0xD || nSlash == 0xA)
                                     nSlash = (sal_Char)GetNextChar();
 
@@ -364,6 +370,12 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
                                 }
                             }
 
+                            if (bEOF)
+                            {
+                                bContinue = false;        // abort, string together
+                                break;
+                            }
+
                             nNextCh = GetNextChar();
 
                             if (nSlash != '\\' || nNextCh != '\'')
@@ -384,16 +396,16 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
                 case '}':
                 case '{':
                 case '+':       // I found in a RTF file
-                    aStrBuffer.append(nNextCh);
+                    aStrBuffer.append(sal_Unicode(nNextCh));
                     break;
                 case '~':       // nonbreaking space
-                    aStrBuffer.append(static_cast< sal_Unicode >(0xA0));
+                    aStrBuffer.append(u'\x00A0');
                     break;
                 case '-':       // optional hyphen
-                    aStrBuffer.append(static_cast< sal_Unicode >(0xAD));
+                    aStrBuffer.append(u'\x00AD');
                     break;
                 case '_':       // nonbreaking hyphen
-                    aStrBuffer.append(static_cast< sal_Unicode >(0x2011));
+                    aStrBuffer.append(u'\x2011');
                     break;
 
                 case 'u':
@@ -408,8 +420,8 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
 
                             OUString sSave( aToken );
                             nNextCh = '\\';
-                            int nToken = _GetNextToken();
-                            DBG_ASSERT( RTF_U == nToken, "doch kein UNI-Code Zeichen" );
+                            int nToken = GetNextToken_();
+                            DBG_ASSERT( RTF_U == nToken, "still not an UNI-Code character" );
                             // don't convert symbol chars
                             aStrBuffer.append(static_cast< sal_Unicode >(nTokenValue));
 
@@ -447,7 +459,8 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
                                     nNextCh = GetNextChar();
                                 } while ( RTF_ISDIGIT( nNextCh ) );
                                 nUCharOverread = nNewOverread;
-                                aParserStates.top().nUCharOverread = nNewOverread;
+                                if (!aParserStates.empty())
+                                    aParserStates.top().nUCharOverread = nNewOverread;
                             }
                             bNextCh = 0x20 == nNextCh;
                         }
@@ -468,8 +481,9 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
             }
             break;
 
-        case sal_Unicode(EOF): eState = SVPAR_ERROR;
-                // continue
+        case sal_Unicode(EOF):
+            eState = SvParserState::Error;
+            SAL_FALLTHROUGH;
         case '{':
         case '}':
             bContinue = false;
@@ -486,7 +500,7 @@ void SvRTFParser::ScanText( const sal_Unicode cBreak )
             {
                 do {
                     // all other characters end up in the text
-                    aStrBuffer.append(nNextCh);
+                    aStrBuffer.appendUtf32(nNextCh);
 
                     if (sal_Unicode(EOF) == (nNextCh = GetNextChar()))
                     {
@@ -535,7 +549,7 @@ _inSkipGroup++;
                 }
                 break;
         }
-        int nToken = _GetNextToken();
+        int nToken = GetNextToken_();
         if (nToken == RTF_BIN)
         {
             rInput.SeekRel(-1);
@@ -548,14 +562,13 @@ _inSkipGroup++;
         }
     } while (sal_Unicode(EOF) != nNextCh && IsParserWorking());
 
-    if( SVPAR_PENDING != eState && '}' != nNextCh )
-        eState = SVPAR_ERROR;
+    if( SvParserState::Pending != eState && '}' != nNextCh )
+        eState = SvParserState::Error;
     _inSkipGroup--;
 }
 
 void SvRTFParser::ReadUnknownData() { SkipGroup(); }
 void SvRTFParser::ReadBitmapData()  { SkipGroup(); }
-void SvRTFParser::ReadOLEData()     { SkipGroup(); }
 
 
 SvParserState SvRTFParser::CallParser()
@@ -563,21 +576,20 @@ SvParserState SvRTFParser::CallParser()
     sal_Char cFirstCh;
     nNextChPos = rInput.Tell();
     rInput.ReadChar( cFirstCh ); nNextCh = cFirstCh;
-    eState = SVPAR_WORKING;
+    eState = SvParserState::Working;
     nOpenBrakets = 0;
     SetSrcEncoding( eCodeSet = RTL_TEXTENCODING_MS_1252 );
-    eUNICodeSet = RTL_TEXTENCODING_MS_1252;     // default is ANSI-CodeSet
 
     // the first two tokens should be '{' and \\rtf !!
     if( '{' == GetNextToken() && RTF_RTF == GetNextToken() )
     {
         AddFirstRef();
         Continue( 0 );
-        if( SVPAR_PENDING != eState )
+        if( SvParserState::Pending != eState )
             ReleaseRef();       // now parser is not needed anymore
     }
     else
-        eState = SVPAR_ERROR;
+        eState = SvParserState::Error;
 
     return eState;
 }
@@ -598,7 +610,7 @@ void SvRTFParser::Continue( int nToken )
         case '}':
             if( nOpenBrakets )
                 goto NEXTTOKEN;
-            eState = SVPAR_ACCEPTED;
+            eState = SvParserState::Accepted;
             break;
 
         case '{':
@@ -614,7 +626,7 @@ void SvRTFParser::Continue( int nToken )
                     ReadUnknownData();
                     nToken = GetNextToken();
                     if( '}' != nToken )
-                        eState = SVPAR_ERROR;
+                        eState = SvParserState::Error;
                     break;      // move to next token!!
                 }
             }
@@ -649,8 +661,8 @@ NEXTTOKEN:
                                     // continue with new token!
         nToken = GetNextToken();
     }
-    if( SVPAR_ACCEPTED == eState && 0 < nOpenBrakets )
-        eState = SVPAR_ERROR;
+    if( SvParserState::Accepted == eState && 0 < nOpenBrakets )
+        eState = SvParserState::Error;
 }
 
 void SvRTFParser::SetEncoding( rtl_TextEncoding eEnc )
