@@ -17,25 +17,29 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <stdio.h>
 #include <svtools/svparser.hxx>
 #include <tools/stream.hxx>
 #include <tools/debug.hxx>
 #include <rtl/textcvt.h>
 #include <rtl/tencinfo.h>
+#include <rtl/character.hxx>
+
+#include <vector>
+#include <climits>
 
 // structure to store the actuel data
+template<typename T>
 struct SvParser_Impl
 {
     OUString        aToken;             // gescanntes Token
-    sal_uLong       nFilePos;           // actual position in stream
+    sal_uInt64      nFilePos;           // actual position in stream
     sal_uLong       nlLineNr;           // actual line number
     sal_uLong       nlLinePos;          // actual column number
     long            nTokenValue;        // extra value (RTF)
-    bool        bTokenHasValue;     // indicates whether nTokenValue is valid
-    int             nToken;             // actual Token
-    sal_Unicode     nNextCh;            // actual character
-    int             nSaveToken;         // the token from Continue
+    bool            bTokenHasValue;     // indicates whether nTokenValue is valid
+    T               nToken;             // actual Token
+    sal_uInt32      nNextCh;            // actual character
+    T               nSaveToken;         // the token from Continue
 
     rtl_TextToUnicodeConverter hConv;
     rtl_TextToUnicodeContext   hContext;
@@ -46,45 +50,53 @@ struct SvParser_Impl
         , nlLinePos(0)
         , nTokenValue(0)
         , bTokenHasValue(false)
-        , nToken(0)
+        , nToken(static_cast<T>(0))
         , nNextCh(0)
-        , nSaveToken(0)
-        , hConv( 0 )
-        , hContext( (rtl_TextToUnicodeContext)1 )
+        , nSaveToken(static_cast<T>(0))
+        , hConv( nullptr )
+        , hContext( reinterpret_cast<rtl_TextToUnicodeContext>(1) )
     {
     }
 
 };
 
 
+template<typename T>
+SvParser<T>::TokenStackType::TokenStackType()
+  : nTokenValue(0)
+    , bTokenHasValue(false)
+    , nTokenId(static_cast<T>(0))
+{
+}
 
-// Construktor
-SvParser::SvParser( SvStream& rIn, sal_uInt8 nStackSize )
+// Constructor
+template<typename T>
+SvParser<T>::SvParser( SvStream& rIn, sal_uInt8 nStackSize )
     : rInput( rIn )
     , nlLineNr( 1 )
     , nlLinePos( 1 )
-    , pImplData( 0 )
+    , pImplData( nullptr )
     , nTokenValue( 0 )
     , bTokenHasValue( false )
-    , eState( SVPAR_NOTSTARTED )
+    , eState( SvParserState::NotStarted )
     , eSrcEnc( RTL_TEXTENCODING_DONTKNOW )
     , nNextChPos(0)
     , nNextCh(0)
-    , bDownloadingFile(false)
     , bUCS2BSrcEnc(false)
     , bSwitchToUCS2(false)
     , bRTF_InTextRead(false)
     , nTokenStackSize( nStackSize )
     , nTokenStackPos( 0 )
 {
-    eState = SVPAR_NOTSTARTED;
+    eState = SvParserState::NotStarted;
     if( nTokenStackSize < 3 )
         nTokenStackSize = 3;
     pTokenStack = new TokenStackType[ nTokenStackSize ];
     pTokenStackPos = pTokenStack;
 }
 
-SvParser::~SvParser()
+template<typename T>
+SvParser<T>::~SvParser()
 {
     if( pImplData && pImplData->hConv )
     {
@@ -93,82 +105,101 @@ SvParser::~SvParser()
         rtl_destroyTextToUnicodeConverter( pImplData->hConv );
     }
 
-    delete pImplData;
-
     delete [] pTokenStack;
 }
 
-void SvParser::ClearTxtConvContext()
+template<typename T> SvParserState SvParser<T>::GetStatus() const { return eState; }
+template<typename T> sal_uLong  SvParser<T>::GetLineNr() const       { return nlLineNr; }
+template<typename T> sal_uLong  SvParser<T>::GetLinePos() const      { return nlLinePos; }
+template<typename T> void       SvParser<T>::IncLineNr()             { ++nlLineNr; }
+template<typename T> sal_uLong  SvParser<T>::IncLinePos()            { return ++nlLinePos; }
+template<typename T> void       SvParser<T>::SetLineNr( sal_uLong nlNum ) { nlLineNr = nlNum; }
+template<typename T> void       SvParser<T>::SetLinePos( sal_uLong nlPos ) {   nlLinePos = nlPos; }
+template<typename T> bool       SvParser<T>::IsParserWorking() const { return SvParserState::Working == eState; }
+template<typename T> rtl_TextEncoding SvParser<T>::GetSrcEncoding() const { return eSrcEnc; }
+template<typename T> void       SvParser<T>::SetSwitchToUCS2( bool bSet ) { bSwitchToUCS2 = bSet; }
+template<typename T> bool       SvParser<T>::IsSwitchToUCS2() const { return bSwitchToUCS2; }
+template<typename T> sal_uInt16 SvParser<T>::GetCharSize() const { return (RTL_TEXTENCODING_UCS2 == eSrcEnc) ? 2 : 1; }
+template<typename T> Link<LinkParamNone*,void> SvParser<T>::GetAsynchCallLink() const
+{
+    return LINK( const_cast<SvParser*>(this), SvParser, NewDataRead );
+}
+
+template<typename T>
+void SvParser<T>::ClearTxtConvContext()
 {
     if( pImplData && pImplData->hConv )
         rtl_resetTextToUnicodeContext( pImplData->hConv, pImplData->hContext );
 }
 
-void SvParser::SetSrcEncoding( rtl_TextEncoding eEnc )
+template<typename T>
+void SvParser<T>::SetSrcEncoding( rtl_TextEncoding eEnc )
 {
+    if( eEnc == eSrcEnc )
+        return;
 
-    if( eEnc != eSrcEnc )
+    if( pImplData && pImplData->hConv )
     {
-        if( pImplData && pImplData->hConv )
-        {
-            rtl_destroyTextToUnicodeContext( pImplData->hConv,
-                                             pImplData->hContext );
-            rtl_destroyTextToUnicodeConverter( pImplData->hConv );
-            pImplData->hConv = 0;
-            pImplData->hContext = (rtl_TextToUnicodeContext )1;
-        }
+        rtl_destroyTextToUnicodeContext( pImplData->hConv,
+                                         pImplData->hContext );
+        rtl_destroyTextToUnicodeConverter( pImplData->hConv );
+        pImplData->hConv = nullptr;
+        pImplData->hContext = reinterpret_cast<rtl_TextToUnicodeContext>(1);
+    }
 
-        if( rtl_isOctetTextEncoding(eEnc) ||
-            RTL_TEXTENCODING_UCS2 == eEnc  )
-        {
-            eSrcEnc = eEnc;
-            if( !pImplData )
-                pImplData = new SvParser_Impl;
-            pImplData->hConv = rtl_createTextToUnicodeConverter( eSrcEnc );
-            DBG_ASSERT( pImplData->hConv,
-                        "SvParser::SetSrcEncoding: no converter for source encoding" );
-            if( !pImplData->hConv )
-                eSrcEnc = RTL_TEXTENCODING_DONTKNOW;
-            else
-                pImplData->hContext =
-                    rtl_createTextToUnicodeContext( pImplData->hConv );
-        }
-        else
-        {
-            DBG_ASSERT( !this,
-                        "SvParser::SetSrcEncoding: invalid source encoding" );
+    if( rtl_isOctetTextEncoding(eEnc) ||
+        RTL_TEXTENCODING_UCS2 == eEnc  )
+    {
+        eSrcEnc = eEnc;
+        if( !pImplData )
+            pImplData.reset(new SvParser_Impl<T>);
+        pImplData->hConv = rtl_createTextToUnicodeConverter( eSrcEnc );
+        DBG_ASSERT( pImplData->hConv,
+                    "SvParser::SetSrcEncoding: no converter for source encoding" );
+        if( !pImplData->hConv )
             eSrcEnc = RTL_TEXTENCODING_DONTKNOW;
-        }
+        else
+            pImplData->hContext =
+                rtl_createTextToUnicodeContext( pImplData->hConv );
+    }
+    else
+    {
+        SAL_WARN( "svtools",
+                    "SvParser::SetSrcEncoding: invalid source encoding" );
+        eSrcEnc = RTL_TEXTENCODING_DONTKNOW;
     }
 }
 
-void SvParser::RereadLookahead()
+template<typename T>
+void SvParser<T>::RereadLookahead()
 {
     rInput.Seek(nNextChPos);
     nNextCh = GetNextChar();
 }
 
-sal_Unicode SvParser::GetNextChar()
+template<typename T>
+sal_uInt32 SvParser<T>::GetNextChar()
 {
-    sal_Unicode c = 0U;
+    sal_uInt32 c = 0U;
 
-    // When reading muliple bytes, we don't have to care about the file
-    // position when we run inti the pending state. The file position is
+    // When reading multiple bytes, we don't have to care about the file
+    // position when we run into the pending state. The file position is
     // maintained by SaveState/RestoreState.
     bool bErr;
     if( bSwitchToUCS2 && 0 == rInput.Tell() )
     {
-        unsigned char c1, c2;
+        unsigned char c1;
         bool bSeekBack = true;
 
         rInput.ReadUChar( c1 );
-        bErr = rInput.IsEof() || rInput.GetError();
+        bErr = !rInput.good();
         if( !bErr )
         {
             if( 0xff == c1 || 0xfe == c1 )
             {
+                unsigned char c2;
                 rInput.ReadUChar( c2 );
-                bErr = rInput.IsEof() || rInput.GetError();
+                bErr = !rInput.good();
                 if( !bErr )
                 {
                     if( 0xfe == c1 && 0xff == c2 )
@@ -187,18 +218,19 @@ sal_Unicode SvParser::GetNextChar()
             }
             else if( 0xef == c1 || 0xbb == c1 ) // check for UTF-8 BOM
             {
+                unsigned char c2;
                 rInput.ReadUChar( c2 );
-                bErr = rInput.IsEof() || rInput.GetError();
+                bErr = !rInput.good();
                 if( !bErr )
                 {
                     if( ( 0xef == c1 && 0xbb == c2 ) || ( 0xbb == c1 && 0xef == c2 ) )
                     {
                         unsigned char c3(0);
                         rInput.ReadUChar( c3 );
-                        bErr = rInput.IsEof() || rInput.GetError();
+                        bErr = !rInput.good();
                         if( !bErr && ( 0xbf == c3 ) )
                         {
-                            eSrcEnc = RTL_TEXTENCODING_UTF8;
+                            SetSrcEncoding(RTL_TEXTENCODING_UTF8);
                             bSeekBack = false;
                         }
                     }
@@ -219,13 +251,12 @@ sal_Unicode SvParser::GetNextChar()
         unsigned char c1, c2;
 
         rInput.ReadUChar( c1 ).ReadUChar( c2 );
-        if( 2 == rInput.Tell() &&
-            !(rInput.IsEof() || rInput.GetError()) &&
+        if( 2 == rInput.Tell() && rInput.good() &&
             ( (bUCS2BSrcEnc && 0xfe == c1 && 0xff == c2) ||
               (!bUCS2BSrcEnc && 0xff == c1 && 0xfe == c2) ) )
             rInput.ReadUChar( c1 ).ReadUChar( c2 );
 
-        bErr = rInput.IsEof() || rInput.GetError();
+        bErr = !rInput.good();
         if( !bErr )
         {
             if( bUCS2BSrcEnc )
@@ -246,7 +277,7 @@ sal_Unicode SvParser::GetNextChar()
         {
             sal_Char c1;    // signed, that's the text converter expects
             rInput.ReadChar( c1 );
-            bErr = rInput.IsEof() || rInput.GetError();
+            bErr = !rInput.good();
             if( !bErr )
             {
                 if (
@@ -254,14 +285,13 @@ sal_Unicode SvParser::GetNextChar()
                      RTL_TEXTENCODING_SYMBOL == eSrcEnc
                    )
                 {
-                    // no convserion shall take place
-                    c = (sal_Unicode)c1;
+                    // no conversion shall take place
+                    c = reinterpret_cast<sal_uChar&>( c1 );
                     nChars = 1;
                 }
                 else
                 {
-                    DBG_ASSERT( pImplData && pImplData->hConv,
-                                "no text converter!" );
+                    assert(pImplData && pImplData->hConv && "no text converter!");
 
                     sal_Unicode cUC;
                     sal_uInt32 nInfo = 0;
@@ -273,22 +303,23 @@ sal_Unicode SvParser::GetNextChar()
                                 RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_ERROR|
                                 RTL_TEXTTOUNICODE_FLAGS_INVALID_ERROR,
                                 &nInfo, &nCvtBytes);
-                    if( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL) != 0 )
+                    if( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL) != 0 )
                     {
                         // The conversion wasn't successful because we haven't
                         // read enough characters.
-                        if( pImplData->hContext != (rtl_TextToUnicodeContext)1 )
+                        if( pImplData->hContext != reinterpret_cast<rtl_TextToUnicodeContext>(1) )
                         {
-                            while( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL) != 0 )
+                            sal_Unicode sCh[2];
+                            while( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL) != 0 )
                             {
                                 rInput.ReadChar( c1 );
-                                bErr = rInput.IsEof() || rInput.GetError();
+                                bErr = !rInput.good();
                                 if( bErr )
                                     break;
 
                                 nChars = rtl_convertTextToUnicode(
                                             pImplData->hConv, pImplData->hContext,
-                                            &c1, 1, &cUC, 1,
+                                            &c1, 1, sCh , 2,
                                             RTL_TEXTTOUNICODE_FLAGS_UNDEFINED_ERROR|
                                             RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_ERROR|
                                             RTL_TEXTTOUNICODE_FLAGS_INVALID_ERROR,
@@ -298,19 +329,23 @@ sal_Unicode SvParser::GetNextChar()
                             {
                                 if( 1 == nChars && 0 == nInfo )
                                 {
-                                    c = cUC;
+                                    c = sal_uInt32( sCh[0] );
+                                }
+                                else if( 2 == nChars && 0 == nInfo )
+                                {
+                                    c = rtl::combineSurrogates( sCh[0], sCh[1] );
                                 }
                                 else if( 0 != nChars || 0 != nInfo )
                                 {
-                                    DBG_ASSERT( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL) == 0,
+                                    DBG_ASSERT( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL) == 0,
                                         "source buffer is to small" );
-                                    DBG_ASSERT( (nInfo&~(RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL)) == 0,
+                                    DBG_ASSERT( (nInfo&~(RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL)) == 0,
                                          "there is a conversion error" );
                                     DBG_ASSERT( 0 == nChars,
                                        "there is a converted character, but an error" );
                                     // There are still errors, but nothing we can
                                     // do
-                                    c = (sal_Unicode)'?';
+                                    c = '?';
                                     nChars = 1;
                                 }
                             }
@@ -320,17 +355,17 @@ sal_Unicode SvParser::GetNextChar()
                             sal_Char sBuffer[10];
                             sBuffer[0] = c1;
                             sal_uInt16 nLen = 1;
-                            while( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL) != 0 &&
+                            while( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL) != 0 &&
                                     nLen < 10 )
                             {
                                 rInput.ReadChar( c1 );
-                                bErr = rInput.IsEof() || rInput.GetError();
+                                bErr = !rInput.good();
                                 if( bErr )
                                     break;
 
                                 sBuffer[nLen++] = c1;
                                 nChars = rtl_convertTextToUnicode(
-                                            pImplData->hConv, 0, sBuffer, nLen, &cUC, 1,
+                                            pImplData->hConv, nullptr, sBuffer, nLen, &cUC, 1,
                                             RTL_TEXTTOUNICODE_FLAGS_UNDEFINED_ERROR|
                                             RTL_TEXTTOUNICODE_FLAGS_MBUNDEFINED_ERROR|
                                             RTL_TEXTTOUNICODE_FLAGS_INVALID_ERROR,
@@ -346,16 +381,16 @@ sal_Unicode SvParser::GetNextChar()
                                 }
                                 else
                                 {
-                                    DBG_ASSERT( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL) == 0,
+                                    DBG_ASSERT( (nInfo&RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL) == 0,
                                         "source buffer is to small" );
-                                    DBG_ASSERT( (nInfo&~(RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOSMALL)) == 0,
+                                    DBG_ASSERT( (nInfo&~(RTL_TEXTTOUNICODE_INFO_SRCBUFFERTOOSMALL)) == 0,
                                          "there is a conversion error" );
                                     DBG_ASSERT( 0 == nChars,
                                        "there is a converted character, but an error" );
 
                                     // There are still errors, so we use the first
                                     // character and restart after that.
-                                    c = (sal_Unicode)sBuffer[0];
+                                    c = reinterpret_cast<sal_uChar&>( sBuffer[0] );
                                     rInput.SeekRel( -(nLen-1) );
                                     nChars = 1;
                                 }
@@ -377,7 +412,7 @@ sal_Unicode SvParser::GetNextChar()
                                 "there is no converted character and no error" );
                         // #73398#: If the character could not be converted,
                         // because a conversion is not available, do no conversion at all.
-                        c = (sal_Unicode)c1;
+                        c = reinterpret_cast<sal_uChar&>( c1 );
                         nChars = 1;
 
                     }
@@ -386,11 +421,15 @@ sal_Unicode SvParser::GetNextChar()
         }
         while( 0 == nChars  && !bErr );
     }
+
+    if ( ! rtl::isUnicodeScalarValue( c ) )
+        c = '?' ;
+
     if( bErr )
     {
         if( ERRCODE_IO_PENDING == rInput.GetError() )
         {
-            eState = SVPAR_PENDING;
+            eState = SvParserState::Pending;
             return c;
         }
         else
@@ -400,25 +439,27 @@ sal_Unicode SvParser::GetNextChar()
     if( c == '\n' )
     {
         IncLineNr();
-        SetLinePos( 1L );
+        SetLinePos( 1 );
     }
     else
         IncLinePos();
+
     return c;
 }
 
-int SvParser::GetNextToken()
+template<typename T>
+T SvParser<T>::GetNextToken()
 {
-    int nRet = 0;
+    T nRet = static_cast<T>(0);
 
     if( !nTokenStackPos )
     {
-        aToken = "";     // empty token buffer
+        aToken.clear();     // empty token buffer
         nTokenValue = -1;   // marker for no value read
         bTokenHasValue = false;
 
-        nRet = _GetNextToken();
-        if( SVPAR_PENDING == eState )
+        nRet = GetNextToken_();
+        if( SvParserState::Pending == eState )
             return nRet;
     }
 
@@ -436,20 +477,21 @@ int SvParser::GetNextToken()
         nRet = pTokenStackPos->nTokenId;
     }
     // no, now push actual value on stack
-    else if( SVPAR_WORKING == eState )
+    else if( SvParserState::Working == eState )
     {
         pTokenStackPos->sToken = aToken;
         pTokenStackPos->nTokenValue = nTokenValue;
         pTokenStackPos->bTokenHasValue = bTokenHasValue;
         pTokenStackPos->nTokenId = nRet;
     }
-    else if( SVPAR_ACCEPTED != eState && SVPAR_PENDING != eState )
-        eState = SVPAR_ERROR;       // an error occurred
+    else if( SvParserState::Accepted != eState && SvParserState::Pending != eState )
+        eState = SvParserState::Error;       // an error occurred
 
     return nRet;
 }
 
-int SvParser::SkipToken( short nCnt )       // "skip" n Tokens backward
+template<typename T>
+T SvParser<T>::SkipToken( short nCnt )       // "skip" n Tokens backward
 {
     pTokenStackPos = GetStackPtr( nCnt );
     short nTmp = nTokenStackPos - nCnt;
@@ -467,7 +509,8 @@ int SvParser::SkipToken( short nCnt )       // "skip" n Tokens backward
     return pTokenStackPos->nTokenId;
 }
 
-SvParser::TokenStackType* SvParser::GetStackPtr( short nCnt )
+template<typename T>
+typename SvParser<T>::TokenStackType* SvParser<T>::GetStackPtr( short nCnt )
 {
     sal_uInt8 nAktPos = sal_uInt8(pTokenStackPos - pTokenStack );
     if( nCnt > 0 )
@@ -494,25 +537,28 @@ SvParser::TokenStackType* SvParser::GetStackPtr( short nCnt )
 }
 
 // is called for each token which is recognised by CallParser
-void SvParser::NextToken( int )
+template<typename T>
+void SvParser<T>::NextToken( T )
 {
 }
 
 
 // to read asynchronous from SvStream
 
-int SvParser::GetSaveToken() const
+template<typename T>
+T SvParser<T>::GetSaveToken() const
 {
-    return pImplData ? pImplData->nSaveToken : 0;
+    return pImplData ? pImplData->nSaveToken : static_cast<T>(0);
 }
 
-void SvParser::SaveState( int nToken )
+template<typename T>
+void SvParser<T>::SaveState( T nToken )
 {
     // save actual status
     if( !pImplData )
     {
-        pImplData = new SvParser_Impl;
-        pImplData->nSaveToken = 0;
+        pImplData.reset(new SvParser_Impl<T>);
+        pImplData->nSaveToken = static_cast<T>(0);
     }
 
     pImplData->nFilePos = rInput.Tell();
@@ -526,33 +572,35 @@ void SvParser::SaveState( int nToken )
     pImplData->nNextCh = nNextCh;
 }
 
-void SvParser::RestoreState()
+template<typename T>
+void SvParser<T>::RestoreState()
 {
     // restore old status
-    if( pImplData )
-    {
-        if( ERRCODE_IO_PENDING == rInput.GetError() )
-            rInput.ResetError();
-        aToken = pImplData->aToken;
-        nlLineNr = pImplData->nlLineNr;
-        nlLinePos = pImplData->nlLinePos;
-        nTokenValue= pImplData->nTokenValue;
-        bTokenHasValue=pImplData->bTokenHasValue;
-        nNextCh = pImplData->nNextCh;
+    if( !pImplData )
+        return;
 
-        pImplData->nSaveToken = pImplData->nToken;
+    if( ERRCODE_IO_PENDING == rInput.GetError() )
+        rInput.ResetError();
+    aToken = pImplData->aToken;
+    nlLineNr = pImplData->nlLineNr;
+    nlLinePos = pImplData->nlLinePos;
+    nTokenValue= pImplData->nTokenValue;
+    bTokenHasValue=pImplData->bTokenHasValue;
+    nNextCh = pImplData->nNextCh;
 
-        rInput.Seek( pImplData->nFilePos );
-    }
+    pImplData->nSaveToken = pImplData->nToken;
+
+    rInput.Seek( pImplData->nFilePos );
 }
 
-void SvParser::Continue( int )
+template<typename T>
+void SvParser<T>::Continue( T )
 {
 }
 
-void SvParser::BuildWhichTbl( std::vector<sal_uInt16> &rWhichMap,
-                              sal_uInt16 *pWhichIds,
-                              sal_uInt16 nWhichIds )
+void BuildWhichTable( std::vector<sal_uInt16> &rWhichMap,
+                      sal_uInt16 *pWhichIds,
+                      sal_uInt16 nWhichIds )
 {
     sal_uInt16 aNewRange[2];
 
@@ -606,84 +654,75 @@ void SvParser::BuildWhichTbl( std::vector<sal_uInt16> &rWhichMap,
 }
 
 
-IMPL_STATIC_LINK( SvParser, NewDataRead, void*, EMPTYARG )
+// expanded out version of
+//   IMPL_LINK_NOARG( SvParser, NewDataRead, LinkParamNone*, void )
+// since it can't cope with template methods
+template<typename T>
+void SvParser<T>::LinkStubNewDataRead(void * instance, LinkParamNone* data) {
+    return static_cast<SvParser<T> *>(instance)->NewDataRead(data);
+}
+template<typename T>
+void SvParser<T>::NewDataRead(SAL_UNUSED_PARAMETER LinkParamNone*)
 {
-    switch( pThis->eState )
+    switch( eState )
     {
-    case SVPAR_PENDING:
-        // if file is loaded we are not allowed to continue
-        // instead should ignore the call.
-        if( pThis->IsDownloadingFile() )
-            break;
+    case SvParserState::Pending:
+        eState = SvParserState::Working;
+        RestoreState();
 
-        pThis->eState = SVPAR_WORKING;
-        pThis->RestoreState();
+        Continue( pImplData->nToken );
 
-        pThis->Continue( pThis->pImplData->nToken );
+        if( ERRCODE_IO_PENDING == rInput.GetError() )
+            rInput.ResetError();
 
-        if( ERRCODE_IO_PENDING == pThis->rInput.GetError() )
-            pThis->rInput.ResetError();
-
-        if( SVPAR_PENDING != pThis->eState )
-            pThis->ReleaseRef();                    // ready otherwise!
+        if( SvParserState::Pending != eState )
+            ReleaseRef();                    // ready otherwise!
         break;
 
-    case SVPAR_WAITFORDATA:
-        pThis->eState = SVPAR_WORKING;
-        break;
-
-    case SVPAR_NOTSTARTED:
-    case SVPAR_WORKING:
+    case SvParserState::NotStarted:
+    case SvParserState::Working:
         break;
 
     default:
-        pThis->ReleaseRef();                    // ready otherwise!
+        ReleaseRef();                    // ready otherwise!
         break;
     }
-
-    return 0;
 }
 
+template class SVT_DLLPUBLIC SvParser<int>;
+template class SVT_DLLPUBLIC SvParser<HtmlTokenId>;
+
 /*========================================================================
  *
  * SvKeyValueIterator.
  *
  *======================================================================*/
 
-/*
- * SvKeyValueIterator.
- */
-SvKeyValueIterator::SvKeyValueIterator (void)
-    : m_pList (new SvKeyValueList_Impl),
-      m_nPos  (0)
-{
-}
+typedef std::vector<SvKeyValue> SvKeyValueList_Impl;
 
-/*
- * ~SvKeyValueIterator.
- */
-SvKeyValueIterator::~SvKeyValueIterator (void)
+struct SvKeyValueIterator::Impl
 {
-    delete m_pList;
-}
+    SvKeyValueList_Impl maList;
+    sal_uInt16 mnPos;
+
+    Impl() : mnPos(0) {}
+};
+
+SvKeyValueIterator::SvKeyValueIterator() : mpImpl(new Impl) {}
+
+SvKeyValueIterator::~SvKeyValueIterator() = default;
 
-/*
- * GetFirst.
- */
 bool SvKeyValueIterator::GetFirst (SvKeyValue &rKeyVal)
 {
-    m_nPos = m_pList->size();
+    mpImpl->mnPos = mpImpl->maList.size();
     return GetNext (rKeyVal);
 }
 
-/*
- * GetNext.
- */
 bool SvKeyValueIterator::GetNext (SvKeyValue &rKeyVal)
 {
-    if (m_nPos > 0)
+    if (mpImpl->mnPos > 0)
     {
-        rKeyVal = (*m_pList)[--m_nPos];
+        rKeyVal = mpImpl->maList[--mpImpl->mnPos];
         return true;
     }
     else
@@ -693,12 +732,9 @@ bool SvKeyValueIterator::GetNext (SvKeyValue &rKeyVal)
     }
 }
 
-/*
- * Append.
- */
 void SvKeyValueIterator::Append (const SvKeyValue &rKeyVal)
 {
-    m_pList->push_back(new SvKeyValue(rKeyVal));
+    mpImpl->maList.push_back(rKeyVal);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
