@@ -20,52 +20,43 @@
 #include "unocontroltablemodel.hxx"
 #include "unogridcolumnfacade.hxx"
 
-#include "svtools/table/defaultinputhandler.hxx"
-#include "svtools/table/gridtablerenderer.hxx"
-#include "svtools/table/tablecontrol.hxx"
+#include <table/defaultinputhandler.hxx>
+#include <table/gridtablerenderer.hxx>
+#include <table/tablecontrol.hxx>
 
 #include <com/sun/star/awt/grid/XGridColumn.hpp>
 #include <com/sun/star/view/SelectionType.hpp>
-#include <com/sun/star/awt/grid/XGridColumnListener.hpp>
 #include <com/sun/star/awt/grid/XSortableGridData.hpp>
 
 #include <cppuhelper/weakref.hxx>
 #include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
 #include <vcl/svapp.hxx>
-#include <osl/mutex.hxx>
 
-// .....................................................................................................................
+
 namespace svt { namespace table
 {
-// .....................................................................................................................
 
-    using ::com::sun::star::uno::Reference;
-    using ::com::sun::star::uno::RuntimeException;
-    using ::com::sun::star::uno::Sequence;
-    using ::com::sun::star::uno::UNO_QUERY_THROW;
-    using ::com::sun::star::uno::UNO_QUERY;
-    using ::com::sun::star::awt::grid::XGridColumn;
-    using ::com::sun::star::uno::XInterface;
-    using ::com::sun::star::uno::Exception;
-    using ::com::sun::star::awt::grid::XGridColumnListener;
-    using ::com::sun::star::lang::EventObject;
-    using ::com::sun::star::awt::grid::GridColumnEvent;
-    using ::com::sun::star::awt::grid::XGridDataModel;
-    using ::com::sun::star::awt::grid::XGridColumnModel;
-    using ::com::sun::star::uno::Any;
-    using ::com::sun::star::style::HorizontalAlignment_LEFT;
-    using ::com::sun::star::style::HorizontalAlignment;
-    using ::com::sun::star::style::VerticalAlignment_TOP;
-    using ::com::sun::star::style::VerticalAlignment;
-    using ::com::sun::star::uno::WeakReference;
-    using ::com::sun::star::awt::grid::GridDataEvent;
-    using ::com::sun::star::awt::grid::XSortableGridData;
-    using ::com::sun::star::beans::Pair;
 
-    //==================================================================================================================
+    using css::uno::Reference;
+    using css::uno::Sequence;
+    using css::uno::UNO_QUERY_THROW;
+    using css::uno::UNO_QUERY;
+    using css::awt::grid::XGridColumn;
+    using css::uno::Exception;
+    using css::awt::grid::XGridDataModel;
+    using css::awt::grid::XGridColumnModel;
+    using css::uno::Any;
+    using css::style::VerticalAlignment_TOP;
+    using css::style::VerticalAlignment;
+    using css::uno::WeakReference;
+    using css::awt::grid::GridDataEvent;
+    using css::awt::grid::XSortableGridData;
+    using css::beans::Pair;
+
+
     //= UnoControlTableModel_Impl
-    //==================================================================================================================
+
     typedef ::std::vector< PTableModelListener >    ModellListeners;
     typedef ::std::vector< PColumnModel >           ColumnModels;
     struct UnoControlTableModel_Impl
@@ -91,6 +82,7 @@ namespace svt { namespace table
         ::boost::optional< ::Color >                    m_aTextLineColor;
         ::boost::optional< ::std::vector< ::Color > >   m_aRowColors;
         VerticalAlignment                               m_eVerticalAlign;
+        bool                                            bEnabled;
         ModellListeners                                 m_aListeners;
         WeakReference< XGridDataModel >                 m_aDataModel;
         WeakReference< XGridColumnModel >               m_aColumnModel;
@@ -117,63 +109,38 @@ namespace svt { namespace table
             ,m_aTextLineColor               ( )
             ,m_aRowColors                   ( )
             ,m_eVerticalAlign               ( VerticalAlignment_TOP )
+            ,bEnabled                       ( true )
         {
         }
     };
 
-    //==================================================================================================================
     //= UnoControlTableModel
-    //==================================================================================================================
-#ifdef DBG_UTIL
-    const char* UnoControlTableModel_checkInvariants( const void* _pInstance )
-    {
-        return static_cast< const UnoControlTableModel* >( _pInstance )->checkInvariants();
-    }
-
-    //------------------------------------------------------------------------------------------------------------------
-    const char* UnoControlTableModel::checkInvariants() const
-    {
-        Reference< XGridDataModel > const xDataModel( m_pImpl->m_aDataModel );
-        if ( !xDataModel.is() )
-            return "data model anymore";
-
-        // TODO: more?
-
-        return NULL;
-    }
-#endif
-
 #define DBG_CHECK_ME() \
     DBG_TESTSOLARMUTEX(); \
-    DBG_CHKTHIS( UnoControlTableModel, UnoControlTableModel_checkInvariants )
 
-    //------------------------------------------------------------------------------------------------------------------
-    DBG_NAME( UnoControlTableModel )
     UnoControlTableModel::UnoControlTableModel()
         :m_pImpl( new UnoControlTableModel_Impl )
     {
-        DBG_CTOR( UnoControlTableModel, UnoControlTableModel_checkInvariants );
         m_pImpl->bHasColumnHeaders = true;
         m_pImpl->bHasRowHeaders = false;
+        m_pImpl->bEnabled = true;
         m_pImpl->pRenderer.reset( new GridTableRenderer( *this ) );
         m_pImpl->pInputHandler.reset( new DefaultInputHandler );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     UnoControlTableModel::~UnoControlTableModel()
     {
-        DBG_DTOR( UnoControlTableModel, UnoControlTableModel_checkInvariants );
-        DELETEZ( m_pImpl );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     TableSize UnoControlTableModel::getColumnCount() const
     {
         DBG_CHECK_ME();
         return (TableSize)m_pImpl->aColumns.size();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     TableSize UnoControlTableModel::getRowCount() const
     {
         DBG_CHECK_ME();
@@ -192,21 +159,21 @@ namespace svt { namespace table
         return nRowCount;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     bool UnoControlTableModel::hasColumnHeaders() const
     {
         DBG_CHECK_ME();
         return m_pImpl->bHasColumnHeaders;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     bool UnoControlTableModel::hasRowHeaders() const
     {
         DBG_CHECK_ME();
         return m_pImpl->bHasRowHeaders;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setRowHeaders(bool _bRowHeaders)
     {
         DBG_CHECK_ME();
@@ -217,7 +184,7 @@ namespace svt { namespace table
         impl_notifyTableMetricsChanged();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setColumnHeaders(bool _bColumnHeaders)
     {
         DBG_CHECK_ME();
@@ -228,16 +195,7 @@ namespace svt { namespace table
         impl_notifyTableMetricsChanged();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    bool UnoControlTableModel::isCellEditable( ColPos col, RowPos row ) const
-    {
-        DBG_CHECK_ME();
-        (void)col;
-        (void)row;
-        return false;
-    }
 
-    //------------------------------------------------------------------------------------------------------------------
     PColumnModel UnoControlTableModel::getColumnModel( ColPos column )
     {
         DBG_CHECK_ME();
@@ -246,14 +204,14 @@ namespace svt { namespace table
         return m_pImpl->aColumns[ column ];
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::appendColumn( Reference< XGridColumn > const & i_column )
     {
         DBG_CHECK_ME();
         insertColumn( m_pImpl->aColumns.size(), i_column );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::insertColumn( ColPos const i_position, Reference< XGridColumn > const & i_column )
     {
         DBG_CHECK_ME();
@@ -270,11 +228,11 @@ namespace svt { namespace table
                 ++loop
             )
         {
-            (*loop)->columnInserted( i_position );
+            (*loop)->columnInserted();
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::removeColumn( ColPos const i_position )
     {
         DBG_CHECK_ME();
@@ -293,17 +251,17 @@ namespace svt { namespace table
                 ++loop
             )
         {
-            (*loop)->columnRemoved( i_position );
+            (*loop)->columnRemoved();
         }
 
         // dispose the column
         UnoGridColumnFacade* pColumnImpl = dynamic_cast< UnoGridColumnFacade* >( pColumn.get() );
-        OSL_ENSURE( pColumnImpl != NULL, "UnoControlTableModel::removeColumn: illegal column implementation!" );
+        OSL_ENSURE( pColumnImpl != nullptr, "UnoControlTableModel::removeColumn: illegal column implementation!" );
         if ( pColumnImpl )
             pColumnImpl->dispose();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::removeAllColumns()
     {
         DBG_CHECK_ME();
@@ -338,7 +296,7 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::impl_notifyTableMetricsChanged() const
     {
         ModellListeners aListeners( m_pImpl->m_aListeners );
@@ -351,28 +309,28 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     PTableRenderer UnoControlTableModel::getRenderer() const
     {
         DBG_CHECK_ME();
         return m_pImpl->pRenderer;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     PTableInputHandler UnoControlTableModel::getInputHandler() const
     {
         DBG_CHECK_ME();
         return m_pImpl->pInputHandler;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     TableMetrics UnoControlTableModel::getRowHeight() const
     {
         DBG_CHECK_ME();
         return m_pImpl->nRowHeight;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setRowHeight(TableMetrics _nRowHeight)
     {
         DBG_CHECK_ME();
@@ -383,7 +341,7 @@ namespace svt { namespace table
         impl_notifyTableMetricsChanged();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     TableMetrics UnoControlTableModel::getColumnHeaderHeight() const
     {
         DBG_CHECK_ME();
@@ -391,14 +349,14 @@ namespace svt { namespace table
         return m_pImpl->nColumnHeaderHeight;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     TableMetrics UnoControlTableModel::getRowHeaderWidth() const
     {
         DBG_CHECK_ME();
         DBG_ASSERT( hasRowHeaders(), "DefaultTableModel::getRowHeaderWidth: invalid call!" );
         return m_pImpl->nRowHeaderWidth;
     }
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setColumnHeaderHeight(TableMetrics _nHeight)
     {
         DBG_CHECK_ME();
@@ -409,7 +367,7 @@ namespace svt { namespace table
         impl_notifyTableMetricsChanged();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setRowHeaderWidth(TableMetrics _nWidth)
     {
         DBG_CHECK_ME();
@@ -420,21 +378,21 @@ namespace svt { namespace table
         impl_notifyTableMetricsChanged();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ScrollbarVisibility UnoControlTableModel::getVerticalScrollbarVisibility() const
     {
         DBG_CHECK_ME();
         return m_pImpl->eVScrollMode;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ScrollbarVisibility UnoControlTableModel::getHorizontalScrollbarVisibility() const
     {
         DBG_CHECK_ME();
         return m_pImpl->eHScrollMode;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::addTableModelListener( const PTableModelListener& i_listener )
     {
         DBG_CHECK_ME();
@@ -442,7 +400,7 @@ namespace svt { namespace table
         m_pImpl->m_aListeners.push_back( i_listener );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::removeTableModelListener( const PTableModelListener& i_listener )
     {
         DBG_CHECK_ME();
@@ -460,21 +418,21 @@ namespace svt { namespace table
         OSL_ENSURE( false, "UnoControlTableModel::removeTableModelListener: listener is not registered - sure you're doing the right thing here?" );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setVerticalScrollbarVisibility( ScrollbarVisibility const i_visibility ) const
     {
         DBG_CHECK_ME();
         m_pImpl->eVScrollMode = i_visibility;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setHorizontalScrollbarVisibility( ScrollbarVisibility const i_visibility ) const
     {
         DBG_CHECK_ME();
         m_pImpl->eHScrollMode = i_visibility;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setDataModel( Reference< XGridDataModel > const & i_gridDataModel )
     {
         DBG_CHECK_ME();
@@ -483,40 +441,40 @@ namespace svt { namespace table
         // own listeners
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     Reference< XGridDataModel > UnoControlTableModel::getDataModel() const
     {
         Reference< XGridDataModel > const xDataModel( m_pImpl->m_aDataModel );
         return xDataModel;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     bool UnoControlTableModel::hasDataModel() const
     {
         return getDataModel().is();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setColumnModel( Reference< XGridColumnModel > const & i_gridColumnModel )
     {
         DBG_CHECK_ME();
         m_pImpl->m_aColumnModel = i_gridColumnModel;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     Reference< XGridColumnModel > UnoControlTableModel::getColumnModel() const
     {
         Reference< XGridColumnModel > const xColumnModel( m_pImpl->m_aColumnModel );
         return xColumnModel;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     bool UnoControlTableModel::hasColumnModel() const
     {
         return getColumnModel().is();
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::getCellContent( ColPos const i_col, RowPos const i_row, Any& o_cellContent )
     {
         DBG_CHECK_ME();
@@ -529,7 +487,7 @@ namespace svt { namespace table
 
             PColumnModel const pColumn = getColumnModel( i_col );
             UnoGridColumnFacade* pColumnImpl = dynamic_cast< UnoGridColumnFacade* >( pColumn.get() );
-            ENSURE_OR_RETURN_VOID( pColumnImpl != NULL, "UnoControlTableModel::getCellContent: no (valid) column at this position!" );
+            ENSURE_OR_RETURN_VOID( pColumnImpl != nullptr, "UnoControlTableModel::getCellContent: no (valid) column at this position!" );
             sal_Int32 const nDataColumnIndex = pColumnImpl->getDataColumnIndex() >= 0 ? pColumnImpl->getDataColumnIndex() : i_col;
 
             if ( nDataColumnIndex >= xDataModel->getColumnCount() )
@@ -538,11 +496,9 @@ namespace svt { namespace table
                 // not (yet?) know about it.
                 // So, handle it gracefully.
             #if OSL_DEBUG_LEVEL > 0
-                {
-                    Reference< XGridColumnModel > const xColumnModel( m_pImpl->m_aColumnModel );
-                    OSL_ENSURE( xColumnModel.is() && i_col < xColumnModel->getColumnCount(),
-                        "UnoControlTableModel::getCellContent: request a column's value which the ColumnModel doesn't know about!" );
-                }
+                Reference< XGridColumnModel > const xColumnModel( m_pImpl->m_aColumnModel );
+                OSL_ENSURE( xColumnModel.is() && i_col < xColumnModel->getColumnCount(),
+                    "UnoControlTableModel::getCellContent: request a column's value which the ColumnModel doesn't know about!" );
             #endif
             }
             else
@@ -556,7 +512,7 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::getCellToolTip( ColPos const i_col, RowPos const i_row, Any& o_cellToolTip )
     {
         DBG_CHECK_ME();
@@ -573,7 +529,7 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     Any UnoControlTableModel::getRowHeading( RowPos const i_rowPos ) const
     {
         DBG_CHECK_ME();
@@ -594,7 +550,7 @@ namespace svt { namespace table
         return aRowHeading;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     namespace
     {
         void lcl_setColor( Any const & i_color, ::boost::optional< ::Color > & o_convertedColor )
@@ -616,144 +572,144 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::Color > UnoControlTableModel::getLineColor() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aGridLineColor;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setLineColor( Any const & i_color )
     {
         DBG_CHECK_ME();
         lcl_setColor( i_color, m_pImpl->m_aGridLineColor );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::Color > UnoControlTableModel::getHeaderBackgroundColor() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aHeaderBackgroundColor;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setHeaderBackgroundColor( Any const & i_color )
     {
         DBG_CHECK_ME();
         lcl_setColor( i_color, m_pImpl->m_aHeaderBackgroundColor );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::Color > UnoControlTableModel::getHeaderTextColor() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aHeaderTextColor;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::Color > UnoControlTableModel::getActiveSelectionBackColor() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aActiveSelectionBackColor;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::Color > UnoControlTableModel::getInactiveSelectionBackColor() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aInactiveSelectionBackColor;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::Color > UnoControlTableModel::getActiveSelectionTextColor() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aActiveSelectionTextColor;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::Color > UnoControlTableModel::getInactiveSelectionTextColor() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aInactiveSelectionTextColor;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setHeaderTextColor( Any const & i_color )
     {
         DBG_CHECK_ME();
         lcl_setColor( i_color, m_pImpl->m_aHeaderTextColor );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setActiveSelectionBackColor( Any const & i_color )
     {
         DBG_CHECK_ME();
         lcl_setColor( i_color, m_pImpl->m_aActiveSelectionBackColor );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setInactiveSelectionBackColor( Any const & i_color )
     {
         DBG_CHECK_ME();
         lcl_setColor( i_color, m_pImpl->m_aInactiveSelectionBackColor );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setActiveSelectionTextColor( Any const & i_color )
     {
         DBG_CHECK_ME();
         lcl_setColor( i_color, m_pImpl->m_aActiveSelectionTextColor );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setInactiveSelectionTextColor( Any const & i_color )
     {
         DBG_CHECK_ME();
         lcl_setColor( i_color, m_pImpl->m_aInactiveSelectionTextColor );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::Color > UnoControlTableModel::getTextColor() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aTextColor;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setTextColor( Any const & i_color )
     {
         DBG_CHECK_ME();
         lcl_setColor( i_color, m_pImpl->m_aTextColor );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::Color > UnoControlTableModel::getTextLineColor() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aTextColor;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setTextLineColor( Any const & i_color )
     {
         DBG_CHECK_ME();
         lcl_setColor( i_color, m_pImpl->m_aTextLineColor );
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ::boost::optional< ::std::vector< ::Color > > UnoControlTableModel::getRowBackgroundColors() const
     {
         DBG_CHECK_ME();
         return m_pImpl->m_aRowColors;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    void UnoControlTableModel::setRowBackgroundColors( ::com::sun::star::uno::Any const & i_APIValue )
+
+    void UnoControlTableModel::setRowBackgroundColors( css::uno::Any const & i_APIValue )
     {
         DBG_CHECK_ME();
-        Sequence< ::com::sun::star::util::Color > aAPIColors;
+        Sequence< css::util::Color > aAPIColors;
         if ( !( i_APIValue >>= aAPIColors ) )
             m_pImpl->m_aRowColors.reset();
         else
@@ -767,21 +723,21 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     VerticalAlignment UnoControlTableModel::getVerticalAlign() const
     {
         DBG_CHECK_ME();
         return  m_pImpl->m_eVerticalAlign;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::setVerticalAlign( VerticalAlignment _xAlign )
     {
         DBG_CHECK_ME();
         m_pImpl->m_eVerticalAlign = _xAlign;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ColPos UnoControlTableModel::getColumnPos( UnoGridColumnFacade const & i_column ) const
     {
         DBG_CHECK_ME();
@@ -797,7 +753,7 @@ namespace svt { namespace table
         return COL_INVALID;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ITableDataSort* UnoControlTableModel::getSortAdapter()
     {
         DBG_CHECK_ME();
@@ -805,10 +761,24 @@ namespace svt { namespace table
         Reference< XSortableGridData > const xSortAccess( getDataModel(), UNO_QUERY );
         if ( xSortAccess.is() )
             return this;
-        return NULL;
+        return nullptr;
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
+    bool UnoControlTableModel::isEnabled() const
+    {
+        DBG_CHECK_ME();
+        return m_pImpl->bEnabled;
+    }
+
+
+    void UnoControlTableModel::setEnabled( bool _bEnabled )
+    {
+        DBG_CHECK_ME();
+        m_pImpl->bEnabled = _bEnabled;
+    }
+
+
     void UnoControlTableModel::sortByColumn( ColPos const i_column, ColumnSortDirection const i_sortDirection )
     {
         DBG_CHECK_ME();
@@ -824,7 +794,7 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     ColumnSort UnoControlTableModel::getCurrentSortOrder() const
     {
         DBG_CHECK_ME();
@@ -833,7 +803,7 @@ namespace svt { namespace table
         try
         {
             Reference< XSortableGridData > const xSortAccess( getDataModel(), UNO_QUERY_THROW );
-            Pair< ::sal_Int32, ::sal_Bool > const aCurrentSortOrder( xSortAccess->getCurrentSortOrder() );
+            Pair< ::sal_Int32, sal_Bool > const aCurrentSortOrder( xSortAccess->getCurrentSortOrder() );
             currentSort.nColumnPos = aCurrentSortOrder.First;
             currentSort.eSortDirection = aCurrentSortOrder.Second ? ColumnSortAscending : ColumnSortDescending;
         }
@@ -844,7 +814,7 @@ namespace svt { namespace table
         return currentSort;
     }
 
-    //--------------------------------------------------------------------
+
     void UnoControlTableModel::notifyColumnChange( ColPos const i_columnPos, ColumnAttributeGroup const i_attributeGroup ) const
     {
         DBG_CHECK_ME();
@@ -861,7 +831,7 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::notifyRowsInserted( GridDataEvent const & i_event ) const
     {
         // check sanity of the event
@@ -898,7 +868,7 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::notifyRowsRemoved( GridDataEvent const & i_event ) const
     {
         ModellListeners aListeners( m_pImpl->m_aListeners );
@@ -911,11 +881,9 @@ namespace svt { namespace table
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
-    void UnoControlTableModel::notifyDataChanged( ::com::sun::star::awt::grid::GridDataEvent const & i_event ) const
+
+    void UnoControlTableModel::notifyDataChanged( css::awt::grid::GridDataEvent const & i_event ) const
     {
-        ColPos const firstCol = i_event.FirstColumn == -1 ? 0 : i_event.FirstColumn;
-        ColPos const lastCol = i_event.FirstColumn == -1 ? getColumnCount() - 1 : i_event.LastColumn;
         RowPos const firstRow = i_event.FirstRow == -1 ? 0 : i_event.FirstRow;
         RowPos const lastRow = i_event.FirstRow == -1 ? getRowCount() - 1 : i_event.LastRow;
 
@@ -925,11 +893,11 @@ namespace svt { namespace table
                 ++loop
             )
         {
-            (*loop)->cellsUpdated( firstCol, lastCol, firstRow, lastRow );
+            (*loop)->cellsUpdated( firstRow, lastRow );
         }
     }
 
-    //------------------------------------------------------------------------------------------------------------------
+
     void UnoControlTableModel::notifyAllDataChanged() const
     {
         ModellListeners aListeners( m_pImpl->m_aListeners );
@@ -938,11 +906,11 @@ namespace svt { namespace table
                 ++loop
             )
         {
-            (*loop)->cellsUpdated( 0, getColumnCount() - 1, 0, getRowCount() - 1 );
+            (*loop)->cellsUpdated( 0, getRowCount() - 1 );
         }
     }
 
-// .....................................................................................................................
+
 } } // svt::table
-// .....................................................................................................................
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
