@@ -17,11 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
 #include <vcl/wrkwin.hxx>
-#include <sot/factory.hxx>
 #include <tools/helpers.hxx>
 #include <vcl/msgbox.hxx>
 #include <svl/eitem.hxx>
+#include <sfx2/ctrlitem.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <svtools/miscopt.hxx>
@@ -29,15 +31,15 @@
 #include <comphelper/processfactory.hxx>
 
 #include <svx/dialmgr.hxx>
-#include "svx/xoutbmp.hxx"
-#include <svx/dialogs.hrc>
+#include <svx/xoutbmp.hxx>
+#include <svx/strings.hrc>
 #include <svx/svxids.hrc>
 #include <svx/contdlg.hxx>
 #include "contimp.hxx"
 #include "contwnd.hxx"
 #include <svx/svdtrans.hxx>
 #include <svx/svdopath.hxx>
-#include "svx/dlgutil.hxx"
+#include <svx/dlgutil.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
 #include <vcl/virdev.hxx>
@@ -46,8 +48,8 @@
 
 SFX_IMPL_FLOATINGWINDOW_WITHID( SvxContourDlgChildWindow, SID_CONTOUR_DLG );
 
-SvxContourDlgItem::SvxContourDlgItem( sal_uInt16 _nId, SvxSuperContourDlg& rContourDlg, SfxBindings& rBindings ) :
-            SfxControllerItem   ( _nId, rBindings ),
+SvxContourDlgItem::SvxContourDlgItem( SvxSuperContourDlg& rContourDlg, SfxBindings& rBindings ) :
+            SfxControllerItem   ( SID_CONTOUR_EXEC, rBindings ),
             rDlg                ( rContourDlg )
 {
 }
@@ -64,7 +66,7 @@ void SvxContourDlgItem::StateChanged( sal_uInt16 nSID, SfxItemState /*eState*/,
 }
 
 SvxContourDlgChildWindow::SvxContourDlgChildWindow( vcl::Window* _pParent, sal_uInt16 nId,
-                                                    SfxBindings* pBindings, SfxChildWinInfo* pInfo ) :
+                                                    SfxBindings* pBindings, SfxChildWinInfo const * pInfo ) :
             SfxChildWindow( _pParent, nId )
 {
     VclPtr<SvxSuperContourDlg> pDlg = VclPtr<SvxSuperContourDlg>::Create(pBindings, this, _pParent);
@@ -101,13 +103,13 @@ void SvxContourDlg::SetSuperClass( SvxSuperContourDlg& rSuperClass )
 }
 
 tools::PolyPolygon SvxContourDlg::CreateAutoContour( const Graphic& rGraphic,
-                                              const Rectangle* pRect,
-                                              const sal_uIntPtr nFlags )
+                                                     const tools::Rectangle* pRect,
+                                                     const sal_uIntPtr nFlags )
 {
     Bitmap  aBmp;
-    sal_uIntPtr nContourFlags = XOUTBMP_CONTOUR_HORZ;
+    XOutFlags nContourFlags = XOutFlags::ContourHorz;
 
-    if ( rGraphic.GetType() == GRAPHIC_BITMAP )
+    if ( rGraphic.GetType() == GraphicType::Bitmap )
     {
         if( rGraphic.IsAnimated() )
         {
@@ -136,7 +138,7 @@ tools::PolyPolygon SvxContourDlg::CreateAutoContour( const Graphic& rGraphic,
                 aTransMap.SetOrigin( Point() );
                 pVDev->SetMapMode( aTransMap );
                 aBmp = pVDev->GetBitmap( Point(), rSizePix );
-                aBmp.Convert( BMP_CONVERSION_1BIT_THRESHOLD );
+                aBmp.Convert( BmpConversion::N1BitThreshold );
             }
         }
         else if( rGraphic.IsTransparent() )
@@ -144,10 +146,10 @@ tools::PolyPolygon SvxContourDlg::CreateAutoContour( const Graphic& rGraphic,
         else
         {
             aBmp = rGraphic.GetBitmap();
-            nContourFlags |= XOUTBMP_CONTOUR_EDGEDETECT;
+            nContourFlags |= XOutFlags::ContourEdgeDetect;
         }
     }
-    else if( rGraphic.GetType() != GRAPHIC_NONE )
+    else if( rGraphic.GetType() != GraphicType::NONE )
     {
         const Graphic   aTmpGrf( rGraphic.GetGDIMetaFile().GetMonochromeMtf( Color( COL_BLACK ) ) );
         ScopedVclPtrInstance< VirtualDevice > pVDev;
@@ -170,13 +172,13 @@ tools::PolyPolygon SvxContourDlg::CreateAutoContour( const Graphic& rGraphic,
             aBmp = pVDev->GetBitmap( aPt, aSizePix );
         }
 
-        nContourFlags |= XOUTBMP_CONTOUR_EDGEDETECT;
+        nContourFlags |= XOutFlags::ContourEdgeDetect;
     }
 
     aBmp.SetPrefSize( rGraphic.GetPrefSize() );
     aBmp.SetPrefMapMode( rGraphic.GetPrefMapMode() );
 
-    return tools::PolyPolygon( XOutBitmap::GetCountour( aBmp, nContourFlags, 128, pRect ) );
+    return tools::PolyPolygon( XOutBitmap::GetContour( aBmp, nContourFlags, 128, pRect ) );
 }
 
 // Loop through to super class, no virtual Methods to not become incompatible
@@ -194,7 +196,7 @@ bool SvxContourDlg::IsGraphicChanged() const
 
 tools::PolyPolygon SvxContourDlg::GetPolyPolygon()
 {
-    return pSuperClass->GetPolyPolygon(true);
+    return pSuperClass->GetPolyPolygon();
 }
 
 const void* SvxContourDlg::GetEditingObject() const
@@ -211,10 +213,12 @@ void SvxContourDlg::Update( const Graphic& rGraphic, bool bGraphicLinked,
 SvxSuperContourDlg::SvxSuperContourDlg(SfxBindings *_pBindings, SfxChildWindow *pCW,
                                        vcl::Window* _pParent) :
         SvxContourDlg       ( _pBindings, pCW, _pParent ),
+        aUpdateIdle         ( "SvxSuperContourDlg UpdateIdle" ),
+        aCreateIdle         ( "SvxSuperContourDlg CreateIdle" ),
         pUpdateEditingObject( nullptr ),
         pCheckObj           ( nullptr ),
-        aContourItem        ( SID_CONTOUR_EXEC, *this, *_pBindings ),
-        nGrfChanged         ( 0UL ),
+        aContourItem        ( *this, *_pBindings ),
+        nGrfChanged         ( 0 ),
         bExecState          ( false ),
         bUpdateGraphicLinked( false ),
         bGraphicLinked      ( false )
@@ -270,24 +274,23 @@ SvxSuperContourDlg::SvxSuperContourDlg(SfxBindings *_pBindings, SfxChildWindow *
     m_pTbx1->SetSizePixel( aTbxSize );
     m_pTbx1->SetSelectHdl( LINK( this, SvxSuperContourDlg, Tbx1ClickHdl ) );
 
-    aPos.X() += aTbxSize.Width() + LogicToPixel( Size( 3, 0 ), MapMode( MAP_APPFONT ) ).Width();
+    aPos.X() += aTbxSize.Width() + LogicToPixel( Size( 3, 0 ), MapMode( MapUnit::MapAppFont ) ).Width();
     m_pMtfTolerance->SetPosPixel( aPos );
-    m_pMtfTolerance->SetValue( 10L );
+    m_pMtfTolerance->SetValue( 10 );
 
     SetMinOutputSizePixel( aLastSize = GetOutputSizePixel() );
 
-    m_pStbStatus->InsertItem( 1, 130, SIB_LEFT | SIB_IN | SIB_AUTOSIZE );
+    m_pStbStatus->InsertItem( 1, 130, StatusBarItemBits::Left | StatusBarItemBits::In | StatusBarItemBits::AutoSize );
     m_pStbStatus->InsertItem( 2, 10 + GetTextWidth( " 9999,99 cm / 9999,99 cm " ) );
     m_pStbStatus->InsertItem( 3, 10 + GetTextWidth( " 9999,99 cm x 9999,99 cm " ) );
     m_pStbStatus->InsertItem( 4, 20 );
 
     Resize();
 
-    aUpdateIdle.SetPriority( SchedulerPriority::LOW );
-    aUpdateIdle.SetIdleHdl( LINK( this, SvxSuperContourDlg, UpdateHdl ) );
+    aUpdateIdle.SetInvokeHandler( LINK( this, SvxSuperContourDlg, UpdateHdl ) );
 
-    aCreateIdle.SetPriority( SchedulerPriority::RESIZE );
-    aCreateIdle.SetIdleHdl( LINK( this, SvxSuperContourDlg, CreateHdl ) );
+    aCreateIdle.SetPriority( TaskPriority::RESIZE );
+    aCreateIdle.SetInvokeHandler( LINK( this, SvxSuperContourDlg, CreateHdl ) );
 }
 
 SvxSuperContourDlg::~SvxSuperContourDlg()
@@ -321,8 +324,9 @@ bool SvxSuperContourDlg::Close()
         if ( nRet == RET_YES )
         {
             SfxBoolItem aBoolItem( SID_CONTOUR_EXEC, true );
-            GetBindings().GetDispatcher()->Execute(
-                SID_CONTOUR_EXEC, SfxCallMode::SYNCHRON | SfxCallMode::RECORD, &aBoolItem, 0L );
+            GetBindings().GetDispatcher()->ExecuteList(
+                SID_CONTOUR_EXEC, SfxCallMode::SYNCHRON | SfxCallMode::RECORD,
+                { &aBoolItem });
         }
         else if ( nRet == RET_CANCEL )
             bRet = false;
@@ -342,19 +346,19 @@ void SvxSuperContourDlg::SetGraphic( const Graphic& rGraphic )
 {
     aUndoGraphic = aRedoGraphic = Graphic();
     aGraphic = rGraphic;
-    nGrfChanged = 0UL;
+    nGrfChanged = 0;
     m_pContourWnd->SetGraphic( aGraphic );
 }
 
 void SvxSuperContourDlg::SetPolyPolygon( const tools::PolyPolygon& rPolyPoly )
 {
-    DBG_ASSERT(  m_pContourWnd->GetGraphic().GetType() != GRAPHIC_NONE, "Graphic must've been set first!" );
+    DBG_ASSERT(  m_pContourWnd->GetGraphic().GetType() != GraphicType::NONE, "Graphic must've been set first!" );
 
     tools::PolyPolygon aPolyPoly( rPolyPoly );
-    const MapMode   aMap100( MAP_100TH_MM );
+    const MapMode   aMap100( MapUnit::Map100thMM );
     const MapMode   aGrfMap( aGraphic.GetPrefMapMode() );
     OutputDevice*   pOutDev = Application::GetDefaultDevice();
-    bool            bPixelMap = aGrfMap.GetMapUnit() == MAP_PIXEL;
+    bool            bPixelMap = aGrfMap.GetMapUnit() == MapUnit::MapPixel;
 
     for ( sal_uInt16 j = 0, nPolyCount = aPolyPoly.Count(); j < nPolyCount; j++ )
     {
@@ -375,30 +379,27 @@ void SvxSuperContourDlg::SetPolyPolygon( const tools::PolyPolygon& rPolyPoly )
     m_pContourWnd->GetSdrModel()->SetChanged();
 }
 
-tools::PolyPolygon SvxSuperContourDlg::GetPolyPolygon( bool bRescaleToGraphic )
+tools::PolyPolygon SvxSuperContourDlg::GetPolyPolygon()
 {
     tools::PolyPolygon aRetPolyPoly( m_pContourWnd->GetPolyPolygon() );
 
-    if ( bRescaleToGraphic )
+    const MapMode   aMap100( MapUnit::Map100thMM );
+    const MapMode   aGrfMap( aGraphic.GetPrefMapMode() );
+    OutputDevice*   pOutDev = Application::GetDefaultDevice();
+    bool            bPixelMap = aGrfMap.GetMapUnit() == MapUnit::MapPixel;
+
+    for ( sal_uInt16 j = 0, nPolyCount = aRetPolyPoly.Count(); j < nPolyCount; j++ )
     {
-        const MapMode   aMap100( MAP_100TH_MM );
-        const MapMode   aGrfMap( aGraphic.GetPrefMapMode() );
-        OutputDevice*   pOutDev = Application::GetDefaultDevice();
-        bool            bPixelMap = aGrfMap.GetMapUnit() == MAP_PIXEL;
+        tools::Polygon& rPoly = aRetPolyPoly[ j ];
 
-        for ( sal_uInt16 j = 0, nPolyCount = aRetPolyPoly.Count(); j < nPolyCount; j++ )
+        for ( sal_uInt16 i = 0, nCount = rPoly.GetSize(); i < nCount; i++ )
         {
-            tools::Polygon& rPoly = aRetPolyPoly[ j ];
+            Point& rPt = rPoly[ i ];
 
-            for ( sal_uInt16 i = 0, nCount = rPoly.GetSize(); i < nCount; i++ )
-            {
-                Point& rPt = rPoly[ i ];
+            rPt = pOutDev->LogicToPixel( rPt, aMap100  );
 
-                rPt = pOutDev->LogicToPixel( rPt, aMap100  );
-
-                if ( !bPixelMap )
-                    rPt = pOutDev->PixelToLogic( rPt, aGrfMap  );
-            }
+            if ( !bPixelMap )
+                rPt = pOutDev->PixelToLogic( rPt, aGrfMap  );
         }
     }
 
@@ -420,19 +421,9 @@ void SvxSuperContourDlg::UpdateGraphic( const Graphic& rGraphic, bool _bGraphicL
     aUpdateIdle.Start();
 }
 
-bool SvxSuperContourDlg::IsUndoPossible() const
-{
-    return aUndoGraphic.GetType() != GRAPHIC_NONE;
-}
-
-bool SvxSuperContourDlg::IsRedoPossible() const
-{
-    return aRedoGraphic.GetType() != GRAPHIC_NONE;
-}
-
 // Click handler for ToolBox
 
-IMPL_LINK_TYPED( SvxSuperContourDlg, Tbx1ClickHdl, ToolBox*, pTbx, void )
+IMPL_LINK( SvxSuperContourDlg, Tbx1ClickHdl, ToolBox*, pTbx, void )
 {
     sal_uInt16 nNewItemId = pTbx->GetCurItemId();
 
@@ -440,8 +431,9 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, Tbx1ClickHdl, ToolBox*, pTbx, void )
     if (nId == mnApplyId)
     {
         SfxBoolItem aBoolItem( SID_CONTOUR_EXEC, true );
-        GetBindings().GetDispatcher()->Execute(
-            SID_CONTOUR_EXEC, SfxCallMode::ASYNCHRON | SfxCallMode::RECORD, &aBoolItem, 0L );
+        GetBindings().GetDispatcher()->ExecuteList(
+            SID_CONTOUR_EXEC, SfxCallMode::ASYNCHRON | SfxCallMode::RECORD,
+            { &aBoolItem });
     }
     else if (nId == mnWorkSpaceId)
     {
@@ -533,9 +525,11 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, Tbx1ClickHdl, ToolBox*, pTbx, void )
 
         m_pContourWnd->SetPipetteMode( bPipette );
     }
+    Invalidate();
+    m_pContourWnd->QueueIdleUpdate();
 }
 
-IMPL_LINK_TYPED( SvxSuperContourDlg, MousePosHdl, GraphCtrl*, pWnd, void )
+IMPL_LINK( SvxSuperContourDlg, MousePosHdl, GraphCtrl*, pWnd, void )
 {
     OUString aStr;
     const FieldUnit eFieldUnit = GetBindings().GetDispatcher()->GetModule()->GetFieldUnit();
@@ -543,14 +537,14 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, MousePosHdl, GraphCtrl*, pWnd, void )
     const LocaleDataWrapper& rLocaleWrapper( Application::GetSettings().GetLocaleDataWrapper() );
     const sal_Unicode cSep = rLocaleWrapper.getNumDecimalSep()[0];
 
-    aStr = GetUnitString( rMousePos.X(), eFieldUnit, cSep );
-    aStr += " / ";
-    aStr += GetUnitString( rMousePos.Y(), eFieldUnit, cSep );
+    aStr = GetUnitString( rMousePos.X(), eFieldUnit, cSep )
+         + " / "
+         + GetUnitString( rMousePos.Y(), eFieldUnit, cSep );
 
     m_pStbStatus->SetItemText( 2, aStr );
 }
 
-IMPL_LINK_TYPED( SvxSuperContourDlg, GraphSizeHdl, GraphCtrl*, pWnd, void )
+IMPL_LINK( SvxSuperContourDlg, GraphSizeHdl, GraphCtrl*, pWnd, void )
 {
     OUString aStr;
     const FieldUnit eFieldUnit = GetBindings().GetDispatcher()->GetModule()->GetFieldUnit();
@@ -558,14 +552,14 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, GraphSizeHdl, GraphCtrl*, pWnd, void )
     const LocaleDataWrapper& rLocaleWrapper( Application::GetSettings().GetLocaleDataWrapper() );
     const sal_Unicode cSep = rLocaleWrapper.getNumDecimalSep()[0];
 
-    aStr = GetUnitString( rSize.Width(), eFieldUnit, cSep );
-    aStr += " x ";
-    aStr += GetUnitString( rSize.Height(), eFieldUnit, cSep );
+    aStr = GetUnitString( rSize.Width(), eFieldUnit, cSep )
+         + " x "
+         + GetUnitString( rSize.Height(), eFieldUnit, cSep );
 
     m_pStbStatus->SetItemText( 3, aStr );
 }
 
-IMPL_LINK_NOARG_TYPED(SvxSuperContourDlg, UpdateHdl, Idle *, void)
+IMPL_LINK_NOARG(SvxSuperContourDlg, UpdateHdl, Timer *, void)
 {
     aUpdateIdle.Stop();
 
@@ -576,7 +570,7 @@ IMPL_LINK_NOARG_TYPED(SvxSuperContourDlg, UpdateHdl, Idle *, void)
 
         SetGraphic( aUpdateGraphic );
         SetPolyPolygon( aUpdatePolyPoly );
-        SetEditingObject( pUpdateEditingObject );
+        pCheckObj = pUpdateEditingObject;
         bGraphicLinked = bUpdateGraphicLinked;
 
         aUpdateGraphic = Graphic();
@@ -587,13 +581,14 @@ IMPL_LINK_NOARG_TYPED(SvxSuperContourDlg, UpdateHdl, Idle *, void)
     }
 
     GetBindings().Invalidate( SID_CONTOUR_EXEC );
+    m_pContourWnd->QueueIdleUpdate();
 }
 
-IMPL_LINK_NOARG_TYPED(SvxSuperContourDlg, CreateHdl, Idle *, void)
+IMPL_LINK_NOARG(SvxSuperContourDlg, CreateHdl, Timer *, void)
 {
     aCreateIdle.Stop();
 
-    const Rectangle aWorkRect = m_pContourWnd->LogicToPixel( m_pContourWnd->GetWorkRect(), MapMode( MAP_100TH_MM ) );
+    const tools::Rectangle aWorkRect = m_pContourWnd->LogicToPixel( m_pContourWnd->GetWorkRect(), MapMode( MapUnit::Map100thMM ) );
     const Graphic&  rGraphic = m_pContourWnd->GetGraphic();
     const bool      bValid = aWorkRect.Left() != aWorkRect.Right() && aWorkRect.Top() != aWorkRect.Bottom();
 
@@ -602,7 +597,7 @@ IMPL_LINK_NOARG_TYPED(SvxSuperContourDlg, CreateHdl, Idle *, void)
     LeaveWait();
 }
 
-IMPL_LINK_TYPED( SvxSuperContourDlg, StateHdl, GraphCtrl*, pWnd, void )
+IMPL_LINK( SvxSuperContourDlg, StateHdl, GraphCtrl*, pWnd, void )
 {
     const SdrObject*    pObj = pWnd->GetSelectedSdrObject();
     const SdrView*      pView = pWnd->GetSdrView();
@@ -611,7 +606,7 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, StateHdl, GraphCtrl*, pWnd, void )
     const bool          bPipette = m_pTbx1->IsItemChecked(mnPipetteId);
     const bool          bWorkplace = m_pTbx1->IsItemChecked(mnWorkSpaceId);
     const bool          bDontHide = !( bPipette || bWorkplace );
-    const bool          bBitmap = pWnd->GetGraphic().GetType() == GRAPHIC_BITMAP;
+    const bool          bBitmap = pWnd->GetGraphic().GetType() == GraphicType::Bitmap;
 
     m_pTbx1->EnableItem(mnApplyId, bDontHide && bExecState && pWnd->IsChanged());
 
@@ -630,8 +625,8 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, StateHdl, GraphCtrl*, pWnd, void )
     m_pTbx1->EnableItem(mnAutoContourId, bDontHide && bDrawEnabled);
     m_pTbx1->EnableItem(mnPipetteId, !bWorkplace && bDrawEnabled && bBitmap);
 
-    m_pTbx1->EnableItem(mnUndoId, bDontHide && IsUndoPossible());
-    m_pTbx1->EnableItem(mnRedoId, bDontHide && IsRedoPossible());
+    m_pTbx1->EnableItem(mnUndoId, bDontHide && aUndoGraphic.GetType() != GraphicType::NONE);
+    m_pTbx1->EnableItem(mnRedoId, bDontHide && aRedoGraphic.GetType() != GraphicType::NONE);
 
     if ( bPolyEdit )
     {
@@ -639,8 +634,8 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, StateHdl, GraphCtrl*, pWnd, void )
 
         switch( pWnd->GetPolyEditMode() )
         {
-            case( SID_BEZIER_MOVE ): nId = mnPolyMoveId; break;
-            case( SID_BEZIER_INSERT ): nId = mnPolyInsertId; break;
+            case SID_BEZIER_MOVE: nId = mnPolyMoveId; break;
+            case SID_BEZIER_INSERT: nId = mnPolyInsertId; break;
 
             default:
             break;
@@ -657,12 +652,12 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, StateHdl, GraphCtrl*, pWnd, void )
     }
 }
 
-IMPL_LINK_TYPED( SvxSuperContourDlg, PipetteHdl, ContourWindow&, rWnd, void )
+IMPL_LINK( SvxSuperContourDlg, PipetteHdl, ContourWindow&, rWnd, void )
 {
     const Color& rOldLineColor = m_pStbStatus->GetLineColor();
     const Color& rOldFillColor = m_pStbStatus->GetFillColor();
 
-    Rectangle       aRect( m_pStbStatus->GetItemRect( 4 ) );
+    tools::Rectangle       aRect( m_pStbStatus->GetItemRect( 4 ) );
     const Color&    rColor = rWnd.GetPipetteColor();
 
     m_pStbStatus->SetLineColor( rColor );
@@ -679,7 +674,7 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, PipetteHdl, ContourWindow&, rWnd, void )
     m_pStbStatus->SetFillColor( rOldFillColor );
 }
 
-IMPL_LINK_TYPED( SvxSuperContourDlg, PipetteClickHdl, ContourWindow&, rWnd, void )
+IMPL_LINK( SvxSuperContourDlg, PipetteClickHdl, ContourWindow&, rWnd, void )
 {
     if ( rWnd.IsClickValid() )
     {
@@ -688,7 +683,7 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, PipetteClickHdl, ContourWindow&, rWnd, void
 
         EnterWait();
 
-        if( aGraphic.GetType() == GRAPHIC_BITMAP )
+        if( aGraphic.GetType() == GraphicType::Bitmap )
         {
             Bitmap      aBmp( aGraphic.GetBitmap() );
             const long  nTol = static_cast<long>(m_pMtfTolerance->GetValue() * 255L / 100L);
@@ -696,7 +691,7 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, PipetteClickHdl, ContourWindow&, rWnd, void
             aMask = aBmp.CreateMask( rColor, nTol );
 
             if( aGraphic.IsTransparent() )
-                aMask.CombineSimple( aGraphic.GetBitmapEx().GetMask(), BMP_COMBINE_OR );
+                aMask.CombineSimple( aGraphic.GetBitmapEx().GetMask(), BmpCombine::Or );
 
             if( !!aMask )
             {
@@ -724,14 +719,17 @@ IMPL_LINK_TYPED( SvxSuperContourDlg, PipetteClickHdl, ContourWindow&, rWnd, void
     m_pStbStatus->Invalidate();
 }
 
-IMPL_LINK_TYPED( SvxSuperContourDlg, WorkplaceClickHdl, ContourWindow&, rWnd, void )
+IMPL_LINK( SvxSuperContourDlg, WorkplaceClickHdl, ContourWindow&, rWnd, void )
 {
     m_pTbx1->CheckItem(mnWorkSpaceId, false);
     m_pTbx1->CheckItem(mnSelectId);
     rWnd.SetWorkplaceMode( false );
+
+    m_pContourWnd->QueueIdleUpdate();
+    Invalidate();
 }
 
-IMPL_LINK_NOARG_TYPED(SvxSuperContourDlg, MiscHdl, LinkParamNone*, void)
+IMPL_LINK_NOARG(SvxSuperContourDlg, MiscHdl, LinkParamNone*, void)
 {
     SvtMiscOptions aMiscOptions;
     m_pTbx1->SetOutStyle( aMiscOptions.GetToolboxStyle() );
