@@ -18,16 +18,16 @@
  */
 
 #include <svx/xoutbmp.hxx>
-#include <svx/dialogs.hrc>
+#include <svx/strings.hrc>
 #include <svx/svxids.hrc>
-#include <contwnd.hxx>
+#include "contwnd.hxx"
 #include <svx/svdpage.hxx>
 #include <svx/svdopath.hxx>
 #include <svx/xfltrit.hxx>
 #include <svx/xfillit.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
-#include "svx/sdrpaintwindow.hxx"
+#include <svx/sdrpaintwindow.hxx>
 
 using namespace css;
 
@@ -40,7 +40,7 @@ ContourWindow::ContourWindow(vcl::Window* pParent, WinBits nBits)
     , bWorkplaceMode(false)
     , bClickValid(false)
 {
-    SetWinStyle(WB_SDRMODE);
+    SetSdrMode(true);
 }
 
 void ContourWindow::SetPolyPolygon(const tools::PolyPolygon& rPolyPoly)
@@ -96,7 +96,7 @@ const tools::PolyPolygon& ContourWindow::GetPolyPolygon()
             SdrPathObj* pPathObj = static_cast<SdrPathObj*>(pPage->GetObj(0));
             // Not sure if subdivision is needed for ContourWindow, but maybe it cannot handle
             // curves at all. Keeping subdivision here for security
-            const basegfx::B2DPolyPolygon aB2DPolyPolygon(basegfx::tools::adaptiveSubdivideByAngle(pPathObj->GetPathPoly()));
+            const basegfx::B2DPolyPolygon aB2DPolyPolygon(basegfx::utils::adaptiveSubdivideByAngle(pPathObj->GetPathPoly()));
             aPolyPoly = tools::PolyPolygon(aB2DPolyPolygon);
         }
 
@@ -142,8 +142,8 @@ void ContourWindow::MouseButtonDown( const MouseEvent& rMEvt )
         const Point aLogPt( PixelToLogic( rMEvt.GetPosPixel() ) );
 
         SetPolyPolygon( tools::PolyPolygon() );
-        aWorkRect = Rectangle( aLogPt, aLogPt );
-        Invalidate(Rectangle(Point(), GetGraphicSize()));
+        aWorkRect = tools::Rectangle( aLogPt, aLogPt );
+        Invalidate(tools::Rectangle(Point(), GetGraphicSize()));
         SetEditMode( true );
     }
 
@@ -162,7 +162,7 @@ void ContourWindow::MouseMove( const MouseEvent& rMEvt )
         aPipetteColor = GetPixel( aLogPt );
         Control::MouseMove( rMEvt );
 
-        if ( aPipetteLink.IsSet() && Rectangle( Point(), GetGraphicSize() ).IsInside( aLogPt ) )
+        if ( aPipetteLink.IsSet() && tools::Rectangle( Point(), GetGraphicSize() ).IsInside( aLogPt ) )
         {
             SetPointer( PointerStyle::RefHand );
             aPipetteLink.Call( *this );
@@ -175,7 +175,7 @@ void ContourWindow::MouseMove( const MouseEvent& rMEvt )
 void ContourWindow::MouseButtonUp(const MouseEvent& rMEvt)
 {
     Point aTmpPoint;
-    const Rectangle aGraphRect( aTmpPoint, GetGraphicSize() );
+    const tools::Rectangle aGraphRect( aTmpPoint, GetGraphicSize() );
     const Point     aLogPt( PixelToLogic( rMEvt.GetPosPixel() ) );
 
     bClickValid = aGraphRect.IsInside( aLogPt );
@@ -215,7 +215,7 @@ void ContourWindow::MouseButtonUp(const MouseEvent& rMEvt)
         GraphCtrl::MouseButtonUp( rMEvt );
 }
 
-void ContourWindow::Paint(vcl::RenderContext& rRenderContext, const Rectangle& rRect)
+void ContourWindow::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle& rRect)
 {
     // #i75482#
     // encapsulate the redraw using Begin/End and use the returned
@@ -227,17 +227,17 @@ void ContourWindow::Paint(vcl::RenderContext& rRenderContext, const Rectangle& r
     rTarget.Push(PushFlags::LINECOLOR |PushFlags::FILLCOLOR);
     rTarget.SetLineColor(Color(COL_BLACK));
     rTarget.SetFillColor(Color(COL_WHITE));
-    rTarget.DrawRect( Rectangle( Point(), GetGraphicSize() ) );
+    rTarget.DrawRect( tools::Rectangle( Point(), GetGraphicSize() ) );
     rTarget.Pop();
 
-    if (rGraphic.GetType() != GRAPHIC_NONE)
+    if (rGraphic.GetType() != GraphicType::NONE)
         rGraphic.Draw(&rTarget, Point(), GetGraphicSize());
 
     if (aWorkRect.Left() != aWorkRect.Right() && aWorkRect.Top() != aWorkRect.Bottom())
     {
         tools::PolyPolygon _aPolyPoly(2, 2);
         rTarget.Push(PushFlags::FILLCOLOR);
-        _aPolyPoly.Insert(Rectangle(Point(), GetGraphicSize()));
+        _aPolyPoly.Insert(tools::Rectangle(Point(), GetGraphicSize()));
         _aPolyPoly.Insert(aWorkRect);
         rTarget.SetFillColor(COL_LIGHTRED);
         rTarget.DrawTransparent(_aPolyPoly, 50);
@@ -252,7 +252,7 @@ void ContourWindow::Paint(vcl::RenderContext& rRenderContext, const Rectangle& r
 
 Size ContourWindow::GetOptimalSize() const
 {
-    return LogicToPixel(Size(270, 170), MAP_APPFONT);
+    return LogicToPixel(Size(270, 170), MapMode(MapUnit::MapAppFont));
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
