@@ -30,7 +30,8 @@
 #include <editeng/unolingu.hxx>
 #include <svx/langbox.hxx>
 #include <svx/dialmgr.hxx>
-#include <svx/dialogs.hrc>
+#include <svx/strings.hrc>
+#include <bitmaps.hlst>
 #include <vcl/builderfactory.hxx>
 #include <vcl/i18nhelp.hxx>
 
@@ -41,11 +42,11 @@ using namespace ::com::sun::star::uno;
 
 static_assert((LISTBOX_APPEND == COMBOBOX_APPEND) && (LISTBOX_ENTRY_NOTFOUND == COMBOBOX_ENTRY_NOTFOUND), "If these ever dispersed we'd need a solution");
 
-OUString GetDicInfoStr( const OUString& rName, const sal_uInt16 nLang, bool bNeg )
+OUString GetDicInfoStr( const OUString& rName, const LanguageType nLang, bool bNeg )
 {
     INetURLObject aURLObj;
     aURLObj.SetSmartProtocol( INetProtocol::File );
-    aURLObj.SetSmartURL( rName, INetURLObject::ENCODE_ALL );
+    aURLObj.SetSmartURL( rName, INetURLObject::EncodeMechanism::All );
     OUString aTmp( aURLObj.GetBase() );
     aTmp += " ";
 
@@ -55,11 +56,11 @@ OUString GetDicInfoStr( const OUString& rName, const sal_uInt16 nLang, bool bNeg
     }
 
     if ( LANGUAGE_NONE == nLang )
-        aTmp += SVX_RESSTR(RID_SVXSTR_LANGUAGE_ALL);
+        aTmp += SvxResId(RID_SVXSTR_LANGUAGE_ALL);
     else
     {
         aTmp += "[";
-        aTmp += SvtLanguageTable::GetLanguageString( (LanguageType)nLang );
+        aTmp += SvtLanguageTable::GetLanguageString( nLang );
         aTmp += "]";
     }
 
@@ -70,16 +71,15 @@ OUString GetDicInfoStr( const OUString& rName, const sal_uInt16 nLang, bool bNeg
 //  misc local helper functions
 
 
-static Sequence< sal_Int16 > lcl_LocaleSeqToLangSeq( Sequence< css::lang::Locale > &rSeq )
+static std::vector< LanguageType > lcl_LocaleSeqToLangSeq( Sequence< css::lang::Locale > const &rSeq )
 {
     const css::lang::Locale *pLocale = rSeq.getConstArray();
     sal_Int32 nCount = rSeq.getLength();
 
-    Sequence< sal_Int16 >   aLangs( nCount );
-    sal_Int16 *pLang = aLangs.getArray();
+    std::vector< LanguageType >   aLangs;
     for (sal_Int32 i = 0;  i < nCount;  ++i)
     {
-        pLang[i] = LanguageTag::convertToLanguageType( pLocale[i] );
+        aLangs.push_back( LanguageTag::convertToLanguageType( pLocale[i] ) );
 
     }
 
@@ -87,6 +87,13 @@ static Sequence< sal_Int16 > lcl_LocaleSeqToLangSeq( Sequence< css::lang::Locale
 }
 
 
+static bool lcl_SeqHasLang( const std::vector< LanguageType > & rLangSeq, LanguageType nLang )
+{
+    for (auto const & i : rLangSeq)
+        if (i == nLang)
+            return true;
+    return false;
+}
 static bool lcl_SeqHasLang( const Sequence< sal_Int16 > & rLangSeq, sal_Int16 nLang )
 {
     sal_Int32 i = -1;
@@ -103,10 +110,10 @@ static bool lcl_SeqHasLang( const Sequence< sal_Int16 > & rLangSeq, sal_Int16 nL
     return i >= 0  &&  i < nLen;
 }
 
-VCL_BUILDER_DECL_FACTORY(SvxLanguageBox)
+extern "C" SAL_DLLPUBLIC_EXPORT void SAL_CALL makeSvxLanguageBox(VclPtr<vcl::Window> & rRet, VclPtr<vcl::Window> & pParent, VclBuilder::stringmap & rMap)
 {
     WinBits nBits = WB_LEFT|WB_VCENTER|WB_3DLOOK|WB_TABSTOP;
-    bool bDropdown = VclBuilder::extractDropdown(rMap);
+    bool bDropdown = BuilderUtils::extractDropdown(rMap);
     if (bDropdown)
         nBits |= WB_DROPDOWN;
     else
@@ -116,10 +123,10 @@ VCL_BUILDER_DECL_FACTORY(SvxLanguageBox)
     rRet = pLanguageBox;
 }
 
-VCL_BUILDER_DECL_FACTORY(SvxLanguageComboBox)
+extern "C" SAL_DLLPUBLIC_EXPORT void SAL_CALL makeSvxLanguageComboBox(VclPtr<vcl::Window> & rRet, VclPtr<vcl::Window> & pParent, VclBuilder::stringmap & rMap)
 {
     WinBits nBits = WB_LEFT|WB_VCENTER|WB_3DLOOK|WB_TABSTOP;
-    bool bDropdown = VclBuilder::extractDropdown(rMap);
+    bool bDropdown = BuilderUtils::extractDropdown(rMap);
     if (bDropdown)
         nBits |= WB_DROPDOWN;
     else
@@ -131,7 +138,6 @@ VCL_BUILDER_DECL_FACTORY(SvxLanguageComboBox)
 
 SvxLanguageBoxBase::SvxLanguageBoxBase()
     : m_pSpellUsedLang(nullptr)
-    , m_nLangList(SvxLanguageListFlags::EMPTY)
     , m_bHasLangNone(false)
     , m_bLangNoneIsLangAll(false)
     , m_bWithCheckmark(false)
@@ -140,10 +146,9 @@ SvxLanguageBoxBase::SvxLanguageBoxBase()
 
 void SvxLanguageBoxBase::ImplLanguageBoxBaseInit()
 {
-    m_aNotCheckedImage = Image( SVX_RES( RID_SVXIMG_NOTCHECKED ) );
-    m_aCheckedImage = Image( SVX_RES( RID_SVXIMG_CHECKED ) );
-    m_aAllString            = SVX_RESSTR( RID_SVXSTR_LANGUAGE_ALL );
-    m_nLangList             = SvxLanguageListFlags::EMPTY;
+    m_aNotCheckedImage = Image(BitmapEx(RID_SVXBMP_NOTCHECKED));
+    m_aCheckedImage = Image(BitmapEx(RID_SVXBMP_CHECKED));
+    m_aAllString            = SvxResId( RID_SVXSTR_LANGUAGE_ALL );
     m_bHasLangNone          = false;
     m_bLangNoneIsLangAll    = false;
 
@@ -164,136 +169,174 @@ void SvxLanguageBoxBase::ImplLanguageBoxBaseInit()
             if ( bInsert )
                 InsertLanguage( nLangType );
         }
-        m_nLangList = SvxLanguageListFlags::ALL;
     }
 }
 
 
 SvxLanguageBoxBase::~SvxLanguageBoxBase()
 {
-    delete m_pSpellUsedLang;
 }
 
+namespace {
+
+bool lcl_isPrerequisite( LanguageType nLangType, SvxLanguageListFlags nLangList )
+{
+    return
+        nLangType != LANGUAGE_DONTKNOW &&
+        nLangType != LANGUAGE_SYSTEM &&
+        nLangType != LANGUAGE_NONE &&
+        !MsLangId::isLegacy( nLangType) &&
+        (MsLangId::getSubLanguage( nLangType) ||
+         bool(nLangList & SvxLanguageListFlags::ALSO_PRIMARY_ONLY));
+}
+
+bool lcl_isScriptTypeRequested( LanguageType nLangType, SvxLanguageListFlags nLangList )
+{
+    return
+        bool(nLangList & SvxLanguageListFlags::ALL) ||
+        (bool(nLangList & SvxLanguageListFlags::WESTERN) &&
+         (SvtLanguageOptions::GetScriptTypeOfLanguage(nLangType) == SvtScriptType::LATIN)) ||
+        (bool(nLangList & SvxLanguageListFlags::CTL) &&
+         (SvtLanguageOptions::GetScriptTypeOfLanguage(nLangType) == SvtScriptType::COMPLEX)) ||
+        (bool(nLangList & SvxLanguageListFlags::CJK) &&
+         (SvtLanguageOptions::GetScriptTypeOfLanguage(nLangType) == SvtScriptType::ASIAN));
+}
+
+}
+
+void SvxLanguageBoxBase::AddLanguages( const std::vector< LanguageType >& rLanguageTypes,
+        SvxLanguageListFlags nLangList )
+{
+    for ( auto const & nLangType : rLanguageTypes )
+    {
+        if (lcl_isPrerequisite( nLangType, nLangList))
+        {
+            LanguageType nLang = MsLangId::getReplacementForObsoleteLanguage( nLangType );
+            if (lcl_isScriptTypeRequested( nLang, nLangList))
+            {
+                sal_Int32 nAt = ImplTypeToPos( nLang );
+                if (nAt == LISTBOX_ENTRY_NOTFOUND)
+                    InsertLanguage( nLang );
+            }
+        }
+    }
+}
 
 void SvxLanguageBoxBase::SetLanguageList( SvxLanguageListFlags nLangList,
         bool bHasLangNone, bool bLangNoneIsLangAll, bool bCheckSpellAvail )
 {
     ImplClear();
 
-    m_nLangList             = nLangList;
     m_bHasLangNone          = bHasLangNone;
     m_bLangNoneIsLangAll    = bLangNoneIsLangAll;
     m_bWithCheckmark        = bCheckSpellAvail;
 
-    if ( SvxLanguageListFlags::EMPTY != nLangList )
+    if ( SvxLanguageListFlags::EMPTY == nLangList )
+        return;
+
+    bool bAddAvailable = (!(nLangList & SvxLanguageListFlags::ONLY_KNOWN) &&
+            ((nLangList & SvxLanguageListFlags::ALL) ||
+             (nLangList & SvxLanguageListFlags::WESTERN) ||
+             (nLangList & SvxLanguageListFlags::CTL) ||
+             (nLangList & SvxLanguageListFlags::CJK)));
+    std::vector< LanguageType > aSpellAvailLang;
+    std::vector< LanguageType > aHyphAvailLang;
+    std::vector< LanguageType > aThesAvailLang;
+    Sequence< sal_Int16 > aSpellUsedLang;
+    std::vector< LanguageType > aHyphUsedLang;
+    std::vector< LanguageType > aThesUsedLang;
+    Reference< XAvailableLocales > xAvail( LinguMgr::GetLngSvcMgr(), UNO_QUERY );
+    if (xAvail.is())
     {
-        Sequence< sal_Int16 > aSpellAvailLang;
-        Sequence< sal_Int16 > aHyphAvailLang;
-        Sequence< sal_Int16 > aThesAvailLang;
-        Sequence< sal_Int16 > aSpellUsedLang;
-        Sequence< sal_Int16 > aHyphUsedLang;
-        Sequence< sal_Int16 > aThesUsedLang;
-        Reference< XAvailableLocales > xAvail( LinguMgr::GetLngSvcMgr(), UNO_QUERY );
-        if (xAvail.is())
-        {
-            Sequence< css::lang::Locale > aTmp;
+        Sequence< css::lang::Locale > aTmp;
 
-            if (SvxLanguageListFlags::SPELL_AVAIL & nLangList)
-            {
-                aTmp = xAvail->getAvailableLocales( SN_SPELLCHECKER );
-                aSpellAvailLang = lcl_LocaleSeqToLangSeq( aTmp );
-            }
-            if (SvxLanguageListFlags::HYPH_AVAIL  & nLangList)
-            {
-                aTmp = xAvail->getAvailableLocales( SN_HYPHENATOR );
-                aHyphAvailLang = lcl_LocaleSeqToLangSeq( aTmp );
-            }
-            if (SvxLanguageListFlags::THES_AVAIL  & nLangList)
-            {
-                aTmp = xAvail->getAvailableLocales( SN_THESAURUS );
-                aThesAvailLang = lcl_LocaleSeqToLangSeq( aTmp );
-            }
-        }
-        if (SvxLanguageListFlags::SPELL_USED & nLangList)
+        if (bAddAvailable || (SvxLanguageListFlags::SPELL_AVAIL & nLangList))
         {
-            Reference< XSpellChecker1 > xTmp1( LinguMgr::GetSpellChecker(), UNO_QUERY );
-            if (xTmp1.is())
-                aSpellUsedLang = xTmp1->getLanguages();
+            aTmp = xAvail->getAvailableLocales( SN_SPELLCHECKER );
+            aSpellAvailLang = lcl_LocaleSeqToLangSeq( aTmp );
         }
-        if (SvxLanguageListFlags::HYPH_USED  & nLangList)
+        if (bAddAvailable || (SvxLanguageListFlags::HYPH_AVAIL  & nLangList))
         {
-            Reference< XHyphenator > xTmp( LinguMgr::GetHyphenator() );
-            if (xTmp.is()) {
-                Sequence < css::lang::Locale > aLocaleSequence( xTmp->getLocales() );
-                aHyphUsedLang = lcl_LocaleSeqToLangSeq( aLocaleSequence );
-            }
+            aTmp = xAvail->getAvailableLocales( SN_HYPHENATOR );
+            aHyphAvailLang = lcl_LocaleSeqToLangSeq( aTmp );
         }
-        if (SvxLanguageListFlags::THES_USED  & nLangList)
+        if (bAddAvailable || (SvxLanguageListFlags::THES_AVAIL  & nLangList))
         {
-            Reference< XThesaurus > xTmp( LinguMgr::GetThesaurus() );
-            if (xTmp.is()) {
-                Sequence < css::lang::Locale > aLocaleSequence( xTmp->getLocales() );
-                aThesUsedLang = lcl_LocaleSeqToLangSeq( aLocaleSequence );
-            }
+            aTmp = xAvail->getAvailableLocales( SN_THESAURUS );
+            aThesAvailLang = lcl_LocaleSeqToLangSeq( aTmp );
         }
-
-        css::uno::Sequence< sal_uInt16 > xKnown;
-        const sal_uInt16* pKnown;
-        sal_uInt32 nCount;
-        if ( nLangList & SvxLanguageListFlags::ONLY_KNOWN )
-        {
-            xKnown = LocaleDataWrapper::getInstalledLanguageTypes();
-            pKnown = xKnown.getConstArray();
-            nCount = xKnown.getLength();
-        }
-        else
-        {
-            nCount = SvtLanguageTable::GetLanguageEntryCount();
-            pKnown = nullptr;
-        }
-        for ( sal_uInt32 i = 0; i < nCount; i++ )
-        {
-            LanguageType nLangType;
-            if ( nLangList & SvxLanguageListFlags::ONLY_KNOWN )
-                nLangType = pKnown[i];
-            else
-                nLangType = SvtLanguageTable::GetLanguageTypeAtIndex( i );
-            if ( nLangType != LANGUAGE_DONTKNOW &&
-                 nLangType != LANGUAGE_SYSTEM &&
-                 nLangType != LANGUAGE_NONE &&
-                 !MsLangId::isLegacy( nLangType) &&
-                 (MsLangId::getSubLanguage( nLangType) ||
-                  bool(nLangList & SvxLanguageListFlags::ALSO_PRIMARY_ONLY)) &&
-                 (bool(nLangList & SvxLanguageListFlags::ALL) ||
-                  (bool(nLangList & SvxLanguageListFlags::WESTERN) &&
-                   (SvtLanguageOptions::GetScriptTypeOfLanguage(nLangType) ==
-                    SvtScriptType::LATIN)) ||
-                  (bool(nLangList & SvxLanguageListFlags::CTL) &&
-                   (SvtLanguageOptions::GetScriptTypeOfLanguage(nLangType) ==
-                    SvtScriptType::COMPLEX)) ||
-                  (bool(nLangList & SvxLanguageListFlags::CJK) &&
-                   (SvtLanguageOptions::GetScriptTypeOfLanguage(nLangType) ==
-                    SvtScriptType::ASIAN)) ||
-                  (bool(nLangList & SvxLanguageListFlags::FBD_CHARS) &&
-                   MsLangId::hasForbiddenCharacters(nLangType)) ||
-                  (bool(nLangList & SvxLanguageListFlags::SPELL_AVAIL) &&
-                   lcl_SeqHasLang(aSpellAvailLang, nLangType)) ||
-                  (bool(nLangList & SvxLanguageListFlags::HYPH_AVAIL) &&
-                   lcl_SeqHasLang(aHyphAvailLang, nLangType)) ||
-                  (bool(nLangList & SvxLanguageListFlags::THES_AVAIL) &&
-                   lcl_SeqHasLang(aThesAvailLang, nLangType)) ||
-                  (bool(nLangList & SvxLanguageListFlags::SPELL_USED) &&
-                   lcl_SeqHasLang(aSpellUsedLang, nLangType)) ||
-                  (bool(nLangList & SvxLanguageListFlags::HYPH_USED) &&
-                   lcl_SeqHasLang(aHyphUsedLang, nLangType)) ||
-                  (bool(nLangList & SvxLanguageListFlags::THES_USED) &&
-                   lcl_SeqHasLang(aThesUsedLang, nLangType))) )
-                InsertLanguage( nLangType );
-        }
-
-        if (bHasLangNone)
-            InsertLanguage( LANGUAGE_NONE );
     }
+    if (SvxLanguageListFlags::SPELL_USED & nLangList)
+    {
+        Reference< XSpellChecker1 > xTmp1( LinguMgr::GetSpellChecker(), UNO_QUERY );
+        if (xTmp1.is())
+            aSpellUsedLang = xTmp1->getLanguages();
+    }
+    if (SvxLanguageListFlags::HYPH_USED  & nLangList)
+    {
+        Reference< XHyphenator > xTmp( LinguMgr::GetHyphenator() );
+        if (xTmp.is()) {
+            Sequence < css::lang::Locale > aLocaleSequence( xTmp->getLocales() );
+            aHyphUsedLang = lcl_LocaleSeqToLangSeq( aLocaleSequence );
+        }
+    }
+    if (SvxLanguageListFlags::THES_USED  & nLangList)
+    {
+        Reference< XThesaurus > xTmp( LinguMgr::GetThesaurus() );
+        if (xTmp.is()) {
+            Sequence < css::lang::Locale > aLocaleSequence( xTmp->getLocales() );
+            aThesUsedLang = lcl_LocaleSeqToLangSeq( aLocaleSequence );
+        }
+    }
+
+    std::vector<LanguageType> aKnown;
+    sal_uInt32 nCount;
+    if ( nLangList & SvxLanguageListFlags::ONLY_KNOWN )
+    {
+        aKnown = LocaleDataWrapper::getInstalledLanguageTypes();
+        nCount = aKnown.size();
+    }
+    else
+    {
+        nCount = SvtLanguageTable::GetLanguageEntryCount();
+    }
+    for ( sal_uInt32 i = 0; i < nCount; i++ )
+    {
+        LanguageType nLangType;
+        if ( nLangList & SvxLanguageListFlags::ONLY_KNOWN )
+            nLangType = aKnown[i];
+        else
+            nLangType = SvtLanguageTable::GetLanguageTypeAtIndex( i );
+        if ( lcl_isPrerequisite( nLangType, nLangList) &&
+             (lcl_isScriptTypeRequested( nLangType, nLangList) ||
+              (bool(nLangList & SvxLanguageListFlags::FBD_CHARS) &&
+               MsLangId::hasForbiddenCharacters(nLangType)) ||
+              (bool(nLangList & SvxLanguageListFlags::SPELL_AVAIL) &&
+               lcl_SeqHasLang(aSpellAvailLang, nLangType)) ||
+              (bool(nLangList & SvxLanguageListFlags::HYPH_AVAIL) &&
+               lcl_SeqHasLang(aHyphAvailLang, nLangType)) ||
+              (bool(nLangList & SvxLanguageListFlags::THES_AVAIL) &&
+               lcl_SeqHasLang(aThesAvailLang, nLangType)) ||
+              (bool(nLangList & SvxLanguageListFlags::SPELL_USED) &&
+               lcl_SeqHasLang(aSpellUsedLang, (sal_uInt16)nLangType)) ||
+              (bool(nLangList & SvxLanguageListFlags::HYPH_USED) &&
+               lcl_SeqHasLang(aHyphUsedLang, nLangType)) ||
+              (bool(nLangList & SvxLanguageListFlags::THES_USED) &&
+               lcl_SeqHasLang(aThesUsedLang, nLangType))) )
+            InsertLanguage( nLangType );
+    }
+
+    if (bAddAvailable)
+    {
+        // Spell checkers, hyphenators and thesauri may add language tags
+        // unknown so far.
+        AddLanguages( aSpellAvailLang, nLangList);
+        AddLanguages( aHyphAvailLang, nLangList);
+        AddLanguages( aThesAvailLang, nLangList);
+    }
+
+    if (bHasLangNone)
+        InsertLanguage( LANGUAGE_NONE );
 }
 
 
@@ -343,17 +386,17 @@ sal_Int32 SvxLanguageBoxBase::ImplInsertLanguage( const LanguageType nLangType,
         {
             Reference< XSpellChecker1 > xSpell( LinguMgr::GetSpellChecker(), UNO_QUERY );
             if ( xSpell.is() )
-                m_pSpellUsedLang = new Sequence< sal_Int16 >( xSpell->getLanguages() );
+                m_pSpellUsedLang.reset( new Sequence< sal_Int16 >( xSpell->getLanguages() ) );
         }
         bFound = m_pSpellUsedLang &&
-            lcl_SeqHasLang( *m_pSpellUsedLang, nRealLang );
+            lcl_SeqHasLang( *m_pSpellUsedLang, (sal_uInt16)nRealLang );
 
         nAt = ImplInsertImgEntry( aStrEntry, nPos, bFound );
     }
     else
         nAt = ImplInsertEntry( aStrEntry, nPos );
 
-    ImplSetEntryData( nAt, reinterpret_cast<void*>(nLangType) );
+    ImplSetEntryData( nAt, reinterpret_cast<void*>((sal_uInt16)nLangType) );
     return nAt;
 }
 
@@ -389,7 +432,7 @@ void SvxLanguageBoxBase::InsertLanguage( const LanguageType nLangType,
         aStrEntry = m_aAllString;
 
     sal_Int32 nAt = ImplInsertImgEntry( aStrEntry, LISTBOX_APPEND, bCheckEntry );
-    ImplSetEntryData( nAt, reinterpret_cast<void*>(nLang) );
+    ImplSetEntryData( nAt, reinterpret_cast<void*>((sal_uInt16)nLang) );
 }
 
 
@@ -409,7 +452,7 @@ LanguageType SvxLanguageBoxBase::GetSelectLanguage() const
     if ( nPos != LISTBOX_ENTRY_NOTFOUND )
         return LanguageType( reinterpret_cast<sal_uIntPtr>(ImplGetEntryData(nPos)) );
     else
-        return LanguageType( LANGUAGE_DONTKNOW );
+        return LANGUAGE_DONTKNOW;
 }
 
 
@@ -445,7 +488,7 @@ bool SvxLanguageBoxBase::IsLanguageSelected( const LanguageType eLangType ) cons
 
 sal_Int32 SvxLanguageBoxBase::ImplTypeToPos( LanguageType eType ) const
 {
-    return ImplGetEntryPos( reinterpret_cast<void*>(eType) );
+    return ImplGetEntryPos( reinterpret_cast<void*>((sal_uInt16)eType) );
 }
 
 
@@ -568,12 +611,12 @@ void SvxLanguageComboBox::ImplSetEntryData( sal_Int32 nPos, void* pData )
 
 sal_Int32 SvxLanguageBox::ImplGetSelectEntryPos() const
 {
-    return GetSelectEntryPos();
+    return GetSelectedEntryPos();
 }
 
 sal_Int32 SvxLanguageComboBox::ImplGetSelectEntryPos() const
 {
-    return GetSelectEntryPos();
+    return GetSelectedEntryPos();
 }
 
 
@@ -662,7 +705,7 @@ void SvxLanguageBox::ImplSaveValue()
 void SvxLanguageComboBox::ImplSaveValue()
 {
     // Emulate the ListBox behavior.
-    mnSavedValuePos = GetSelectEntryPos();
+    mnSavedValuePos = GetSelectedEntryPos();
 }
 
 
