@@ -19,14 +19,13 @@
 
 #include <svx/polygn3d.hxx>
 #include <svx/svdpage.hxx>
-#include "svx/globl3d.hxx"
+#include <svx/globl3d.hxx>
 #include <basegfx/point/b3dpoint.hxx>
 #include <sdr/contact/viewcontactofe3dpolygon.hxx>
 #include <basegfx/polygon/b3dpolygon.hxx>
 #include <basegfx/polygon/b3dpolygontools.hxx>
 
 
-
 // DrawContact section
 
 sdr::contact::ViewContact* E3dPolygonObj::CreateObjectSpecificViewContact()
@@ -36,10 +35,9 @@ sdr::contact::ViewContact* E3dPolygonObj::CreateObjectSpecificViewContact()
 
 E3dPolygonObj::E3dPolygonObj(
     E3dDefaultAttributes& rDefault,
-    const basegfx::B3DPolyPolygon& rPolyPoly3D,
-    bool bLinOnly)
+    const basegfx::B3DPolyPolygon& rPolyPoly3D)
 :   E3dCompoundObject(rDefault),
-    bLineOnly(bLinOnly)
+    bLineOnly(true)
 {
     // Set geometry
     SetPolyPolygon3D(rPolyPoly3D);
@@ -63,7 +61,7 @@ void E3dPolygonObj::CreateDefaultNormals()
     basegfx::B3DPolyPolygon aPolyNormals;
 
     // Create a complete tools::PolyPolygon with the plane normal
-    for(sal_uInt32 a(0L); a < aPolyPoly3D.count(); a++)
+    for(sal_uInt32 a(0); a < aPolyPoly3D.count(); a++)
     {
         // Find source polygon
         const basegfx::B3DPolygon aPolygon(aPolyPoly3D.getB3DPolygon(a));
@@ -75,7 +73,7 @@ void E3dPolygonObj::CreateDefaultNormals()
         basegfx::B3DVector aNormal(-aPolygon.getNormal());
 
         // Fill new polygon
-        for(sal_uInt32 b(0L); b < aPolygon.count(); b++)
+        for(sal_uInt32 b(0); b < aPolygon.count(); b++)
         {
             aNormals.append(aNormal);
         }
@@ -94,13 +92,13 @@ void E3dPolygonObj::CreateDefaultTexture()
     // Create a complete tools::PolyPolygon with the texture coordinates
     // The texture coordinates extend over X,Y and Z
     // on the whole extreme values in the range 0.0 .. 1.0
-    for(sal_uInt32 a(0L); a < aPolyPoly3D.count(); a++)
+    for(sal_uInt32 a(0); a < aPolyPoly3D.count(); a++)
     {
         // Find source polygon
         const basegfx::B3DPolygon& aPolygon(aPolyPoly3D.getB3DPolygon(a));
 
         // Determine the total size of the object
-        basegfx::B3DRange aVolume(basegfx::tools::getRange(aPolygon));
+        basegfx::B3DRange aVolume(basegfx::utils::getRange(aPolygon));
 
         // Get normal
         basegfx::B3DVector aNormal(aPolygon.getNormal());
@@ -130,7 +128,7 @@ void E3dPolygonObj::CreateDefaultTexture()
         basegfx::B2DPolygon aTexture;
 
         // Fill new polygon
-        for(sal_uInt32 b(0L); b < aPolygon.count(); b++)
+        for(sal_uInt32 b(0); b < aPolygon.count(); b++)
         {
             basegfx::B2DPoint aTex;
             const basegfx::B3DPoint aCandidate(aPolygon.getB3DPoint(b));
