@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "svx/dbcharsethelper.hxx"
+#include <svx/dbcharsethelper.hxx>
 
 #include <connectivity/dbtools.hxx>
 #include <connectivity/dbcharset.hxx>
@@ -47,6 +47,4 @@ namespace svxform { namespace charset_helper
 }
 
 
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
