@@ -19,11 +19,12 @@
 
 #include <config_features.h>
 
-#include "fmscriptingenv.hxx"
-#include "svx/fmmodel.hxx"
+#include <fmscriptingenv.hxx>
+#include <svx/fmmodel.hxx>
 
 #include <com/sun/star/awt/XControl.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
+#include <com/sun/star/frame/TerminationVetoException.hpp>
 #include <com/sun/star/frame/XTerminateListener.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <com/sun/star/lang/EventObject.hpp>
@@ -88,10 +89,10 @@ namespace svxform
         explicit FormScriptListener( FormScriptingEnvironment * pScriptExecutor );
 
         // XScriptListener
-        virtual void SAL_CALL firing( const ScriptEvent& aEvent ) throw (RuntimeException, std::exception) override;
-        virtual Any SAL_CALL approveFiring( const ScriptEvent& aEvent ) throw (InvocationTargetException, RuntimeException, std::exception) override;
+        virtual void SAL_CALL firing( const ScriptEvent& aEvent ) override;
+        virtual Any SAL_CALL approveFiring( const ScriptEvent& aEvent ) override;
         // XEventListener
-        virtual void SAL_CALL disposing( const EventObject& Source ) throw (RuntimeException, std::exception) override;
+        virtual void SAL_CALL disposing( const EventObject& Source ) override;
 
         // lifetime control
         void SAL_CALL dispose();
@@ -151,7 +152,6 @@ namespace svxform
 
     public:
         explicit FormScriptingEnvironment( FmFormModel& _rModel );
-        virtual ~FormScriptingEnvironment() override;
         FormScriptingEnvironment(const FormScriptingEnvironment&) = delete;
         FormScriptingEnvironment& operator=(const FormScriptingEnvironment&) = delete;
 
@@ -723,7 +723,7 @@ namespace svxform
     }
 
 
-    void SAL_CALL FormScriptListener::firing( const ScriptEvent& _rEvent ) throw (RuntimeException, std::exception)
+    void SAL_CALL FormScriptListener::firing( const ScriptEvent& _rEvent )
     {
        if ( _rEvent.ScriptType == "VBAInterop" )
            return; // not handled here
@@ -744,7 +744,7 @@ namespace svxform
     }
 
 
-    Any SAL_CALL FormScriptListener::approveFiring( const ScriptEvent& _rEvent ) throw (InvocationTargetException, RuntimeException, std::exception)
+    Any SAL_CALL FormScriptListener::approveFiring( const ScriptEvent& _rEvent )
     {
         Any aResult;
 
@@ -756,7 +756,7 @@ namespace svxform
     }
 
 
-    void SAL_CALL FormScriptListener::disposing( const EventObject& /*Source*/ ) throw (RuntimeException, std::exception)
+    void SAL_CALL FormScriptListener::disposing( const EventObject& /*Source*/ )
     {
         // not interested in
     }
@@ -786,8 +786,7 @@ namespace svxform
             bool mbQuitBlocked;
         public:
             // XTerminateListener
-            virtual void SAL_CALL queryTermination(const css::lang::EventObject& /*rEvent*/)
-                throw(css::frame::TerminationVetoException, css::uno::RuntimeException, std::exception) override
+            virtual void SAL_CALL queryTermination(const css::lang::EventObject& /*rEvent*/) override
             {
                 mbQuitBlocked = true;
 #if HAVE_FEATURE_SCRIPTING
@@ -796,16 +795,14 @@ namespace svxform
                 throw css::frame::TerminationVetoException();
             }
 
-            virtual void SAL_CALL notifyTermination(const css::lang::EventObject& /*rEvent*/)
-                throw(css::uno::RuntimeException, std::exception) override
+            virtual void SAL_CALL notifyTermination(const css::lang::EventObject& /*rEvent*/) override
             {
                 mbQuitBlocked = false;
             }
 
             using cppu::WeakComponentImplHelperBase::disposing;
 
-            virtual void SAL_CALL disposing(const css::lang::EventObject& rEvent)
-                throw(css::uno::RuntimeException, std::exception) override
+            virtual void SAL_CALL disposing(const css::lang::EventObject& rEvent) override
             {
                 const bool bShutDown = (rEvent.Source == m_xDesktop);
                 if (bShutDown && m_xDesktop.is())
@@ -816,23 +813,19 @@ namespace svxform
             }
 
             // XServiceInfo
-            virtual OUString SAL_CALL getImplementationName()
-                throw (css::uno::RuntimeException, std::exception) override
+            virtual OUString SAL_CALL getImplementationName() override
             {
                 return OUString("com.sun.star.comp.svx.StarBasicQuitGuard");
             }
 
-            virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
-                throw (css::uno::RuntimeException, std::exception) override
+            virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName) override
             {
                 return cppu::supportsService(this, ServiceName);
             }
 
-            virtual css::uno::Sequence<OUString> SAL_CALL getSupportedServiceNames()
-                throw (css::uno::RuntimeException, std::exception) override
+            virtual css::uno::Sequence<OUString> SAL_CALL getSupportedServiceNames() override
             {
-                css::uno::Sequence<OUString> aSeq { "com.sun.star.svx.StarBasicQuitGuard" };
-                return aSeq;
+                return { "com.sun.star.svx.StarBasicQuitGuard" };
             }
 
         public:
@@ -860,19 +853,17 @@ namespace svxform
             }
         };
 
-        TerminateListener* mpListener;
-        css::uno::Reference<css::frame::XTerminateListener> mxLifeCycle;
+        rtl::Reference<TerminateListener> mxListener;
     public:
         QuitGuard()
-            : mpListener(new TerminateListener)
-            , mxLifeCycle(mpListener)
+            : mxListener(new TerminateListener)
         {
-            mpListener->start();
+            mxListener->start();
         }
 
         ~QuitGuard()
         {
-            mpListener->stop();
+            mxListener->stop();
         }
     };
 
@@ -908,12 +899,6 @@ namespace svxform
         // This cycle is broken up when our instance is disposed.
     }
 
-
-    FormScriptingEnvironment::~FormScriptingEnvironment()
-    {
-    }
-
-
     void FormScriptingEnvironment::impl_registerOrRevoke_throw( const Reference< XEventAttacherManager >& _rxManager, bool _bRegister )
     {
         ::osl::MutexGuard aGuard( m_aMutex );
@@ -957,19 +942,7 @@ namespace svxform
 
     namespace
     {
-
-        //. NewStyleUNOScript
-
-        class SAL_NO_VTABLE IScript
-        {
-        public:
-            virtual void invoke( const Sequence< Any >& _rArguments, Any& _rSynchronousResult ) = 0;
-
-            virtual ~IScript() { }
-        };
-        typedef std::shared_ptr< IScript >  PScript;
-
-        class NewStyleUNOScript : public IScript
+        class NewStyleUNOScript
         {
             SfxObjectShell&         m_rObjectShell;
             const OUString   m_sScriptCode;
@@ -981,8 +954,7 @@ namespace svxform
             {
             }
 
-            // IScript
-            virtual void invoke( const Sequence< Any >& _rArguments, Any& _rSynchronousResult ) override;
+            void invoke( const Sequence< Any >& _rArguments, Any& _rSynchronousResult );
         };
 
 
@@ -1022,11 +994,11 @@ namespace svxform
 
         // SfxObjectShellRef is good here since the model controls the lifetime of the object
         SfxObjectShellRef xObjectShell = m_rFormModel.GetObjectShell();
-        if( !xObjectShell.Is() )
+        if( !xObjectShell.is() )
             return;
 
         // the script to execute
-        PScript pScript;
+        std::shared_ptr< NewStyleUNOScript > pScript;
 
         if ( _rEvent.ScriptType != "StarBasic" )
         {
