@@ -17,21 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <o3tl/any.hxx>
 #include <svx/sdasitm.hxx>
 #include <svx/svdattr.hxx>
 
 using namespace ::std;
 using namespace com::sun::star;
 
-SdrCustomShapeEngineItem::SdrCustomShapeEngineItem()
-:   SfxStringItem( SDRATTR_CUSTOMSHAPE_ENGINE, "" )
-{}
-
-SdrCustomShapeDataItem::SdrCustomShapeDataItem()
-:   SfxStringItem( SDRATTR_CUSTOMSHAPE_DATA, "" )
-{}
-
-TYPEINIT1_FACTORY( SdrCustomShapeGeometryItem, SfxPoolItem , new  SdrCustomShapeGeometryItem);
 
 SdrCustomShapeGeometryItem::SdrCustomShapeGeometryItem()
 :   SfxPoolItem( SDRATTR_CUSTOMSHAPE_GEOMETRY )
@@ -54,101 +48,93 @@ SdrCustomShapeGeometryItem::SdrCustomShapeGeometryItem( const uno::Sequence< bea
             throw uno::RuntimeException(
                 "CustomShapeGeometry has duplicate property " + rPropVal.Name);
         }
-        if ( rPropVal.Value.getValueType() == cppu::UnoType<css::uno::Sequence < beans::PropertyValue >>::get() )
+        if (auto rPropSeq = o3tl::tryAccess<uno::Sequence<beans::PropertyValue>>(
+                rPropVal.Value))
         {
-            uno::Sequence< beans::PropertyValue > const & rPropSeq = *static_cast<uno::Sequence< beans::PropertyValue > const *>(rPropVal.Value.getValue());
-            for ( j = 0; j < rPropSeq.getLength(); j++ )
+            for ( j = 0; j < rPropSeq->getLength(); j++ )
             {
-                beans::PropertyValue const & rPropVal2 = rPropSeq[ j ];
+                beans::PropertyValue const & rPropVal2 = (*rPropSeq)[ j ];
                 aPropPairHashMap[ PropertyPair( rPropVal.Name, rPropVal2.Name ) ] = j;
             }
         }
     }
 }
 
-com::sun::star::uno::Any* SdrCustomShapeGeometryItem::GetPropertyValueByName( const OUString& rPropName )
+css::uno::Any* SdrCustomShapeGeometryItem::GetPropertyValueByName( const OUString& rPropName )
 {
-    com::sun::star::uno::Any* pRet = NULL;
+    css::uno::Any* pRet = nullptr;
     PropertyHashMap::iterator aHashIter( aPropHashMap.find( rPropName ) );
     if ( aHashIter != aPropHashMap.end() )
         pRet = &aPropSeq[ (*aHashIter).second ].Value;
     return pRet;
 }
 
-const com::sun::star::uno::Any* SdrCustomShapeGeometryItem::GetPropertyValueByName( const OUString& rPropName ) const
+const css::uno::Any* SdrCustomShapeGeometryItem::GetPropertyValueByName( const OUString& rPropName ) const
 {
-    const com::sun::star::uno::Any* pRet = NULL;
+    const css::uno::Any* pRet = nullptr;
     PropertyHashMap::const_iterator aHashIter( aPropHashMap.find( rPropName ) );
     if ( aHashIter != aPropHashMap.end() )
         pRet = &aPropSeq[ (*aHashIter).second ].Value;
     return pRet;
 }
 
-com::sun::star::uno::Any* SdrCustomShapeGeometryItem::GetPropertyValueByName( const OUString& rSequenceName, const OUString& rPropName )
+css::uno::Any* SdrCustomShapeGeometryItem::GetPropertyValueByName( const OUString& rSequenceName, const OUString& rPropName )
 {
-    com::sun::star::uno::Any* pRet = NULL;
-    com::sun::star::uno::Any* pSeqAny = GetPropertyValueByName( rSequenceName );
+    css::uno::Any* pRet = nullptr;
+    css::uno::Any* pSeqAny = GetPropertyValueByName( rSequenceName );
     if ( pSeqAny )
     {
-        if ( pSeqAny->getValueType() == cppu::UnoType<css::uno::Sequence < beans::PropertyValue >>::get() )
+        if ( auto rSecSequence = o3tl::tryAccess<css::uno::Sequence<beans::PropertyValue>>(*pSeqAny) )
         {
             PropertyPairHashMap::iterator aHashIter( aPropPairHashMap.find( PropertyPair( rSequenceName, rPropName ) ) );
             if ( aHashIter != aPropPairHashMap.end() )
             {
-                ::com::sun::star::uno::Sequence < beans::PropertyValue > const & rSecSequence =
-                    *static_cast<css::uno::Sequence < beans::PropertyValue > const *>(pSeqAny->getValue());
-                pRet = const_cast<css::uno::Any *>(&rSecSequence[ (*aHashIter).second ].Value);
+                pRet = const_cast<css::uno::Any *>(&(*rSecSequence)[ (*aHashIter).second ].Value);
             }
         }
     }
     return pRet;
 }
 
-const com::sun::star::uno::Any* SdrCustomShapeGeometryItem::GetPropertyValueByName( const OUString& rSequenceName, const OUString& rPropName ) const
+const css::uno::Any* SdrCustomShapeGeometryItem::GetPropertyValueByName( const OUString& rSequenceName, const OUString& rPropName ) const
 {
-    const com::sun::star::uno::Any* pRet = NULL;
-    const com::sun::star::uno::Any* pSeqAny = GetPropertyValueByName( rSequenceName );
+    const css::uno::Any* pRet = nullptr;
+    const css::uno::Any* pSeqAny = GetPropertyValueByName( rSequenceName );
     if ( pSeqAny )
     {
-        if ( pSeqAny->getValueType() == cppu::UnoType<css::uno::Sequence < beans::PropertyValue >>::get() )
+        if ( auto rSecSequence = o3tl::tryAccess<css::uno::Sequence<beans::PropertyValue>>(*pSeqAny) )
         {
             PropertyPairHashMap::const_iterator aHashIter( aPropPairHashMap.find( PropertyPair( rSequenceName, rPropName ) ) );
             if ( aHashIter != aPropPairHashMap.end() )
             {
-                ::com::sun::star::uno::Sequence < beans::PropertyValue > const & rSecSequence =
-                    *static_cast<css::uno::Sequence < beans::PropertyValue > const *>(pSeqAny->getValue());
-                pRet = &rSecSequence[ (*aHashIter).second ].Value;
+                pRet = &(*rSecSequence)[ (*aHashIter).second ].Value;
             }
         }
     }
     return pRet;
 }
 
-void SdrCustomShapeGeometryItem::SetPropertyValue( const com::sun::star::beans::PropertyValue& rPropVal )
+void SdrCustomShapeGeometryItem::SetPropertyValue( const css::beans::PropertyValue& rPropVal )
 {
-    com::sun::star::uno::Any* pAny = GetPropertyValueByName( rPropVal.Name );
+    css::uno::Any* pAny = GetPropertyValueByName( rPropVal.Name );
     if ( pAny )
     {   // property is already available
         sal_Int32 i;
-        if ( pAny->getValueType() == cppu::UnoType<css::uno::Sequence < beans::PropertyValue >>::get() )
+        if ( auto rSecSequence = o3tl::tryAccess<css::uno::Sequence<beans::PropertyValue>>(*pAny) )
         {   // old property is a sequence->each entry has to be removed from the HashPairMap
-            ::com::sun::star::uno::Sequence < beans::PropertyValue > const & rSecSequence =
-                *static_cast<css::uno::Sequence < beans::PropertyValue > const *>(pAny->getValue());
-            for ( i = 0; i < rSecSequence.getLength(); i++ )
+            for ( i = 0; i < rSecSequence->getLength(); i++ )
             {
-                PropertyPairHashMap::iterator aHashIter( aPropPairHashMap.find( PropertyPair( rPropVal.Name, rSecSequence[ i ].Name ) ) );
+                PropertyPairHashMap::iterator aHashIter( aPropPairHashMap.find( PropertyPair( rPropVal.Name, (*rSecSequence)[ i ].Name ) ) );
                 if ( aHashIter != aPropPairHashMap.end() )
                     aPropPairHashMap.erase( aHashIter );
             }
         }
         *pAny = rPropVal.Value;
-        if ( rPropVal.Value.getValueType() == cppu::UnoType<css::uno::Sequence < beans::PropertyValue >>::get() )
+        if ( auto rSecSequence = o3tl::tryAccess<css::uno::Sequence<beans::PropertyValue>>(*pAny) )
         {   // the new property is a sequence->each entry has to be inserted into the HashPairMap
-            ::com::sun::star::uno::Sequence < beans::PropertyValue > const & rSecSequence =
-                *static_cast<css::uno::Sequence < beans::PropertyValue > const *>(pAny->getValue());
-            for ( i = 0; i < rSecSequence.getLength(); i++ )
+            for ( i = 0; i < rSecSequence->getLength(); i++ )
             {
-                beans::PropertyValue const & rPropVal2 = rSecSequence[ i ];
+                beans::PropertyValue const & rPropVal2 = (*rSecSequence)[ i ];
                 aPropPairHashMap[ PropertyPair( rPropVal.Name, rPropVal2.Name ) ] = i;
             }
         }
@@ -166,20 +152,20 @@ void SdrCustomShapeGeometryItem::SetPropertyValue( const com::sun::star::beans::
     }
 }
 
-void SdrCustomShapeGeometryItem::SetPropertyValue( const OUString& rSequenceName, const com::sun::star::beans::PropertyValue& rPropVal )
+void SdrCustomShapeGeometryItem::SetPropertyValue( const OUString& rSequenceName, const css::beans::PropertyValue& rPropVal )
 {
-    com::sun::star::uno::Any* pAny = GetPropertyValueByName( rSequenceName, rPropVal.Name );
+    css::uno::Any* pAny = GetPropertyValueByName( rSequenceName, rPropVal.Name );
     if ( pAny ) // just replacing
         *pAny = rPropVal.Value;
     else
     {
-        com::sun::star::uno::Any* pSeqAny = GetPropertyValueByName( rSequenceName );
-        if( pSeqAny == NULL )
+        css::uno::Any* pSeqAny = GetPropertyValueByName( rSequenceName );
+        if( pSeqAny == nullptr )
         {
-            ::com::sun::star::uno::Sequence < beans::PropertyValue > aSeq;
+            css::uno::Sequence < beans::PropertyValue > aSeq;
             beans::PropertyValue aValue;
             aValue.Name = rSequenceName;
-            aValue.Value = ::com::sun::star::uno::makeAny( aSeq );
+            aValue.Value <<= aSeq;
 
             assert(aPropSeq.end() == std::find_if(aPropSeq.begin(), aPropSeq.end(),
                 [&rSequenceName](beans::PropertyValue const& rV)
@@ -196,23 +182,18 @@ void SdrCustomShapeGeometryItem::SetPropertyValue( const OUString& rSequenceName
 
         if( pSeqAny )
         {
-            if ( pSeqAny->getValueType() == cppu::UnoType<css::uno::Sequence < beans::PropertyValue >>::get() )
+            if ( auto rSecSequence = o3tl::tryAccess<css::uno::Sequence<beans::PropertyValue>>(*pSeqAny) )
             {
                 PropertyPairHashMap::iterator aHashIter( aPropPairHashMap.find( PropertyPair( rSequenceName, rPropVal.Name ) ) );
                 if ( aHashIter != aPropPairHashMap.end() )
                 {
-                    ::com::sun::star::uno::Sequence < beans::PropertyValue > const & rSecSequence =
-                        *static_cast<css::uno::Sequence < beans::PropertyValue > const *>(pSeqAny->getValue());
-                    const_cast<css::uno::Sequence<css::beans::PropertyValue> &>(rSecSequence)[ (*aHashIter).second ].Value = rPropVal.Value;
+                    const_cast<css::uno::Sequence<css::beans::PropertyValue> &>(*rSecSequence)[ (*aHashIter).second ].Value = rPropVal.Value;
                 }
                 else
                 {
-                    ::com::sun::star::uno::Sequence < beans::PropertyValue > const & rSecSequence =
-                        *static_cast<css::uno::Sequence < beans::PropertyValue > const *>(pSeqAny->getValue());
-
-                    sal_Int32 nCount = rSecSequence.getLength();
-                    const_cast<css::uno::Sequence<css::beans::PropertyValue> &>(rSecSequence).realloc( nCount + 1 );
-                    const_cast<css::uno::Sequence<css::beans::PropertyValue> &>(rSecSequence)[ nCount ] = rPropVal;
+                    sal_Int32 nCount = rSecSequence->getLength();
+                    const_cast<css::uno::Sequence<css::beans::PropertyValue> &>(*rSecSequence).realloc( nCount + 1 );
+                    const_cast<css::uno::Sequence<css::beans::PropertyValue> &>(*rSecSequence)[ nCount ] = rPropVal;
 
                     aPropPairHashMap[ PropertyPair( rSequenceName, rPropVal.Name ) ] = nCount;
                 }
@@ -228,18 +209,15 @@ void SdrCustomShapeGeometryItem::ClearPropertyValue( const OUString& rPropName )
         PropertyHashMap::iterator aHashIter( aPropHashMap.find( rPropName ) );
         if ( aHashIter != aPropHashMap.end() )
         {
-             com::sun::star::uno::Any* pSeqAny = &aPropSeq[ (*aHashIter).second ].Value;
+             css::uno::Any* pSeqAny = &aPropSeq[ (*aHashIter).second ].Value;
             if ( pSeqAny )
             {
-                if ( pSeqAny->getValueType() == cppu::UnoType<css::uno::Sequence < beans::PropertyValue >>::get() )
+                if ( auto rSecSequence = o3tl::tryAccess<css::uno::Sequence<beans::PropertyValue>>(*pSeqAny) )
                 {
-                    ::com::sun::star::uno::Sequence < beans::PropertyValue > const & rSecSequence =
-                        *static_cast<css::uno::Sequence < beans::PropertyValue > const *>(pSeqAny->getValue());
-
                     sal_Int32 i;
-                    for ( i = 0; i < rSecSequence.getLength(); i++ )
+                    for ( i = 0; i < rSecSequence->getLength(); i++ )
                     {
-                        PropertyPairHashMap::iterator _aHashIter( aPropPairHashMap.find( PropertyPair( rPropName, rSecSequence[ i ].Name ) ) );
+                        PropertyPairHashMap::iterator _aHashIter( aPropPairHashMap.find( PropertyPair( rPropName, (*rSecSequence)[ i ].Name ) ) );
                         if ( _aHashIter != aPropPairHashMap.end() )
                             aPropPairHashMap.erase( _aHashIter );       // removing property from pair hashmap
                     }
@@ -265,14 +243,6 @@ void SdrCustomShapeGeometryItem::ClearPropertyValue( const OUString& rPropName )
 SdrCustomShapeGeometryItem::~SdrCustomShapeGeometryItem()
 {
 }
-SdrCustomShapeGeometryItem::SdrCustomShapeGeometryItem( SvStream& /*rIn*/, sal_uInt16 nVersion ):
-    SfxPoolItem( SDRATTR_CUSTOMSHAPE_GEOMETRY )
-{
-    if ( nVersion )
-    {
-
-    }
-}
 bool SdrCustomShapeGeometryItem::operator==( const SfxPoolItem& rCmp ) const
 {
     bool bRet = SfxPoolItem::operator==( rCmp );
@@ -282,37 +252,23 @@ bool SdrCustomShapeGeometryItem::operator==( const SfxPoolItem& rCmp ) const
 }
 
 bool SdrCustomShapeGeometryItem::GetPresentation(
-    SfxItemPresentation ePresentation, SfxMapUnit /*eCoreMetric*/,
-    SfxMapUnit /*ePresentationMetric*/, OUString &rText, const IntlWrapper *) const
+    SfxItemPresentation ePresentation, MapUnit /*eCoreMetric*/,
+    MapUnit /*ePresentationMetric*/, OUString &rText, const IntlWrapper&) const
 {
     rText += " ";
-    if ( ePresentation == SFX_ITEM_PRESENTATION_COMPLETE )
+    if ( ePresentation == SfxItemPresentation::Complete )
     {
         rText = " " + rText;
         return true;
     }
-    else if ( ePresentation == SFX_ITEM_PRESENTATION_NAMELESS )
+    else if ( ePresentation == SfxItemPresentation::Nameless )
         return true;
     return false;
 }
 
-SfxPoolItem* SdrCustomShapeGeometryItem::Create( SvStream& rIn, sal_uInt16 nItemVersion ) const
-{
-    return new SdrCustomShapeGeometryItem( rIn, nItemVersion );
-}
-
-SvStream& SdrCustomShapeGeometryItem::Store( SvStream& rOut, sal_uInt16 nItemVersion ) const
-{
-    if ( nItemVersion )
-    {
-
-    }
-    return rOut;
-}
-
 SfxPoolItem* SdrCustomShapeGeometryItem::Clone( SfxItemPool * /*pPool*/ ) const
 {
-    return new SdrCustomShapeGeometryItem( GetGeometry() );
+    return new SdrCustomShapeGeometryItem( aPropSeq );
 }
 
 sal_uInt16 SdrCustomShapeGeometryItem::GetVersion( sal_uInt16 /*nFileFormatVersion*/ ) const
@@ -348,8 +304,4 @@ bool SdrCustomShapeGeometryItem::PutValue( const uno::Any& rVal, sal_uInt8 /*nMe
     }
 }
 
-SdrCustomShapeReplacementURLItem::SdrCustomShapeReplacementURLItem()
-:   SfxStringItem( SDRATTR_CUSTOMSHAPE_REPLACEMENT_URL, "" )
-{}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
