@@ -23,15 +23,15 @@
 #include <com/sun/star/uno/Sequence.hxx>
 #include <com/sun/star/beans/PropertyValue.hpp>
 
-// -----------------------------------------------------------------------
+#include <osl/diagnose.h>
 
-TYPEINIT1_FACTORY(SvxViewLayoutItem,SfxUInt16Item, new SvxViewLayoutItem);
+
+SfxPoolItem* SvxViewLayoutItem::CreateDefault() { return new SvxViewLayoutItem; }
 
 #define VIEWLAYOUT_PARAM_COLUMNS    "Columns"
 #define VIEWLAYOUT_PARAM_BOOKMODE   "BookMode"
 #define VIEWLAYOUT_PARAMS           2
 
-// -----------------------------------------------------------------------
 
 SvxViewLayoutItem::SvxViewLayoutItem
 (
@@ -44,7 +44,6 @@ SvxViewLayoutItem::SvxViewLayoutItem
 {
 }
 
-// -----------------------------------------------------------------------
 
 SvxViewLayoutItem::SvxViewLayoutItem( const SvxViewLayoutItem& rOrig )
 :   SfxUInt16Item( rOrig.Which(), rOrig.GetValue() ),
@@ -52,63 +51,46 @@ SvxViewLayoutItem::SvxViewLayoutItem( const SvxViewLayoutItem& rOrig )
 {
 }
 
-// -----------------------------------------------------------------------
 
 SvxViewLayoutItem::~SvxViewLayoutItem()
 {
 }
 
-// -----------------------------------------------------------------------
 
 SfxPoolItem* SvxViewLayoutItem::Clone( SfxItemPool * /*pPool*/ ) const
 {
     return new SvxViewLayoutItem( *this );
 }
 
-// -----------------------------------------------------------------------
 
-SfxPoolItem* SvxViewLayoutItem::Create( SvStream& /*rStrm*/, sal_uInt16 /*nVersion*/ ) const
+bool SvxViewLayoutItem::operator==( const SfxPoolItem& rAttr ) const
 {
-    return 0;
-}
+    assert(SfxPoolItem::operator==(rAttr));
 
-// -----------------------------------------------------------------------
-
-SvStream& SvxViewLayoutItem::Store( SvStream& rStrm, sal_uInt16 /*nItemVersion*/ ) const
-{
-    return rStrm;
-}
-
-// -----------------------------------------------------------------------
-
-int SvxViewLayoutItem::operator==( const SfxPoolItem& rAttr ) const
-{
-    DBG_ASSERT( SfxPoolItem::operator==(rAttr), "unequal types" );
-
-    SvxViewLayoutItem& rItem = (SvxViewLayoutItem&)rAttr;
+    const SvxViewLayoutItem& rItem = static_cast<const SvxViewLayoutItem&>(rAttr);
 
     return ( GetValue() == rItem.GetValue()     &&
              mbBookMode == rItem.IsBookMode() );
 }
 
-bool SvxViewLayoutItem::QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId ) const
+bool SvxViewLayoutItem::QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId ) const
 {
     nMemberId &= ~CONVERT_TWIPS;
     switch ( nMemberId )
     {
         case 0 :
         {
-            ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > aSeq( VIEWLAYOUT_PARAMS );
-            aSeq[0].Name = OUString( VIEWLAYOUT_PARAM_COLUMNS );
+            css::uno::Sequence< css::beans::PropertyValue > aSeq( VIEWLAYOUT_PARAMS );
+            aSeq[0].Name = VIEWLAYOUT_PARAM_COLUMNS;
             aSeq[0].Value <<= sal_Int32( GetValue() );
-            aSeq[1].Name = OUString( VIEWLAYOUT_PARAM_BOOKMODE );
-            aSeq[1].Value <<= sal_Bool( mbBookMode );
+            aSeq[1].Name = VIEWLAYOUT_PARAM_BOOKMODE;
+            aSeq[1].Value <<= mbBookMode;
             rVal <<= aSeq;
         }
         break;
 
         case MID_VIEWLAYOUT_COLUMNS : rVal <<= (sal_Int32) GetValue(); break;
-        case MID_VIEWLAYOUT_BOOKMODE: rVal <<= (sal_Bool) mbBookMode; break;
+        case MID_VIEWLAYOUT_BOOKMODE: rVal <<= mbBookMode; break;
         default:
             OSL_FAIL("svx::SvxViewLayoutItem::QueryValue(), Wrong MemberId!");
             return false;
@@ -117,28 +99,28 @@ bool SvxViewLayoutItem::QueryValue( com::sun::star::uno::Any& rVal, sal_uInt8 nM
     return true;
 }
 
-bool SvxViewLayoutItem::PutValue( const com::sun::star::uno::Any& rVal, sal_uInt8 nMemberId )
+bool SvxViewLayoutItem::PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId )
 {
     nMemberId &= ~CONVERT_TWIPS;
     switch ( nMemberId )
     {
         case 0 :
         {
-            ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > aSeq;
+            css::uno::Sequence< css::beans::PropertyValue > aSeq;
             if (( rVal >>= aSeq ) && ( aSeq.getLength() == VIEWLAYOUT_PARAMS ))
             {
                 sal_Int32 nColumns( 0 );
-                sal_Bool  bBookMode = sal_False;
-                sal_Bool  bAllConverted( sal_True );
+                bool  bBookMode = false;
+                bool bAllConverted( true );
                 sal_Int16 nConvertedCount( 0 );
                 for ( sal_Int32 i = 0; i < aSeq.getLength(); i++ )
                 {
-                    if ( aSeq[i].Name.equalsAscii( VIEWLAYOUT_PARAM_COLUMNS ))
+                    if ( aSeq[i].Name == VIEWLAYOUT_PARAM_COLUMNS )
                     {
                         bAllConverted &= ( aSeq[i].Value >>= nColumns );
                         ++nConvertedCount;
                     }
-                    else if ( aSeq[i].Name.equalsAscii( VIEWLAYOUT_PARAM_BOOKMODE ))
+                    else if ( aSeq[i].Name == VIEWLAYOUT_PARAM_BOOKMODE )
                     {
                         bAllConverted &= ( aSeq[i].Value >>= bBookMode );
                         ++nConvertedCount;
@@ -170,7 +152,7 @@ bool SvxViewLayoutItem::PutValue( const com::sun::star::uno::Any& rVal, sal_uInt
 
         case MID_VIEWLAYOUT_BOOKMODE:
         {
-            sal_Bool bBookMode = sal_False;
+            bool bBookMode = false;
             if ( rVal >>= bBookMode )
             {
                 mbBookMode = bBookMode;
