@@ -29,7 +29,7 @@
 #include <svx/sdr/contact/objectcontact.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <sdr/primitive2d/sdrgrafprimitive2d.hxx>
-#include "svx/svdstr.hrc"
+#include <svx/strings.hrc>
 #include <svdglob.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
@@ -45,7 +45,8 @@
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
 #include <drawinglayer/primitive2d/sdrdecompositiontools2d.hxx>
 
-#include "eventhandler.hxx"
+#include <eventhandler.hxx>
+#include <bitmaps.hlst>
 
 namespace sdr
 {
@@ -72,7 +73,7 @@ namespace sdr
 
         void ViewContactOfGraphic::flushGraphicObjects()
         {
-            // #i102380# The graphic is swapped out. To let that have an effect ist is necessary to
+            // #i102380# The graphic is swapped out. To let that have an effect, it is necessary to
             // delete copies of the GraphicObject which are not swapped out and have no SwapHandler set
             // (this is what happens when the GraphicObject gets copied to a SdrGrafPrimitive2D). This
             // is best achieved for the VC by clearing the local decomposition cache. It would be possible
@@ -81,11 +82,11 @@ namespace sdr
             flushViewIndependentPrimitive2DSequence();
         }
 
-        drawinglayer::primitive2d::Primitive2DSequence ViewContactOfGraphic::createVIP2DSForPresObj(
+        drawinglayer::primitive2d::Primitive2DContainer ViewContactOfGraphic::createVIP2DSForPresObj(
             const basegfx::B2DHomMatrix& rObjectMatrix,
             const drawinglayer::attribute::SdrLineFillShadowTextAttribute& rAttribute) const
         {
-            drawinglayer::primitive2d::Primitive2DSequence xRetval;
+            drawinglayer::primitive2d::Primitive2DContainer xRetval;
             GraphicObject aEmptyGraphicObject;
             GraphicAttr aEmptyGraphicAttr;
 
@@ -95,7 +96,7 @@ namespace sdr
                 rAttribute,
                 aEmptyGraphicObject,
                 aEmptyGraphicAttr));
-            xRetval = drawinglayer::primitive2d::Primitive2DSequence(&xReferenceA, 1);
+            xRetval = drawinglayer::primitive2d::Primitive2DContainer { xReferenceA };
 
             // SdrGrafPrimitive2D with content (which is the preview graphic) scaled to smaller size and
             // without attributes
@@ -106,13 +107,13 @@ namespace sdr
             // safe to assume 100th mm as target.
             Size aPrefSize(GetGrafObject().GetGrafPrefSize());
 
-            if(MAP_PIXEL == GetGrafObject().GetGrafPrefMapMode().GetMapUnit())
+            if(MapUnit::MapPixel == GetGrafObject().GetGrafPrefMapMode().GetMapUnit())
             {
-                aPrefSize = Application::GetDefaultDevice()->PixelToLogic(aPrefSize, MAP_100TH_MM);
+                aPrefSize = Application::GetDefaultDevice()->PixelToLogic(aPrefSize, MapMode(MapUnit::Map100thMM));
             }
             else
             {
-                aPrefSize = OutputDevice::LogicToLogic(aPrefSize, GetGrafObject().GetGrafPrefMapMode(), MAP_100TH_MM);
+                aPrefSize = OutputDevice::LogicToLogic(aPrefSize, GetGrafObject().GetGrafPrefMapMode(), MapMode(MapUnit::Map100thMM));
             }
 
             // decompose object matrix to get single values
@@ -127,8 +128,8 @@ namespace sdr
             {
                 // create the EmptyPresObj fallback visualisation. The fallback graphic
                 // is already provided in rGraphicObject in this case, use it
-                aSmallerMatrix = basegfx::tools::createScaleTranslateB2DHomMatrix(aPrefSize.getWidth(), aPrefSize.getHeight(), fOffsetX, fOffsetY);
-                aSmallerMatrix = basegfx::tools::createShearXRotateTranslateB2DHomMatrix(fShearX, fRotate, aTranslate)
+                aSmallerMatrix = basegfx::utils::createScaleTranslateB2DHomMatrix(aPrefSize.getWidth(), aPrefSize.getHeight(), fOffsetX, fOffsetY);
+                aSmallerMatrix = basegfx::utils::createShearXRotateTranslateB2DHomMatrix(fShearX, fRotate, aTranslate)
                     * aSmallerMatrix;
 
                 const GraphicObject& rGraphicObject = GetGrafObject().GetGraphicObject();
@@ -139,17 +140,17 @@ namespace sdr
                     rGraphicObject,
                     aLocalGrafInfo));
 
-                drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(xRetval, xReferenceB);
+                xRetval.push_back(xReferenceB);
             }
 
             return xRetval;
         }
 
-        drawinglayer::primitive2d::Primitive2DSequence ViewContactOfGraphic::createVIP2DSForDraft(
+        drawinglayer::primitive2d::Primitive2DContainer ViewContactOfGraphic::createVIP2DSForDraft(
             const basegfx::B2DHomMatrix& rObjectMatrix,
             const drawinglayer::attribute::SdrLineFillShadowTextAttribute& rAttribute) const
         {
-            drawinglayer::primitive2d::Primitive2DSequence xRetval;
+            drawinglayer::primitive2d::Primitive2DContainer xRetval;
             GraphicObject aEmptyGraphicObject;
             GraphicAttr aEmptyGraphicAttr;
 
@@ -159,17 +160,17 @@ namespace sdr
                 rAttribute,
                 aEmptyGraphicObject,
                 aEmptyGraphicAttr));
-            xRetval = drawinglayer::primitive2d::Primitive2DSequence(&xReferenceA, 1);
+            xRetval = drawinglayer::primitive2d::Primitive2DContainer { xReferenceA };
 
             if(rAttribute.getLine().isDefault())
             {
                 // create a surrounding frame when no linestyle given
                 const Color aColor(Application::GetSettings().GetStyleSettings().GetShadowColor());
                 const basegfx::BColor aBColor(aColor.getBColor());
-                basegfx::B2DPolygon aOutline(basegfx::tools::createUnitPolygon());
+                basegfx::B2DPolygon aOutline(basegfx::utils::createUnitPolygon());
                 aOutline.transform(rObjectMatrix);
 
-                drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(xRetval,
+                xRetval.push_back(
                     drawinglayer::primitive2d::Primitive2DReference(
                         new drawinglayer::primitive2d::PolygonHairlinePrimitive2D(
                             aOutline,
@@ -192,19 +193,19 @@ namespace sdr
             aTranslate.setY(aTranslate.getY() + fDistance);
 
             // draw a draft bitmap
-            const Bitmap aDraftBitmap(ResId(BMAP_GrafikEi, *ImpGetResMgr()));
+            const BitmapEx aDraftBitmap(BMAP_GrafikEi);
 
             if(!aDraftBitmap.IsEmpty())
             {
                 Size aPrefSize(aDraftBitmap.GetPrefSize());
 
-                if(MAP_PIXEL == aDraftBitmap.GetPrefMapMode().GetMapUnit())
+                if(MapUnit::MapPixel == aDraftBitmap.GetPrefMapMode().GetMapUnit())
                 {
-                    aPrefSize = Application::GetDefaultDevice()->PixelToLogic(aDraftBitmap.GetSizePixel(), MAP_100TH_MM);
+                    aPrefSize = Application::GetDefaultDevice()->PixelToLogic(aDraftBitmap.GetSizePixel(), MapMode(MapUnit::Map100thMM));
                 }
                 else
                 {
-                    aPrefSize = OutputDevice::LogicToLogic(aPrefSize, aDraftBitmap.GetPrefMapMode(), MAP_100TH_MM);
+                    aPrefSize = OutputDevice::LogicToLogic(aPrefSize, aDraftBitmap.GetPrefMapMode(), MapMode(MapUnit::Map100thMM));
                 }
 
                 const double fBitmapScaling(2.0);
@@ -216,10 +217,10 @@ namespace sdr
                     && basegfx::fTools::lessOrEqual(fWidth, aScale.getX())
                     && basegfx::fTools::lessOrEqual(fHeight, aScale.getY()))
                 {
-                    const basegfx::B2DHomMatrix aBitmapMatrix(basegfx::tools::createScaleShearXRotateTranslateB2DHomMatrix(
+                    const basegfx::B2DHomMatrix aBitmapMatrix(basegfx::utils::createScaleShearXRotateTranslateB2DHomMatrix(
                         fWidth, fHeight, fShearX, fRotate, aTranslate.getX(), aTranslate.getY()));
 
-                    drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(xRetval,
+                    xRetval.push_back(
                         drawinglayer::primitive2d::Primitive2DReference(
                             new drawinglayer::primitive2d::BitmapPrimitive2D(
                                 BitmapEx(aDraftBitmap),
@@ -264,11 +265,11 @@ namespace sdr
                 if(pSdrText && pOPO)
                 {
                     // directly use the remaining space as TextRangeTransform
-                    const basegfx::B2DHomMatrix aTextRangeTransform(basegfx::tools::createScaleShearXRotateTranslateB2DHomMatrix(
+                    const basegfx::B2DHomMatrix aTextRangeTransform(basegfx::utils::createScaleShearXRotateTranslateB2DHomMatrix(
                         aScale, fShearX, fRotate, aTranslate));
 
                     // directly create temp SdrBlockTextPrimitive2D
-                    css::uno::Reference< drawinglayer::primitive2d::SdrBlockTextPrimitive2D > xBlockTextPrimitive(new drawinglayer::primitive2d::SdrBlockTextPrimitive2D(
+                    rtl::Reference< drawinglayer::primitive2d::SdrBlockTextPrimitive2D > xBlockTextPrimitive(new drawinglayer::primitive2d::SdrBlockTextPrimitive2D(
                         pSdrText,
                         *pOPO,
                         aTextRangeTransform,
@@ -283,34 +284,31 @@ namespace sdr
                     // decompose immediately with neutral ViewInformation. This will
                     // layout the text to more simple TextPrimitives from drawinglayer
                     const drawinglayer::geometry::ViewInformation2D aViewInformation2D;
-
-                    drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(
-                        xRetval,
-                        xBlockTextPrimitive->get2DDecomposition(aViewInformation2D));
+                    xBlockTextPrimitive->get2DDecomposition(xRetval, aViewInformation2D);
                 }
             }
 
             return xRetval;
         }
 
-        drawinglayer::primitive2d::Primitive2DSequence ViewContactOfGraphic::createViewIndependentPrimitive2DSequence() const
+        drawinglayer::primitive2d::Primitive2DContainer ViewContactOfGraphic::createViewIndependentPrimitive2DSequence() const
         {
-            drawinglayer::primitive2d::Primitive2DSequence xRetval;
+            drawinglayer::primitive2d::Primitive2DContainer xRetval;
             const SfxItemSet& rItemSet = GetGrafObject().GetMergedItemSet();
 
             // create and fill GraphicAttr
             GraphicAttr aLocalGrafInfo;
-            const sal_uInt16 nTrans(static_cast<const SdrGrafTransparenceItem&>(rItemSet.Get(SDRATTR_GRAFTRANSPARENCE)).GetValue());
-            const SdrGrafCropItem& rCrop(static_cast<const SdrGrafCropItem&>(rItemSet.Get(SDRATTR_GRAFCROP)));
-            aLocalGrafInfo.SetLuminance(static_cast<const SdrGrafLuminanceItem&>(rItemSet.Get(SDRATTR_GRAFLUMINANCE)).GetValue());
-            aLocalGrafInfo.SetContrast(static_cast<const SdrGrafContrastItem&>(rItemSet.Get(SDRATTR_GRAFCONTRAST)).GetValue());
-            aLocalGrafInfo.SetChannelR(static_cast<const SdrGrafRedItem&>(rItemSet.Get(SDRATTR_GRAFRED)).GetValue());
-            aLocalGrafInfo.SetChannelG(static_cast<const SdrGrafGreenItem&>(rItemSet.Get(SDRATTR_GRAFGREEN)).GetValue());
-            aLocalGrafInfo.SetChannelB(static_cast<const SdrGrafBlueItem&>(rItemSet.Get(SDRATTR_GRAFBLUE)).GetValue());
-            aLocalGrafInfo.SetGamma(static_cast<const SdrGrafGamma100Item&>(rItemSet.Get(SDRATTR_GRAFGAMMA)).GetValue() * 0.01);
+            const sal_uInt16 nTrans(rItemSet.Get(SDRATTR_GRAFTRANSPARENCE).GetValue());
+            const SdrGrafCropItem& rCrop(rItemSet.Get(SDRATTR_GRAFCROP));
+            aLocalGrafInfo.SetLuminance(rItemSet.Get(SDRATTR_GRAFLUMINANCE).GetValue());
+            aLocalGrafInfo.SetContrast(rItemSet.Get(SDRATTR_GRAFCONTRAST).GetValue());
+            aLocalGrafInfo.SetChannelR(rItemSet.Get(SDRATTR_GRAFRED).GetValue());
+            aLocalGrafInfo.SetChannelG(rItemSet.Get(SDRATTR_GRAFGREEN).GetValue());
+            aLocalGrafInfo.SetChannelB(rItemSet.Get(SDRATTR_GRAFBLUE).GetValue());
+            aLocalGrafInfo.SetGamma(rItemSet.Get(SDRATTR_GRAFGAMMA).GetValue() * 0.01);
             aLocalGrafInfo.SetTransparency((sal_uInt8)::basegfx::fround(std::min(nTrans, (sal_uInt16)100) * 2.55));
-            aLocalGrafInfo.SetInvert(static_cast<const SdrGrafInvertItem&>(rItemSet.Get(SDRATTR_GRAFINVERT)).GetValue());
-            aLocalGrafInfo.SetDrawMode(static_cast<const SdrGrafModeItem&>(rItemSet.Get(SDRATTR_GRAFMODE)).GetValue());
+            aLocalGrafInfo.SetInvert(rItemSet.Get(SDRATTR_GRAFINVERT).GetValue());
+            aLocalGrafInfo.SetDrawMode(rItemSet.Get(SDRATTR_GRAFMODE).GetValue());
             aLocalGrafInfo.SetCrop(rCrop.GetLeft(), rCrop.GetTop(), rCrop.GetRight(), rCrop.GetBottom());
 
             // we have content if graphic is not completely transparent
@@ -323,7 +321,7 @@ namespace sdr
 
             // take unrotated snap rect for position and size. Directly use model data, not getBoundRect() or getSnapRect()
             // which will use the primitive data we just create in the near future
-            Rectangle rRectangle = GetGrafObject().GetGeoRect();
+            tools::Rectangle rRectangle = GetGrafObject().GetGeoRect();
             // Hack for calc, transform position of object according
             // to current zoom so as objects relative position to grid
             // appears stable
@@ -361,7 +359,7 @@ namespace sdr
             // fill object matrix
             const double fShearX(rGeoStat.nShearAngle ? tan((36000 - rGeoStat.nShearAngle) * F_PI18000) : 0.0);
             const double fRotate(nRotationAngle ? (36000 - nRotationAngle) * F_PI18000 : 0.0);
-            const basegfx::B2DHomMatrix aObjectMatrix(basegfx::tools::createScaleShearXRotateTranslateB2DHomMatrix(
+            const basegfx::B2DHomMatrix aObjectMatrix(basegfx::utils::createScaleShearXRotateTranslateB2DHomMatrix(
                 aObjectRange.getWidth(), aObjectRange.getHeight(),
                 fShearX, fRotate,
                 aObjectRange.getMinX(), aObjectRange.getMinY()));
@@ -397,13 +395,13 @@ namespace sdr
                         rGraphicObject,
                         aLocalGrafInfo));
 
-                xRetval = drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
+                xRetval = drawinglayer::primitive2d::Primitive2DContainer { xReference };
             }
 
             // always append an invisible outline for the cases where no visible content exists
-            drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(xRetval,
+            xRetval.push_back(
                 drawinglayer::primitive2d::createHiddenGeometryPrimitives2D(
-                    false, aObjectMatrix));
+                    aObjectMatrix));
 
             return xRetval;
         }
@@ -427,7 +425,7 @@ namespace sdr
                 return true;
 
             // draft when no graphic
-            if(GRAPHIC_NONE == rGraphicObject.GetType() || GRAPHIC_DEFAULT == rGraphicObject.GetType())
+            if(GraphicType::NONE == rGraphicObject.GetType() || GraphicType::Default == rGraphicObject.GetType())
                return true;
 
             return false;
