@@ -50,7 +50,7 @@ ViewObjectContact& ViewContactOfSdrObj::CreateObjectSpecificViewObjectContact(Ob
 ViewContactOfSdrObj::ViewContactOfSdrObj(SdrObject& rObj)
 :   ViewContact(),
     mrObject(rObj),
-    meRememberedAnimationKind(SDRTEXTANI_NONE)
+    meRememberedAnimationKind(SdrTextAniKind::NONE)
 {
     // init AnimationKind
     if(dynamic_cast<const SdrTextObj*>( &GetSdrObject() ) != nullptr)
@@ -153,12 +153,12 @@ drawinglayer::primitive2d::Primitive2DContainer ViewContactOfSdrObj::createGlueP
             std::vector< basegfx::B2DPoint > aGluepointVector;
 
             // create GluePoint primitives. ATM these are relative to the SnapRect
-            for(sal_uInt32 a(0L); a < nCount; a++)
+            for(sal_uInt32 a(0); a < nCount; a++)
             {
                 const SdrGluePoint& rCandidate = (*pGluePointList)[(sal_uInt16)a];
                 const Point aPosition(rCandidate.GetAbsolutePos(GetSdrObject()));
 
-                aGluepointVector.push_back(basegfx::B2DPoint(aPosition.X(), aPosition.Y()));
+                aGluepointVector.emplace_back(aPosition.X(), aPosition.Y());
             }
 
             if(!aGluepointVector.empty())
