@@ -17,13 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <o3tl/make_unique.hxx>
 #include <sdr/properties/measureproperties.hxx>
 #include <svl/itemset.hxx>
 #include <svl/style.hxx>
 #include <svx/svddef.hxx>
 #include <editeng/eeitem.hxx>
 #include <svx/svdomeas.hxx>
-#include <svx/sxmsuitm.hxx>
 #include <svx/xlnstit.hxx>
 #include <svx/xlnstwit.hxx>
 #include <svx/xlnedit.hxx>
@@ -37,23 +39,18 @@ namespace sdr
     namespace properties
     {
         // create a new itemset
-        SfxItemSet* MeasureProperties::CreateObjectSpecificItemSet(SfxItemPool& rPool)
+        std::unique_ptr<SfxItemSet> MeasureProperties::CreateObjectSpecificItemSet(SfxItemPool& rPool)
         {
-            return new SfxItemSet(rPool,
-
-                // range from SdrAttrObj
-                SDRATTR_START, SDRATTR_SHADOW_LAST,
-                SDRATTR_MISC_FIRST, SDRATTR_MISC_LAST,
-                SDRATTR_TEXTDIRECTION, SDRATTR_TEXTDIRECTION,
-
-                // range from SdrMeasureObj
-                SDRATTR_MEASURE_FIRST, SDRATTR_MEASURE_LAST,
-
-                // range from SdrTextObj
-                EE_ITEMS_START, EE_ITEMS_END,
-
-                // end
-                0, 0);
+            return o3tl::make_unique<SfxItemSet>(
+                rPool,
+                svl::Items<
+                    // Ranges from SdrAttrObj, SdrMeasureObj:
+                    SDRATTR_START, SDRATTR_SHADOW_LAST,
+                    SDRATTR_MISC_FIRST, SDRATTR_MISC_LAST,
+                    SDRATTR_MEASURE_FIRST, SDRATTR_MEASURE_LAST,
+                    SDRATTR_TEXTDIRECTION, SDRATTR_TEXTDIRECTION,
+                    // Range from SdrTextObj:
+                    EE_ITEMS_START, EE_ITEMS_END>{});
         }
 
         MeasureProperties::MeasureProperties(SdrObject& rObj)
@@ -88,10 +85,15 @@ namespace sdr
 
         void MeasureProperties::SetStyleSheet(SfxStyleSheet* pNewStyleSheet, bool bDontRemoveHardAttr)
         {
+            // get access to dimension line object
             SdrMeasureObj& rObj = static_cast<SdrMeasureObj&>(GetSdrObject());
 
             // local changes
+
+            // mark dimension line text as changed (dirty) in the dimension line object
             rObj.SetTextDirty();
+            // tdf#98525 ask the dimension line object to redraw the changed text
+            rObj.UndirtyText();
 
             // call parent
             TextProperties::SetStyleSheet(pNewStyleSheet, bDontRemoveHardAttr);
@@ -106,9 +108,9 @@ namespace sdr
             GetObjectItemSet();
 
             //#71958# by default, the show units Bool-Item is set as hard
-            // attribute to sal_True to aviod confusion when copying SdrMeasureObj's
+            // attribute to sal_True to avoid confusion when copying SdrMeasureObj's
             // from one application to another
-            mpItemSet->Put(makeSdrMeasureShowUnitItem(true));
+            mpItemSet->Put(SdrYesNoItem(SDRATTR_MEASURESHOWUNIT, true));
 
             basegfx::B2DPolygon aNewPolygon;
             aNewPolygon.append(basegfx::B2DPoint(100.0, 0.0));
@@ -120,7 +122,7 @@ namespace sdr
             mpItemSet->Put(XLineStartWidthItem(200));
             mpItemSet->Put(XLineEndItem(OUString(), basegfx::B2DPolyPolygon(aNewPolygon)));
             mpItemSet->Put(XLineEndWidthItem(200));
-            mpItemSet->Put(XLineStyleItem(com::sun::star::drawing::LineStyle_SOLID));
+            mpItemSet->Put(XLineStyleItem(css::drawing::LineStyle_SOLID));
         }
     } // end of namespace properties
 } // end of namespace sdr
