@@ -17,6 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <o3tl/make_unique.hxx>
 #include <sdr/properties/pageproperties.hxx>
 #include <svl/itemset.hxx>
 #include <svx/svdobj.hxx>
@@ -29,10 +32,10 @@ namespace sdr
     namespace properties
     {
         // create a new itemset
-        SfxItemSet* PageProperties::CreateObjectSpecificItemSet(SfxItemPool& rPool)
+        std::unique_ptr<SfxItemSet> PageProperties::CreateObjectSpecificItemSet(SfxItemPool& rPool)
         {
             // override to legally return a valid ItemSet
-            return new SfxItemSet(rPool);
+            return o3tl::make_unique<SfxItemSet>(rPool);
         }
 
         PageProperties::PageProperties(SdrObject& rObj)
@@ -40,8 +43,8 @@ namespace sdr
         {
         }
 
-        PageProperties::PageProperties(const PageProperties& rProps, SdrObject& rObj)
-        :   EmptyProperties(rProps, rObj)
+        PageProperties::PageProperties(const PageProperties& /*rProps*/, SdrObject& rObj)
+        :   EmptyProperties(rObj)
         {
         }
 
@@ -79,6 +82,11 @@ namespace sdr
             return nullptr;
         }
 
+        void PageProperties::SetStyleSheet(SfxStyleSheet* /*pStyleSheet*/, bool /*bDontRemoveHardAttr*/)
+        {
+            // override to legally ignore the StyleSheet here
+        }
+
         void PageProperties::PostItemChange(const sal_uInt16 nWhich )
         {
             if( (nWhich == XATTR_FILLSTYLE) && (mpEmptyItemSet != nullptr) )
