@@ -20,18 +20,17 @@
 #include <svx/svdview.hxx>
 #include <svx/svddrag.hxx>
 
-void SdrDragStat::Clear(bool bLeaveOne)
+SdrDragStatUserData::~SdrDragStatUserData() = default;
+
+SdrDragStat::~SdrDragStat()
 {
-    while (!aPnts.empty()) {
-        delete aPnts.back();
-        aPnts.pop_back();
-    }
-    delete pUser;
-    pUser=nullptr;
-    aPnts.clear();
-    if (bLeaveOne) {
-        aPnts.push_back(new Point);
-    }
+}
+
+void SdrDragStat::Clear()
+{
+    mpUserData.reset();
+    mvPnts.clear();
+    mvPnts.emplace_back();
 }
 
 void SdrDragStat::Reset()
@@ -52,7 +51,7 @@ void SdrDragStat::Reset()
     bEndDragChangesGeoAndAttributes=false;
     mbEndDragChangesLayout=false;
     bMouseIsUp=false;
-    Clear(true);
+    Clear();
     aActionRect=tools::Rectangle();
 }
 
@@ -68,33 +67,24 @@ void SdrDragStat::NextMove(const Point& rPnt)
 {
     aPos0=GetNow();
     RealNow()=rPnt;
-    Point aBla=KorregPos(GetRealNow(),GetPrev());
-    Now()=aBla;
+    Now()=GetRealNow();
 }
 
 void SdrDragStat::NextPoint()
 {
     Point aPnt(GetNow());
-    aPnts.push_back(new Point(KorregPos(GetRealNow(),aPnt)));
+    mvPnts.emplace_back(GetRealNow());
     Prev()=aPnt;
 }
 
 void SdrDragStat::PrevPoint()
 {
-    if (aPnts.size()>=2) { // one has to remain at all times
-        Point* pPnt=aPnts[aPnts.size()-2];
-        aPnts.erase(aPnts.begin()+aPnts.size()-2);
-        delete pPnt;
-        Now()=KorregPos(GetRealNow(),GetPrev());
+    if (mvPnts.size()>=2) { // one has to remain at all times
+        mvPnts.erase(mvPnts.begin()+mvPnts.size()-2);
+        Now() = GetRealNow();
     }
 }
 
-Point SdrDragStat::KorregPos(const Point& rNow, const Point& /*rPrev*/)
-{
-    Point aRet(rNow);
-    return aRet;
-}
-
 bool SdrDragStat::CheckMinMoved(const Point& rPnt)
 {
     if (!bMinMoved) {
