@@ -1,4 +1,4 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4; fill-column:100 -*- */
 /*
  * This file is part of the LibreOffice project.
  *
@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <config_features.h>
 
 #include <svx/svdomedia.hxx>
 
@@ -33,18 +34,13 @@
 #include <vcl/svapp.hxx>
 
 #include <svx/svdmodel.hxx>
-#include "svx/svdglob.hxx"
-#include "svx/svdstr.hrc"
+#include <svdglob.hxx>
+#include <svx/strings.hrc>
 #include <svx/sdr/contact/viewcontactofsdrmediaobj.hxx>
 #include <avmedia/mediawindow.hxx>
 
-
-
 using namespace ::com::sun::star;
 
-// ---------------
-// - SdrMediaObj -
-// ---------------
 
 // Note: the temp file is read only, until it is deleted!
 // It may be shared between multiple documents in case of copy/paste,
@@ -52,7 +48,9 @@ using namespace ::com::sun::star;
 struct MediaTempFile
 {
     OUString const m_TempFileURL;
-    MediaTempFile(OUString const& rURL) : m_TempFileURL(rURL) {}
+    MediaTempFile(OUString const& rURL)
+        : m_TempFileURL(rURL)
+    {}
     ~MediaTempFile()
     {
         ::osl::File::remove(m_TempFileURL);
@@ -62,53 +60,40 @@ struct MediaTempFile
 struct SdrMediaObj::Impl
 {
     ::avmedia::MediaItem                  m_MediaProperties;
-    ::boost::shared_ptr< MediaTempFile >  m_pTempFile;
+    std::shared_ptr< MediaTempFile >  m_pTempFile;
     uno::Reference< graphic::XGraphic >   m_xCachedSnapshot;
+    OUString m_LastFailedPkgURL;
 };
 
-TYPEINIT1( SdrMediaObj, SdrRectObj );
-
-// ------------------------------------------------------------------------------
 
 SdrMediaObj::SdrMediaObj()
     : SdrRectObj()
-    , m_pImpl( new Impl() )
+    , m_xImpl( new Impl )
 {
 }
 
-// ------------------------------------------------------------------------------
-
-SdrMediaObj::SdrMediaObj( const Rectangle& rRect )
+SdrMediaObj::SdrMediaObj( const tools::Rectangle& rRect )
     : SdrRectObj( rRect )
-    , m_pImpl( new Impl() )
+    , m_xImpl( new Impl )
 {
 }
 
-// ------------------------------------------------------------------------------
-
 SdrMediaObj::~SdrMediaObj()
 {
 }
 
-// ------------------------------------------------------------------------------
-
 bool SdrMediaObj::HasTextEdit() const
 {
     return false;
 }
 
-// ------------------------------------------------------------------------------
-
 sdr::contact::ViewContact* SdrMediaObj::CreateObjectSpecificViewContact()
 {
-    return new ::sdr::contact::ViewContactOfSdrMediaObj( *this );
+    return new sdr::contact::ViewContactOfSdrMediaObj( *this );
 }
 
-// ------------------------------------------------------------------------------
-
 void SdrMediaObj::TakeObjInfo( SdrObjTransformInfoRec& rInfo ) const
 {
-    rInfo.bSelectAllowed = true;
     rInfo.bMoveAllowed = true;
     rInfo.bResizeFreeAllowed = true;
     rInfo.bResizePropAllowed = true;
@@ -118,7 +103,6 @@ void SdrMediaObj::TakeObjInfo( SdrObjTransformInfoRec& rInfo ) const
     rInfo.bMirror45Allowed = false;
     rInfo.bMirror90Allowed = false;
     rInfo.bTransparenceAllowed = false;
-    rInfo.bGradientAllowed = false;
     rInfo.bShearAllowed = false;
     rInfo.bEdgeRadiusAllowed = false;
     rInfo.bNoOrthoDesired = false;
@@ -130,15 +114,11 @@ void SdrMediaObj::TakeObjInfo( SdrObjTransformInfoRec& rInfo ) const
     rInfo.bCanConvToPolyLineToArea = false;
 }
 
-// ------------------------------------------------------------------------------
-
 sal_uInt16 SdrMediaObj::GetObjIdentifier() const
 {
     return sal_uInt16( OBJ_MEDIA );
 }
 
-// ------------------------------------------------------------------------------
-
 OUString SdrMediaObj::TakeObjNameSingul() const
 {
     OUStringBuffer sName(ImpGetResStr(STR_ObjNameSingulMEDIA));
@@ -156,15 +136,11 @@ OUString SdrMediaObj::TakeObjNameSingul() const
     return sName.makeStringAndClear();
 }
 
-// ------------------------------------------------------------------------------
-
 OUString SdrMediaObj::TakeObjNamePlural() const
 {
     return ImpGetResStr(STR_ObjNamePluralMEDIA);
 }
 
-// ------------------------------------------------------------------------------
-
 SdrMediaObj* SdrMediaObj::Clone() const
 {
     return CloneHelper< SdrMediaObj >();
@@ -176,29 +152,31 @@ SdrMediaObj& SdrMediaObj::operator=(const SdrMediaObj& rObj)
         return *this;
     SdrRectObj::operator=( rObj );
 
-    m_pImpl->m_pTempFile = rObj.m_pImpl->m_pTempFile; // before props
+    m_xImpl->m_pTempFile = rObj.m_xImpl->m_pTempFile; // before props
     setMediaProperties( rObj.getMediaProperties() );
-    m_pImpl->m_xCachedSnapshot = rObj.m_pImpl->m_xCachedSnapshot;
+    m_xImpl->m_xCachedSnapshot = rObj.m_xImpl->m_xCachedSnapshot;
     return *this;
 }
 
-uno::Reference< graphic::XGraphic > SdrMediaObj::getSnapshot()
+const uno::Reference< graphic::XGraphic > SdrMediaObj::getSnapshot() const
 {
-    if( !m_pImpl->m_xCachedSnapshot.is() )
+#if HAVE_FEATURE_AVMEDIA
+    if( !m_xImpl->m_xCachedSnapshot.is() )
     {
-        OUString aRealURL = m_pImpl->m_MediaProperties.getTempURL();
+        OUString aRealURL = m_xImpl->m_MediaProperties.getTempURL();
         if( aRealURL.isEmpty() )
-            aRealURL = m_pImpl->m_MediaProperties.getURL();
-        m_pImpl->m_xCachedSnapshot = avmedia::MediaWindow::grabFrame( aRealURL, m_pImpl->m_MediaProperties.getReferer(), true );
+            aRealURL = m_xImpl->m_MediaProperties.getURL();
+        m_xImpl->m_xCachedSnapshot = avmedia::MediaWindow::grabFrame( aRealURL, m_xImpl->m_MediaProperties.getReferer(), m_xImpl->m_MediaProperties.getMimeType());
     }
-    return m_pImpl->m_xCachedSnapshot;
+#endif
+    return m_xImpl->m_xCachedSnapshot;
 }
 
-// ------------------------------------------------------------------------------
-
-void SdrMediaObj::AdjustToMaxRect( const Rectangle& rMaxRect, bool bShrinkOnly /* = false */ )
+void SdrMediaObj::AdjustToMaxRect( const tools::Rectangle& rMaxRect, bool bShrinkOnly /* = false */ )
 {
-    Size aSize( Application::GetDefaultDevice()->PixelToLogic( getPreferredSize(), MAP_100TH_MM ) );
+    Size aSize( Application::GetDefaultDevice()->PixelToLogic(
+                    static_cast< sdr::contact::ViewContactOfSdrMediaObj& >( GetViewContact() ).getPreferredSize(),
+                    MapMode(MapUnit::Map100thMM)) );
     Size aMaxSize( rMaxRect.GetSize() );
 
     if( aSize.Height() != 0 && aSize.Width() != 0 )
@@ -232,72 +210,127 @@ void SdrMediaObj::AdjustToMaxRect( const Rectangle& rMaxRect, bool bShrinkOnly /
         }
 
         if( bShrinkOnly )
-            aPos = aRect.TopLeft();
+            aPos = maRect.TopLeft();
 
         aPos.X() -= aSize.Width() / 2;
         aPos.Y() -= aSize.Height() / 2;
-        SetLogicRect( Rectangle( aPos, aSize ) );
+        SetLogicRect( tools::Rectangle( aPos, aSize ) );
     }
 }
 
-// ------------------------------------------------------------------------------
-
-void SdrMediaObj::setURL( const OUString& rURL, const OUString& rReferer )
+void SdrMediaObj::setURL( const OUString& rURL, const OUString& rReferer, const OUString& rMimeType )
 {
     ::avmedia::MediaItem aURLItem;
-
+#if HAVE_FEATURE_AVMEDIA
+    if( !rMimeType.isEmpty() )
+        m_xImpl->m_MediaProperties.setMimeType(rMimeType);
     aURLItem.setURL( rURL, "", rReferer );
+#else
+    (void) rMimeType;
+    (void) rURL;
+    (void) rReferer;
+#endif
     setMediaProperties( aURLItem );
 }
 
-// ------------------------------------------------------------------------------
-
 const OUString& SdrMediaObj::getURL() const
 {
-    return m_pImpl->m_MediaProperties.getURL();
+#if HAVE_FEATURE_AVMEDIA
+    return m_xImpl->m_MediaProperties.getURL();
+#else
+static OUString ret;
+    return ret;
+#endif
 }
 
-// ------------------------------------------------------------------------------
-
 void SdrMediaObj::setMediaProperties( const ::avmedia::MediaItem& rState )
 {
     mediaPropertiesChanged( rState );
-    static_cast< ::sdr::contact::ViewContactOfSdrMediaObj& >( GetViewContact() ).executeMediaItem( getMediaProperties() );
+    static_cast< sdr::contact::ViewContactOfSdrMediaObj& >( GetViewContact() ).executeMediaItem( getMediaProperties() );
 }
 
-// ------------------------------------------------------------------------------
-
 const ::avmedia::MediaItem& SdrMediaObj::getMediaProperties() const
 {
-    return m_pImpl->m_MediaProperties;
+    return m_xImpl->m_MediaProperties;
 }
 
-// ------------------------------------------------------------------------------
-
-Size SdrMediaObj::getPreferredSize() const
-{
-    return static_cast< ::sdr::contact::ViewContactOfSdrMediaObj& >( GetViewContact() ).getPreferredSize();
-}
-
-// ------------------------------------------------------------------------------
-
 uno::Reference<io::XInputStream> SdrMediaObj::GetInputStream()
 {
-    if (!m_pImpl->m_pTempFile)
+    if (!m_xImpl->m_pTempFile)
     {
         SAL_WARN("svx", "this is only intended for embedded media");
-        return 0;
+        return nullptr;
     }
-    ucbhelper::Content tempFile(m_pImpl->m_pTempFile->m_TempFileURL,
+    ucbhelper::Content tempFile(m_xImpl->m_pTempFile->m_TempFileURL,
                 uno::Reference<ucb::XCommandEnvironment>(),
                 comphelper::getProcessComponentContext());
     return tempFile.openStream();
 }
 
+static bool lcl_CopyToTempFile(
+        uno::Reference<io::XInputStream> const& xInStream,
+        OUString & o_rTempFileURL,
+        const OUString& rDesiredExtension)
+{
+    OUString tempFileURL;
+    ::osl::FileBase::RC const err =
+        ::osl::FileBase::createTempFile(nullptr, nullptr, & tempFileURL);
+    if (::osl::FileBase::E_None != err)
+    {
+        SAL_INFO("svx", "cannot create temp file");
+        return false;
+    }
+
+    if (!rDesiredExtension.isEmpty())
+    {
+        OUString newTempFileURL = tempFileURL + rDesiredExtension;
+        if (osl::File::move(tempFileURL, newTempFileURL) != osl::FileBase::E_None)
+        {
+            SAL_WARN("svx", "Could not rename file '" << tempFileURL << "' to '" << newTempFileURL << "'");
+            return false;
+        }
+        tempFileURL = newTempFileURL;
+    }
+
+    try
+    {
+        ::ucbhelper::Content tempContent(tempFileURL,
+                uno::Reference<ucb::XCommandEnvironment>(),
+                comphelper::getProcessComponentContext());
+        tempContent.writeStream(xInStream, true); // copy stream to file
+    }
+    catch (uno::Exception const& e)
+    {
+        SAL_WARN("svx", "exception: '" << e << "'");
+        return false;
+    }
+    o_rTempFileURL = tempFileURL;
+    return true;
+}
+
+void SdrMediaObj::SetInputStream(uno::Reference<io::XInputStream> const& xStream)
+{
+    if (m_xImpl->m_pTempFile || m_xImpl->m_LastFailedPkgURL.isEmpty())
+    {
+        SAL_WARN("svx", "this is only intended for embedded media");
+        return;
+    }
+    OUString tempFileURL;
+    bool const bSuccess = lcl_CopyToTempFile(xStream, tempFileURL, "");
+    if (bSuccess)
+    {
+        m_xImpl->m_pTempFile.reset(new MediaTempFile(tempFileURL));
+        m_xImpl->m_MediaProperties.setURL(
+            m_xImpl->m_LastFailedPkgURL, tempFileURL, "");
+    }
+    m_xImpl->m_LastFailedPkgURL.clear(); // once only
+}
+
 /// copy a stream from XStorage to temp file
+#if HAVE_FEATURE_AVMEDIA
 static bool lcl_HandlePackageURL(
         OUString const & rURL,
-        SdrModel *const pModel,
+        SdrModel const *const pModel,
         OUString & o_rTempFileURL)
 {
     if (!pModel)
@@ -312,12 +345,12 @@ static bool lcl_HandlePackageURL(
     }
     catch (container::NoSuchElementException const&)
     {
-        SAL_INFO("svx", "not found: '" << OUString(rURL) << "'");
+        SAL_INFO("svx", "not found: '" << rURL << "'");
         return false;
     }
     catch (uno::Exception const& e)
     {
-        SAL_WARN("svx", "exception: '" << e.Message << "'");
+        SAL_WARN("svx", "exception: '" << e << "'");
         return false;
     }
     if (!xInStream.is())
@@ -325,88 +358,85 @@ static bool lcl_HandlePackageURL(
         SAL_WARN("svx", "no stream?");
         return false;
     }
-
-    OUString tempFileURL;
-    ::osl::FileBase::RC const err =
-        ::osl::FileBase::createTempFile(0, 0, & tempFileURL);
-    if (::osl::FileBase::E_None != err)
-    {
-        SAL_INFO("svx", "cannot create temp file");
-        return false;
-    }
-
-    try
-    {
-        ::ucbhelper::Content tempContent(tempFileURL,
-                uno::Reference<ucb::XCommandEnvironment>(),
-                comphelper::getProcessComponentContext());
-        tempContent.writeStream(xInStream, true); // copy stream to file
-    }
-    catch (uno::Exception const& e)
-    {
-        SAL_WARN("svx", "exception: '" << e.Message << "'");
-        return false;
-    }
-    o_rTempFileURL = tempFileURL;
-    return true;
+    // Make sure the temporary copy has the same file name extension as the original media file
+    // (like .mp4). That seems to be important for some AVFoundation APIs. For random extension-less
+    // file names, they don't seem to even bother looking inside the file.
+    sal_Int32 nLastDot = rURL.lastIndexOf('.');
+    sal_Int32 nLastSlash = rURL.lastIndexOf('/');
+    OUString sDesiredExtension;
+    if (nLastDot > nLastSlash && nLastDot+1 < rURL.getLength())
+        sDesiredExtension = rURL.copy(nLastDot);
+    return lcl_CopyToTempFile(xInStream, o_rTempFileURL, sDesiredExtension);
 }
+#endif
 
 void SdrMediaObj::mediaPropertiesChanged( const ::avmedia::MediaItem& rNewProperties )
 {
     bool bBroadcastChanged = false;
-    const sal_uInt32 nMaskSet = rNewProperties.getMaskSet();
+#if HAVE_FEATURE_AVMEDIA
+    const AVMediaSetMask nMaskSet = rNewProperties.getMaskSet();
 
-    // use only a subset of MediaItem properties for own own properties
-    if( ( AVMEDIA_SETMASK_URL & nMaskSet ) &&
+    // use only a subset of MediaItem properties for own properties
+    if( AVMediaSetMask::MIME_TYPE & nMaskSet )
+        m_xImpl->m_MediaProperties.setMimeType( rNewProperties.getMimeType() );
+
+    if( ( AVMediaSetMask::URL & nMaskSet ) &&
         ( rNewProperties.getURL() != getURL() ))
     {
-        m_pImpl->m_xCachedSnapshot.clear();
-        OUString const url(rNewProperties.getURL());
+        m_xImpl->m_xCachedSnapshot.clear();
+        OUString const& url(rNewProperties.getURL());
         if (url.startsWithIgnoreAsciiCase("vnd.sun.star.Package:"))
         {
-            if (   !m_pImpl->m_pTempFile
-                || (m_pImpl->m_pTempFile->m_TempFileURL !=
+            if (   !m_xImpl->m_pTempFile
+                || (m_xImpl->m_pTempFile->m_TempFileURL !=
                                 rNewProperties.getTempURL()))
             {
                 OUString tempFileURL;
-                bool const bSuccess = lcl_HandlePackageURL(
-                    url, GetModel(), tempFileURL);
+                bool bSuccess;
+                    bSuccess = lcl_HandlePackageURL(url, GetModel(), tempFileURL);
                 if (bSuccess)
                 {
-                    m_pImpl->m_pTempFile.reset(new MediaTempFile(tempFileURL));
-                    m_pImpl->m_MediaProperties.setURL(url, tempFileURL, "");
+                    m_xImpl->m_pTempFile.reset(
+                            new MediaTempFile(tempFileURL));
+                    m_xImpl->m_MediaProperties.setURL(url, tempFileURL, "");
                 }
                 else // this case is for Clone via operator=
                 {
-                    m_pImpl->m_pTempFile.reset();
-                    m_pImpl->m_MediaProperties.setURL("", "", "");
+                    m_xImpl->m_pTempFile.reset();
+                    m_xImpl->m_MediaProperties.setURL("", "", "");
+                    // UGLY: oox import also gets here, because unlike ODF
+                    // getDocumentStorage() is not the imported file...
+                    m_xImpl->m_LastFailedPkgURL = url;
                 }
             }
             else
             {
-                m_pImpl->m_MediaProperties.setURL(url,
+                m_xImpl->m_MediaProperties.setURL(url,
                         rNewProperties.getTempURL(), "");
             }
         }
         else
         {
-            m_pImpl->m_pTempFile.reset();
-            m_pImpl->m_MediaProperties.setURL(url, "", rNewProperties.getReferer());
+            m_xImpl->m_pTempFile.reset();
+            m_xImpl->m_MediaProperties.setURL(url, "", rNewProperties.getReferer());
         }
         bBroadcastChanged = true;
     }
 
-    if( AVMEDIA_SETMASK_LOOP & nMaskSet )
-        m_pImpl->m_MediaProperties.setLoop( rNewProperties.isLoop() );
+    if( AVMediaSetMask::LOOP & nMaskSet )
+        m_xImpl->m_MediaProperties.setLoop( rNewProperties.isLoop() );
 
-    if( AVMEDIA_SETMASK_MUTE & nMaskSet )
-        m_pImpl->m_MediaProperties.setMute( rNewProperties.isMute() );
+    if( AVMediaSetMask::MUTE & nMaskSet )
+        m_xImpl->m_MediaProperties.setMute( rNewProperties.isMute() );
 
-    if( AVMEDIA_SETMASK_VOLUMEDB & nMaskSet )
-        m_pImpl->m_MediaProperties.setVolumeDB( rNewProperties.getVolumeDB() );
+    if( AVMediaSetMask::VOLUMEDB & nMaskSet )
+        m_xImpl->m_MediaProperties.setVolumeDB( rNewProperties.getVolumeDB() );
 
-    if( AVMEDIA_SETMASK_ZOOM & nMaskSet )
-        m_pImpl->m_MediaProperties.setZoom( rNewProperties.getZoom() );
+    if( AVMediaSetMask::ZOOM & nMaskSet )
+        m_xImpl->m_MediaProperties.setZoom( rNewProperties.getZoom() );
+#else
+    (void) rNewProperties;
+#endif
 
     if( bBroadcastChanged )
     {
