@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <cassert>
 
 #include <svx/svdpage.hxx>
@@ -37,14 +38,13 @@
 #include <svx/svdograf.hxx>
 #include <svx/svdoedge.hxx>
 #include <svx/svdoole2.hxx>
-#include "svx/svditer.hxx"
+#include <svx/svditer.hxx>
 #include <svx/svdmodel.hxx>
 #include <svx/svdlayer.hxx>
 #include <svx/svdotext.hxx>
 #include <svx/svdpagv.hxx>
 #include <svx/svdundo.hxx>
 #include <svx/fmglob.hxx>
-#include <svx/polysc3d.hxx>
 
 #include <svx/fmdpage.hxx>
 
@@ -105,7 +105,7 @@ SdrObjList::~SdrObjList()
 {
 
     // To avoid that the Clear() method will broadcast changes when in destruction
-    // which would call virtual methos (not allowed in destructor), the model is set
+    // which would call virtual method (not allowed in destructor), the model is set
     // to NULL here.
     pModel = nullptr;
 
@@ -135,7 +135,6 @@ void SdrObjList::CopyObjects(const SdrObjList& rSrcList)
     bRectsDirty     =false;
     size_t nCloneErrCnt = 0;
     const size_t nCount = rSrcList.GetObjCount();
-    SdrInsertReason aReason(SdrInsertReasonKind::Copy);
     for (size_t no=0; no<nCount; ++no) {
         SdrObject* pSO=rSrcList.GetObj(no);
 
@@ -144,7 +143,7 @@ void SdrObjList::CopyObjects(const SdrObjList& rSrcList)
         if (pDO!=nullptr) {
             pDO->SetModel(pModel);
             pDO->SetPage(pPage);
-            NbcInsertObject(pDO, SAL_MAX_SIZE, &aReason);
+            NbcInsertObject(pDO, SAL_MAX_SIZE);
         } else {
             nCloneErrCnt++;
         }
@@ -295,7 +294,7 @@ void SdrObjList::RecalcObjOrdNums()
 
 void SdrObjList::RecalcRects()
 {
-    aOutRect=Rectangle();
+    aOutRect=tools::Rectangle();
     aSnapRect=aOutRect;
     const size_t nCount = GetObjCount();
     for (size_t i=0; i<nCount; ++i) {
@@ -316,7 +315,7 @@ void SdrObjList::SetRectsDirty()
     if (pUpList!=nullptr) pUpList->SetRectsDirty();
 }
 
-void SdrObjList::impChildInserted(SdrObject& rChild)
+void SdrObjList::impChildInserted(SdrObject const & rChild)
 {
     sdr::contact::ViewContact* pParent = rChild.GetViewContact().GetParentContact();
 
@@ -326,33 +325,34 @@ void SdrObjList::impChildInserted(SdrObject& rChild)
     }
 }
 
-void SdrObjList::NbcInsertObject(SdrObject* pObj, size_t nPos, const SdrInsertReason* /*pReason*/)
+void SdrObjList::NbcInsertObject(SdrObject* pObj, size_t nPos)
 {
     DBG_ASSERT(pObj!=nullptr,"SdrObjList::NbcInsertObject(NULL)");
-    if (pObj!=nullptr) {
-        DBG_ASSERT(!pObj->IsInserted(),"ZObjekt already has the status Inserted.");
-        const size_t nCount = GetObjCount();
-        if (nPos>nCount) nPos=nCount;
-        InsertObjectIntoContainer(*pObj,nPos);
+    if (pObj==nullptr)
+        return;
 
-        if (nPos<nCount) bObjOrdNumsDirty=true;
-        pObj->SetOrdNum(nPos);
-        pObj->SetObjList(this);
-        pObj->SetPage(pPage);
+    DBG_ASSERT(!pObj->IsInserted(),"The object already has the status Inserted.");
+    const size_t nCount = GetObjCount();
+    if (nPos>nCount) nPos=nCount;
+    InsertObjectIntoContainer(*pObj,nPos);
 
-        // Inform the parent about change to allow invalidations at
-        // evtl. existing parent visualisations
-        impChildInserted(*pObj);
+    if (nPos<nCount) bObjOrdNumsDirty=true;
+    pObj->SetOrdNum(nPos);
+    pObj->SetObjList(this);
+    pObj->SetPage(pPage);
 
-        if (!bRectsDirty) {
-            aOutRect.Union(pObj->GetCurrentBoundRect());
-            aSnapRect.Union(pObj->GetSnapRect());
-        }
-        pObj->SetInserted(true); // calls the UserCall (among others)
+    // Inform the parent about change to allow invalidations at
+    // evtl. existing parent visualisations
+    impChildInserted(*pObj);
+
+    if (!bRectsDirty) {
+        aOutRect.Union(pObj->GetCurrentBoundRect());
+        aSnapRect.Union(pObj->GetSnapRect());
     }
+    pObj->SetInserted(true); // calls the UserCall (among others)
 }
 
-void SdrObjList::InsertObject(SdrObject* pObj, size_t nPos, const SdrInsertReason* pReason)
+void SdrObjList::InsertObject(SdrObject* pObj, size_t nPos)
 {
     DBG_ASSERT(pObj!=nullptr,"SdrObjList::InsertObject(NULL)");
 
@@ -367,7 +367,7 @@ void SdrObjList::InsertObject(SdrObject* pObj, size_t nPos, const SdrInsertReaso
         }
 
         // do insert to new group
-        NbcInsertObject(pObj, nPos, pReason);
+        NbcInsertObject(pObj, nPos);
 
         // In case the object is inserted into a group and doesn't overlap with
         // the group's other members, it needs an own repaint.
@@ -409,8 +409,8 @@ SdrObject* SdrObjList::NbcRemoveObject(size_t nObjNum)
         // flushViewObjectContacts() clears the VOC's and those invalidate
         pObj->GetViewContact().flushViewObjectContacts();
 
-        DBG_ASSERT(pObj->IsInserted(),"ZObjekt does not have the status Inserted.");
-        pObj->SetInserted(false); // Ruft u.a. den UserCall
+        DBG_ASSERT(pObj->IsInserted(),"The object does not have the status Inserted.");
+        pObj->SetInserted(false); // calls UserCall, among other
         pObj->SetObjList(nullptr);
         pObj->SetPage(nullptr);
         if (!bObjOrdNumsDirty) { // optimizing for the case that the last object has to be removed
@@ -441,7 +441,7 @@ SdrObject* SdrObjList::RemoveObject(size_t nObjNum)
         // flushViewObjectContacts() clears the VOC's and those invalidate
         pObj->GetViewContact().flushViewObjectContacts();
 
-        DBG_ASSERT(pObj->IsInserted(),"ZObjekt does not have the status Inserted.");
+        DBG_ASSERT(pObj->IsInserted(),"The object does not have the status Inserted.");
         if (pModel!=nullptr) {
             // TODO: We need a different broadcast here.
             if (pObj->GetPage()!=nullptr) {
@@ -482,7 +482,7 @@ SdrObject* SdrObjList::NbcReplaceObject(SdrObject* pNewObj, size_t nObjNum)
     SdrObject* pObj=maList[nObjNum];
     DBG_ASSERT(pObj!=nullptr,"SdrObjList::ReplaceObject: Could not find object to remove.");
     if (pObj!=nullptr) {
-        DBG_ASSERT(pObj->IsInserted(),"SdrObjList::ReplaceObject: ZObjekt does not have status Inserted.");
+        DBG_ASSERT(pObj->IsInserted(),"SdrObjList::ReplaceObject: the object does not have status Inserted.");
         pObj->SetInserted(false);
         pObj->SetObjList(nullptr);
         pObj->SetPage(nullptr);
@@ -521,7 +521,7 @@ SdrObject* SdrObjList::ReplaceObject(SdrObject* pNewObj, size_t nObjNum)
     SdrObject* pObj=maList[nObjNum];
     DBG_ASSERT(pObj!=nullptr,"SdrObjList::ReplaceObject: Could not find object to remove.");
     if (pObj!=nullptr) {
-        DBG_ASSERT(pObj->IsInserted(),"SdrObjList::ReplaceObject: ZObjekt does not have status Inserted.");
+        DBG_ASSERT(pObj->IsInserted(),"SdrObjList::ReplaceObject: the object does not have status Inserted.");
         if (pModel!=nullptr) {
             // TODO: We need a different broadcast here.
             if (pObj->GetPage()!=nullptr) {
@@ -572,7 +572,7 @@ SdrObject* SdrObjList::SetObjectOrdNum(size_t nOldObjNum, size_t nNewObjNum)
     if (nOldObjNum==nNewObjNum) return pObj;
     DBG_ASSERT(pObj!=nullptr,"SdrObjList::SetObjectOrdNum: Object not found.");
     if (pObj!=nullptr) {
-        DBG_ASSERT(pObj->IsInserted(),"SdrObjList::SetObjectOrdNum: ZObjekt does not have status Inserted.");
+        DBG_ASSERT(pObj->IsInserted(),"SdrObjList::SetObjectOrdNum: the object does not have status Inserted.");
         RemoveObjectFromContainer(nOldObjNum);
         InsertObjectIntoContainer(*pObj,nNewObjNum);
 
@@ -593,7 +593,7 @@ SdrObject* SdrObjList::SetObjectOrdNum(size_t nOldObjNum, size_t nNewObjNum)
     return pObj;
 }
 
-const Rectangle& SdrObjList::GetAllObjSnapRect() const
+const tools::Rectangle& SdrObjList::GetAllObjSnapRect() const
 {
     if (bRectsDirty) {
         const_cast<SdrObjList*>(this)->RecalcRects();
@@ -602,7 +602,7 @@ const Rectangle& SdrObjList::GetAllObjSnapRect() const
     return aSnapRect;
 }
 
-const Rectangle& SdrObjList::GetAllObjBoundRect() const
+const tools::Rectangle& SdrObjList::GetAllObjBoundRect() const
 {
     // #i106183# for deep group hierarchies like in chart2, the invalidates
     // through the hierarchy are not correct; use a 2nd hint for the needed
@@ -734,8 +734,7 @@ void SdrObjList::UnGroupObj( size_t nObjNum )
             for( size_t i=0; i<nCount; ++i )
             {
                 SdrObject* pObj = pSrcLst->RemoveObject(0);
-                SdrInsertReason aReason(SdrInsertReasonKind::ViewCall);
-                InsertObject(pObj, nInsertPos, &aReason);
+                InsertObject(pObj, nInsertPos);
                 ++nInsertPos;
             }
 
@@ -1051,7 +1050,7 @@ void SdrPageProperties::ImpRemoveStyleSheet()
     if(mpStyleSheet)
     {
         EndListening(*mpStyleSheet);
-        mpProperties->SetParent(nullptr);
+        maProperties.SetParent(nullptr);
         mpStyleSheet = nullptr;
     }
 }
@@ -1063,7 +1062,7 @@ void SdrPageProperties::ImpAddStyleSheet(SfxStyleSheet& rNewStyleSheet)
         ImpRemoveStyleSheet();
         mpStyleSheet = &rNewStyleSheet;
         StartListening(rNewStyleSheet);
-        mpProperties->SetParent(&rNewStyleSheet.GetItemSet());
+        maProperties.SetParent(&rNewStyleSheet.GetItemSet());
     }
 }
 
@@ -1083,36 +1082,36 @@ SdrPageProperties::SdrPageProperties(SdrPage& rSdrPage)
 :   SfxListener(),
     mpSdrPage(&rSdrPage),
     mpStyleSheet(nullptr),
-    mpProperties(new SfxItemSet(mpSdrPage->GetModel()->GetItemPool(), XATTR_FILL_FIRST, XATTR_FILL_LAST))
+    maProperties(mpSdrPage->GetModel()->GetItemPool(), svl::Items<XATTR_FILL_FIRST, XATTR_FILL_LAST>{})
 {
     if(!rSdrPage.IsMasterPage())
     {
-        mpProperties->Put(XFillStyleItem(drawing::FillStyle_NONE));
+        maProperties.Put(XFillStyleItem(drawing::FillStyle_NONE));
     }
 }
 
 SdrPageProperties::~SdrPageProperties()
 {
     ImpRemoveStyleSheet();
-    delete mpProperties;
 }
 
 void SdrPageProperties::Notify(SfxBroadcaster& /*rBC*/, const SfxHint& rHint)
 {
     switch(rHint.GetId())
     {
-        case SFX_HINT_DATACHANGED :
+        case SfxHintId::DataChanged :
             {
                 // notify change, broadcast
                 ImpPageChange(*mpSdrPage);
                 break;
             }
-        case SFX_HINT_DYING :
+        case SfxHintId::Dying :
             {
                 // Style needs to be forgotten
                 ImpRemoveStyleSheet();
                 break;
             }
+        default: break;
     }
 }
 
@@ -1126,20 +1125,20 @@ bool SdrPageProperties::isUsedByModel() const
 void SdrPageProperties::PutItemSet(const SfxItemSet& rSet)
 {
     OSL_ENSURE(!mpSdrPage->IsMasterPage(), "Item set at MasterPage Attributes (!)");
-    mpProperties->Put(rSet);
+    maProperties.Put(rSet);
     ImpPageChange(*mpSdrPage);
 }
 
 void SdrPageProperties::PutItem(const SfxPoolItem& rItem)
 {
     OSL_ENSURE(!mpSdrPage->IsMasterPage(), "Item set at MasterPage Attributes (!)");
-    mpProperties->Put(rItem);
+    maProperties.Put(rItem);
     ImpPageChange(*mpSdrPage);
 }
 
 void SdrPageProperties::ClearItem(const sal_uInt16 nWhich)
 {
-    mpProperties->ClearItem(nWhich);
+    maProperties.ClearItem(nWhich);
     ImpPageChange(*mpSdrPage);
 }
 
@@ -1161,23 +1160,23 @@ void SdrPageProperties::SetStyleSheet(SfxStyleSheet* pStyleSheet)
 SdrPage::SdrPage(SdrModel& rNewModel, bool bMasterPage)
 :   SdrObjList(&rNewModel, this),
     mpViewContact(nullptr),
-    nWdt(10L),
-    nHgt(10L),
-    nBordLft(0L),
-    nBordUpp(0L),
-    nBordRgt(0L),
-    nBordLwr(0L),
+    mnWidth(10),
+    mnHeight(10),
+    mnBorderLeft(0),
+    mnBorderUpper(0),
+    mnBorderRight(0),
+    mnBorderLower(0),
     mpLayerAdmin(new SdrLayerAdmin(&rNewModel.GetLayerAdmin())),
     mpSdrPageProperties(nullptr),
     mpMasterPageDescriptor(nullptr),
-    nPageNum(0L),
+    nPageNum(0),
     mbMaster(bMasterPage),
     mbInserted(false),
     mbObjectsNotPersistent(false),
     mbPageBorderOnlyLeftRight(false)
 {
     aPrefVisiLayers.SetAll();
-    eListKind = (bMasterPage) ? SdrObjListKind::MasterPage : SdrObjListKind::DrawPage;
+    eListKind = bMasterPage ? SdrObjListKind::MasterPage : SdrObjListKind::DrawPage;
 
     mpSdrPageProperties.reset(new SdrPageProperties(*this));
 }
@@ -1186,12 +1185,12 @@ SdrPage::SdrPage(const SdrPage& rSrcPage)
 :   SdrObjList(rSrcPage.pModel, this),
     tools::WeakBase< SdrPage >(),
     mpViewContact(nullptr),
-    nWdt(rSrcPage.nWdt),
-    nHgt(rSrcPage.nHgt),
-    nBordLft(rSrcPage.nBordLft),
-    nBordUpp(rSrcPage.nBordUpp),
-    nBordRgt(rSrcPage.nBordRgt),
-    nBordLwr(rSrcPage.nBordLwr),
+    mnWidth(rSrcPage.mnWidth),
+    mnHeight(rSrcPage.mnHeight),
+    mnBorderLeft(rSrcPage.mnBorderLeft),
+    mnBorderUpper(rSrcPage.mnBorderUpper),
+    mnBorderRight(rSrcPage.mnBorderRight),
+    mnBorderLower(rSrcPage.mnBorderLower),
     mpLayerAdmin(new SdrLayerAdmin(rSrcPage.pModel->GetLayerAdmin())),
     mpSdrPageProperties(nullptr),
     mpMasterPageDescriptor(nullptr),
@@ -1259,12 +1258,12 @@ void SdrPage::lateInit(const SdrPage& rSrcPage, SdrModel* const pNewModel)
     mbMaster = rSrcPage.mbMaster;
     mbPageBorderOnlyLeftRight = rSrcPage.mbPageBorderOnlyLeftRight;
     aPrefVisiLayers = rSrcPage.aPrefVisiLayers;
-    nWdt = rSrcPage.nWdt;
-    nHgt = rSrcPage.nHgt;
-    nBordLft = rSrcPage.nBordLft;
-    nBordUpp = rSrcPage.nBordUpp;
-    nBordRgt = rSrcPage.nBordRgt;
-    nBordLwr = rSrcPage.nBordLwr;
+    mnWidth = rSrcPage.mnWidth;
+    mnHeight = rSrcPage.mnHeight;
+    mnBorderLeft = rSrcPage.mnBorderLeft;
+    mnBorderUpper = rSrcPage.mnBorderUpper;
+    mnBorderRight = rSrcPage.mnBorderRight;
+    mnBorderLower = rSrcPage.mnBorderLower;
     nPageNum = rSrcPage.nPageNum;
 
     if(rSrcPage.TRG_HasMasterPage())
@@ -1315,15 +1314,15 @@ void SdrPage::SetSize(const Size& aSiz)
 {
     bool bChanged(false);
 
-    if(aSiz.Width() != nWdt)
+    if(aSiz.Width() != mnWidth)
     {
-        nWdt = aSiz.Width();
+        mnWidth = aSiz.Width();
         bChanged = true;
     }
 
-    if(aSiz.Height() != nHgt)
+    if(aSiz.Height() != mnHeight)
     {
-        nHgt = aSiz.Height();
+        mnHeight = aSiz.Height();
         bChanged = true;
     }
 
@@ -1335,12 +1334,12 @@ void SdrPage::SetSize(const Size& aSiz)
 
 Size SdrPage::GetSize() const
 {
-    return Size(nWdt,nHgt);
+    return Size(mnWidth,mnHeight);
 }
 
-sal_Int32 SdrPage::GetWdt() const
+sal_Int32 SdrPage::GetWidth() const
 {
-    return nWdt;
+    return mnWidth;
 }
 
 void SdrPage::SetOrientation(Orientation eOri)
@@ -1363,36 +1362,36 @@ Orientation SdrPage::GetOrientation() const
     return eRet;
 }
 
-sal_Int32 SdrPage::GetHgt() const
+sal_Int32 SdrPage::GetHeight() const
 {
-    return nHgt;
+    return mnHeight;
 }
 
 void  SdrPage::SetBorder(sal_Int32 nLft, sal_Int32 nUpp, sal_Int32 nRgt, sal_Int32 nLwr)
 {
     bool bChanged(false);
 
-    if(nBordLft != nLft)
+    if(mnBorderLeft != nLft)
     {
-        nBordLft = nLft;
+        mnBorderLeft = nLft;
         bChanged = true;
     }
 
-    if(nBordUpp != nUpp)
+    if(mnBorderUpper != nUpp)
     {
-        nBordUpp = nUpp;
+        mnBorderUpper = nUpp;
         bChanged = true;
     }
 
-    if(nBordRgt != nRgt)
+    if(mnBorderRight != nRgt)
     {
-        nBordRgt = nRgt;
+        mnBorderRight = nRgt;
         bChanged = true;
     }
 
-    if(nBordLwr != nLwr)
+    if(mnBorderLower != nLwr)
     {
-        nBordLwr =  nLwr;
+        mnBorderLower =  nLwr;
         bChanged = true;
     }
 
@@ -1402,60 +1401,60 @@ void  SdrPage::SetBorder(sal_Int32 nLft, sal_Int32 nUpp, sal_Int32 nRgt, sal_Int
     }
 }
 
-void  SdrPage::SetLftBorder(sal_Int32 nBorder)
+void  SdrPage::SetLeftBorder(sal_Int32 nBorder)
 {
-    if(nBordLft != nBorder)
+    if(mnBorderLeft != nBorder)
     {
-        nBordLft = nBorder;
+        mnBorderLeft = nBorder;
         SetChanged();
     }
 }
 
-void  SdrPage::SetUppBorder(sal_Int32 nBorder)
+void  SdrPage::SetUpperBorder(sal_Int32 nBorder)
 {
-    if(nBordUpp != nBorder)
+    if(mnBorderUpper != nBorder)
     {
-        nBordUpp = nBorder;
+        mnBorderUpper = nBorder;
         SetChanged();
     }
 }
 
-void  SdrPage::SetRgtBorder(sal_Int32 nBorder)
+void  SdrPage::SetRightBorder(sal_Int32 nBorder)
 {
-    if(nBordRgt != nBorder)
+    if(mnBorderRight != nBorder)
     {
-        nBordRgt=nBorder;
+        mnBorderRight=nBorder;
         SetChanged();
     }
 }
 
-void  SdrPage::SetLwrBorder(sal_Int32 nBorder)
+void  SdrPage::SetLowerBorder(sal_Int32 nBorder)
 {
-    if(nBordLwr != nBorder)
+    if(mnBorderLower != nBorder)
     {
-        nBordLwr=nBorder;
+        mnBorderLower=nBorder;
         SetChanged();
     }
 }
 
-sal_Int32 SdrPage::GetLftBorder() const
+sal_Int32 SdrPage::GetLeftBorder() const
 {
-    return nBordLft;
+    return mnBorderLeft;
 }
 
-sal_Int32 SdrPage::GetUppBorder() const
+sal_Int32 SdrPage::GetUpperBorder() const
 {
-    return nBordUpp;
+    return mnBorderUpper;
 }
 
-sal_Int32 SdrPage::GetRgtBorder() const
+sal_Int32 SdrPage::GetRightBorder() const
 {
-    return nBordRgt;
+    return mnBorderRight;
 }
 
-sal_Int32 SdrPage::GetLwrBorder() const
+sal_Int32 SdrPage::GetLowerBorder() const
 {
-    return nBordLwr;
+    return mnBorderLower;
 }
 
 void SdrPage::impl_setModelForLayerAdmin(SdrModel* const pNewModel)
@@ -1586,13 +1585,13 @@ SdrPage& SdrPage::TRG_GetMasterPage() const
     return mpMasterPageDescriptor->GetUsedPage();
 }
 
-const SetOfByte& SdrPage::TRG_GetMasterPageVisibleLayers() const
+const SdrLayerIDSet& SdrPage::TRG_GetMasterPageVisibleLayers() const
 {
     DBG_ASSERT(mpMasterPageDescriptor != nullptr, "TRG_GetMasterPageVisibleLayers(): No MasterPage available. Use TRG_HasMasterPage() before access (!)");
     return mpMasterPageDescriptor->GetVisibleLayers();
 }
 
-void SdrPage::TRG_SetMasterPageVisibleLayers(const SetOfByte& rNew)
+void SdrPage::TRG_SetMasterPageVisibleLayers(const SdrLayerIDSet& rNew)
 {
     DBG_ASSERT(mpMasterPageDescriptor != nullptr, "TRG_SetMasterPageVisibleLayers(): No MasterPage available. Use TRG_HasMasterPage() before access (!)");
     mpMasterPageDescriptor->SetVisibleLayers(rNew);
@@ -1616,7 +1615,7 @@ void SdrPage::TRG_ImpMasterPageRemoved(const SdrPage& rRemovedPage)
     }
 }
 
-const SdrPageGridFrameList* SdrPage::GetGridFrameList(const SdrPageView* /*pPV*/, const Rectangle* /*pRect*/) const
+const SdrPageGridFrameList* SdrPage::GetGridFrameList(const SdrPageView* /*pPV*/, const tools::Rectangle* /*pRect*/) const
 {
     return nullptr;
 }
@@ -1638,7 +1637,7 @@ OUString SdrPage::GetLayoutName() const
 
 void SdrPage::SetInserted( bool bIns )
 {
-    if( (bool) mbInserted != bIns )
+    if( mbInserted != bIns )
     {
         mbInserted = bIns;
 
@@ -1689,7 +1688,7 @@ SfxStyleSheet* SdrPage::GetTextStyleSheetForObject( SdrObject* pObj ) const
 
 /** returns an averaged background color of this page */
 // #i75566# GetBackgroundColor -> GetPageBackgroundColor and bScreenDisplay hint value
-Color SdrPage::GetPageBackgroundColor( SdrPageView* pView, bool bScreenDisplay ) const
+Color SdrPage::GetPageBackgroundColor( SdrPageView const * pView, bool bScreenDisplay ) const
 {
     Color aColor;
 
@@ -1707,7 +1706,7 @@ Color SdrPage::GetPageBackgroundColor( SdrPageView* pView, bool bScreenDisplay )
 
     if(!IsMasterPage() && TRG_HasMasterPage())
     {
-        if(drawing::FillStyle_NONE == static_cast<const XFillStyleItem&>(pBackgroundFill->Get(XATTR_FILLSTYLE)).GetValue())
+        if(drawing::FillStyle_NONE == pBackgroundFill->Get(XATTR_FILLSTYLE).GetValue())
         {
             pBackgroundFill = &TRG_GetMasterPage().getSdrPageProperties().GetItemSet();
         }
