@@ -31,26 +31,24 @@
 #include <editeng/outliner.hxx>
 #include <svx/svdetc.hxx>
 #include <svx/svdobj.hxx>
-#include "svx/svditer.hxx"
+#include <svx/svditer.hxx>
 #include <svx/svdogrp.hxx>
 #include <svx/svdtypes.hxx>
 #include <svx/svdoole2.hxx>
 
-#include <svx/sdr/contact/objectcontactofpageview.hxx>
+#include <sdr/contact/objectcontactofpageview.hxx>
 #include <svx/sdr/contact/viewobjectcontactredirector.hxx>
 #include <svx/fmview.hxx>
 
-// for search on vector
 #include <algorithm>
 
-using namespace ::rtl;
-using namespace ::com::sun::star;
 #include <svx/sdrpagewindow.hxx>
 #include <svx/sdrpaintwindow.hxx>
+#include <comphelper/lok.hxx>
+#include <basegfx/range/b2irectangle.hxx>
 
-DBG_NAME(SdrPageView);
+using namespace ::com::sun::star;
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
 // interface to SdrPageWindow
 
 SdrPageWindow* SdrPageView::FindPageWindow(SdrPaintWindow& rPaintWindow) const
@@ -63,7 +61,7 @@ SdrPageWindow* SdrPageView::FindPageWindow(SdrPaintWindow& rPaintWindow) const
         }
     }
 
-    return 0L;
+    return nullptr;
 }
 
 const SdrPageWindow* SdrPageView::FindPatchedPageWindow( const OutputDevice& _rOutDev ) const
@@ -81,7 +79,7 @@ const SdrPageWindow* SdrPageView::FindPatchedPageWindow( const OutputDevice& _rO
         }
     }
 
-    return NULL;
+    return nullptr;
 }
 
 SdrPageWindow* SdrPageView::FindPageWindow(const OutputDevice& rOutDev) const
@@ -94,7 +92,7 @@ SdrPageWindow* SdrPageView::FindPageWindow(const OutputDevice& rOutDev) const
         }
     }
 
-    return 0L;
+    return nullptr;
 }
 
 SdrPageWindow* SdrPageView::GetPageWindow(sal_uInt32 nIndex) const
@@ -104,7 +102,7 @@ SdrPageWindow* SdrPageView::GetPageWindow(sal_uInt32 nIndex) const
         return maPageWindows[nIndex];
     }
 
-    return 0L;
+    return nullptr;
 }
 
 void SdrPageView::ClearPageWindows()
@@ -117,11 +115,6 @@ void SdrPageView::ClearPageWindows()
     maPageWindows.clear();
 }
 
-void SdrPageView::AppendPageWindow(SdrPageWindow& rNew)
-{
-    maPageWindows.push_back(&rNew);
-}
-
 SdrPageWindow* SdrPageView::RemovePageWindow(SdrPageWindow& rOld)
 {
     const SdrPageWindowVector::iterator aFindResult = ::std::find(maPageWindows.begin(), maPageWindows.end(), &rOld);
@@ -134,36 +127,34 @@ SdrPageWindow* SdrPageView::RemovePageWindow(SdrPageWindow& rOld)
         return pSdrPageWindow;
     }
 
-    return 0L;
+    return nullptr;
 }
 
-//////////////////////////////////////////////////////////////////////////////
 
 SdrPageView::SdrPageView(SdrPage* pPage1, SdrView& rNewView)
 :   mrView(rNewView),
     // col_auto color lets the view takes the default SvxColorConfig entry
     maDocumentColor( COL_AUTO ),
     maBackgroundColor(COL_AUTO ), // #i48367# also react on autocolor
-    mpPreparedPageWindow(0) // #i72752#
+    mpPreparedPageWindow(nullptr) // #i72752#
 {
-    DBG_CTOR(SdrPageView,NULL);
     mpPage = pPage1;
 
     if(mpPage)
     {
-        aPgOrg.X()=mpPage->GetLftBorder();
-        aPgOrg.Y()=mpPage->GetUppBorder();
+        aPgOrg.X()=mpPage->GetLeftBorder();
+        aPgOrg.Y()=mpPage->GetUpperBorder();
     }
-    mbHasMarked = sal_False;
+    mbHasMarked = false;
     aLayerVisi.SetAll();
     aLayerPrn.SetAll();
 
-    mbVisible = sal_False;
-    pAktList = NULL;
-    pAktGroup = NULL;
-    SetAktGroupAndList(NULL, mpPage);
+    mbVisible = false;
+    pAktList = nullptr;
+    pAktGroup = nullptr;
+    SetAktGroupAndList(nullptr, mpPage);
 
-    for(sal_uInt32 a(0L); a < rNewView.PaintWindowCount(); a++)
+    for(sal_uInt32 a(0); a < rNewView.PaintWindowCount(); a++)
     {
         AddPaintWindowToPageView(*rNewView.GetPaintWindow(a));
     }
@@ -171,25 +162,16 @@ SdrPageView::SdrPageView(SdrPage* pPage1, SdrView& rNewView)
 
 SdrPageView::~SdrPageView()
 {
-    DBG_DTOR(SdrPageView,NULL);
 
     // cleanup window vector
     ClearPageWindows();
 }
 
-SdrPageWindow& SdrPageView::CreateNewPageWindowEntry(SdrPaintWindow& rPaintWindow)
-{
-    SdrPageWindow& rWindow = *(new SdrPageWindow(*this, rPaintWindow));
-    AppendPageWindow(rWindow);
-
-    return rWindow;
-}
-
 void SdrPageView::AddPaintWindowToPageView(SdrPaintWindow& rPaintWindow)
 {
     if(!FindPageWindow(rPaintWindow))
     {
-        CreateNewPageWindowEntry(rPaintWindow);
+        maPageWindows.push_back(new SdrPageWindow(*this, rPaintWindow));
     }
 }
 
@@ -200,43 +182,38 @@ void SdrPageView::RemovePaintWindowFromPageView(SdrPaintWindow& rPaintWindow)
     if(pCandidate)
     {
         pCandidate = RemovePageWindow(*pCandidate);
-
-        if(pCandidate)
-        {
-            delete pCandidate;
-        }
+        delete pCandidate;
     }
 }
 
-::com::sun::star::uno::Reference< ::com::sun::star::awt::XControlContainer > SdrPageView::GetControlContainer( const OutputDevice& _rDevice ) const
+css::uno::Reference< css::awt::XControlContainer > SdrPageView::GetControlContainer( const OutputDevice& _rDevice ) const
 {
-    ::com::sun::star::uno::Reference< ::com::sun::star::awt::XControlContainer > xReturn;
+    css::uno::Reference< css::awt::XControlContainer > xReturn;
     const SdrPageWindow* pCandidate = FindPatchedPageWindow( _rDevice );
 
     if ( pCandidate )
-        xReturn = pCandidate->GetControlContainer( true );
+        xReturn = pCandidate->GetControlContainer();
 
     return xReturn;
 }
 
 void SdrPageView::ModelHasChanged()
 {
-    if (GetAktGroup()!=NULL) CheckAktGroup();
+    if (GetAktGroup()!=nullptr) CheckAktGroup();
 }
 
-sal_Bool SdrPageView::IsReadOnly() const
+bool SdrPageView::IsReadOnly() const
 {
-    return (0L == GetPage() || GetView().GetModel()->IsReadOnly() || GetPage()->IsReadOnly() || GetObjList()->IsReadOnly());
+    return (nullptr == GetPage() || GetView().GetModel()->IsReadOnly() || GetPage()->IsReadOnly() || GetObjList()->IsReadOnly());
 }
 
 void SdrPageView::Show()
 {
     if(!IsVisible())
     {
-        mbVisible = sal_True;
-        InvalidateAllWin();
+        mbVisible = true;
 
-        for(sal_uInt32 a(0L); a < GetView().PaintWindowCount(); a++)
+        for(sal_uInt32 a(0); a < GetView().PaintWindowCount(); a++)
         {
             AddPaintWindowToPageView(*GetView().GetPaintWindow(a));
         }
@@ -247,29 +224,31 @@ void SdrPageView::Hide()
 {
     if(IsVisible())
     {
-        InvalidateAllWin();
-        mbVisible = sal_False;
+        if (!comphelper::LibreOfficeKit::isActive())
+        {
+            InvalidateAllWin();
+        }
+        mbVisible = false;
         ClearPageWindows();
     }
 }
 
-Rectangle SdrPageView::GetPageRect() const
+tools::Rectangle SdrPageView::GetPageRect() const
 {
-    if (GetPage()==NULL) return Rectangle();
-    return Rectangle(Point(),Size(GetPage()->GetWdt()+1,GetPage()->GetHgt()+1));
+    if (GetPage()==nullptr) return tools::Rectangle();
+    return tools::Rectangle(Point(),Size(GetPage()->GetWidth()+1,GetPage()->GetHeight()+1));
 }
 
 void SdrPageView::InvalidateAllWin()
 {
     if(IsVisible() && GetPage())
     {
-        Rectangle aRect(Point(0,0),Size(GetPage()->GetWdt()+1,GetPage()->GetHgt()+1));
+        tools::Rectangle aRect(Point(0,0),Size(GetPage()->GetWidth()+1,GetPage()->GetHeight()+1));
         aRect.Union(GetPage()->GetAllObjBoundRect());
         GetView().InvalidateAllWin(aRect);
     }
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
 
 void SdrPageView::PrePaint()
 {
@@ -286,7 +265,8 @@ void SdrPageView::PrePaint()
     }
 }
 
-void SdrPageView::CompleteRedraw(SdrPaintWindow& rPaintWindow, const Region& rReg, sdr::contact::ViewObjectContactRedirector* pRedirector) const
+void SdrPageView::CompleteRedraw(
+    SdrPaintWindow& rPaintWindow, const vcl::Region& rReg, sdr::contact::ViewObjectContactRedirector* pRedirector )
 {
     if(GetPage())
     {
@@ -296,7 +276,7 @@ void SdrPageView::CompleteRedraw(SdrPaintWindow& rPaintWindow, const Region& rRe
         if(!pPageWindow)
         {
             // create temp PageWindow
-            pPageWindow = new SdrPageWindow(*((SdrPageView*)this), rPaintWindow);
+            pPageWindow = new SdrPageWindow(*this, rPaintWindow);
             bIsTempTarget = true;
         }
 
@@ -308,12 +288,12 @@ void SdrPageView::CompleteRedraw(SdrPaintWindow& rPaintWindow, const Region& rRe
         if(bIsTempTarget)
         {
             delete pPageWindow;
-            pPageWindow = 0L;
+            pPageWindow = nullptr;
         }
     }
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
+
 // #i74769# use SdrPaintWindow directly
 
 void SdrPageView::setPreparedPageWindow(SdrPageWindow* pKnownTarget)
@@ -322,18 +302,20 @@ void SdrPageView::setPreparedPageWindow(SdrPageWindow* pKnownTarget)
     mpPreparedPageWindow = pKnownTarget;
 }
 
-void SdrPageView::DrawLayer(SdrLayerID nID, OutputDevice* pGivenTarget, sdr::contact::ViewObjectContactRedirector* pRedirector, const Rectangle& rRect) const
+void SdrPageView::DrawLayer(SdrLayerID nID, OutputDevice* pGivenTarget,
+        sdr::contact::ViewObjectContactRedirector* pRedirector,
+        const tools::Rectangle& rRect, basegfx::B2IRectangle const*const pPageFrame)
 {
     if(GetPage())
     {
         if(pGivenTarget)
         {
-            const SdrPageWindow* pKnownTarget = FindPageWindow(*pGivenTarget);
+            SdrPageWindow* pKnownTarget = FindPageWindow(*pGivenTarget);
 
             if(pKnownTarget)
             {
                 // paint known target
-                pKnownTarget->RedrawLayer(&nID, pRedirector);
+                pKnownTarget->RedrawLayer(&nID, pRedirector, nullptr);
             }
             else
             {
@@ -349,11 +331,11 @@ void SdrPageView::DrawLayer(SdrLayerID nID, OutputDevice* pGivenTarget, sdr::con
 
                     // Copy existing paint region to use the same as prepared in BeginDrawLayer
                     SdrPaintWindow& rExistingPaintWindow = pPreparedTarget->GetPaintWindow();
-                    const Region& rExistingRegion = rExistingPaintWindow.GetRedrawRegion();
+                    const vcl::Region& rExistingRegion = rExistingPaintWindow.GetRedrawRegion();
                     bool bUseRect(false);
                     if (!rRect.IsEmpty())
                     {
-                        Region r(rExistingRegion);
+                        vcl::Region r(rExistingRegion);
                         r.Intersect(rRect);
                         // fdo#74435: FIXME: visibility check broken if empty
                         if (!r.IsEmpty())
@@ -362,13 +344,12 @@ void SdrPageView::DrawLayer(SdrLayerID nID, OutputDevice* pGivenTarget, sdr::con
                     if (!bUseRect)
                         aTemporaryPaintWindow.SetRedrawRegion(rExistingRegion);
                     else
-                        aTemporaryPaintWindow.SetRedrawRegion(Region(rRect));
-
+                        aTemporaryPaintWindow.SetRedrawRegion(vcl::Region(rRect));
                     // patch the ExistingPageWindow
                     pPreparedTarget->patchPaintWindow(aTemporaryPaintWindow);
 
                     // redraw the layer
-                    pPreparedTarget->RedrawLayer(&nID, pRedirector);
+                    pPreparedTarget->RedrawLayer(&nID, pRedirector, pPageFrame);
 
                     // restore the ExistingPageWindow
                     pPreparedTarget->unpatchPaintWindow();
@@ -380,7 +361,7 @@ void SdrPageView::DrawLayer(SdrLayerID nID, OutputDevice* pGivenTarget, sdr::con
                     // None of the known OutputDevices is the target of this paint, use
                     // a temporary SdrPageWindow for this Redraw.
                     SdrPaintWindow aTemporaryPaintWindow(mrView, *pGivenTarget);
-                    SdrPageWindow aTemporaryPageWindow(*((SdrPageView*)this), aTemporaryPaintWindow);
+                    SdrPageWindow aTemporaryPageWindow(*this, aTemporaryPaintWindow);
 
                     // #i72752#
                     // Copy existing paint region if other PageWindows exist, this was created by
@@ -388,23 +369,23 @@ void SdrPageView::DrawLayer(SdrLayerID nID, OutputDevice* pGivenTarget, sdr::con
                     // paints into an unknown device other than the view was created for (e.g. VirtualDevice)
                     if(PageWindowCount())
                     {
-                        SdrPageWindow* pExistingPageWindow = GetPageWindow(0L);
+                        SdrPageWindow* pExistingPageWindow = GetPageWindow(0);
                         SdrPaintWindow& rExistingPaintWindow = pExistingPageWindow->GetPaintWindow();
-                        const Region& rExistingRegion = rExistingPaintWindow.GetRedrawRegion();
+                        const vcl::Region& rExistingRegion = rExistingPaintWindow.GetRedrawRegion();
                         aTemporaryPaintWindow.SetRedrawRegion(rExistingRegion);
                     }
 
-                    aTemporaryPageWindow.RedrawLayer(&nID, pRedirector);
+                    aTemporaryPageWindow.RedrawLayer(&nID, pRedirector, nullptr);
                 }
             }
         }
         else
         {
             // paint in all known windows
-            for(sal_uInt32 a(0L); a < PageWindowCount(); a++)
+            for(sal_uInt32 a(0); a < PageWindowCount(); a++)
             {
                 SdrPageWindow* pTarget = GetPageWindow(a);
-                pTarget->RedrawLayer(&nID, pRedirector);
+                pTarget->RedrawLayer(&nID, pRedirector, nullptr);
             }
         }
     }
@@ -412,24 +393,23 @@ void SdrPageView::DrawLayer(SdrLayerID nID, OutputDevice* pGivenTarget, sdr::con
 
 void SdrPageView::SetDesignMode( bool _bDesignMode ) const
 {
-    for ( sal_uInt32 i = 0L; i < PageWindowCount(); ++i )
+    for ( sal_uInt32 i = 0; i < PageWindowCount(); ++i )
     {
         const SdrPageWindow& rPageViewWindow = *GetPageWindow(i);
         rPageViewWindow.SetDesignMode( _bDesignMode );
     }
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////
 
-void SdrPageView::DrawPageViewGrid(OutputDevice& rOut, const Rectangle& rRect, Color aColor)
+void SdrPageView::DrawPageViewGrid(OutputDevice& rOut, const tools::Rectangle& rRect, Color aColor)
 {
-    if (GetPage()==NULL)
+    if (GetPage()==nullptr)
         return;
 
-    long nx1=GetView().aGridBig.Width();
-    long nx2=GetView().aGridFin.Width();
-    long ny1=GetView().aGridBig.Height();
-    long ny2=GetView().aGridFin.Height();
+    long nx1=GetView().maGridBig.Width();
+    long nx2=GetView().maGridFin.Width();
+    long ny1=GetView().maGridBig.Height();
+    long ny2=GetView().maGridFin.Height();
 
     if (nx1==0) nx1=nx2;
     if (nx2==0) nx2=nx1;
@@ -442,178 +422,178 @@ void SdrPageView::DrawPageViewGrid(OutputDevice& rOut, const Rectangle& rRect, C
     if (ny1<0) ny1=-ny1;
     if (ny2<0) ny2=-ny2;
 
-    if (nx1!=0)
+    if (nx1==0)
+        return;
+
+    // no more global output size, use window size instead to decide grid sizes
+    long nScreenWdt = rOut.GetOutputSizePixel().Width();
+
+    long nMinDotPix=2;
+    long nMinLinPix=4;
+
+    if (nScreenWdt>=1600)
     {
-        // no more global output size, use window size instead to decide grid sizes
-        long nScreenWdt = rOut.GetOutputSizePixel().Width();
-
-        long nMinDotPix=2;
-        long nMinLinPix=4;
-
-        if (nScreenWdt>=1600)
-        {
-            nMinDotPix=4;
-            nMinLinPix=8;
-        }
-        else if (nScreenWdt>=1024)
-        {
-            nMinDotPix=3;
-            nMinLinPix=6;
-        }
-        else
-        { // e. g. 640x480
-            nMinDotPix=2;
-            nMinLinPix=4;
-        }
-        Size aMinDotDist(rOut.PixelToLogic(Size(nMinDotPix,nMinDotPix)));
-        Size aMinLinDist(rOut.PixelToLogic(Size(nMinLinPix,nMinLinPix)));
-        bool bHoriSolid=nx2<aMinDotDist.Width();
-        bool bVertSolid=ny2<aMinDotDist.Height();
-        // enlarge line offset (minimum 4 pixels)
-        // enlarge by: *2 *5 *10 *20 *50 *100 ...
-        int nTgl=0;
-        long nVal0=nx1;
-        while (nx1<aMinLinDist.Width())
-        {
-            long a=nx1;
-
-            if (nTgl==0) nx1*=2;
-            if (nTgl==1) nx1=nVal0*5; // => nx1*=2.5
-            if (nTgl==2) nx1*=2;
-
-            nVal0=a;
-            nTgl++; if (nTgl>=3) nTgl=0;
-        }
-        nTgl=0;
-        nVal0=ny1;
-        while (ny1<aMinLinDist.Height())
-        {
-            long a=ny1;
-
-            if (nTgl==0) ny1*=2;
-            if (nTgl==1) ny1=nVal0*5; // => ny1*=2.5
-            if (nTgl==2) ny1*=2;
-
-            nVal0=a;
-            nTgl++;
-
-            if (nTgl>=3) nTgl=0;
-        }
-
-        bool bHoriFine=nx2<nx1;
-        bool bVertFine=ny2<ny1;
-        bool bHoriLines=bHoriSolid || bHoriFine || !bVertFine;
-        bool bVertLines=bVertSolid || bVertFine;
-
-        Color aColorMerk( rOut.GetLineColor() );
-        rOut.SetLineColor( aColor );
-
-        bool bMap0=rOut.IsMapModeEnabled();
-
-        long nWrX=0;
-        long nWrY=0;
-        Point aOrg(aPgOrg);
-        long x1=GetPage()->GetLftBorder()+1+nWrX;
-        long x2=GetPage()->GetWdt()-GetPage()->GetRgtBorder()-1+nWrY;
-        long y1=GetPage()->GetUppBorder()+1+nWrX;
-        long y2=GetPage()->GetHgt()-GetPage()->GetLwrBorder()-1+nWrY;
-        const SdrPageGridFrameList* pFrames=GetPage()->GetGridFrameList(this,NULL);
-
-        sal_uInt16 nGridPaintAnz=1;
-        if (pFrames!=NULL) nGridPaintAnz=pFrames->GetCount();
-        for (sal_uInt16 nGridPaintNum=0; nGridPaintNum<nGridPaintAnz; nGridPaintNum++) {
-            if (pFrames!=NULL) {
-                const SdrPageGridFrame& rGF=(*pFrames)[nGridPaintNum];
-                nWrX=rGF.GetPaperRect().Left();
-                nWrY=rGF.GetPaperRect().Top();
-                x1=rGF.GetUserArea().Left();
-                x2=rGF.GetUserArea().Right();
-                y1=rGF.GetUserArea().Top();
-                y2=rGF.GetUserArea().Bottom();
-                aOrg=rGF.GetUserArea().TopLeft();
-                aOrg-=rGF.GetPaperRect().TopLeft();
-            }
-            if (!rRect.IsEmpty()) {
-                Size a1PixSiz(rOut.PixelToLogic(Size(1,1)));
-                long nX1Pix=a1PixSiz.Width();  // add 1 pixel of tolerance
-                long nY1Pix=a1PixSiz.Height();
-                if (x1<rRect.Left()  -nX1Pix) x1=rRect.Left()  -nX1Pix;
-                if (x2>rRect.Right() +nX1Pix) x2=rRect.Right() +nX1Pix;
-                if (y1<rRect.Top()   -nY1Pix) y1=rRect.Top()   -nY1Pix;
-                if (y2>rRect.Bottom()+nY1Pix) y2=rRect.Bottom()+nY1Pix;
-            }
-
-            long xBigOrg=aOrg.X()+nWrX;
-            while (xBigOrg>=x1) xBigOrg-=nx1;
-            while (xBigOrg<x1) xBigOrg+=nx1;
-            long xFinOrg=xBigOrg;
-            while (xFinOrg>=x1) xFinOrg-=nx2;
-            while (xFinOrg<x1) xFinOrg+=nx2;
-
-            long yBigOrg=aOrg.Y()+nWrY;
-            while (yBigOrg>=y1) yBigOrg-=ny1;
-            while (yBigOrg<y1) yBigOrg+=ny1;
-            long yFinOrg=yBigOrg;
-            while (yFinOrg>=y1) yFinOrg-=ny2;
-            while (yFinOrg<y1) yFinOrg+=ny2;
-
-            if( x1 <= x2 && y1 <= y2 )
-            {
-                if( bHoriLines )
-                {
-                    sal_uIntPtr nGridFlags = ( bHoriSolid ? GRID_HORZLINES : GRID_DOTS );
-                    sal_uInt16 nSteps = sal_uInt16(nx1 / nx2);
-                    sal_uInt32 nRestPerStepMul1000 = nSteps ? ( ((nx1 * 1000L)/ nSteps) - (nx2 * 1000L) ) : 0;
-                    sal_uInt32 nStepOffset = 0;
-                    sal_uInt16 nPointOffset = 0;
-
-                    for(sal_uInt16 a=0;a<nSteps;a++)
-                    {
-                        // draw
-                        rOut.DrawGrid(
-                            Rectangle( xFinOrg + (a * nx2) + nPointOffset, yBigOrg, x2, y2 ),
-                            Size( nx1, ny1 ), nGridFlags );
-
-                        // do a step
-                        nStepOffset += nRestPerStepMul1000;
-                        while(nStepOffset >= 1000)
-                        {
-                            nStepOffset -= 1000;
-                            nPointOffset++;
-                        }
-                    }
-                }
-
-                if( bVertLines )
-                {
-                    sal_uIntPtr nGridFlags = ( bVertSolid ? GRID_VERTLINES : GRID_DOTS );
-                    sal_uInt16 nSteps = sal_uInt16(ny1 / ny2);
-                    sal_uInt32 nRestPerStepMul1000 = nSteps ? ( ((ny1 * 1000L)/ nSteps) - (ny2 * 1000L) ) : 0;
-                    sal_uInt32 nStepOffset = 0;
-                    sal_uInt16 nPointOffset = 0;
-
-                    for(sal_uInt16 a=0;a<nSteps;a++)
-                    {
-                        // draw
-                        rOut.DrawGrid(
-                            Rectangle( xBigOrg, yFinOrg + (a * ny2) + nPointOffset, x2, y2 ),
-                            Size( nx1, ny1 ), nGridFlags );
-
-                        // do a step
-                        nStepOffset += nRestPerStepMul1000;
-                        while(nStepOffset >= 1000)
-                        {
-                            nStepOffset -= 1000;
-                            nPointOffset++;
-                        }
-                    }
-                }
-            }
-        }
-
-        rOut.EnableMapMode(bMap0);
-        rOut.SetLineColor(aColorMerk);
+        nMinDotPix=4;
+        nMinLinPix=8;
     }
+    else if (nScreenWdt>=1024)
+    {
+        nMinDotPix=3;
+        nMinLinPix=6;
+    }
+    else
+    { // e. g. 640x480
+        nMinDotPix=2;
+        nMinLinPix=4;
+    }
+    Size aMinDotDist(rOut.PixelToLogic(Size(nMinDotPix,nMinDotPix)));
+    Size aMinLinDist(rOut.PixelToLogic(Size(nMinLinPix,nMinLinPix)));
+    bool bHoriSolid=nx2<aMinDotDist.Width();
+    bool bVertSolid=ny2<aMinDotDist.Height();
+    // enlarge line offset (minimum 4 pixels)
+    // enlarge by: *2 *5 *10 *20 *50 *100 ...
+    int nTgl=0;
+    long nVal0=nx1;
+    while (nx1<aMinLinDist.Width())
+    {
+        long a=nx1;
+
+        if (nTgl==0) nx1*=2;
+        if (nTgl==1) nx1=nVal0*5; // => nx1*=2.5
+        if (nTgl==2) nx1*=2;
+
+        nVal0=a;
+        nTgl++; if (nTgl>=3) nTgl=0;
+    }
+    nTgl=0;
+    nVal0=ny1;
+    while (ny1<aMinLinDist.Height())
+    {
+        long a=ny1;
+
+        if (nTgl==0) ny1*=2;
+        if (nTgl==1) ny1=nVal0*5; // => ny1*=2.5
+        if (nTgl==2) ny1*=2;
+
+        nVal0=a;
+        nTgl++;
+
+        if (nTgl>=3) nTgl=0;
+    }
+
+    bool bHoriFine=nx2<nx1;
+    bool bVertFine=ny2<ny1;
+    bool bHoriLines=bHoriSolid || bHoriFine || !bVertFine;
+    bool bVertLines=bVertSolid || bVertFine;
+
+    Color aColorMerk( rOut.GetLineColor() );
+    rOut.SetLineColor( aColor );
+
+    bool bMap0=rOut.IsMapModeEnabled();
+
+    long nWrX=0;
+    long nWrY=0;
+    Point aOrg(aPgOrg);
+    long x1=GetPage()->GetLeftBorder()+1+nWrX;
+    long x2=GetPage()->GetWidth()-GetPage()->GetRightBorder()-1+nWrY;
+    long y1=GetPage()->GetUpperBorder()+1+nWrX;
+    long y2=GetPage()->GetHeight()-GetPage()->GetLowerBorder()-1+nWrY;
+    const SdrPageGridFrameList* pFrames=GetPage()->GetGridFrameList(this,nullptr);
+
+    sal_uInt16 nGridPaintCnt=1;
+    if (pFrames!=nullptr) nGridPaintCnt=pFrames->GetCount();
+    for (sal_uInt16 nGridPaintNum=0; nGridPaintNum<nGridPaintCnt; nGridPaintNum++) {
+        if (pFrames!=nullptr) {
+            const SdrPageGridFrame& rGF=(*pFrames)[nGridPaintNum];
+            nWrX=rGF.GetPaperRect().Left();
+            nWrY=rGF.GetPaperRect().Top();
+            x1=rGF.GetUserArea().Left();
+            x2=rGF.GetUserArea().Right();
+            y1=rGF.GetUserArea().Top();
+            y2=rGF.GetUserArea().Bottom();
+            aOrg=rGF.GetUserArea().TopLeft();
+            aOrg-=rGF.GetPaperRect().TopLeft();
+        }
+        if (!rRect.IsEmpty()) {
+            Size a1PixSiz(rOut.PixelToLogic(Size(1,1)));
+            long nX1Pix=a1PixSiz.Width();  // add 1 pixel of tolerance
+            long nY1Pix=a1PixSiz.Height();
+            if (x1<rRect.Left()  -nX1Pix) x1=rRect.Left()  -nX1Pix;
+            if (x2>rRect.Right() +nX1Pix) x2=rRect.Right() +nX1Pix;
+            if (y1<rRect.Top()   -nY1Pix) y1=rRect.Top()   -nY1Pix;
+            if (y2>rRect.Bottom()+nY1Pix) y2=rRect.Bottom()+nY1Pix;
+        }
+
+        long xBigOrg=aOrg.X()+nWrX;
+        while (xBigOrg>=x1) xBigOrg-=nx1;
+        while (xBigOrg<x1) xBigOrg+=nx1;
+        long xFinOrg=xBigOrg;
+        while (xFinOrg>=x1) xFinOrg-=nx2;
+        while (xFinOrg<x1) xFinOrg+=nx2;
+
+        long yBigOrg=aOrg.Y()+nWrY;
+        while (yBigOrg>=y1) yBigOrg-=ny1;
+        while (yBigOrg<y1) yBigOrg+=ny1;
+        long yFinOrg=yBigOrg;
+        while (yFinOrg>=y1) yFinOrg-=ny2;
+        while (yFinOrg<y1) yFinOrg+=ny2;
+
+        if( x1 <= x2 && y1 <= y2 )
+        {
+            if( bHoriLines )
+            {
+                DrawGridFlags nGridFlags = ( bHoriSolid ? DrawGridFlags::HorzLines : DrawGridFlags::Dots );
+                sal_uInt16 nSteps = sal_uInt16(nx1 / nx2);
+                sal_uInt32 nRestPerStepMul1000 = nSteps ? ( ((nx1 * 1000L)/ nSteps) - (nx2 * 1000L) ) : 0;
+                sal_uInt32 nStepOffset = 0;
+                sal_uInt16 nPointOffset = 0;
+
+                for(sal_uInt16 a=0;a<nSteps;a++)
+                {
+                    // draw
+                    rOut.DrawGrid(
+                        tools::Rectangle( xFinOrg + (a * nx2) + nPointOffset, yBigOrg, x2, y2 ),
+                        Size( nx1, ny1 ), nGridFlags );
+
+                    // do a step
+                    nStepOffset += nRestPerStepMul1000;
+                    while(nStepOffset >= 1000)
+                    {
+                        nStepOffset -= 1000;
+                        nPointOffset++;
+                    }
+                }
+            }
+
+            if( bVertLines )
+            {
+                DrawGridFlags nGridFlags = ( bVertSolid ? DrawGridFlags::VertLines : DrawGridFlags::Dots );
+                sal_uInt16 nSteps = sal_uInt16(ny1 / ny2);
+                sal_uInt32 nRestPerStepMul1000 = nSteps ? ( ((ny1 * 1000L)/ nSteps) - (ny2 * 1000L) ) : 0;
+                sal_uInt32 nStepOffset = 0;
+                sal_uInt16 nPointOffset = 0;
+
+                for(sal_uInt16 a=0;a<nSteps;a++)
+                {
+                    // draw
+                    rOut.DrawGrid(
+                        tools::Rectangle( xBigOrg, yFinOrg + (a * ny2) + nPointOffset, x2, y2 ),
+                        Size( nx1, ny1 ), nGridFlags );
+
+                    // do a step
+                    nStepOffset += nRestPerStepMul1000;
+                    while(nStepOffset >= 1000)
+                    {
+                        nStepOffset -= 1000;
+                        nPointOffset++;
+                    }
+                }
+            }
+        }
+    }
+
+    rOut.EnableMapMode(bMap0);
+    rOut.SetLineColor(aColorMerk);
 }
 
 void SdrPageView::AdjHdl()
@@ -621,18 +601,18 @@ void SdrPageView::AdjHdl()
     GetView().AdjustMarkHdl();
 }
 
-void SdrPageView::SetLayer(const OUString& rName, SetOfByte& rBS, bool bJa)
+void SdrPageView::SetLayer(const OUString& rName, SdrLayerIDSet& rBS, bool bJa)
 {
     if(!GetPage())
         return;
 
-    SdrLayerID nID = GetPage()->GetLayerAdmin().GetLayerID(rName, sal_True);
+    SdrLayerID nID = GetPage()->GetLayerAdmin().GetLayerID(rName);
 
     if(SDRLAYER_NOTFOUND != nID)
         rBS.Set(nID, bJa);
 }
 
-bool SdrPageView::IsLayer(const OUString& rName, const SetOfByte& rBS) const
+bool SdrPageView::IsLayer(const OUString& rName, const SdrLayerIDSet& rBS) const
 {
     if(!GetPage())
         return false;
@@ -641,7 +621,7 @@ bool SdrPageView::IsLayer(const OUString& rName, const SetOfByte& rBS) const
 
     if (!rName.isEmpty())
     {
-        SdrLayerID nId = GetPage()->GetLayerAdmin().GetLayerID(rName, true);
+        SdrLayerID nId = GetPage()->GetLayerAdmin().GetLayerID(rName);
 
         if(SDRLAYER_NOTFOUND != nId)
         {
@@ -652,61 +632,49 @@ bool SdrPageView::IsLayer(const OUString& rName, const SetOfByte& rBS) const
     return bRet;
 }
 
-sal_Bool SdrPageView::IsObjMarkable(SdrObject* pObj) const
+bool SdrPageView::IsObjMarkable(SdrObject const * pObj) const
 {
-    if(pObj)
+    if (!pObj)
+        return false;
+    if (pObj->IsMarkProtect())
+        return false;    // excluded from selection?
+    if (!pObj->IsVisible())
+        return false;    // only visible are selectable
+    if (!pObj->IsInserted())
+        return false;    // Obj deleted?
+    if (auto pObjGroup = dynamic_cast<const SdrObjGroup*>(pObj))
     {
-        // excluded from selection?
-        if(pObj->IsMarkProtect())
-        {
-            return sal_False;
-        }
+        // If object is a Group object, visibility may depend on
+        // multiple layers. If one object is markable, Group is markable.
+        SdrObjList* pObjList = pObjGroup->GetSubList();
 
-        // only visible are selectable
-        if( !pObj->IsVisible() )
+        if (pObjList && pObjList->GetObjCount())
         {
-            return sal_False;
-        }
-
-        if(pObj->ISA(SdrObjGroup))
-        {
-            // If object is a Group object, visibility may depend on
-            // multiple layers. If one object is markable, Group is markable.
-            SdrObjList* pObjList = ((SdrObjGroup*)pObj)->GetSubList();
-
-            if(pObjList && pObjList->GetObjCount())
+            for (size_t a = 0; a < pObjList->GetObjCount(); ++a)
             {
-                sal_Bool bGroupIsMarkable(sal_False);
-
-                for(sal_uInt32 a(0L); !bGroupIsMarkable && a < pObjList->GetObjCount(); a++)
-                {
-                    SdrObject* pCandidate = pObjList->GetObj(a);
-
-                    // call recursively
-                    if(IsObjMarkable(pCandidate))
-                    {
-                        bGroupIsMarkable = sal_True;
-                    }
-                }
-
-                return bGroupIsMarkable;
-            }
-            else
-            {
-                // #i43302#
-                // Allow empty groups to be selected to be able to delete them
-                return sal_True;
+                SdrObject* pCandidate = pObjList->GetObj(a);
+                // call recursively
+                if (IsObjMarkable(pCandidate))
+                    return true;
             }
+            return false;
         }
         else
         {
-            // the layer has to be visible and must not be locked
-            SdrLayerID nL = pObj->GetLayer();
-            return (aLayerVisi.IsSet(sal_uInt8(nL)) && !aLayerLock.IsSet(sal_uInt8(nL)));
+            // #i43302#
+            // Allow empty groups to be selected to be able to delete them
+            return true;
         }
     }
-
-    return sal_False;
+    if (!pObj->Is3DObj() && pObj->GetPage()!=GetPage())
+        return false; // Obj suddenly in different Page
+    // the layer has to be visible and must not be locked
+    SdrLayerID nL = pObj->GetLayer();
+    if (!aLayerVisi.IsSet(nL))
+        return false;
+    if (aLayerLock.IsSet(nL))
+        return false;
+    return true;
 }
 
 void SdrPageView::SetPageOrigin(const Point& rOrg)
@@ -724,20 +692,20 @@ void SdrPageView::ImpInvalidateHelpLineArea(sal_uInt16 nNum) const
     if (GetView().IsHlplVisible() && nNum<aHelpLines.GetCount()) {
         const SdrHelpLine& rHL=aHelpLines[nNum];
 
-        for(sal_uInt32 a(0L); a < GetView().PaintWindowCount(); a++)
+        for(sal_uInt32 a(0); a < GetView().PaintWindowCount(); a++)
         {
             SdrPaintWindow* pCandidate = GetView().GetPaintWindow(a);
 
             if(pCandidate->OutputToWindow())
             {
                 OutputDevice& rOutDev = pCandidate->GetOutputDevice();
-                Rectangle aR(rHL.GetBoundRect(rOutDev));
+                tools::Rectangle aR(rHL.GetBoundRect(rOutDev));
                 Size aSiz(rOutDev.PixelToLogic(Size(1,1)));
                 aR.Left() -= aSiz.Width();
                 aR.Right() += aSiz.Width();
                 aR.Top() -= aSiz.Height();
                 aR.Bottom() += aSiz.Height();
-                ((SdrView&)GetView()).InvalidateOneWin((Window&)rOutDev, aR);
+                const_cast<SdrView&>(GetView()).InvalidateOneWin(static_cast<vcl::Window&>(rOutDev), aR);
             }
         }
     }
@@ -755,8 +723,8 @@ void SdrPageView::SetHelpLine(sal_uInt16 nNum, const SdrHelpLine& rNewHelpLine)
         bool bNeedRedraw = true;
         if (aHelpLines[nNum].GetKind()==rNewHelpLine.GetKind()) {
             switch (rNewHelpLine.GetKind()) {
-                case SDRHELPLINE_VERTICAL  : if (aHelpLines[nNum].GetPos().X()==rNewHelpLine.GetPos().X()) bNeedRedraw = false; break;
-                case SDRHELPLINE_HORIZONTAL: if (aHelpLines[nNum].GetPos().Y()==rNewHelpLine.GetPos().Y()) bNeedRedraw = false; break;
+                case SdrHelpLineKind::Vertical  : if (aHelpLines[nNum].GetPos().X()==rNewHelpLine.GetPos().X()) bNeedRedraw = false; break;
+                case SdrHelpLineKind::Horizontal: if (aHelpLines[nNum].GetPos().Y()==rNewHelpLine.GetPos().Y()) bNeedRedraw = false; break;
                 default: break;
             } // switch
         }
@@ -774,10 +742,9 @@ void SdrPageView::DeleteHelpLine(sal_uInt16 nNum)
     }
 }
 
-void SdrPageView::InsertHelpLine(const SdrHelpLine& rHL, sal_uInt16 nNum)
+void SdrPageView::InsertHelpLine(const SdrHelpLine& rHL)
 {
-    if (nNum > aHelpLines.GetCount())
-        nNum = aHelpLines.GetCount();
+    sal_uInt16 nNum = aHelpLines.GetCount();
     aHelpLines.Insert(rHL,nNum);
     if (GetView().IsHlplVisible())
         ImpInvalidateHelpLineArea(nNum);
@@ -796,13 +763,13 @@ void SdrPageView::SetAktGroupAndList(SdrObject* pNewGroup, SdrObjList* pNewList)
     }
 }
 
-sal_Bool SdrPageView::EnterGroup(SdrObject* pObj)
+bool SdrPageView::EnterGroup(SdrObject* pObj)
 {
-    sal_Bool bRet(sal_False);
+    bool bRet(false);
 
     if(pObj && pObj->IsGroupObject())
     {
-        sal_Bool bGlueInvalidate(GetView().ImpIsGlueVisible());
+        bool bGlueInvalidate(GetView().ImpIsGlueVisible());
 
         if(bGlueInvalidate)
         {
@@ -820,7 +787,7 @@ sal_Bool SdrPageView::EnterGroup(SdrObject* pObj)
         // else select nothing and let the user decide what to do next
         if(pNewObjList && pNewObjList->GetObjCount() == 1)
         {
-            SdrObject* pFirstObject = pNewObjList->GetObj(0L);
+            SdrObject* pFirstObject = pNewObjList->GetObj(0);
 
             if(GetView().GetSdrPageView())
             {
@@ -832,17 +799,14 @@ sal_Bool SdrPageView::EnterGroup(SdrObject* pObj)
         GetView().AdjustMarkHdl();
 
         // invalidate only when view wants to visualize group entering
-        if(GetView().DoVisualizeEnteredGroup())
-        {
-            InvalidateAllWin();
-        }
+        InvalidateAllWin();
 
         if (bGlueInvalidate)
         {
             GetView().GlueInvalidate();
         }
 
-        bRet = sal_True;
+        bRet = true;
     }
 
     return bRet;
@@ -850,47 +814,46 @@ sal_Bool SdrPageView::EnterGroup(SdrObject* pObj)
 
 void SdrPageView::LeaveOneGroup()
 {
-    if(GetAktGroup())
-    {
-        sal_Bool bGlueInvalidate = (GetView().ImpIsGlueVisible());
+    if(!GetAktGroup())
+        return;
 
-        if(bGlueInvalidate)
-            GetView().GlueInvalidate();
+    bool bGlueInvalidate = GetView().ImpIsGlueVisible();
 
-        SdrObject* pLastGroup = GetAktGroup();
-        SdrObject* pParentGroup = GetAktGroup()->GetUpGroup();
-        SdrObjList* pParentList = GetPage();
+    if(bGlueInvalidate)
+        GetView().GlueInvalidate();
 
-        if(pParentGroup)
-            pParentList = pParentGroup->GetSubList();
+    SdrObject* pLastGroup = GetAktGroup();
+    SdrObject* pParentGroup = GetAktGroup()->GetUpGroup();
+    SdrObjList* pParentList = GetPage();
 
-        // deselect everything
-        GetView().UnmarkAll();
+    if(pParentGroup)
+        pParentList = pParentGroup->GetSubList();
 
-        // allocations, pAktGroup and pAktList need to be set
-        SetAktGroupAndList(pParentGroup, pParentList);
+    // deselect everything
+    GetView().UnmarkAll();
 
-        // select the group we just left
-        if(pLastGroup)
-            if(GetView().GetSdrPageView())
-                GetView().MarkObj(pLastGroup, GetView().GetSdrPageView());
+    // allocations, pAktGroup and pAktList need to be set
+    SetAktGroupAndList(pParentGroup, pParentList);
 
-        GetView().AdjustMarkHdl();
+    // select the group we just left
+    if(pLastGroup)
+        if(GetView().GetSdrPageView())
+            GetView().MarkObj(pLastGroup, GetView().GetSdrPageView());
 
-        // invalidate only if view wants to visualize group entering
-        if(GetView().DoVisualizeEnteredGroup())
-            InvalidateAllWin();
+    GetView().AdjustMarkHdl();
 
-        if(bGlueInvalidate)
-            GetView().GlueInvalidate();
-    }
+    // invalidate only if view wants to visualize group entering
+    InvalidateAllWin();
+
+    if(bGlueInvalidate)
+        GetView().GlueInvalidate();
 }
 
 void SdrPageView::LeaveAllGroup()
 {
     if(GetAktGroup())
     {
-        sal_Bool bGlueInvalidate = (GetView().ImpIsGlueVisible());
+        bool bGlueInvalidate = GetView().ImpIsGlueVisible();
 
         if(bGlueInvalidate)
             GetView().GlueInvalidate();
@@ -901,7 +864,7 @@ void SdrPageView::LeaveAllGroup()
         GetView().UnmarkAll();
 
         // allocations, pAktGroup and pAktList always need to be set
-        SetAktGroupAndList(NULL, GetPage());
+        SetAktGroupAndList(nullptr, GetPage());
 
         // find and select uppermost group
         if(pLastGroup)
@@ -916,8 +879,7 @@ void SdrPageView::LeaveAllGroup()
         GetView().AdjustMarkHdl();
 
         // invalidate only when view wants to visualize group entering
-        if(GetView().DoVisualizeEnteredGroup())
-            InvalidateAllWin();
+        InvalidateAllWin();
 
         if(bGlueInvalidate)
             GetView().GlueInvalidate();
@@ -926,25 +888,25 @@ void SdrPageView::LeaveAllGroup()
 
 sal_uInt16 SdrPageView::GetEnteredLevel() const
 {
-    sal_uInt16 nAnz=0;
+    sal_uInt16 nCount=0;
     SdrObject* pGrp=GetAktGroup();
-    while (pGrp!=NULL) {
-        nAnz++;
+    while (pGrp!=nullptr) {
+        nCount++;
         pGrp=pGrp->GetUpGroup();
     }
-    return nAnz;
+    return nCount;
 }
 
 void SdrPageView::CheckAktGroup()
 {
     SdrObject* pGrp=GetAktGroup();
-    while (pGrp!=NULL &&
-           (!pGrp->IsInserted() || pGrp->GetObjList()==NULL ||
-            pGrp->GetPage()==NULL || pGrp->GetModel()==NULL)) { // anything outside of the borders?
+    while (pGrp!=nullptr &&
+           (!pGrp->IsInserted() || pGrp->GetObjList()==nullptr ||
+            pGrp->GetPage()==nullptr || pGrp->GetModel()==nullptr)) { // anything outside of the borders?
         pGrp=pGrp->GetUpGroup();
     }
     if (pGrp!=GetAktGroup()) {
-        if (pGrp!=NULL) EnterGroup(pGrp);
+        if (pGrp!=nullptr) EnterGroup(pGrp);
         else LeaveAllGroup();
     }
 }
@@ -955,10 +917,6 @@ void SdrPageView::SetApplicationBackgroundColor(Color aBackgroundColor)
     maBackgroundColor = aBackgroundColor;
 }
 
-Color SdrPageView::GetApplicationBackgroundColor() const
-{
-    return maBackgroundColor;
-}
 
 // Set document color for svx at SdrPageViews
 void SdrPageView::SetApplicationDocumentColor(Color aDocumentColor)
@@ -966,10 +924,5 @@ void SdrPageView::SetApplicationDocumentColor(Color aDocumentColor)
     maDocumentColor = aDocumentColor;
 }
 
-Color SdrPageView::GetApplicationDocumentColor() const
-{
-    return maDocumentColor;
-}
-
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
