@@ -25,12 +25,9 @@
 #include <svtools/grfmgr.hxx>
 #include <svx/svdmodel.hxx>
 
-#ifdef DBG_UTIL
-#include <svdibrow.hxx>
-#endif
 #include <svx/svdpage.hxx>
 #include <svx/svdpagv.hxx>
-#include <svl/smplhint.hxx>
+#include <svl/hint.hxx>
 
 #include <editeng/editdata.hxx>
 #include <svx/svdmrkv.hxx>
@@ -39,8 +36,8 @@
 #include <svx/svdglue.hxx>
 #include <svx/svdobj.hxx>
 #include <svx/svdograf.hxx>
-#include "svdibrow.hxx"
-#include "svx/svditer.hxx"
+#include <svdibrow.hxx>
+#include <svx/svditer.hxx>
 #include <svx/svdouno.hxx>
 #include <svx/sdr/overlay/overlayobjectlist.hxx>
 #include <sdr/overlay/overlayrollingrectangle.hxx>
@@ -59,10 +56,13 @@
 #include <svx/sdr/contact/viewcontact.hxx>
 #include <drawinglayer/primitive2d/metafileprimitive2d.hxx>
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
+#include <comphelper/lok.hxx>
+#include <svx/svdviter.hxx>
+
+#include <sfx2/lokhelper.hxx>
 
 using namespace ::com::sun::star;
 
-
 // interface to SdrPaintWindow
 
 SdrPaintWindow* SdrPaintView::FindPaintWindow(const OutputDevice& rOut) const
@@ -88,24 +88,14 @@ SdrPaintWindow* SdrPaintView::GetPaintWindow(sal_uInt32 nIndex) const
     return nullptr;
 }
 
-void SdrPaintView::AppendPaintWindow(SdrPaintWindow& rNew)
+void SdrPaintView::RemovePaintWindow(SdrPaintWindow& rOld)
 {
-    maPaintWindows.push_back(&rNew);
-}
-
-SdrPaintWindow* SdrPaintView::RemovePaintWindow(SdrPaintWindow& rOld)
-{
-    SdrPaintWindow* pRetval = nullptr;
     const SdrPaintWindowVector::iterator aFindResult = ::std::find(maPaintWindows.begin(), maPaintWindows.end(), &rOld);
 
     if(aFindResult != maPaintWindows.end())
     {
-        // remember return value, aFindResult is no longer valid after deletion
-        pRetval = *aFindResult;
         maPaintWindows.erase(aFindResult);
     }
-
-    return pRetval;
 }
 
 OutputDevice* SdrPaintView::GetFirstOutputDevice() const
@@ -119,16 +109,11 @@ OutputDevice* SdrPaintView::GetFirstOutputDevice() const
 }
 
 
-
-SvxViewHint::SvxViewHint (HintType eHintType)
-    : meHintType(eHintType)
+SvxViewChangedHint::SvxViewChangedHint()
 {
 }
 
 
-
-
-
 BitmapEx convertMetafileToBitmapEx(
     const GDIMetaFile& rMtf,
     const basegfx::B2DRange& rTargetRange,
@@ -140,12 +125,12 @@ BitmapEx convertMetafileToBitmapEx(
     {
         const drawinglayer::primitive2d::Primitive2DReference aMtf(
             new drawinglayer::primitive2d::MetafilePrimitive2D(
-                basegfx::tools::createScaleTranslateB2DHomMatrix(
+                basegfx::utils::createScaleTranslateB2DHomMatrix(
                     rTargetRange.getRange(),
                     rTargetRange.getMinimum()),
                 rMtf));
         aBitmapEx = convertPrimitive2DSequenceToBitmapEx(
-            drawinglayer::primitive2d::Primitive2DSequence(&aMtf, 1),
+            drawinglayer::primitive2d::Primitive2DContainer { aMtf },
             rTargetRange,
             nMaximumQuadraticPixels);
     }
@@ -154,15 +139,13 @@ BitmapEx convertMetafileToBitmapEx(
 }
 
 
-
-
-
 void SdrPaintView::ImpClearVars()
 {
 #ifdef DBG_UTIL
     mpItemBrowser=nullptr;
 #endif
     mbPageVisible=true;
+    mbPageShadowVisible=true;
     mbPageBorderVisible=true;
     mbBordVisible=true;
     mbGridVisible=true;
@@ -177,7 +160,7 @@ void SdrPaintView::ImpClearVars()
     mbPrintPreview=false;
     mbPreviewRenderer=false;
 
-    meAnimationMode = SDR_ANIMATION_ANIMATE;
+    meAnimationMode = SdrAnimationMode::Animate;
     mbAnimationPause = false;
 
     mnHitTolPix=2;
@@ -186,12 +169,11 @@ void SdrPaintView::ImpClearVars()
     mnMinMovLog=0;
     mpActualOutDev=nullptr;
     mpDragWin=nullptr;
-    mbRestoreColors=true;
     mpDefaultStyleSheet=nullptr;
     mbSomeObjChgdFlag=false;
-    mnGraphicManagerDrawMode = GraphicManagerDrawFlags::STANDARD;
-    maComeBackIdle.SetPriority(SchedulerPriority::REPAINT);
-    maComeBackIdle.SetIdleHdl(LINK(this,SdrPaintView,ImpComeBackHdl));
+    maComeBackIdle.SetPriority(TaskPriority::REPAINT);
+    maComeBackIdle.SetInvokeHandler(LINK(this,SdrPaintView,ImpComeBackHdl));
+    maComeBackIdle.SetDebugName( "svx::SdrPaintView aComeBackIdle" );
 
     if (mpModel)
         SetDefaultStyleSheet(mpModel->GetDefaultStyleSheet(), true);
@@ -218,9 +200,6 @@ SdrPaintView::SdrPaintView(SdrModel* pModel, OutputDevice* pOut)
         AddWindowToPaintView(pOut, nullptr);
     }
 
-    // flag to visualize groups
-    mbVisualizeEnteredGroup = true;
-
     maColorConfig.AddListener(this);
     onChangeColorConfig();
 }
@@ -246,14 +225,12 @@ SdrPaintView::~SdrPaintView()
 }
 
 
-
 void SdrPaintView::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
 {
     //If the stylesheet has been destroyed
     if (&rBC == mpDefaultStyleSheet)
     {
-        const SfxSimpleHint* pSimpleHint = dynamic_cast<const SfxSimpleHint*>(&rHint);
-        if (pSimpleHint && pSimpleHint->GetId() == SFX_HINT_DYING)
+        if (rHint.GetId() == SfxHintId::Dying)
             mpDefaultStyleSheet = nullptr;
         return;
     }
@@ -263,7 +240,7 @@ void SdrPaintView::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
         return;
 
     SdrHintKind eKind = pSdrHint->GetKind();
-    if (eKind==HINT_OBJCHG || eKind==HINT_OBJINSERTED || eKind==HINT_OBJREMOVED)
+    if (eKind==SdrHintKind::ObjectChange || eKind==SdrHintKind::ObjectInserted || eKind==SdrHintKind::ObjectRemoved)
     {
         bool bObjChg = !mbSomeObjChgdFlag; // if true, evaluate for ComeBack timer
         if (bObjChg)
@@ -273,7 +250,7 @@ void SdrPaintView::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
         }
     }
 
-    if (eKind==HINT_PAGEORDERCHG)
+    if (eKind==SdrHintKind::PageOrderChange)
     {
         const SdrPage* pPg=pSdrHint->GetPage();
         if (pPg && !pPg->IsInserted())
@@ -286,13 +263,13 @@ void SdrPaintView::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
     }
 }
 
-void SdrPaintView::ConfigurationChanged( ::utl::ConfigurationBroadcaster* , sal_uInt32 )
+void SdrPaintView::ConfigurationChanged( ::utl::ConfigurationBroadcaster* , ConfigurationHints )
 {
     onChangeColorConfig();
     InvalidateAllWin();
 }
 
-IMPL_LINK_NOARG_TYPED(SdrPaintView, ImpComeBackHdl, Idle *, void)
+IMPL_LINK_NOARG(SdrPaintView, ImpComeBackHdl, Timer *, void)
 {
     if (mbSomeObjChgdFlag) {
         mbSomeObjChgdFlag=false;
@@ -332,7 +309,6 @@ void SdrPaintView::ModelHasChanged()
 }
 
 
-
 bool SdrPaintView::IsAction() const
 {
     return false;
@@ -354,7 +330,7 @@ void SdrPaintView::BrkAction()
 {
 }
 
-void SdrPaintView::TakeActionRect(Rectangle&) const
+void SdrPaintView::TakeActionRect(tools::Rectangle&) const
 {
 }
 
@@ -372,7 +348,6 @@ SdrPageView* SdrPaintView::GetTextEditPageView() const
 }
 
 
-
 sal_uInt16 SdrPaintView::ImpGetMinMovLogic(short nMinMov, const OutputDevice* pOut) const
 {
     if (nMinMov>=0) return sal_uInt16(nMinMov);
@@ -416,7 +391,6 @@ void SdrPaintView::SetActualWin(const OutputDevice* pWin)
 }
 
 
-
 void SdrPaintView::ClearPageView()
 {
     BrkAction();
@@ -460,7 +434,7 @@ void SdrPaintView::AddWindowToPaintView(OutputDevice* pNewWin, vcl::Window *pWin
 {
     DBG_ASSERT(pNewWin, "SdrPaintView::AddWindowToPaintView: No OutputDevice(!)");
     SdrPaintWindow* pNewPaintWindow = new SdrPaintWindow(*this, *pNewWin, pWindow);
-    AppendPaintWindow(*pNewPaintWindow);
+    maPaintWindows.push_back(pNewPaintWindow);
 
     if(mpPageView)
     {
@@ -568,10 +542,10 @@ void SdrPaintView::CompleteRedraw(OutputDevice* pOut, const vcl::Region& rReg, s
 #define REMEMBERED_TIMES_COUNT  (10)
     static bool bDoTimerTest(false);
     static bool bTimesInited(false);
-    static sal_uInt32 nRepeatCount(10L);
+    static sal_uInt32 nRepeatCount(10);
     static double fLastTimes[REMEMBERED_TIMES_COUNT];
     const sal_uInt64 nStartTime(tools::Time::GetSystemTicks());
-    sal_uInt32 count(1L);
+    sal_uInt32 count(1);
     sal_uInt32 a;
 
     if(bDoTimerTest)
@@ -579,7 +553,7 @@ void SdrPaintView::CompleteRedraw(OutputDevice* pOut, const vcl::Region& rReg, s
         count = nRepeatCount;
     }
 
-    for(a = 0L; a < count; a++)
+    for(a = 0; a < count; a++)
     {
 #endif // SVX_REPAINT_TIMER_TEST
 
@@ -650,7 +624,7 @@ void SdrPaintView::CompleteRedraw(OutputDevice* pOut, const vcl::Region& rReg, s
 
         if(!bTimesInited)
         {
-            for(a = 0L; a < REMEMBERED_TIMES_COUNT; a++)
+            for(a = 0; a < REMEMBERED_TIMES_COUNT; a++)
             {
                 fLastTimes[a] = fTimePerPaint;
             }
@@ -659,17 +633,17 @@ void SdrPaintView::CompleteRedraw(OutputDevice* pOut, const vcl::Region& rReg, s
         }
         else
         {
-            for(a = 1L; a < REMEMBERED_TIMES_COUNT; a++)
+            for(a = 1; a < REMEMBERED_TIMES_COUNT; a++)
             {
-                fLastTimes[a - 1L] = fLastTimes[a];
+                fLastTimes[a - 1] = fLastTimes[a];
             }
 
-            fLastTimes[REMEMBERED_TIMES_COUNT - 1L] = fTimePerPaint;
+            fLastTimes[REMEMBERED_TIMES_COUNT - 1] = fTimePerPaint;
         }
 
         double fAddedTimes(0.0);
 
-        for(a = 0L; a < REMEMBERED_TIMES_COUNT; a++)
+        for(a = 0; a < REMEMBERED_TIMES_COUNT; a++)
         {
             fAddedTimes += fLastTimes[a];
         }
@@ -680,7 +654,7 @@ void SdrPaintView::CompleteRedraw(OutputDevice* pOut, const vcl::Region& rReg, s
         fprintf(stderr, "StartTime : %" SAL_PRIuUINT64 ", StopTime: %" SAL_PRIuUINT64 ", NeededTime: %" SAL_PRIuUINT64 ", TimePerPaint: %f\n", nStartTime, nStopTime, nNeededTime, fTimePerPaint);
         fprintf(stderr, "Remembered times: ");
 
-        for(a = 0L; a < REMEMBERED_TIMES_COUNT; a++)
+        for(a = 0; a < REMEMBERED_TIMES_COUNT; a++)
         {
             fprintf(stderr, "%d: %f ", a, fLastTimes[a]);
         }
@@ -730,7 +704,7 @@ void SdrPaintView::DoCompleteRedraw(SdrPaintWindow& rPaintWindow, const vcl::Reg
 void SdrPaintView::EndCompleteRedraw(SdrPaintWindow& rPaintWindow, bool bPaintFormLayer)
 {
     std::unique_ptr<SdrPaintWindow> pPaintWindow;
-    if (GetModel()->isTiledRendering() && rPaintWindow.getTemporaryTarget())
+    if (comphelper::LibreOfficeKit::isActive() && rPaintWindow.getTemporaryTarget())
     {
         // Tiled rendering, we must paint the TextEdit to the output device.
         pPaintWindow.reset(&rPaintWindow);
@@ -759,6 +733,26 @@ void SdrPaintView::EndCompleteRedraw(SdrPaintWindow& rPaintWindow, bool bPaintFo
             static_cast< SdrView* >(this)->TextEditDrawing(rPaintWindow);
         }
 
+        if (comphelper::LibreOfficeKit::isActive())
+        {
+            // Look for active text edits in other views showing the same page,
+            // and show them as well.
+            if (SdrPageView* pPageView = GetSdrPageView())
+            {
+                SdrViewIter aIter(pPageView->GetPage());
+                for (SdrView* pView = aIter.FirstView(); pView; pView = aIter.NextView())
+                {
+                    if (pView == this)
+                        continue;
+
+                    if (pView->IsTextEdit() && pView->GetSdrPageView())
+                    {
+                        pView->TextEditDrawing(rPaintWindow);
+                    }
+                }
+            }
+        }
+
         // draw Overlay, also to PreRender device if exists
         rPaintWindow.DrawOverlay(rPaintWindow.GetRedrawRegion());
 
@@ -768,7 +762,6 @@ void SdrPaintView::EndCompleteRedraw(SdrPaintWindow& rPaintWindow, bool bPaintFo
 }
 
 
-
 SdrPaintWindow* SdrPaintView::BeginDrawLayers(OutputDevice* pOut, const vcl::Region& rReg, bool bDisableIntersect)
 {
     // #i74769# use BeginCompleteRedraw() as common base
@@ -806,7 +799,7 @@ void SdrPaintView::EndDrawLayers(SdrPaintWindow& rPaintWindow, bool bPaintFormLa
     }
 }
 
-void SdrPaintView::UpdateDrawLayersRegion(OutputDevice* pOut, const vcl::Region& rReg, bool bDisableIntersect)
+void SdrPaintView::UpdateDrawLayersRegion(OutputDevice* pOut, const vcl::Region& rReg)
 {
     SdrPaintWindow* pPaintWindow = FindPaintWindow(*pOut);
     OSL_ENSURE(pPaintWindow, "SdrPaintView::UpdateDrawLayersRegion: No SdrPaintWindow (!)");
@@ -817,7 +810,7 @@ void SdrPaintView::UpdateDrawLayersRegion(OutputDevice* pOut, const vcl::Region&
 
         if(pKnownTarget)
         {
-            vcl::Region aOptimizedRepaintRegion = OptimizeDrawLayersRegion( pOut, rReg, bDisableIntersect );
+            vcl::Region aOptimizedRepaintRegion = OptimizeDrawLayersRegion( pOut, rReg, false/*bDisableIntersect*/ );
             pKnownTarget->GetPaintWindow().SetRedrawRegion(aOptimizedRepaintRegion);
             mpPageView->setPreparedPageWindow(pKnownTarget); // already set actually
         }
@@ -852,7 +845,6 @@ vcl::Region SdrPaintView::OptimizeDrawLayersRegion(OutputDevice* pOut, const vcl
 }
 
 
-
 void SdrPaintView::ImpFormLayerDrawing( SdrPaintWindow& rPaintWindow )
 {
     if(mpPageView)
@@ -863,7 +855,7 @@ void SdrPaintView::ImpFormLayerDrawing( SdrPaintWindow& rPaintWindow )
         {
             const SdrModel& rModel = *(GetModel());
             const SdrLayerAdmin& rLayerAdmin = rModel.GetLayerAdmin();
-            const SdrLayerID nControlLayerId = rLayerAdmin.GetLayerID(rLayerAdmin.GetControlLayerName(), false);
+            const SdrLayerID nControlLayerId = rLayerAdmin.GetLayerID(rLayerAdmin.GetControlLayerName());
 
             // BUFFERED use GetTargetOutputDevice() now, it may be targeted to VDevs, too
             // need to set PreparedPageWindow to make DrawLayer use the correct ObjectContact
@@ -875,7 +867,6 @@ void SdrPaintView::ImpFormLayerDrawing( SdrPaintWindow& rPaintWindow )
 }
 
 
-
 bool SdrPaintView::KeyInput(const KeyEvent& /*rKEvt*/, vcl::Window* /*pWin*/)
 {
     return false;
@@ -885,7 +876,7 @@ void SdrPaintView::GlueInvalidate() const
 {
     const sal_uInt32 nWindowCount(PaintWindowCount());
 
-    for(sal_uInt32 nWinNum(0L); nWinNum < nWindowCount; nWinNum++)
+    for(sal_uInt32 nWinNum(0); nWinNum < nWindowCount; nWinNum++)
     {
         SdrPaintWindow* pPaintWindow = GetPaintWindow(nWinNum);
 
@@ -913,7 +904,7 @@ void SdrPaintView::InvalidateAllWin()
 {
     const sal_uInt32 nWindowCount(PaintWindowCount());
 
-    for(sal_uInt32 a(0L); a < nWindowCount; a++)
+    for(sal_uInt32 a(0); a < nWindowCount; a++)
     {
         SdrPaintWindow* pPaintWindow = GetPaintWindow(a);
 
@@ -924,35 +915,25 @@ void SdrPaintView::InvalidateAllWin()
     }
 }
 
-void SdrPaintView::InvalidateAllWin(const Rectangle& rRect, bool bPlus1Pix)
+void SdrPaintView::InvalidateAllWin(const tools::Rectangle& rRect)
 {
     const sal_uInt32 nWindowCount(PaintWindowCount());
 
-    for(sal_uInt32 a(0L); a < nWindowCount; a++)
+    for(sal_uInt32 a(0); a < nWindowCount; a++)
     {
         SdrPaintWindow* pPaintWindow = GetPaintWindow(a);
 
         if(pPaintWindow->OutputToWindow())
         {
             OutputDevice& rOutDev = pPaintWindow->GetOutputDevice();
-            Rectangle aRect(rRect);
-
-            if(bPlus1Pix)
-            {
-                Size aPixSiz(1,1);
-                Size aSiz(rOutDev.PixelToLogic(aPixSiz));
-                aRect.Left  ()-=aSiz.Width();
-                aRect.Top   ()-=aSiz.Height();
-                aRect.Right ()+=aSiz.Width();
-                aRect.Bottom()+=aSiz.Height();
-            }
+            tools::Rectangle aRect(rRect);
 
             Point aOrg(rOutDev.GetMapMode().GetOrigin());
             aOrg.X()=-aOrg.X(); aOrg.Y()=-aOrg.Y();
-            Rectangle aOutRect(aOrg, rOutDev.GetOutputSize());
+            tools::Rectangle aOutRect(aOrg, rOutDev.GetOutputSize());
 
             // In case of tiled rendering we want to get all invalidations, so visual area is not interesting.
-            if (aRect.IsOver(aOutRect) || GetModel()->isTiledRendering())
+            if (aRect.IsOver(aOutRect) || comphelper::LibreOfficeKit::isActive())
             {
                 InvalidateOneWin(static_cast<vcl::Window&>(rOutDev), aRect);
             }
@@ -966,7 +947,7 @@ void SdrPaintView::InvalidateOneWin(vcl::Window& rWin)
     rWin.Invalidate(InvalidateFlags::NoErase);
 }
 
-void SdrPaintView::InvalidateOneWin(vcl::Window& rWin, const Rectangle& rRect)
+void SdrPaintView::InvalidateOneWin(vcl::Window& rWin, const tools::Rectangle& rRect)
 {
     // do not erase background, that causes flicker (!)
     rWin.Invalidate(rRect, InvalidateFlags::NoErase);
@@ -998,7 +979,7 @@ bool SdrPaintView::IsGroupEntered() const
     return false;
 }
 
-void SdrPaintView::SetNotPersistDefaultAttr(const SfxItemSet& rAttr, bool /*bReplaceAll*/)
+void SdrPaintView::SetNotPersistDefaultAttr(const SfxItemSet& rAttr)
 {
     // bReplaceAll has no effect here at all.
     bool bMeasure= dynamic_cast<const SdrView*>(this) != nullptr && static_cast<SdrView*>(this)->IsMeasureTool();
@@ -1017,13 +998,13 @@ void SdrPaintView::SetNotPersistDefaultAttr(const SfxItemSet& rAttr, bool /*bRep
     }
 }
 
-void SdrPaintView::MergeNotPersistDefaultAttr(SfxItemSet& rAttr, bool /*bOnlyHardAttr*/) const
+void SdrPaintView::MergeNotPersistDefaultAttr(SfxItemSet& rAttr) const
 {
     // bOnlyHardAttr has no effect here at all.
     bool bMeasure= dynamic_cast<const SdrView*>(this) != nullptr && static_cast<const SdrView*>(this)->IsMeasureTool();
     const OUString& aNam = bMeasure ? maMeasureLayer : maActualLayer;
     rAttr.Put(SdrLayerNameItem(aNam));
-    SdrLayerID nLayer=mpModel->GetLayerAdmin().GetLayerID(aNam,true);
+    SdrLayerID nLayer=mpModel->GetLayerAdmin().GetLayerID(aNam);
     if (nLayer!=SDRLAYER_NOTFOUND) {
         rAttr.Put(SdrLayerIdItem(nLayer));
     }
@@ -1047,13 +1028,13 @@ void SdrPaintView::SetDefaultAttr(const SfxItemSet& rAttr, bool bReplaceAll)
         if(bHasEEFeatureItems)
         {
             OUString aMessage("SdrPaintView::SetDefaultAttr(): Setting EE_FEATURE items at the SdrView does not make sense! It only leads to overhead and unreadable documents.");
-            ScopedVclPtr<InfoBox>::Create(nullptr, aMessage)->Execute();
+            ScopedVclPtrInstance<InfoBox>(nullptr, aMessage)->Execute();
         }
     }
 #endif
     if (bReplaceAll) maDefaultAttr.Set(rAttr);
     else maDefaultAttr.Put(rAttr,false); // if FALSE, regard InvalidItems as "holes," not as Default
-    SetNotPersistDefaultAttr(rAttr,bReplaceAll);
+    SetNotPersistDefaultAttr(rAttr);
 #ifdef DBG_UTIL
     if (mpItemBrowser!=nullptr) mpItemBrowser->SetDirty();
 #endif
@@ -1094,7 +1075,7 @@ bool SdrPaintView::GetAttributes(SfxItemSet& rTargetSet, bool bOnlyHardAttr) con
         rTargetSet.Put(mpDefaultStyleSheet->GetItemSet(), false);
         rTargetSet.Put(maDefaultAttr, false);
     }
-    MergeNotPersistDefaultAttr(rTargetSet, bOnlyHardAttr);
+    MergeNotPersistDefaultAttr(rTargetSet);
     return true;
 }
 
@@ -1106,7 +1087,7 @@ bool SdrPaintView::SetAttributes(const SfxItemSet& rSet, bool bReplaceAll)
 
 SfxStyleSheet* SdrPaintView::GetStyleSheet() const
 {
-    return GetDefaultStyleSheet();
+    return mpDefaultStyleSheet;
 }
 
 bool SdrPaintView::SetStyleSheet(SfxStyleSheet* pStyleSheet, bool bDontRemoveHardAttr)
@@ -1116,7 +1097,6 @@ bool SdrPaintView::SetStyleSheet(SfxStyleSheet* pStyleSheet, bool bDontRemoveHar
 }
 
 
-
 #ifdef DBG_UTIL
 void SdrPaintView::ShowItemBrowser(bool bShow)
 {
@@ -1135,52 +1115,59 @@ void SdrPaintView::ShowItemBrowser(bool bShow)
 }
 #endif
 
-void SdrPaintView::MakeVisible(const Rectangle& rRect, vcl::Window& rWin)
+void SdrPaintView::MakeVisible(const tools::Rectangle& rRect, vcl::Window& rWin)
 {
+    // TODO: handle when the text cursor goes out of the chart area
+    // However this hack avoids that the cursor gets misplaced wrt the text.
+    if (comphelper::LibreOfficeKit::isActive() && rWin.IsChart())
+    {
+        return;
+    }
+
     MapMode aMap(rWin.GetMapMode());
     Size aActualSize(rWin.GetOutputSize());
 
-    if( aActualSize.Height() > 0 && aActualSize.Width() > 0 )
+    if( aActualSize.Height() <= 0 || aActualSize.Width() <= 0 )
+        return;
+
+    Size aNewSize(rRect.GetSize());
+    bool bNewScale=false;
+    bool bNeedMoreX=aNewSize.Width()>aActualSize.Width();
+    bool bNeedMoreY=aNewSize.Height()>aActualSize.Height();
+    if (bNeedMoreX || bNeedMoreY)
     {
-        Size aNewSize(rRect.GetSize());
-        bool bNewScale=false;
-        bool bNeedMoreX=aNewSize.Width()>aActualSize.Width();
-        bool bNeedMoreY=aNewSize.Height()>aActualSize.Height();
-        if (bNeedMoreX || bNeedMoreY)
-        {
-            bNewScale=true;
-            // set new MapMode (Size+Org) and invalidate everything
-            Fraction aXFact(aNewSize.Width(),aActualSize.Width());
-            Fraction aYFact(aNewSize.Height(),aActualSize.Height());
-            if (aYFact>aXFact) aXFact=aYFact;
-            aXFact*=aMap.GetScaleX();
-            aXFact.ReduceInaccurate(10); // to avoid runovers and BigInt mapping
-            aMap.SetScaleX(aXFact);
-            aMap.SetScaleY(aYFact);
+        bNewScale=true;
+        // set new MapMode (Size+Org) and invalidate everything
+        Fraction aXFact(aNewSize.Width(),aActualSize.Width());
+        Fraction aYFact(aNewSize.Height(),aActualSize.Height());
+        if (aYFact>aXFact) aXFact=aYFact;
+        aXFact*=aMap.GetScaleX();
+        aXFact.ReduceInaccurate(10); // to avoid runovers and BigInt mapping
+        aMap.SetScaleX(aXFact);
+        aMap.SetScaleY(aYFact);
+        rWin.SetMapMode(aMap);
+        aActualSize=rWin.GetOutputSize();
+    }
+    Point aOrg(aMap.GetOrigin());
+    long dx=0,dy=0;
+    long l=-aOrg.X();
+    long r=-aOrg.X()+aActualSize.Width()-1;
+    long o=-aOrg.Y();
+    long u=-aOrg.Y()+aActualSize.Height()-1;
+    if (l>rRect.Left()) dx=rRect.Left()-l;
+    else if (r<rRect.Right()) dx=rRect.Right()-r;
+    if (o>rRect.Top()) dy=rRect.Top()-o;
+    else if (u<rRect.Bottom()) dy=rRect.Bottom()-u;
+    aMap.SetOrigin(Point(aOrg.X()-dx,aOrg.Y()-dy));
+    if (!bNewScale) {
+        if (dx!=0 || dy!=0) {
+            rWin.Scroll(-dx,-dy);
             rWin.SetMapMode(aMap);
-            aActualSize=rWin.GetOutputSize();
-        }
-        Point aOrg(aMap.GetOrigin());
-        long dx=0,dy=0;
-        long l=-aOrg.X();
-        long r=-aOrg.X()+aActualSize.Width()-1;
-        long o=-aOrg.Y();
-        long u=-aOrg.Y()+aActualSize.Height()-1;
-        if (l>rRect.Left()) dx=rRect.Left()-l;
-        else if (r<rRect.Right()) dx=rRect.Right()-r;
-        if (o>rRect.Top()) dy=rRect.Top()-o;
-        else if (u<rRect.Bottom()) dy=rRect.Bottom()-u;
-        aMap.SetOrigin(Point(aOrg.X()-dx,aOrg.Y()-dy));
-        if (!bNewScale) {
-            if (dx!=0 || dy!=0) {
-                rWin.Scroll(-dx,-dy);
-                rWin.SetMapMode(aMap);
-                rWin.Update();
-            }
-        } else {
-            rWin.SetMapMode(aMap);
-            InvalidateOneWin(rWin);
+            rWin.Update();
         }
+    } else {
+        rWin.SetMapMode(aMap);
+        InvalidateOneWin(rWin);
     }
 }
 
@@ -1190,7 +1177,7 @@ void SdrPaintView::DoConnect(SdrOle2Obj* /*pOleObj*/)
 
 void SdrPaintView::SetAnimationEnabled( bool bEnable )
 {
-    SetAnimationMode( bEnable ? SDR_ANIMATION_ANIMATE : SDR_ANIMATION_DISABLE );
+    SetAnimationMode( bEnable ? SdrAnimationMode::Animate : SdrAnimationMode::Disable );
 }
 
 #if defined DBG_UTIL
@@ -1202,13 +1189,13 @@ vcl::Window* SdrPaintView::GetItemBrowser() const
 
 void SdrPaintView::SetAnimationPause( bool bSet )
 {
-    if((bool)mbAnimationPause != bSet)
+    if(mbAnimationPause != bSet)
     {
         mbAnimationPause = bSet;
 
         if(mpPageView)
         {
-            for(sal_uInt32 b(0L); b < mpPageView->PageWindowCount(); b++)
+            for(sal_uInt32 b(0); b < mpPageView->PageWindowCount(); b++)
             {
                 SdrPageWindow& rPageWindow = *(mpPageView->GetPageWindow(b));
                 sdr::contact::ObjectContact& rObjectContact = rPageWindow.GetObjectContact();
@@ -1238,34 +1225,26 @@ void SdrPaintView::VisAreaChanged(const OutputDevice* pOut)
 
             if(pWindow)
             {
-                VisAreaChanged(*pWindow);
+                VisAreaChanged();
             }
         }
         else
         {
-            for(sal_uInt32 a(0L); a < mpPageView->PageWindowCount(); a++)
-            {
-                VisAreaChanged(*mpPageView->GetPageWindow(a));
-            }
+            VisAreaChanged();
         }
     }
 }
 
-void SdrPaintView::VisAreaChanged(const SdrPageWindow& /*rWindow*/)
+void SdrPaintView::VisAreaChanged()
 {
     // notify SfxListener
-    Broadcast(SvxViewHint(SvxViewHint::SVX_HINT_VIEWCHANGED));
+    Broadcast(SvxViewChangedHint());
 }
 
 
 void SdrPaintView::onChangeColorConfig()
 {
-    SetGridColor( Color( maColorConfig.GetColorValue( svtools::DRAWGRID ).nColor ) );
-}
-
-void SdrPaintView::SetGridColor( Color aColor )
-{
-    maGridColor = aColor;
+    maGridColor = Color( maColorConfig.GetColorValue( svtools::DRAWGRID ).nColor );
 }
 
 
@@ -1294,7 +1273,7 @@ bool SdrPaintView::IsBufferedOutputAllowed() const
 
 void SdrPaintView::SetBufferedOutputAllowed(bool bNew)
 {
-    if(bNew != (bool)mbBufferedOutputAllowed)
+    if(bNew != mbBufferedOutputAllowed)
     {
         mbBufferedOutputAllowed = bNew;
     }
@@ -1307,7 +1286,7 @@ bool SdrPaintView::IsBufferedOverlayAllowed() const
 
 void SdrPaintView::SetBufferedOverlayAllowed(bool bNew)
 {
-    if(bNew != (bool)mbBufferedOverlayAllowed)
+    if(bNew != mbBufferedOverlayAllowed)
     {
         mbBufferedOverlayAllowed = bNew;
     }
@@ -1316,7 +1295,7 @@ void SdrPaintView::SetBufferedOverlayAllowed(bool bNew)
 
 void SdrPaintView::SetPagePaintingAllowed(bool bNew)
 {
-    if(bNew != (bool)mbPagePaintingAllowed)
+    if(bNew != mbPagePaintingAllowed)
     {
         mbPagePaintingAllowed = bNew;
     }
@@ -1328,7 +1307,7 @@ void SdrPaintView::SetAnimationTimer(sal_uInt32 nTime)
     if(mpPageView)
     {
         // first, reset all timers at all windows to 0L
-        for(sal_uInt32 a(0L); a < mpPageView->PageWindowCount(); a++)
+        for(sal_uInt32 a(0); a < mpPageView->PageWindowCount(); a++)
         {
             SdrPageWindow& rPageWindow = *mpPageView->GetPageWindow(a);
             sdr::contact::ObjectContact& rObjectContact = rPageWindow.GetObjectContact();
