@@ -24,8 +24,8 @@
 #include <svx/svdpage.hxx>
 #include <svx/svdopath.hxx>
 #include <svx/svdundo.hxx>
-#include "svx/svdstr.hrc"
-#include "svdglob.hxx"
+#include <svx/strings.hrc>
+#include <svdglob.hxx>
 #include <svx/svdtrans.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
@@ -104,7 +104,7 @@ void SdrPolyEditView::CheckPolyPossibilitiesHelper( SdrMark* pM, bool& b1stSmoot
         if(PolyPolygonEditor::GetRelativePolyPoint(pPath->GetPathPoly(), nNum, nPolyNum, nPntNum))
         {
             const basegfx::B2DPolygon aLocalPolygon(pPath->GetPathPoly().getB2DPolygon(nPolyNum));
-            bool bCanSegment(bClosed || nPntNum < aLocalPolygon.count() - 1L);
+            bool bCanSegment(bClosed || nPntNum < aLocalPolygon.count() - 1);
 
             if(!bSetMarkedSegmentsKindPossible && bCanSegment)
             {
@@ -116,11 +116,11 @@ void SdrPolyEditView::CheckPolyPossibilitiesHelper( SdrMark* pM, bool& b1stSmoot
                 if (b1stSmooth)
                 {
                     b1stSmooth = false;
-                    eSmooth = basegfx::tools::getContinuityInPoint(aLocalPolygon, nPntNum);
+                    eSmooth = basegfx::utils::getContinuityInPoint(aLocalPolygon, nPntNum);
                 }
                 else
                 {
-                    bSmoothFuz = (eSmooth != basegfx::tools::getContinuityInPoint(aLocalPolygon, nPntNum));
+                    bSmoothFuz = (eSmooth != basegfx::utils::getContinuityInPoint(aLocalPolygon, nPntNum));
                 }
             }
 
@@ -164,7 +164,7 @@ void SdrPolyEditView::CheckPolyPossibilitiesHelper( SdrMark* pM, bool& b1stSmoot
 
     if(!b1stSegm && !bSegmFuz)
     {
-        eMarkedSegmentsKind = (bCurve) ? SdrPathSegmentKind::Curve : SdrPathSegmentKind::Line;
+        eMarkedSegmentsKind = bCurve ? SdrPathSegmentKind::Curve : SdrPathSegmentKind::Line;
     }
 }
 
@@ -365,15 +365,15 @@ void SdrPolyEditView::RipUpAtMarkedPoints()
 
             for(SdrUShortCont::const_reverse_iterator it = rPts.rbegin(); it != rPts.rend(); ++it)
             {
-                sal_uInt32 nNewPt0Idx(0L);
-                SdrObject* pNeuObj = pObj->RipPoint(*it, nNewPt0Idx);
+                sal_uInt32 nNewPt0Idx(0);
+                SdrObject* pNewObj = pObj->RipPoint(*it, nNewPt0Idx);
 
-                if(pNeuObj)
+                if(pNewObj)
                 {
-                    pM->GetPageView()->GetObjList()->InsertObject(pNeuObj, pObj->GetOrdNum() + 1);
+                    pM->GetPageView()->GetObjList()->InsertObject(pNewObj, pObj->GetOrdNum() + 1);
                     if( bUndo )
-                        AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoNewObject(*pNeuObj));
-                    MarkObj(pNeuObj, pM->GetPageView(), false, true);
+                        AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoNewObject(*pNewObj));
+                    MarkObj(pNewObj, pM->GetPageView(), false, true);
                 }
 
                 if(nNewPt0Idx)
