@@ -29,8 +29,8 @@
 #include <svx/svdmodel.hxx>
 #include <svx/svdview.hxx>
 #include <svx/xfillit0.hxx>
-#include "svx/svdstr.hrc"
-#include "svdglob.hxx"
+#include <svx/strings.hrc>
+#include <svdglob.hxx>
 #include <svx/scene3d.hxx>
 #include <editeng/editdata.hxx>
 #include <editeng/outlobj.hxx>
@@ -214,9 +214,9 @@ SdrUndoObj::SdrUndoObj(SdrObject& rNewObj)
 {
 }
 
-OUString SdrUndoObj::GetDescriptionStringForObject( const SdrObject& _rForObject, sal_uInt16 nStrCacheID, bool bRepeat )
+OUString SdrUndoObj::GetDescriptionStringForObject( const SdrObject& _rForObject, const char* pStrCacheID, bool bRepeat )
 {
-    const OUString rStr {ImpGetResStr(nStrCacheID)};
+    const OUString rStr {ImpGetResStr(pStrCacheID)};
 
     const sal_Int32 nPos = rStr.indexOf("%1");
     if (nPos < 0)
@@ -228,10 +228,10 @@ OUString SdrUndoObj::GetDescriptionStringForObject( const SdrObject& _rForObject
     return rStr.replaceAt(nPos, 2, _rForObject.TakeObjNameSingul());
 }
 
-void SdrUndoObj::ImpTakeDescriptionStr(sal_uInt16 nStrCacheID, OUString& rStr, bool bRepeat) const
+void SdrUndoObj::ImpTakeDescriptionStr(const char* pStrCacheID, OUString& rStr, bool bRepeat) const
 {
     if ( pObj )
-        rStr = GetDescriptionStringForObject( *pObj, nStrCacheID, bRepeat );
+        rStr = GetDescriptionStringForObject( *pObj, pStrCacheID, bRepeat );
 }
 
 // common call method for possible change of the page when UNDO/REDO is triggered
@@ -264,7 +264,6 @@ SdrUndoAttrObj::SdrUndoAttrObj(SdrObject& rNewObj, bool bStyleSheet1, bool bSave
     : SdrUndoObj(rNewObj)
     , pUndoSet(nullptr)
     , pRedoSet(nullptr)
-    , pRepeatSet(nullptr)
     , mxUndoStyleSheet()
     , mxRedoStyleSheet()
     , bHaveToTakeRedoSet(true)
@@ -311,7 +310,6 @@ SdrUndoAttrObj::~SdrUndoAttrObj()
 {
     delete pUndoSet;
     delete pRedoSet;
-    delete pRepeatSet;
     delete pUndoGroup;
     delete pTextUndo;
     delete pTextRedo;
@@ -521,19 +519,6 @@ OUString SdrUndoAttrObj::GetComment() const
     return aStr;
 }
 
-void SdrUndoAttrObj::SdrRepeat(SdrView& rView)
-{
-    if(pRepeatSet)
-    {
-        rView.SetAttrToMarked(*pRepeatSet, false);
-    }
-}
-
-bool SdrUndoAttrObj::CanSdrRepeat(SdrView& rView) const
-{
-    return (pRepeatSet!=nullptr && rView.AreObjectsMarked());
-}
-
 OUString SdrUndoAttrObj::GetSdrRepeatComment(SdrView& /*rView*/) const
 {
     OUString aStr;
@@ -1344,7 +1329,7 @@ OUString SdrUndoDelLayer::GetComment() const
 
 void SdrUndoMoveLayer::Undo()
 {
-    SdrLayer* pCmpLayer= pLayerAdmin->RemoveLayer(nNeuPos);
+    SdrLayer* pCmpLayer= pLayerAdmin->RemoveLayer(nNewPos);
     DBG_ASSERT(pCmpLayer==pLayer,"SdrUndoMoveLayer::Undo(): Removed layer is != pLayer.");
     pLayerAdmin->InsertLayer(pLayer,nNum);
 }
@@ -1353,7 +1338,7 @@ void SdrUndoMoveLayer::Redo()
 {
     SdrLayer* pCmpLayer= pLayerAdmin->RemoveLayer(nNum);
     DBG_ASSERT(pCmpLayer==pLayer,"SdrUndoMoveLayer::Redo(): Removed layer is != pLayer.");
-    pLayerAdmin->InsertLayer(pLayer,nNeuPos);
+    pLayerAdmin->InsertLayer(pLayer,nNewPos);
 }
 
 OUString SdrUndoMoveLayer::GetComment() const
@@ -1399,7 +1384,6 @@ void SdrUndoPage::ImpRemovePage(sal_uInt16 nNum)
             pChkPg=rMod.RemovePage(nNum);
         }
         DBG_ASSERT(pChkPg==&mrPage,"SdrUndoPage::ImpRemovePage(): RemovePage!=&mrPage");
-        (void)pChkPg;
     }
 }
 
@@ -1419,9 +1403,9 @@ void SdrUndoPage::ImpMovePage(sal_uInt16 nOldNum, sal_uInt16 nNewNum)
     }
 }
 
-void SdrUndoPage::ImpTakeDescriptionStr(sal_uInt16 nStrCacheID, OUString& rStr)
+void SdrUndoPage::ImpTakeDescriptionStr(const char* pStrCacheID, OUString& rStr)
 {
-    rStr = ImpGetResStr(nStrCacheID);
+    rStr = ImpGetResStr(pStrCacheID);
 }
 
 
@@ -1465,9 +1449,9 @@ SdrUndoDelPage::SdrUndoDelPage(SdrPage& rNewPg)
     // now remember the master page relationships
     if(mrPage.IsMasterPage())
     {
-        sal_uInt16 nPageAnz(rMod.GetPageCount());
+        sal_uInt16 nPageCnt(rMod.GetPageCount());
 
-        for(sal_uInt16 nPageNum2(0); nPageNum2 < nPageAnz; nPageNum2++)
+        for(sal_uInt16 nPageNum2(0); nPageNum2 < nPageCnt; nPageNum2++)
         {
             SdrPage* pDrawPage = rMod.GetPage(nPageNum2);
 
@@ -1835,9 +1819,9 @@ SdrUndoAction* SdrUndoFactory::CreateUndoDeleteLayer(sal_uInt16 nLayerNum, SdrLa
     return new SdrUndoDelLayer( nLayerNum, rNewLayerAdmin, rNewModel );
 }
 
-SdrUndoAction* SdrUndoFactory::CreateUndoMoveLayer(sal_uInt16 nLayerNum, SdrLayerAdmin& rNewLayerAdmin, SdrModel& rNewModel, sal_uInt16 nNeuPos1)
+SdrUndoAction* SdrUndoFactory::CreateUndoMoveLayer(sal_uInt16 nLayerNum, SdrLayerAdmin& rNewLayerAdmin, SdrModel& rNewModel, sal_uInt16 nNewPos1)
 {
-    return new SdrUndoMoveLayer( nLayerNum, rNewLayerAdmin, rNewModel, nNeuPos1 );
+    return new SdrUndoMoveLayer( nLayerNum, rNewLayerAdmin, rNewModel, nNewPos1 );
 }
 
 // page
