@@ -20,8 +20,8 @@
 #include <editeng/eeitem.hxx>
 #include <editeng/outlobj.hxx>
 
-#include "svx/svdstr.hrc"
-#include "svdglob.hxx"
+#include <svx/strings.hrc>
+#include <svdglob.hxx>
 #include <svx/svdpagv.hxx>
 #include <svx/svdmrkv.hxx>
 #include <svx/svdedxv.hxx>
@@ -35,13 +35,13 @@
 #include <svdibrow.hxx>
 #endif
 
-#include "svx/svdoutl.hxx"
-#include "svx/svdview.hxx"
-#include "editeng/editview.hxx"
-#include "editeng/flditem.hxx"
-#include "svx/obj3d.hxx"
-#include "svx/svddrgmt.hxx"
-#include "svx/svdotable.hxx"
+#include <svx/svdoutl.hxx>
+#include <svx/svdview.hxx>
+#include <editeng/editview.hxx>
+#include <editeng/flditem.hxx>
+#include <svx/obj3d.hxx>
+#include <svx/svddrgmt.hxx>
+#include <svx/svdotable.hxx>
 #include <tools/tenccvt.hxx>
 #include <svx/sdr/overlay/overlaypolypolygon.hxx>
 #include <svx/sdr/overlay/overlaymanager.hxx>
@@ -50,6 +50,7 @@
 #include <svx/sdrhittesthelper.hxx>
 #include <svx/sdr/contact/viewcontact.hxx>
 #include <drawinglayer/processor2d/contourextractor2d.hxx>
+#include <drawinglayer/primitive2d/texthierarchyprimitive2d.hxx>
 
 
 SdrViewEvent::SdrViewEvent()
@@ -60,7 +61,6 @@ SdrViewEvent::SdrViewEvent()
       pURLField(nullptr),
       eHit(SdrHitKind::NONE),
       eEvent(SdrEventKind::NONE),
-      eEndCreateCmd(SdrCreateCmd::NextPoint),
       nMouseClicks(0),
       nMouseMode(MouseEventModifiers::NONE),
       nMouseCode(0),
@@ -70,15 +70,10 @@ SdrViewEvent::SdrViewEvent()
       bMouseUp(false),
       bIsAction(false),
       bIsTextEdit(false),
-      bTextEditHit(false),
       bAddMark(false),
       bUnmark(false),
       bPrevNextMark(false),
-      bMarkPrev(false),
-      bInsPointNewObj(false),
-      bDragWithCopy(false),
-      bCaptureMouse(false),
-      bReleaseMouse(false)
+      bMarkPrev(false)
 {
 }
 
@@ -93,7 +88,7 @@ void SdrDropMarkerOverlay::ImplCreateOverlays(
     const SdrView& rView,
     const basegfx::B2DPolyPolygon& rLinePolyPolygon)
 {
-    for(sal_uInt32 a(0L); a < rView.PaintWindowCount(); a++)
+    for(sal_uInt32 a(0); a < rView.PaintWindowCount(); a++)
     {
         SdrPaintWindow* pCandidate = rView.GetPaintWindow(a);
         rtl::Reference< sdr::overlay::OverlayManager > xTargetOverlay = pCandidate->GetOverlayManager();
@@ -104,7 +99,7 @@ void SdrDropMarkerOverlay::ImplCreateOverlays(
                 rLinePolyPolygon);
 
             xTargetOverlay->add(*pNew);
-            maObjects.append(*pNew);
+            maObjects.append(pNew);
         }
     }
 }
@@ -116,7 +111,7 @@ SdrDropMarkerOverlay::SdrDropMarkerOverlay(const SdrView& rView, const SdrObject
         rObject.TakeXorPoly());
 }
 
-SdrDropMarkerOverlay::SdrDropMarkerOverlay(const SdrView& rView, const Rectangle& rRectangle)
+SdrDropMarkerOverlay::SdrDropMarkerOverlay(const SdrView& rView, const tools::Rectangle& rRectangle)
 {
     basegfx::B2DPolygon aB2DPolygon;
 
@@ -156,11 +151,8 @@ SdrView::SdrView(SdrModel* pModel1, OutputDevice* pOut)
 :   SdrCreateView(pModel1,pOut),
     bNoExtendedMouseDispatcher(false),
     bNoExtendedKeyDispatcher(false),
-    bNoExtendedCommandDispatcher(false),
     mbMasterPagePaintCaching(false)
 {
-    bTextEditOnObjectsWithoutTextIfTextTool=false;
-
     maAccessibilityOptions.AddListener(this);
 
     onAccessibilityOptionsChanged();
@@ -449,47 +441,68 @@ SdrHitKind SdrView::PickAnything(const Point& rLogicPos, SdrViewEvent& rVEvt) co
         SdrTextObj* pTextObj=dynamic_cast<SdrTextObj*>( pHitObj );
         if (pTextObj!=nullptr && pTextObj->HasText())
         {
-            bool bTEHit(pPV &&
-                SdrObjectPrimitiveHit(*pTextObj, aLocalLogicPosition, 0, *pPV, &pPV->GetVisibleLayers(), true));
+            // use the primitive-based HitTest which is more accurate anyways. It
+            // will correctly handle rotated/mirrored/sheared/scaled text and can
+            // now return a HitContainer containing the primitive hierarchy of the
+            // primitive that triggered the hit. The first entry is that primitive,
+            // the others are the full stack of primitives leading to that one which
+            // includes grouping primitives (like TextHierarchyPrimitives we deed here)
+            // but also all decomposed ones which lead to the creation of that primitive
+            drawinglayer::primitive2d::Primitive2DContainer aHitContainer;
+            const bool bTEHit(pPV && SdrObjectPrimitiveHit(*pTextObj, aLocalLogicPosition, 0, *pPV, &pPV->GetVisibleLayers(), true, &aHitContainer));
 
-            if (bTEHit)
+            if (bTEHit && !aHitContainer.empty())
             {
-                Rectangle aTextRect;
-                Rectangle aAnchor;
-                SdrOutliner* pOutliner = &pTextObj->ImpGetDrawOutliner();
-                if( pTextObj->GetModel() )
-                    pOutliner = &pTextObj->GetModel()->GetHitTestOutliner();
+                // search for TextHierarchyFieldPrimitive2D which contains the needed information
+                // about a possible URLField
+                const drawinglayer::primitive2d::TextHierarchyFieldPrimitive2D* pTextHierarchyFieldPrimitive2D = nullptr;
 
-                pTextObj->TakeTextRect( *pOutliner, aTextRect, false, &aAnchor, false );
-
-                // #i73628# Use a text-relative position for hit test in hit test outliner
-                Point aTemporaryTextRelativePosition(aLocalLogicPosition - aTextRect.TopLeft());
-
-                // account for FitToSize
-                bool bFitToSize(pTextObj->IsFitToSize());
-                if (bFitToSize) {
-                    Fraction aX(aTextRect.GetWidth()-1,aAnchor.GetWidth()-1);
-                    Fraction aY(aTextRect.GetHeight()-1,aAnchor.GetHeight()-1);
-                    ResizePoint(aTemporaryTextRelativePosition,Point(),aX,aY);
-                }
-                // account for rotation
-                const GeoStat& rGeo=pTextObj->GetGeoStat();
-                if (rGeo.nRotationAngle!=0) RotatePoint(aTemporaryTextRelativePosition,Point(),-rGeo.nSin,rGeo.nCos); // -sin for Unrotate
-                // we currently don't account for ticker text
-                if(mpActualOutDev && mpActualOutDev->GetOutDevType() == OUTDEV_WINDOW)
+                for (const drawinglayer::primitive2d::Primitive2DReference& xReference : aHitContainer)
                 {
-                    OutlinerView aOLV(pOutliner, const_cast<vcl::Window*>(static_cast<const vcl::Window*>(mpActualOutDev.get())));
-                    const EditView& aEV=aOLV.GetEditView();
-                    const SvxFieldItem* pItem=aEV.GetField(aTemporaryTextRelativePosition);
-                    if (pItem!=nullptr) {
-                        const SvxFieldData* pFld=pItem->GetField();
-                        const SvxURLField* pURL=dynamic_cast<const SvxURLField*>( pFld );
-                        if (pURL!=nullptr) {
-                            eHit=SdrHitKind::UrlField;
-                            rVEvt.pURLField=pURL;
+                    if (xReference.is())
+                    {
+                        // try to cast to drawinglayer::primitive2d::TextHierarchyFieldPrimitive2D implementation
+                        pTextHierarchyFieldPrimitive2D = dynamic_cast<const drawinglayer::primitive2d::TextHierarchyFieldPrimitive2D*>(xReference.get());
+
+                        if (pTextHierarchyFieldPrimitive2D)
+                        {
+                            break;
                         }
                     }
                 }
+
+                if (nullptr != pTextHierarchyFieldPrimitive2D)
+                {
+                    if (drawinglayer::primitive2d::FieldType::FIELD_TYPE_URL == pTextHierarchyFieldPrimitive2D->getType())
+                    {
+                        // problem with the old code is that a *pointer* to an instance of
+                        // SvxURLField is set in the Event which is per se not good since that
+                        // data comes from a temporary EditEngine's data and could vanish any
+                        // moment. Have to replace for now with a static instance that gets
+                        // filled/initialized from the original data held in the TextHierarchyField-
+                        // Primitive2D (see impTextBreakupHandler::impCheckFieldPrimitive).
+                        // Unfortunately things like 'TargetFrame' are still used in Calc, so this
+                        // can currently not get replaced. For the future the Name/Value vector or
+                        // the TextHierarchyFieldPrimitive2D itself should/will be used for handling
+                        // that data
+                        static SvxURLField aSvxURLField;
+
+                        aSvxURLField.SetURL(pTextHierarchyFieldPrimitive2D->getValue("URL"));
+                        aSvxURLField.SetRepresentation(pTextHierarchyFieldPrimitive2D->getValue("Representation"));
+                        aSvxURLField.SetTargetFrame(pTextHierarchyFieldPrimitive2D->getValue("TargetFrame"));
+                        const OUString aFormat(pTextHierarchyFieldPrimitive2D->getValue("SvxURLFormat"));
+
+                        if (!aFormat.isEmpty())
+                        {
+                            aSvxURLField.SetFormat(static_cast<SvxURLFormat>(aFormat.toInt32()));
+                        }
+
+                        // set HitKind and pointer to local static instance in the Event
+                        // to comply to old stuff
+                        eHit = SdrHitKind::UrlField;
+                        rVEvt.pURLField = &aSvxURLField;
+                    }
+                }
             }
         }
     }
@@ -499,7 +512,7 @@ SdrHitKind SdrView::PickAnything(const Point& rLogicPos, SdrViewEvent& rVEvt) co
         (IsTextTool() || (IsEditMode() && IsQuickTextEditMode())) && pHitObj->HasTextEdit())
     {
         // Around the TextEditArea there's a border to select without going into text edit mode.
-        Rectangle aBoundRect(pHitObj->GetCurrentBoundRect());
+        tools::Rectangle aBoundRect(pHitObj->GetCurrentBoundRect());
 
         // Force to SnapRect when Fontwork
         if( dynamic_cast<const SdrTextObj*>( pHitObj) != nullptr && static_cast<SdrTextObj*>(pHitObj)->IsFontwork())
@@ -568,14 +581,10 @@ SdrHitKind SdrView::PickAnything(const Point& rLogicPos, SdrViewEvent& rVEvt) co
                 if (IsDragObj())
                 {
                     eEvent=SdrEventKind::EndDrag;
-                    rVEvt.bDragWithCopy=MODKEY_CopyDrag;
                 }
                 else if (IsCreateObj() || IsInsObjPoint())
                 {
                     eEvent=IsCreateObj() ? SdrEventKind::EndCreate : SdrEventKind::EndInsertObjPoint;
-                    rVEvt.eEndCreateCmd=SdrCreateCmd::NextPoint;
-                    if (MODKEY_PolyPoly) rVEvt.eEndCreateCmd=SdrCreateCmd::NextObject;
-                    if (rVEvt.nMouseClicks>1) rVEvt.eEndCreateCmd=SdrCreateCmd::ForceEnd;
                 }
                 else if (IsMarking())
                 {
@@ -652,7 +661,6 @@ SdrHitKind SdrView::PickAnything(const Point& rLogicPos, SdrViewEvent& rVEvt) co
         else if (bInsPolyPt && (MODKEY_PolyPoly || (!MODKEY_MultiMark && !MODKEY_DeepMark)))
         {
             eEvent=SdrEventKind::BeginInsertObjPoint;
-            rVEvt.bInsPointNewObj=MODKEY_PolyPoly;
         }
         else if (bInsGluePt && !MODKEY_MultiMark && !MODKEY_DeepMark)
         {
@@ -718,7 +726,6 @@ SdrHitKind SdrView::PickAnything(const Point& rLogicPos, SdrViewEvent& rVEvt) co
     }
     rVEvt.bIsAction=bIsAction;
     rVEvt.bIsTextEdit=bIsTextEdit;
-    rVEvt.bTextEditHit=bTextEditHit;
     rVEvt.aLogicPos=aLocalLogicPosition;
     rVEvt.pHdl=pHdl;
     rVEvt.pObj=pObj;
@@ -729,8 +736,6 @@ SdrHitKind SdrView::PickAnything(const Point& rLogicPos, SdrViewEvent& rVEvt) co
     rVEvt.nGlueId=nGlueId;
     rVEvt.eHit=eHit;
     rVEvt.eEvent=eEvent;
-    rVEvt.bCaptureMouse=bMouseLeft && bMouseDown && eEvent!=SdrEventKind::NONE;
-    rVEvt.bReleaseMouse=bMouseLeft && bMouseUp;
 #ifdef DGB_UTIL
     if (rVEvt.pRootObj!=NULL) {
         if (rVEvt.pRootObj->GetObjList()!=rVEvt.pPV->GetObjList()) {
@@ -789,7 +794,6 @@ bool SdrView::DoMouseEvent(const SdrViewEvent& rVEvt)
         case SdrEventKind::MoveAction: MovAction(aLogicPos); bRet=true; break;
         case SdrEventKind::EndAction: EndAction(); bRet=true; break;
         case SdrEventKind::BackAction: BckAction(); bRet=true; break;
-        case SdrEventKind::BrkAction: BrkAction(); bRet=true; break;
         case SdrEventKind::EndMark  : EndAction(); bRet=true; break;
         case SdrEventKind::BrkMark  : {
             BrkAction();
@@ -812,7 +816,7 @@ bool SdrView::DoMouseEvent(const SdrViewEvent& rVEvt)
                     if (eHit==SdrHitKind::TextEdit)
                     {
                         bool bRet2(mpActualOutDev && OUTDEV_WINDOW == mpActualOutDev->GetOutDevType() &&
-                            SdrBeginTextEdit(rVEvt.pObj, rVEvt.pPV, const_cast<vcl::Window*>(static_cast<const vcl::Window*>(mpActualOutDev.get()))));
+                            SdrBeginTextEdit(rVEvt.pObj, rVEvt.pPV, static_cast<vcl::Window*>(mpActualOutDev.get())));
 
                         if(bRet2)
                         {
@@ -855,7 +859,7 @@ bool SdrView::DoMouseEvent(const SdrViewEvent& rVEvt)
         case SdrEventKind::MarkPoint: { // + (if applicable) BegDrag
             if (!rVEvt.bAddMark) UnmarkAllPoints();
             if (rVEvt.bPrevNextMark) {
-                bRet=MarkNextPoint(aLogicPos,rVEvt.bMarkPrev);
+                bRet=MarkNextPoint();
             } else {
                 bRet=MarkPoint(*rVEvt.pHdl,rVEvt.bUnmark);
             }
@@ -867,9 +871,9 @@ bool SdrView::DoMouseEvent(const SdrViewEvent& rVEvt)
         case SdrEventKind::MarkGluePoint: { // + (if applicable) BegDrag
             if (!rVEvt.bAddMark) UnmarkAllGluePoints();
             if (rVEvt.bPrevNextMark) {
-                bRet=MarkNextGluePoint(aLogicPos,rVEvt.bMarkPrev);
+                bRet=MarkNextGluePoint();
             } else {
-                bRet=MarkGluePoint(rVEvt.pObj,rVEvt.nGlueId,rVEvt.pPV,rVEvt.bUnmark);
+                bRet=MarkGluePoint(rVEvt.pObj,rVEvt.nGlueId,rVEvt.bUnmark);
             }
             if (!rVEvt.bUnmark && !rVEvt.bPrevNextMark) {
                 SdrHdl* pHdl=GetGluePointHdl(rVEvt.pObj,rVEvt.nGlueId);
@@ -896,7 +900,7 @@ bool SdrView::DoMouseEvent(const SdrViewEvent& rVEvt)
             } else bRet=BegCreateObj(aLogicPos);
         } break;
         case SdrEventKind::BeginMacroObj: {
-            bRet=BegMacroObj(aLogicPos,mnHitTolLog,rVEvt.pObj,rVEvt.pPV,const_cast<vcl::Window*>(static_cast<const vcl::Window*>(mpActualOutDev.get())));
+            bRet=BegMacroObj(aLogicPos,mnHitTolLog,rVEvt.pObj,rVEvt.pPV,static_cast<vcl::Window*>(mpActualOutDev.get()));
         } break;
         case SdrEventKind::BeginTextEdit: {
             if (!IsObjMarked(rVEvt.pObj)) {
@@ -905,7 +909,7 @@ bool SdrView::DoMouseEvent(const SdrViewEvent& rVEvt)
             }
 
             bRet = mpActualOutDev && OUTDEV_WINDOW == mpActualOutDev->GetOutDevType()&&
-                 SdrBeginTextEdit(rVEvt.pObj, rVEvt.pPV, const_cast<vcl::Window*>(static_cast<const vcl::Window*>(mpActualOutDev.get())));
+                 SdrBeginTextEdit(rVEvt.pObj, rVEvt.pPV, static_cast<vcl::Window*>(mpActualOutDev.get()));
 
             if(bRet)
             {
@@ -918,7 +922,7 @@ bool SdrView::DoMouseEvent(const SdrViewEvent& rVEvt)
         default: break;
     } // switch
     if (bRet && mpActualOutDev && mpActualOutDev->GetOutDevType()==OUTDEV_WINDOW) {
-        vcl::Window* pWin=const_cast<vcl::Window*>(static_cast<const vcl::Window*>(mpActualOutDev.get()));
+        vcl::Window* pWin=static_cast<vcl::Window*>(mpActualOutDev.get());
         // left mouse button pressed?
         bool bLeftDown=(rVEvt.nMouseCode&MOUSE_LEFT)!=0 && rVEvt.bMouseDown;
         // left mouse button released?
@@ -957,7 +961,6 @@ Pointer SdrView::GetPreferredPointer(const Point& rMousePos, const OutputDevice*
         aHitRec.pVisiLayer=&pMacroPV->GetVisibleLayers();
         aHitRec.pPageView=pMacroPV;
         aHitRec.pOut=pMacroWin.get();
-        aHitRec.bDown=bMacroDown;
         return pMacroObj->GetMacroPointer(aHitRec);
     }
 
@@ -1076,7 +1079,7 @@ Pointer SdrView::GetPreferredPointer(const Point& rMousePos, const OutputDevice*
                 if (bMov)
                     return Pointer(PointerStyle::Rotate);
             } break;
-            case SdrDragMode::Shear: case SdrDragMode::Distort: {
+            case SdrDragMode::Shear: {
                 if (bCorner) {
                     if (!IsDistortAllowed(true) && !IsDistortAllowed()) return Pointer(PointerStyle::NotAllowed);
                     else return Pointer(PointerStyle::RefHand);
@@ -1371,7 +1374,7 @@ void SdrView::UnmarkAll()
     else UnmarkAllObj();
 }
 
-const Rectangle& SdrView::GetMarkedRect() const
+const tools::Rectangle& SdrView::GetMarkedRect() const
 {
     if (IsGluePointEditMode() && HasMarkedGluePoints()) {
         return GetMarkedGluePointsRect();
@@ -1424,10 +1427,10 @@ bool SdrView::BegMark(const Point& rPnt, bool bAddMark, bool bUnmark)
     }
 }
 
-void SdrView::ConfigurationChanged( ::utl::ConfigurationBroadcaster*p, sal_uInt32 nHint)
+void SdrView::ConfigurationChanged( ::utl::ConfigurationBroadcaster*p, ConfigurationHints nHint)
 {
     onAccessibilityOptionsChanged();
-     SdrCreateView::ConfigurationChanged(p, nHint);
+    SdrCreateView::ConfigurationChanged(p, nHint);
 }
 
 
@@ -1447,7 +1450,7 @@ void SdrView::SetMasterPagePaintCaching(bool bOn)
 
         if(pPageView)
         {
-            for(sal_uInt32 b(0L); b < pPageView->PageWindowCount(); b++)
+            for(sal_uInt32 b(0); b < pPageView->PageWindowCount(); b++)
             {
                 SdrPageWindow* pPageWindow = pPageView->GetPageWindow(b);
                 assert(pPageWindow && "SdrView::SetMasterPagePaintCaching: Corrupt SdrPageWindow list (!)");
