@@ -17,15 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
 
-#include "svx/svdotable.hxx"
+#include <com/sun/star/lang/NoSupportException.hpp>
+#include <svx/svdotable.hxx>
 #include "cellcursor.hxx"
 #include "tablelayouter.hxx"
-#include "cell.hxx"
-#include "svx/svdmodel.hxx"
-#include "svx/svdstr.hrc"
-#include "svdglob.hxx"
-
+#include <cell.hxx>
+#include <svx/svdmodel.hxx>
+#include <svx/strings.hrc>
+#include <svdglob.hxx>
 
 
 using namespace ::com::sun::star::uno;
@@ -35,7 +36,6 @@ using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::table;
 
 
-
 namespace sdr { namespace table {
 
 CellCursor::CellCursor( const TableModelRef & xTable, sal_Int32 nLeft, sal_Int32 nTop, sal_Int32 nRight, sal_Int32 nBottom )
@@ -44,7 +44,6 @@ CellCursor::CellCursor( const TableModelRef & xTable, sal_Int32 nLeft, sal_Int32
 }
 
 
-
 CellCursor::~CellCursor()
 {
 }
@@ -53,21 +52,19 @@ CellCursor::~CellCursor()
 // XCellCursor
 
 
-Reference< XCell > SAL_CALL CellCursor::getCellByPosition( sal_Int32 nColumn, sal_Int32 nRow ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+Reference< XCell > SAL_CALL CellCursor::getCellByPosition( sal_Int32 nColumn, sal_Int32 nRow )
 {
     return CellRange::getCellByPosition( nColumn, nRow );
 }
 
 
-
-Reference< XCellRange > SAL_CALL CellCursor::getCellRangeByPosition( sal_Int32 nLeft, sal_Int32 nTop, sal_Int32 nRight, sal_Int32 nBottom ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+Reference< XCellRange > SAL_CALL CellCursor::getCellRangeByPosition( sal_Int32 nLeft, sal_Int32 nTop, sal_Int32 nRight, sal_Int32 nBottom )
 {
     return CellRange::getCellRangeByPosition( nLeft, nTop, nRight, nBottom );
 }
 
 
-
-Reference< XCellRange > SAL_CALL CellCursor::getCellRangeByName( const OUString& aRange ) throw (RuntimeException, std::exception)
+Reference< XCellRange > SAL_CALL CellCursor::getCellRangeByName( const OUString& aRange )
 {
     return CellRange::getCellRangeByName( aRange );
 }
@@ -76,23 +73,21 @@ Reference< XCellRange > SAL_CALL CellCursor::getCellRangeByName( const OUString&
 // XCellCursor
 
 
-void SAL_CALL CellCursor::gotoStart(  ) throw (RuntimeException, std::exception)
+void SAL_CALL CellCursor::gotoStart(  )
 {
     mnRight = mnLeft;
     mnBottom = mnTop;
 }
 
 
-
-void SAL_CALL CellCursor::gotoEnd(  ) throw (RuntimeException, std::exception)
+void SAL_CALL CellCursor::gotoEnd(  )
 {
     mnLeft = mnRight;
     mnTop = mnBottom;
 }
 
 
-
-void SAL_CALL CellCursor::gotoNext(  ) throw (RuntimeException, std::exception)
+void SAL_CALL CellCursor::gotoNext(  )
 {
     if( mxTable.is() )
     {
@@ -120,8 +115,7 @@ void SAL_CALL CellCursor::gotoNext(  ) throw (RuntimeException, std::exception)
 }
 
 
-
-void SAL_CALL CellCursor::gotoPrevious(  ) throw (RuntimeException, std::exception)
+void SAL_CALL CellCursor::gotoPrevious(  )
 {
     if( mxTable.is() )
     {
@@ -141,8 +135,7 @@ void SAL_CALL CellCursor::gotoPrevious(  ) throw (RuntimeException, std::excepti
 }
 
 
-
-void SAL_CALL CellCursor::gotoOffset( ::sal_Int32 nColumnOffset, ::sal_Int32 nRowOffset ) throw (RuntimeException, std::exception)
+void SAL_CALL CellCursor::gotoOffset( ::sal_Int32 nColumnOffset, ::sal_Int32 nRowOffset )
 {
     if( mxTable.is() )
     {
@@ -240,8 +233,7 @@ bool CellCursor::GetMergedSelection( CellPos& rStart, CellPos& rEnd )
 }
 
 
-
-void SAL_CALL CellCursor::merge(  ) throw (NoSupportException, RuntimeException, std::exception)
+void SAL_CALL CellCursor::merge(  )
 {
     CellPos aStart, aEnd;
     if( !GetMergedSelection( aStart, aEnd ) )
@@ -259,8 +251,7 @@ void SAL_CALL CellCursor::merge(  ) throw (NoSupportException, RuntimeException,
     try
     {
         mxTable->merge( aStart.mnCol, aStart.mnRow, aEnd.mnCol - aStart.mnCol + 1, aEnd.mnRow - aStart.mnRow + 1 );
-        mxTable->optimize();
-        mxTable->setModified(sal_True);
+        mxTable->setModified(true);
     }
     catch( Exception& )
     {
@@ -275,7 +266,6 @@ void SAL_CALL CellCursor::merge(  ) throw (NoSupportException, RuntimeException,
 }
 
 
-
 void CellCursor::split_column( sal_Int32 nCol, sal_Int32 nColumns, std::vector< sal_Int32 >& rLeftOvers )
 {
     const sal_Int32 nRowCount = mxTable->getRowCount();
@@ -379,7 +369,6 @@ void CellCursor::split_column( sal_Int32 nCol, sal_Int32 nColumns, std::vector<
 }
 
 
-
 void CellCursor::split_horizontal( sal_Int32 nColumns )
 {
     const sal_Int32 nRowCount = mxTable->getRowCount();
@@ -391,7 +380,6 @@ void CellCursor::split_horizontal( sal_Int32 nColumns )
 }
 
 
-
 void CellCursor::split_row( sal_Int32 nRow, sal_Int32 nRows, std::vector< sal_Int32 >& rLeftOvers )
 {
     const sal_Int32 nColCount = mxTable->getColumnCount();
@@ -495,7 +483,6 @@ void CellCursor::split_row( sal_Int32 nRow, sal_Int32 nRows, std::vector< sal_In
 }
 
 
-
 void CellCursor::split_vertical( sal_Int32 nRows )
 {
     const sal_Int32 nColCount = mxTable->getColumnCount();
@@ -507,8 +494,7 @@ void CellCursor::split_vertical( sal_Int32 nRows )
 }
 
 
-
-void SAL_CALL CellCursor::split( sal_Int32 nColumns, sal_Int32 nRows ) throw (NoSupportException, IllegalArgumentException, RuntimeException, std::exception)
+void SAL_CALL CellCursor::split( sal_Int32 nColumns, sal_Int32 nRows )
 {
     if( (nColumns < 0) || (nRows < 0) )
         throw IllegalArgumentException();
@@ -530,7 +516,7 @@ void SAL_CALL CellCursor::split( sal_Int32 nColumns, sal_Int32 nRows ) throw (No
             split_vertical( nRows );
 
         if( nColumns > 0 ||nRows > 0 )
-            mxTable->setModified(sal_True);
+            mxTable->setModified(true);
     }
     catch( Exception& )
     {
@@ -546,15 +532,13 @@ void SAL_CALL CellCursor::split( sal_Int32 nColumns, sal_Int32 nRows ) throw (No
 }
 
 
-
-sal_Bool SAL_CALL CellCursor::isMergeable(  ) throw (RuntimeException, std::exception)
+sal_Bool SAL_CALL CellCursor::isMergeable(  )
 {
     CellPos aStart, aEnd;
     return GetMergedSelection( aStart, aEnd );
 }
 
 
-
 } }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
