@@ -19,27 +19,27 @@
 
 
 #include <com/sun/star/table/XMergeableCell.hpp>
-#include <com/sun/star/awt/XLayoutConstrains.hpp>
 
 #include <tools/gen.hxx>
+#include <libxml/xmlwriter.h>
 
-#include "cell.hxx"
+#include <cell.hxx>
 #include "cellrange.hxx"
-#include "tablemodel.hxx"
+#include <o3tl/safeint.hxx>
+#include <tablemodel.hxx>
 #include "tablerow.hxx"
 #include "tablerows.hxx"
 #include "tablecolumn.hxx"
 #include "tablecolumns.hxx"
 #include "tablelayouter.hxx"
-#include "svx/svdotable.hxx"
-#include "editeng/borderline.hxx"
-#include "editeng/boxitem.hxx"
-#include "svx/svdmodel.hxx"
-#include "svx/svdstr.hrc"
-#include "svdglob.hxx"
+#include <svx/svdotable.hxx>
+#include <editeng/borderline.hxx>
+#include <editeng/boxitem.hxx>
+#include <svx/svdmodel.hxx>
+#include <svx/strings.hrc>
+#include <svdglob.hxx>
 
 using ::editeng::SvxBorderLine;
-using ::com::sun::star::awt::XLayoutConstrains;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::container;
@@ -48,15 +48,12 @@ using namespace ::com::sun::star::table;
 using namespace ::com::sun::star::text;
 
 
-
 namespace sdr { namespace table {
 
 
-
 static SvxBorderLine gEmptyBorder;
 
 
-
 TableLayouter::TableLayouter( const TableModelRef& xTableModel )
 : mxTable( xTableModel )
 , msSize( "Size" )
@@ -64,14 +61,12 @@ TableLayouter::TableLayouter( const TableModelRef& xTableModel )
 }
 
 
-
 TableLayouter::~TableLayouter()
 {
     ClearBorderLayout();
 }
 
 
-
 basegfx::B2ITuple TableLayouter::getCellSize( const CellRef& xCell, const CellPos& rPos  ) const
 {
     sal_Int32 width = 0;
@@ -115,7 +110,6 @@ basegfx::B2ITuple TableLayouter::getCellSize( const CellRef& xCell, const CellPo
 }
 
 
-
 bool TableLayouter::getCellArea( const CellRef& xCell, const CellPos& rPos, basegfx::B2IRectangle& rArea ) const
 {
     try
@@ -125,20 +119,30 @@ bool TableLayouter::getCellArea( const CellRef& xCell, const CellPos& rPos, base
             const basegfx::B2ITuple aCellSize( getCellSize( xCell, rPos ) );
             const bool bRTL = (mxTable->getSdrTableObj()->GetWritingMode() == WritingMode_RL_TB);
 
-            if( (rPos.mnCol < ((sal_Int32)maColumns.size()) && (rPos.mnRow < ((sal_Int32)maRows.size()) ) ) )
+            if( (rPos.mnCol < ((sal_Int32)maColumns.size())) && (rPos.mnRow < ((sal_Int32)maRows.size()) ) )
             {
                 const sal_Int32 y = maRows[rPos.mnRow].mnPos;
 
+                sal_Int32 endy;
+                if (o3tl::checked_add(y, aCellSize.getY(), endy))
+                    return false;
+
                 if(bRTL)
                 {
                     ///For RTL Table Calculate the Right End of cell instead of Left
                     const sal_Int32 x = maColumns[rPos.mnCol].mnPos + maColumns[rPos.mnCol].mnSize;
-                    rArea = basegfx::B2IRectangle( x-aCellSize.getX(), y, x, y + aCellSize.getY()  );
+                    sal_Int32 startx;
+                    if (o3tl::checked_sub(x, aCellSize.getX(), startx))
+                        return false;
+                    rArea = basegfx::B2IRectangle(startx, y, x, endy);
                 }
                 else
                 {
                     const sal_Int32 x = maColumns[rPos.mnCol].mnPos;
-                    rArea = basegfx::B2IRectangle( x, y, x + aCellSize.getX(), y + aCellSize.getY()  );
+                    sal_Int32 endx;
+                    if (o3tl::checked_add(x, aCellSize.getX(), endx))
+                        return false;
+                    rArea = basegfx::B2IRectangle(x, y, endx, endy);
                 }
                 return true;
             }
@@ -170,7 +174,6 @@ sal_Int32 TableLayouter::getColumnWidth( sal_Int32 nColumn ) const
 }
 
 
-
 bool TableLayouter::isEdgeVisible( sal_Int32 nEdgeX, sal_Int32 nEdgeY, bool bHorizontal ) const
 {
     const BorderLineMap& rMap = bHorizontal ? maHorizontalBorders : maVerticalBorders;
@@ -189,7 +192,6 @@ bool TableLayouter::isEdgeVisible( sal_Int32 nEdgeX, sal_Int32 nEdgeY, bool bHor
 }
 
 
-
 /** returns the requested borderline in rpBorderLine or a null pointer if there is no border at this edge */
 SvxBorderLine* TableLayouter::getBorderLine( sal_Int32 nEdgeX, sal_Int32 nEdgeY, bool bHorizontal )const
 {
@@ -213,7 +215,6 @@ SvxBorderLine* TableLayouter::getBorderLine( sal_Int32 nEdgeX, sal_Int32 nEdgeY,
 }
 
 
-
 sal_Int32 TableLayouter::getHorizontalEdge( int nEdgeY, sal_Int32* pnMin /*= 0*/, sal_Int32* pnMax /*= 0*/ )
 {
     sal_Int32 nRet = 0;
@@ -244,7 +245,6 @@ sal_Int32 TableLayouter::getHorizontalEdge( int nEdgeY, sal_Int32* pnMin /*= 0*/
 }
 
 
-
 sal_Int32 TableLayouter::getVerticalEdge( int nEdgeX, sal_Int32* pnMin /*= 0*/, sal_Int32* pnMax /*= 0*/ )
 {
     sal_Int32 nRet = 0;
@@ -299,7 +299,6 @@ sal_Int32 TableLayouter::getVerticalEdge( int nEdgeX, sal_Int32* pnMin /*= 0*/,
 }
 
 
-
 static bool checkMergeOrigin( const TableModelRef& xTable, sal_Int32 nMergedX, sal_Int32 nMergedY, sal_Int32 nCellX, sal_Int32 nCellY, bool& bRunning )
 {
     Reference< XMergeableCell > xCell( xTable->getCellByPosition( nCellX, nCellY ), UNO_QUERY );
@@ -420,7 +419,6 @@ bool findMergeOrigin( const TableModelRef& xTable, sal_Int32 nMergedX, sal_Int32
 }
 
 
-
 sal_Int32 TableLayouter::getMinimumColumnWidth( sal_Int32 nColumn )
 {
     if( isValidColumn( nColumn ) )
@@ -435,26 +433,29 @@ sal_Int32 TableLayouter::getMinimumColumnWidth( sal_Int32 nColumn )
 }
 
 
-
 sal_Int32 TableLayouter::distribute( LayoutVector& rLayouts, sal_Int32 nDistribute )
 {
     // break loops after 100 runs to avoid freezing office due to developer error
     sal_Int32 nSafe = 100;
 
-    const sal_Size nCount = rLayouts.size();
-    sal_Size nIndex;
+    const std::size_t nCount = rLayouts.size();
+    std::size_t nIndex;
 
     bool bConstrainsBroken = false;
 
     do
     {
+        bConstrainsBroken = false;
+
         // first enforce minimum size constrains on all entities
         for( nIndex = 0; nIndex < nCount; ++nIndex )
         {
             Layout& rLayout = rLayouts[nIndex];
             if( rLayout.mnSize < rLayout.mnMinSize )
             {
-                nDistribute -= rLayout.mnMinSize - rLayout.mnSize;
+                sal_Int32 nDiff(0);
+                bConstrainsBroken |= o3tl::checked_sub(rLayout.mnMinSize, rLayout.mnSize, nDiff);
+                bConstrainsBroken |= o3tl::checked_sub(nDistribute, nDiff, nDistribute);
                 rLayout.mnSize = rLayout.mnMinSize;
             }
         }
@@ -467,11 +468,9 @@ sal_Int32 TableLayouter::distribute( LayoutVector& rLayouts, sal_Int32 nDistribu
         {
             Layout& rLayout = rLayouts[nIndex];
             if( (nDistribute > 0) || (rLayout.mnSize > rLayout.mnMinSize) )
-                nCurrentWidth += rLayout.mnSize;
+                nCurrentWidth = o3tl::saturating_add(nCurrentWidth, rLayout.mnSize);
         }
 
-        bConstrainsBroken = false;
-
         // now distribute over entities
         if( (nCurrentWidth != 0) && (nDistribute != 0) )
         {
@@ -481,14 +480,15 @@ sal_Int32 TableLayouter::distribute( LayoutVector& rLayouts, sal_Int32 nDistribu
                 Layout& rLayout = rLayouts[nIndex];
                 if( (nDistribute > 0) || (rLayout.mnSize > rLayout.mnMinSize) )
                 {
-                    sal_Int32 n;
-                    if( nIndex == (nCount-1) )
-                        n = nDistributed; // for last entity use up rest
-                    else
-                        n  = (nDistribute * rLayout.mnSize) / nCurrentWidth;
+                    sal_Int32 n(nDistributed); // for last entity use up rest
+                    if (nIndex != (nCount-1))
+                    {
+                        bConstrainsBroken |= o3tl::checked_multiply(nDistribute, rLayout.mnSize, n);
+                        n /= nCurrentWidth;
+                    }
 
+                    bConstrainsBroken |= o3tl::checked_add(rLayout.mnSize, n, rLayout.mnSize);
                     nDistributed -= n;
-                    rLayout.mnSize += n;
 
                     if( rLayout.mnSize < rLayout.mnMinSize )
                         bConstrainsBroken = true;
@@ -505,14 +505,12 @@ sal_Int32 TableLayouter::distribute( LayoutVector& rLayouts, sal_Int32 nDistribu
 }
 
 
-
 typedef std::vector< CellRef > MergeableCellVector;
 typedef std::vector< MergeableCellVector > MergeVector;
 typedef std::vector< sal_Int32 > Int32Vector;
 
 
-
-void TableLayouter::LayoutTableWidth( Rectangle& rArea, bool bFit )
+void TableLayouter::LayoutTableWidth( tools::Rectangle& rArea, bool bFit )
 {
     const sal_Int32 nColCount = getColumnCount();
     const sal_Int32 nRowCount = getRowCount();
@@ -585,7 +583,7 @@ void TableLayouter::LayoutTableWidth( Rectangle& rArea, bool bFit )
             if( maColumns[nCol].mnSize < nMinWidth )
                 maColumns[nCol].mnSize = nMinWidth;
 
-            nCurrentWidth += maColumns[nCol].mnSize;
+            nCurrentWidth = o3tl::saturating_add(nCurrentWidth, maColumns[nCol].mnSize);
         }
     }
 
@@ -651,7 +649,7 @@ void TableLayouter::LayoutTableWidth( Rectangle& rArea, bool bFit )
     while( coliter.next(nCol ) )
     {
         maColumns[nCol].mnPos = nNewWidth;
-        nNewWidth += maColumns[nCol].mnSize;
+        nNewWidth = o3tl::saturating_add(nNewWidth, maColumns[nCol].mnSize);
         if( bFit )
         {
             Reference< XPropertySet > xColSet( xCols->getByIndex(nCol), UNO_QUERY_THROW );
@@ -664,8 +662,7 @@ void TableLayouter::LayoutTableWidth( Rectangle& rArea, bool bFit )
 }
 
 
-
-void TableLayouter::LayoutTableHeight( Rectangle& rArea, bool bFit )
+void TableLayouter::LayoutTableHeight( tools::Rectangle& rArea, bool bFit )
 {
     const sal_Int32 nColCount = getColumnCount();
     const sal_Int32 nRowCount = getRowCount();
@@ -746,7 +743,7 @@ void TableLayouter::LayoutTableHeight( Rectangle& rArea, bool bFit )
             if( maRows[nRow].mnSize < nMinHeight )
                 maRows[nRow].mnSize = nMinHeight;
 
-            nCurrentHeight += maRows[nRow].mnSize;
+            nCurrentHeight = o3tl::saturating_add(nCurrentHeight, maRows[nRow].mnSize);
         }
     }
 
@@ -822,10 +819,9 @@ void TableLayouter::LayoutTableHeight( Rectangle& rArea, bool bFit )
 }
 
 
-
 /** try to fit the table into the given rectangle.
     If the rectangle is to small, it will be grown to fit the table. */
-void TableLayouter::LayoutTable( Rectangle& rRectangle, bool bFitWidth, bool bFitHeight )
+void TableLayouter::LayoutTable( tools::Rectangle& rRectangle, bool bFitWidth, bool bFitHeight )
 {
     if( !mxTable.is() )
         return;
@@ -838,7 +834,6 @@ void TableLayouter::LayoutTable( Rectangle& rRectangle, bool bFitWidth, bool bFi
         if( static_cast< sal_Int32 >( maRows.size() ) != nRowCount )
             maRows.resize( nRowCount );
 
-        Reference< XTableRows > xRows( mxTable->getRows() );
         for( sal_Int32 nRow = 0; nRow < nRowCount; nRow++ )
             maRows[nRow].clear();
 
@@ -855,8 +850,7 @@ void TableLayouter::LayoutTable( Rectangle& rRectangle, bool bFitWidth, bool bFi
 }
 
 
-
-void TableLayouter::updateCells( Rectangle& rRectangle )
+void TableLayouter::updateCells( tools::Rectangle& rRectangle )
 {
     const sal_Int32 nColCount = getColumnCount();
     const sal_Int32 nRowCount = getRowCount();
@@ -872,7 +866,7 @@ void TableLayouter::updateCells( Rectangle& rRectangle )
                 basegfx::B2IRectangle aCellArea;
                 if( getCellArea( xCell, aPos, aCellArea ) )
                 {
-                    Rectangle aCellRect;
+                    tools::Rectangle aCellRect;
                     aCellRect.Left() = aCellArea.getMinX();
                     aCellRect.Right() = aCellArea.getMaxX();
                     aCellRect.Top() = aCellArea.getMinY();
@@ -886,7 +880,6 @@ void TableLayouter::updateCells( Rectangle& rRectangle )
 }
 
 
-
 CellRef TableLayouter::getCell( const CellPos& rPos ) const
 {
     CellRef xCell;
@@ -902,7 +895,6 @@ CellRef TableLayouter::getCell( const CellPos& rPos ) const
 }
 
 
-
 bool TableLayouter::HasPriority( const SvxBorderLine* pThis, const SvxBorderLine* pOther )
 {
     if (!pThis || ((pThis == &gEmptyBorder) && (pOther != nullptr)))
@@ -937,39 +929,40 @@ bool TableLayouter::HasPriority( const SvxBorderLine* pThis, const SvxBorderLine
     }
 }
 
-
-
 void TableLayouter::SetBorder( sal_Int32 nCol, sal_Int32 nRow, bool bHorizontal, const SvxBorderLine* pLine )
 {
-    if( pLine == nullptr )
+    if (!pLine)
         pLine = &gEmptyBorder;
 
-    SvxBorderLine *pOld = bHorizontal ? maHorizontalBorders[nCol][nRow] : maVerticalBorders[nCol][nRow];
+    BorderLineMap& rMap = bHorizontal ? maHorizontalBorders : maVerticalBorders;
 
-    if( HasPriority( pLine, pOld ) )
+    if( (nCol >= 0) && (nCol < sal::static_int_cast<sal_Int32>(rMap.size())) &&
+        (nRow >= 0) && (nRow < sal::static_int_cast<sal_Int32>(rMap[nCol].size())) )
     {
-        if( (pOld != nullptr) && (pOld != &gEmptyBorder) )
-            delete pOld;
+        SvxBorderLine *pOld = rMap[nCol][nRow];
 
-        SvxBorderLine* pNew = ( pLine != &gEmptyBorder ) ?  new SvxBorderLine(*pLine) : &gEmptyBorder;
+        if (HasPriority(pLine, pOld))
+        {
+            if (pOld && pOld != &gEmptyBorder)
+                delete pOld;
 
-        if( bHorizontal )
-            maHorizontalBorders[nCol][nRow] = pNew;
-        else
-            maVerticalBorders[nCol][nRow]  = pNew;
+            SvxBorderLine* pNew = (pLine != &gEmptyBorder) ?  new SvxBorderLine(*pLine) : &gEmptyBorder;
+
+            rMap[nCol][nRow] = pNew;
+        }
+    }
+    else
+    {
+        OSL_FAIL( "sdr::table::TableLayouter::SetBorder(), invalid border!" );
     }
 }
 
-
-
 void TableLayouter::ClearBorderLayout()
 {
     ClearBorderLayout(maHorizontalBorders);
     ClearBorderLayout(maVerticalBorders);
 }
 
-
-
 void TableLayouter::ClearBorderLayout(BorderLineMap& rMap)
 {
     const sal_Int32 nColCount = rMap.size();
@@ -991,8 +984,6 @@ void TableLayouter::ClearBorderLayout(BorderLineMap& rMap)
     }
 }
 
-
-
 void TableLayouter::ResizeBorderLayout()
 {
     ClearBorderLayout();
@@ -1001,7 +992,6 @@ void TableLayouter::ResizeBorderLayout()
 }
 
 
-
 void TableLayouter::ResizeBorderLayout( BorderLineMap& rMap )
 {
     const sal_Int32 nColCount = getColumnCount() + 1;
@@ -1018,7 +1008,6 @@ void TableLayouter::ResizeBorderLayout( BorderLineMap& rMap )
 }
 
 
-
 void TableLayouter::UpdateBorderLayout()
 {
     // make sure old border layout is cleared and border maps have correct size
@@ -1036,7 +1025,7 @@ void TableLayouter::UpdateBorderLayout()
             if( !xCell.is() )
                 continue;
 
-            const SvxBoxItem* pThisAttr = static_cast<const SvxBoxItem*>(xCell->GetItemSet().GetItem( SDRATTR_TABLE_BORDER ));
+            const SvxBoxItem* pThisAttr = xCell->GetItemSet().GetItem<SvxBoxItem>( SDRATTR_TABLE_BORDER );
             OSL_ENSURE(pThisAttr,"sdr::table::TableLayouter::UpdateBorderLayout(), no border attribute?");
 
             if( !pThisAttr )
@@ -1061,8 +1050,7 @@ void TableLayouter::UpdateBorderLayout()
 }
 
 
-
-void TableLayouter::DistributeColumns( ::Rectangle& rArea, sal_Int32 nFirstCol, sal_Int32 nLastCol )
+void TableLayouter::DistributeColumns( ::tools::Rectangle& rArea, sal_Int32 nFirstCol, sal_Int32 nLastCol )
 {
     if( mxTable.is() ) try
     {
@@ -1092,16 +1080,14 @@ void TableLayouter::DistributeColumns( ::Rectangle& rArea, sal_Int32 nFirstCol,
 
         LayoutTable( rArea, true, false );
     }
-    catch( Exception& e )
+    catch( Exception& )
     {
-        (void)e;
         OSL_FAIL("sdr::table::TableLayouter::DistributeColumns(), exception caught!");
     }
 }
 
 
-
-void TableLayouter::DistributeRows( ::Rectangle& rArea, sal_Int32 nFirstRow, sal_Int32 nLastRow )
+void TableLayouter::DistributeRows( ::tools::Rectangle& rArea, sal_Int32 nFirstRow, sal_Int32 nLastRow )
 {
     if( mxTable.is() ) try
     {
@@ -1144,13 +1130,40 @@ void TableLayouter::DistributeRows( ::Rectangle& rArea, sal_Int32 nFirstRow, sal
 
         LayoutTable( rArea, false, true );
     }
-    catch( Exception& e )
+    catch( Exception& )
     {
-        (void)e;
         OSL_FAIL("sdr::table::TableLayouter::DistributeRows(), exception caught!");
     }
 }
 
+void TableLayouter::dumpAsXml(xmlTextWriterPtr pWriter) const
+{
+    xmlTextWriterStartElement(pWriter, BAD_CAST("TableLayouter"));
+
+    xmlTextWriterStartElement(pWriter, BAD_CAST("columns"));
+    for (const auto& rColumn : maColumns)
+        rColumn.dumpAsXml(pWriter);
+    xmlTextWriterEndElement(pWriter);
+
+    xmlTextWriterStartElement(pWriter, BAD_CAST("rows"));
+    for (const auto& rRow : maRows)
+        rRow.dumpAsXml(pWriter);
+    xmlTextWriterEndElement(pWriter);
+
+    xmlTextWriterEndElement(pWriter);
+}
+
+void TableLayouter::Layout::dumpAsXml(xmlTextWriterPtr pWriter) const
+{
+    xmlTextWriterStartElement(pWriter, BAD_CAST("TableLayouter_Layout"));
+
+    xmlTextWriterWriteAttribute(pWriter, BAD_CAST("pos"), BAD_CAST(OString::number(mnPos).getStr()));
+    xmlTextWriterWriteAttribute(pWriter, BAD_CAST("size"), BAD_CAST(OString::number(mnSize).getStr()));
+    xmlTextWriterWriteAttribute(pWriter, BAD_CAST("minSize"), BAD_CAST(OString::number(mnMinSize).getStr()));
+
+    xmlTextWriterEndElement(pWriter);
+}
+
 } }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
