@@ -28,18 +28,18 @@
 #include <osl/mutex.hxx>
 #include <libxml/xmlwriter.h>
 
-#include "cell.hxx"
+#include <cell.hxx>
 #include "cellcursor.hxx"
-#include "tablemodel.hxx"
+#include <tablemodel.hxx>
 #include "tablerow.hxx"
 #include "tablerows.hxx"
 #include "tablecolumn.hxx"
 #include "tablecolumns.hxx"
 #include "tableundo.hxx"
-#include "svx/svdotable.hxx"
-#include "svx/svdmodel.hxx"
-#include "svx/svdstr.hrc"
-#include "svdglob.hxx"
+#include <svx/svdotable.hxx>
+#include <svx/svdmodel.hxx>
+#include <svx/strings.hrc>
+#include <svdglob.hxx>
 
 using namespace ::osl;
 using namespace ::com::sun::star::uno;
@@ -1007,9 +1007,8 @@ void TableModel::optimize()
                     nWidth1 += nWidth2;
                     xSet2->setPropertyValue( sWidth, Any( nWidth1 ) );
                 }
-                catch( Exception& e )
+                catch( Exception& )
                 {
-                    (void)e;
                     OSL_FAIL("svx::TableModel::optimize(), exception caught!");
                 }
 
@@ -1045,9 +1044,8 @@ void TableModel::optimize()
                     nHeight1 += nHeight2;
                     xSet2->setPropertyValue( sHeight, Any( nHeight1 ) );
                 }
-                catch( Exception& e )
+                catch( Exception& )
                 {
-                    (void)e;
                     OSL_FAIL("svx::TableModel::optimize(), exception caught!");
                 }
 
