@@ -20,9 +20,8 @@
 
 #include <string>
 
-#include <osl/mutex.hxx>
-
 #include <svtools/toolbarmenu.hxx>
+#include <svx/colorwindow.hxx>
 #include <vcl/toolbox.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/dispatch.hxx>
@@ -32,23 +31,18 @@
 #include <svl/intitem.hxx>
 #include <editeng/colritem.hxx>
 
-#include <svx/dialogs.hrc>
+#include <svx/strings.hrc>
 #include <svx/svdtrans.hxx>
 #include <svx/sdasitm.hxx>
 #include <svx/dialmgr.hxx>
 
-#include "coreservices.hxx"
-#include "helpid.hrc"
+#include <coreservices.hxx>
+#include <helpids.h>
 #include "extrusioncontrols.hxx"
-#include "extrusioncontrols.hrc"
-#include "colorwindow.hxx"
-#include "extrusiondepthdialog.hxx"
+#include <extrusiondepthdialog.hxx>
 
+#include <bitmaps.hlst>
 
-
-//using ::svtools::ToolbarMenu;
-
-using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::beans;
@@ -59,49 +53,111 @@ namespace svx
 {
 
 static const sal_Int32 gSkewList[] = { 135, 90, 45, 180, 0, -360, -135, -90, -45 };
+static const char g_sExtrusionDirection[] = ".uno:ExtrusionDirection";
+static const char g_sExtrusionProjection[] = ".uno:ExtrusionProjection";
+
+static const OUStringLiteral aLightOffBmps[] =
+{
+    RID_SVXBMP_LIGHT_OFF_FROM_TOP_LEFT,
+    RID_SVXBMP_LIGHT_OFF_FROM_TOP,
+    RID_SVXBMP_LIGHT_OFF_FROM_TOP_RIGHT,
+    RID_SVXBMP_LIGHT_OFF_FROM_LEFT,
+    "",
+    RID_SVXBMP_LIGHT_OFF_FROM_RIGHT,
+    RID_SVXBMP_LIGHT_OFF_FROM_BOTTOM_LEFT,
+    RID_SVXBMP_LIGHT_OFF_FROM_BOTTOM,
+    RID_SVXBMP_LIGHT_OFF_FROM_BOTTOM_RIGHT
+};
+
+static const OUStringLiteral aLightOnBmps[] =
+{
+    RID_SVXBMP_LIGHT_ON_FROM_TOP_LEFT,
+    RID_SVXBMP_LIGHT_ON_FROM_TOP,
+    RID_SVXBMP_LIGHT_ON_FROM_TOP_RIGHT,
+    RID_SVXBMP_LIGHT_ON_FROM_LEFT,
+    "",
+    RID_SVXBMP_LIGHT_ON_FROM_RIGHT,
+    RID_SVXBMP_LIGHT_ON_FROM_BOTTOM_LEFT,
+    RID_SVXBMP_LIGHT_ON_FROM_BOTTOM,
+    RID_SVXBMP_LIGHT_ON_FROM_BOTTOM_RIGHT
+};
+
+static const OUStringLiteral aLightPreviewBmps[] =
+{
+    RID_SVXBMP_LIGHT_PREVIEW_FROM_TOP_LEFT,
+    RID_SVXBMP_LIGHT_PREVIEW_FROM_TOP,
+    RID_SVXBMP_LIGHT_PREVIEW_FROM_TOP_RIGHT,
+    RID_SVXBMP_LIGHT_PREVIEW_FROM_LEFT,
+    RID_SVXBMP_LIGHT_PREVIEW_FROM_RIGHT,
+    RID_SVXBMP_LIGHT_PREVIEW_FROM_FRONT,
+    RID_SVXBMP_LIGHT_PREVIEW_FROM_BOTTOM_LEFT,
+    RID_SVXBMP_LIGHT_PREVIEW_FROM_BOTTOM,
+    RID_SVXBMP_LIGHT_PREVIEW_FROM_BOTTOM_RIGHT
+};
+
+static const OUStringLiteral aDirectionBmps[] =
+{
+    RID_SVXBMP_DIRECTION_DIRECTION_NW,
+    RID_SVXBMP_DIRECTION_DIRECTION_N,
+    RID_SVXBMP_DIRECTION_DIRECTION_NE,
+    RID_SVXBMP_DIRECTION_DIRECTION_W,
+    RID_SVXBMP_DIRECTION_DIRECTION_NONE,
+    RID_SVXBMP_DIRECTION_DIRECTION_E,
+    RID_SVXBMP_DIRECTION_DIRECTION_SW,
+    RID_SVXBMP_DIRECTION_DIRECTION_S,
+    RID_SVXBMP_DIRECTION_DIRECTION_SE
+};
+
+static const char* aDirectionStrs[] =
+{
+    RID_SVXSTR_DIRECTION_NW,
+    RID_SVXSTR_DIRECTION_N,
+    RID_SVXSTR_DIRECTION_NE,
+    RID_SVXSTR_DIRECTION_W,
+    RID_SVXSTR_DIRECTION_NONE,
+    RID_SVXSTR_DIRECTION_E,
+    RID_SVXSTR_DIRECTION_SW,
+    RID_SVXSTR_DIRECTION_S,
+    RID_SVXSTR_DIRECTION_SE
+};
 
 ExtrusionDirectionWindow::ExtrusionDirectionWindow(
     svt::ToolboxController& rController,
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
     vcl::Window* pParentWindow
 )
-    : ToolbarMenu(rFrame, pParentWindow,
-                  WB_MOVEABLE|WB_CLOSEABLE|WB_HIDE|WB_3DLOOK)
+    : ToolbarMenu(rController.getFrameInterface(), pParentWindow, WB_STDPOPUP)
     , mrController(rController)
-    , maImgPerspective(SVX_RES(RID_SVXIMG_PERSPECTIVE))
-    , maImgParallel(SVX_RES(RID_SVXIMG_PARALLEL))
-    , msExtrusionDirection(".uno:ExtrusionDirection")
-    , msExtrusionProjection(".uno:ExtrusionProjection")
+    , maImgPerspective(BitmapEx(RID_SVXBMP_PERSPECTIVE))
+    , maImgParallel(BitmapEx(RID_SVXBMP_PARALLEL))
 {
-    for(sal_uInt16 i = DIRECTION_NW; i <= DIRECTION_SE; ++i)
+    for (sal_uInt16 i = DIRECTION_NW; i <= DIRECTION_SE; ++i)
     {
-        maImgDirection[i] = Image( SVX_RES( RID_SVXIMG_DIRECTION + i ) );
+        maImgDirection[i] = Image(BitmapEx(aDirectionBmps[i]));
     }
 
-    SetSelectHdl( LINK( this, ExtrusionDirectionWindow, SelectHdl ) );
+    SetSelectHdl( LINK( this, ExtrusionDirectionWindow, SelectToolbarMenuHdl ) );
     mpDirectionSet = createEmptyValueSetControl();
 
-    mpDirectionSet->SetSelectHdl( LINK( this, ExtrusionDirectionWindow, SelectHdl ) );
+    mpDirectionSet->SetSelectHdl( LINK( this, ExtrusionDirectionWindow, SelectValueSetHdl ) );
     mpDirectionSet->SetColCount( 3 );
     mpDirectionSet->EnableFullItemMode( false );
 
     for (sal_uInt16 i = DIRECTION_NW; i <= DIRECTION_SE; ++i)
     {
-        OUString aText(SVX_RESSTR(RID_SVXSTR_DIRECTION + i));
-        mpDirectionSet->InsertItem(i + 1, maImgDirection[i], aText);
+        mpDirectionSet->InsertItem(i + 1, maImgDirection[i], SvxResId(aDirectionStrs[i]));
     }
 
     mpDirectionSet->SetOutputSizePixel(Size(72, 72));
 
     appendEntry(2, mpDirectionSet );
     appendSeparator();
-    appendEntry(0, SVX_RESSTR(RID_SVXSTR_PERSPECTIVE), maImgPerspective);
-    appendEntry(1, SVX_RESSTR(RID_SVXSTR_PARALLEL), maImgParallel);
+    appendEntry(0, SvxResId(RID_SVXSTR_PERSPECTIVE), maImgPerspective);
+    appendEntry(1, SvxResId(RID_SVXSTR_PARALLEL), maImgParallel);
 
     SetOutputSizePixel( getMenuSize() );
 
-    AddStatusListener( msExtrusionDirection );
-    AddStatusListener( msExtrusionProjection );
+    AddStatusListener( g_sExtrusionDirection );
+    AddStatusListener( g_sExtrusionProjection );
 }
 
 ExtrusionDirectionWindow::~ExtrusionDirectionWindow()
@@ -132,7 +188,6 @@ void ExtrusionDirectionWindow::DataChanged( const DataChangedEvent& rDCEvt )
 }
 
 
-
 void ExtrusionDirectionWindow::implSetDirection( sal_Int32 nSkew, bool bEnabled )
 {
     if( mpDirectionSet )
@@ -157,7 +212,6 @@ void ExtrusionDirectionWindow::implSetDirection( sal_Int32 nSkew, bool bEnabled
 }
 
 
-
 void ExtrusionDirectionWindow::implSetProjection( sal_Int32 nProjection, bool bEnabled )
 {
     checkEntry( 0, (nProjection == 0) && bEnabled );
@@ -167,12 +221,11 @@ void ExtrusionDirectionWindow::implSetProjection( sal_Int32 nProjection, bool bE
 }
 
 
-
 void ExtrusionDirectionWindow::statusChanged(
-    const ::com::sun::star::frame::FeatureStateEvent& Event
-)   throw ( ::com::sun::star::uno::RuntimeException )
+    const css::frame::FeatureStateEvent& Event
+)
 {
-    if( Event.FeatureURL.Main.equals( msExtrusionDirection ) )
+    if( Event.FeatureURL.Main == g_sExtrusionDirection )
     {
         if( !Event.IsEnabled )
         {
@@ -185,7 +238,7 @@ void ExtrusionDirectionWindow::statusChanged(
                 implSetDirection( nValue, true );
         }
     }
-    else if( Event.FeatureURL.Main.equals( msExtrusionProjection ) )
+    else if( Event.FeatureURL.Main == g_sExtrusionProjection )
     {
         if( !Event.IsEnabled )
         {
@@ -201,8 +254,15 @@ void ExtrusionDirectionWindow::statusChanged(
 }
 
 
-
-IMPL_LINK( ExtrusionDirectionWindow, SelectHdl, void *, pControl )
+IMPL_LINK( ExtrusionDirectionWindow, SelectValueSetHdl, ValueSet*, pControl, void )
+{
+    SelectHdl(pControl);
+}
+IMPL_LINK( ExtrusionDirectionWindow, SelectToolbarMenuHdl, ToolbarMenu*, pControl, void )
+{
+    SelectHdl(pControl);
+}
+void ExtrusionDirectionWindow::SelectHdl(void const * pControl)
 {
     if ( IsInPopupMode() )
         EndPopupMode();
@@ -210,10 +270,10 @@ IMPL_LINK( ExtrusionDirectionWindow, SelectHdl, void *, pControl )
     if( pControl == mpDirectionSet )
     {
         Sequence< PropertyValue > aArgs( 1 );
-        aArgs[0].Name = msExtrusionDirection.copy(5);
+        aArgs[0].Name = OUString(g_sExtrusionDirection).copy(5);
         aArgs[0].Value <<= (sal_Int32)gSkewList[mpDirectionSet->GetSelectItemId()-1];
 
-        mrController.dispatchCommand( msExtrusionDirection, aArgs );
+        mrController.dispatchCommand( g_sExtrusionDirection, aArgs );
     }
     else
     {
@@ -221,41 +281,37 @@ IMPL_LINK( ExtrusionDirectionWindow, SelectHdl, void *, pControl )
         if( (nProjection >= 0) && (nProjection < 2 ) )
         {
             Sequence< PropertyValue > aArgs( 1 );
-            aArgs[0].Name = msExtrusionProjection.copy(5);
+            aArgs[0].Name = OUString(g_sExtrusionProjection).copy(5);
             aArgs[0].Value <<= (sal_Int32)nProjection;
 
-            mrController.dispatchCommand( msExtrusionProjection, aArgs );
+            mrController.dispatchCommand( g_sExtrusionProjection, aArgs );
             implSetProjection( nProjection, true );
         }
     }
-
-    return 0;
 }
 
 ExtrusionDirectionControl::ExtrusionDirectionControl(
     const Reference< XComponentContext >& rxContext
 )   : svt::PopupWindowController(
         rxContext,
-        Reference< frame::XFrame >(),
-        OUString( ".uno:ExtrusionDirectionFloater" )
+        Reference< css::frame::XFrame >(),
+        ".uno:ExtrusionDirectionFloater"
     )
 {
 }
 
 
-
 VclPtr<vcl::Window> ExtrusionDirectionControl::createPopupWindow( vcl::Window* pParent )
 {
-    return VclPtr<ExtrusionDirectionWindow>::Create( *this, m_xFrame, pParent );
+    return VclPtr<ExtrusionDirectionWindow>::Create( *this, pParent );
 }
 
 // XInitialization
 void SAL_CALL ExtrusionDirectionControl::initialize( const css::uno::Sequence< css::uno::Any >& aArguments )
-    throw ( css::uno::Exception, css::uno::RuntimeException, std::exception )
 {
     svt::PopupWindowController::initialize( aArguments );
 
-    ToolBox* pToolBox = 0;
+    ToolBox* pToolBox = nullptr;
     sal_uInt16 nId = 0;
     if ( getToolboxId( nId, &pToolBox ) )
         pToolBox->SetItemBits( nId, pToolBox->GetItemBits( nId ) | ToolBoxItemBits::DROPDOWNONLY );
@@ -270,33 +326,28 @@ OUString SAL_CALL ExtrusionDirectionControl_getImplementationName()
 }
 
 
-
-Sequence< OUString > SAL_CALL ExtrusionDirectionControl_getSupportedServiceNames() throw( RuntimeException )
+Sequence< OUString > SAL_CALL ExtrusionDirectionControl_getSupportedServiceNames()
 {
-    Sequence< OUString > aSNS( 1 );
-    aSNS.getArray()[0] = "com.sun.star.frame.ToolbarController";
+    Sequence<OUString> aSNS { "com.sun.star.frame.ToolbarController" };
     return aSNS;
 }
 
 
-
 Reference< XInterface > SAL_CALL SAL_CALL ExtrusionDirectionControl_createInstance(
     const Reference< XMultiServiceFactory >& rSMgr
-)   throw( RuntimeException )
+)
 {
     return *new ExtrusionDirectionControl( comphelper::getComponentContext(rSMgr) );
 }
 
 
-
-OUString SAL_CALL ExtrusionDirectionControl::getImplementationName(  ) throw (RuntimeException, std::exception)
+OUString SAL_CALL ExtrusionDirectionControl::getImplementationName(  )
 {
     return ExtrusionDirectionControl_getImplementationName();
 }
 
 
-
-Sequence< OUString > SAL_CALL ExtrusionDirectionControl::getSupportedServiceNames(  ) throw (RuntimeException, std::exception)
+Sequence< OUString > SAL_CALL ExtrusionDirectionControl::getSupportedServiceNames(  )
 {
     return ExtrusionDirectionControl_getSupportedServiceNames();
 }
@@ -325,21 +376,20 @@ double ExtrusionDepthDialog::getDepth() const
     return (double)( m_pMtrDepth->GetValue( FUNIT_100TH_MM ) ) / 100.0;
 }
 
-double aDepthListInch[] = { 0, 1270,2540,5080,10160 };
-double aDepthListMM[] = { 0, 1000, 2500, 5000, 10000 };
+double const aDepthListInch[] = { 0, 1270,2540,5080,10160 };
+double const aDepthListMM[] = { 0, 1000, 2500, 5000, 10000 };
 
 ExtrusionDepthWindow::ExtrusionDepthWindow(
     svt::ToolboxController& rController,
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
     vcl::Window* pParentWindow
-)   : ToolbarMenu( rFrame, pParentWindow, WB_MOVEABLE|WB_CLOSEABLE|WB_HIDE|WB_3DLOOK)
+)   : ToolbarMenu( rController.getFrameInterface(), pParentWindow, WB_STDPOPUP )
     , mrController( rController )
-    , maImgDepth0(SVX_RES(RID_SVXIMG_DEPTH_0))
-    , maImgDepth1(SVX_RES(RID_SVXIMG_DEPTH_1))
-    , maImgDepth2(SVX_RES(RID_SVXIMG_DEPTH_2))
-    , maImgDepth3(SVX_RES(RID_SVXIMG_DEPTH_3))
-    , maImgDepth4(SVX_RES(RID_SVXIMG_DEPTH_4))
-    , maImgDepthInfinity(SVX_RES(RID_SVXIMG_DEPTH_INFINITY))
+    , maImgDepth0(BitmapEx(RID_SVXBMP_DEPTH_0))
+    , maImgDepth1(BitmapEx(RID_SVXBMP_DEPTH_1))
+    , maImgDepth2(BitmapEx(RID_SVXBMP_DEPTH_2))
+    , maImgDepth3(BitmapEx(RID_SVXBMP_DEPTH_3))
+    , maImgDepth4(BitmapEx(RID_SVXBMP_DEPTH_4))
+    , maImgDepthInfinity(BitmapEx(RID_SVXBMP_DEPTH_INFINITY))
     , meUnit(FUNIT_NONE)
     , mfDepth( -1.0 )
     , msExtrusionDepth( ".uno:ExtrusionDepth" )
@@ -347,14 +397,13 @@ ExtrusionDepthWindow::ExtrusionDepthWindow(
 {
     SetSelectHdl( LINK( this, ExtrusionDepthWindow, SelectHdl ) );
 
-    OUString aEmpty;
-    appendEntry(0, aEmpty, maImgDepth0);
-    appendEntry(1, aEmpty, maImgDepth1);
-    appendEntry(2, aEmpty, maImgDepth2);
-    appendEntry(3, aEmpty, maImgDepth3);
-    appendEntry(4, aEmpty, maImgDepth4);
-    appendEntry(5, SVX_RESSTR(RID_SVXSTR_INFINITY), maImgDepthInfinity);
-    appendEntry(6, SVX_RESSTR(RID_SVXSTR_CUSTOM));
+    appendEntry(0, "", maImgDepth0);
+    appendEntry(1, "", maImgDepth1);
+    appendEntry(2, "", maImgDepth2);
+    appendEntry(3, "", maImgDepth3);
+    appendEntry(4, "", maImgDepth4);
+    appendEntry(5, SvxResId(RID_SVXSTR_INFINITY), maImgDepthInfinity);
+    appendEntry(6, SvxResId(RID_SVXSTR_CUSTOM));
 
     SetOutputSizePixel( getMenuSize() );
 
@@ -379,27 +428,44 @@ void ExtrusionDepthWindow::implSetDepth( double fDepth )
     }
 }
 
-
-
 void ExtrusionDepthWindow::implFillStrings( FieldUnit eUnit )
 {
     meUnit = eUnit;
-    sal_uInt16 nResource = IsMetric( eUnit ) ? RID_SVXSTR_DEPTH_0 : RID_SVXSTR_DEPTH_0_INCH;
 
-    for( int i = 0; i < 5; i++ )
+    const char* aDepths[] =
     {
-        OUString aStr( SVX_RESSTR( nResource + i ) );
-        setEntryText( i, aStr );
+        RID_SVXSTR_DEPTH_0,
+        RID_SVXSTR_DEPTH_1,
+        RID_SVXSTR_DEPTH_2,
+        RID_SVXSTR_DEPTH_3,
+        RID_SVXSTR_DEPTH_4
+    };
+
+    const char* aDepthsInch[] =
+    {
+        RID_SVXSTR_DEPTH_0_INCH,
+        RID_SVXSTR_DEPTH_1_INCH,
+        RID_SVXSTR_DEPTH_2_INCH,
+        RID_SVXSTR_DEPTH_3_INCH,
+        RID_SVXSTR_DEPTH_4_INCH
+    };
+
+    assert(SAL_N_ELEMENTS(aDepths) == SAL_N_ELEMENTS(aDepthsInch));
+
+    const char** pResource = IsMetric(eUnit) ? aDepths : aDepthsInch;
+
+    for (size_t i = 0; i < SAL_N_ELEMENTS(aDepths); ++i)
+    {
+        OUString aStr(SvxResId(pResource[i]));
+        setEntryText(i, aStr);
     }
 }
 
-
-
 void ExtrusionDepthWindow::statusChanged(
-    const ::com::sun::star::frame::FeatureStateEvent& Event
-)   throw ( ::com::sun::star::uno::RuntimeException )
+    const css::frame::FeatureStateEvent& Event
+)
 {
-    if( Event.FeatureURL.Main.equals( msExtrusionDepth ) )
+    if( Event.FeatureURL.Main == msExtrusionDepth )
     {
         if( !Event.IsEnabled )
         {
@@ -412,7 +478,7 @@ void ExtrusionDepthWindow::statusChanged(
                 implSetDepth( fValue );
         }
     }
-    else if( Event.FeatureURL.Main.equals( msMetricUnit ) )
+    else if( Event.FeatureURL.Main == msMetricUnit )
     {
         if( Event.IsEnabled )
         {
@@ -427,7 +493,7 @@ void ExtrusionDepthWindow::statusChanged(
     }
 }
 
-IMPL_LINK_NOARG(ExtrusionDepthWindow, SelectHdl)
+IMPL_LINK_NOARG(ExtrusionDepthWindow, SelectHdl, ToolbarMenu*, void)
 {
     int nSelected = getSelectedEntryId();
     if( nSelected != -1 )
@@ -471,7 +537,6 @@ IMPL_LINK_NOARG(ExtrusionDepthWindow, SelectHdl)
                 EndPopupMode();
         }
     }
-    return 0;
 }
 
 
@@ -482,26 +547,24 @@ ExtrusionDepthController::ExtrusionDepthController(
     const Reference< XComponentContext >& rxContext
 )   : svt::PopupWindowController(
         rxContext,
-        Reference< frame::XFrame >(),
-        OUString( ".uno:ExtrusionDepthFloater" )
+        Reference< css::frame::XFrame >(),
+        ".uno:ExtrusionDepthFloater"
     )
 {
 }
 
 
-
 VclPtr<vcl::Window> ExtrusionDepthController::createPopupWindow( vcl::Window* pParent )
 {
-    return VclPtr<ExtrusionDepthWindow>::Create( *this, m_xFrame, pParent );
+    return VclPtr<ExtrusionDepthWindow>::Create( *this, pParent );
 }
 
 // XInitialization
 void SAL_CALL ExtrusionDepthController::initialize( const css::uno::Sequence< css::uno::Any >& aArguments )
-    throw ( css::uno::Exception, css::uno::RuntimeException, std::exception )
 {
     svt::PopupWindowController::initialize( aArguments );
 
-    ToolBox* pToolBox = 0;
+    ToolBox* pToolBox = nullptr;
     sal_uInt16 nId = 0;
     if ( getToolboxId( nId, &pToolBox ) )
         pToolBox->SetItemBits( nId, pToolBox->GetItemBits( nId ) | ToolBoxItemBits::DROPDOWNONLY );
@@ -516,62 +579,57 @@ OUString SAL_CALL ExtrusionDepthController_getImplementationName()
 }
 
 
-
-Sequence< OUString > SAL_CALL ExtrusionDepthController_getSupportedServiceNames() throw( RuntimeException )
+Sequence< OUString > SAL_CALL ExtrusionDepthController_getSupportedServiceNames()
 {
-    Sequence< OUString > aSNS( 1 );
-    aSNS.getArray()[0] = "com.sun.star.frame.ToolbarController";
+    Sequence<OUString> aSNS { "com.sun.star.frame.ToolbarController" };
     return aSNS;
 }
 
 
-
-Reference< XInterface > SAL_CALL SAL_CALL ExtrusionDepthController_createInstance( const Reference< XMultiServiceFactory >& rSMgr ) throw( RuntimeException )
+Reference< XInterface > SAL_CALL SAL_CALL ExtrusionDepthController_createInstance( const Reference< XMultiServiceFactory >& rSMgr )
 {
     return *new ExtrusionDepthController( comphelper::getComponentContext(rSMgr) );
 }
 
-OUString SAL_CALL ExtrusionDepthController::getImplementationName(  ) throw (RuntimeException, std::exception)
+OUString SAL_CALL ExtrusionDepthController::getImplementationName(  )
 {
     return ExtrusionDepthController_getImplementationName();
 }
 
-Sequence< OUString > SAL_CALL ExtrusionDepthController::getSupportedServiceNames(  ) throw (RuntimeException, std::exception)
+Sequence< OUString > SAL_CALL ExtrusionDepthController::getSupportedServiceNames(  )
 {
     return ExtrusionDepthController_getSupportedServiceNames();
 }
 
+static const char g_sExtrusionLightingDirection[] = ".uno:ExtrusionLightingDirection";
+static const char g_sExtrusionLightingIntensity[] = ".uno:ExtrusionLightingIntensity";
+
 ExtrusionLightingWindow::ExtrusionLightingWindow(svt::ToolboxController& rController,
-                                                 const css::uno::Reference<css::frame::XFrame >& rFrame,
                                                  vcl::Window* pParentWindow)
-    : ToolbarMenu(rFrame, pParentWindow, WB_MOVEABLE|WB_CLOSEABLE|WB_HIDE|WB_3DLOOK)
+    : ToolbarMenu(rController.getFrameInterface(), pParentWindow, WB_STDPOPUP)
     , mrController(rController)
-    , maImgBright(SVX_RES(RID_SVXIMG_LIGHTING_BRIGHT))
-    , maImgNormal(SVX_RES(RID_SVXIMG_LIGHTING_NORMAL))
-    , maImgDim(SVX_RES(RID_SVXIMG_LIGHTING_DIM))
-    , mnLevel(0)
-    , mbLevelEnabled(false)
+    , maImgBright(BitmapEx(RID_SVXBMP_LIGHTING_BRIGHT))
+    , maImgNormal(BitmapEx(RID_SVXBMP_LIGHTING_NORMAL))
+    , maImgDim(BitmapEx(RID_SVXBMP_LIGHTING_DIM))
     , mnDirection(FROM_FRONT)
     , mbDirectionEnabled(false)
-    , msExtrusionLightingDirection(".uno:ExtrusionLightingDirection")
-    , msExtrusionLightingIntensity(".uno:ExtrusionLightingIntensity")
 {
     for (sal_uInt16 i = FROM_TOP_LEFT; i <= FROM_BOTTOM_RIGHT; ++i)
     {
         if( i != FROM_FRONT )
         {
-            maImgLightingOff[i] = Image(SVX_RES(RID_SVXIMG_LIGHT_OFF + i));
-            maImgLightingOn[i] = Image(SVX_RES(RID_SVXIMG_LIGHT_ON + i));
+            maImgLightingOff[i] = Image(BitmapEx(aLightOffBmps[i]));
+            maImgLightingOn[i] = Image(BitmapEx(aLightOnBmps[i]));
         }
-        maImgLightingPreview[i] = Image(SVX_RES(RID_SVXIMG_LIGHT_PREVIEW + i));
+        maImgLightingPreview[i] = Image(BitmapEx(aLightPreviewBmps[i]));
     }
 
-    SetSelectHdl( LINK( this, ExtrusionLightingWindow, SelectHdl ) );
+    SetSelectHdl( LINK( this, ExtrusionLightingWindow, SelectToolbarMenuHdl ) );
 
     mpLightingSet = createEmptyValueSetControl();
     mpLightingSet->SetHelpId( HID_VALUESET_EXTRUSION_LIGHTING );
 
-    mpLightingSet->SetSelectHdl( LINK( this, ExtrusionLightingWindow, SelectHdl ) );
+    mpLightingSet->SetSelectHdl( LINK( this, ExtrusionLightingWindow, SelectValueSetHdl ) );
     mpLightingSet->SetColCount( 3 );
     mpLightingSet->EnableFullItemMode( false );
 
@@ -590,14 +648,14 @@ ExtrusionLightingWindow::ExtrusionLightingWindow(svt::ToolboxController& rContro
 
     appendEntry(3, mpLightingSet);
     appendSeparator();
-    appendEntry(0, SVX_RESSTR(RID_SVXSTR_BRIGHT), maImgBright);
-    appendEntry(1, SVX_RESSTR(RID_SVXSTR_NORMAL), maImgNormal);
-    appendEntry(2, SVX_RESSTR(RID_SVXSTR_DIM), maImgDim);
+    appendEntry(0, SvxResId(RID_SVXSTR_BRIGHT), maImgBright);
+    appendEntry(1, SvxResId(RID_SVXSTR_NORMAL), maImgNormal);
+    appendEntry(2, SvxResId(RID_SVXSTR_DIM), maImgDim);
 
     SetOutputSizePixel( getMenuSize() );
 
-    AddStatusListener( msExtrusionLightingDirection );
-    AddStatusListener( msExtrusionLightingIntensity );
+    AddStatusListener( g_sExtrusionLightingDirection );
+    AddStatusListener( g_sExtrusionLightingIntensity );
 }
 
 ExtrusionLightingWindow::~ExtrusionLightingWindow()
@@ -613,8 +671,6 @@ void ExtrusionLightingWindow::dispose()
 
 void ExtrusionLightingWindow::implSetIntensity( int nLevel, bool bEnabled )
 {
-    mnLevel = nLevel;
-    mbLevelEnabled = bEnabled;
     for (int i = 0; i < 3; ++i)
     {
         checkEntry( i, (i == nLevel) && bEnabled );
@@ -650,12 +706,11 @@ void ExtrusionLightingWindow::implSetDirection( int nDirection, bool bEnabled )
 }
 
 
-
 void ExtrusionLightingWindow::statusChanged(
-    const ::com::sun::star::frame::FeatureStateEvent& Event
-)   throw ( ::com::sun::star::uno::RuntimeException )
+    const css::frame::FeatureStateEvent& Event
+)
 {
-    if( Event.FeatureURL.Main.equals( msExtrusionLightingIntensity ) )
+    if( Event.FeatureURL.Main == g_sExtrusionLightingIntensity )
     {
         if( !Event.IsEnabled )
         {
@@ -668,7 +723,7 @@ void ExtrusionLightingWindow::statusChanged(
                 implSetIntensity( nValue, true );
         }
     }
-    else if( Event.FeatureURL.Main.equals( msExtrusionLightingDirection ) )
+    else if( Event.FeatureURL.Main == g_sExtrusionLightingDirection )
     {
         if( !Event.IsEnabled )
         {
@@ -684,7 +739,6 @@ void ExtrusionLightingWindow::statusChanged(
 }
 
 
-
 void ExtrusionLightingWindow::DataChanged( const DataChangedEvent& rDCEvt )
 {
     ToolbarMenu::DataChanged( rDCEvt );
@@ -699,8 +753,15 @@ void ExtrusionLightingWindow::DataChanged( const DataChangedEvent& rDCEvt )
 }
 
 
-
-IMPL_LINK( ExtrusionLightingWindow, SelectHdl, void *, pControl )
+IMPL_LINK( ExtrusionLightingWindow, SelectValueSetHdl, ValueSet*, pControl, void )
+{
+    SelectHdl(pControl);
+}
+IMPL_LINK( ExtrusionLightingWindow, SelectToolbarMenuHdl, ToolbarMenu*, pControl, void )
+{
+    SelectHdl(pControl);
+}
+void ExtrusionLightingWindow::SelectHdl(void const * pControl)
 {
     if ( IsInPopupMode() )
         EndPopupMode();
@@ -713,10 +774,10 @@ IMPL_LINK( ExtrusionLightingWindow, SelectHdl, void *, pControl )
             if( nLevel != 3 )
             {
                 Sequence< PropertyValue > aArgs( 1 );
-                aArgs[0].Name = msExtrusionLightingIntensity.copy(5);
+                aArgs[0].Name = OUString(g_sExtrusionLightingIntensity).copy(5);
                 aArgs[0].Value <<= (sal_Int32)nLevel;
 
-                mrController.dispatchCommand( msExtrusionLightingIntensity, aArgs );
+                mrController.dispatchCommand( g_sExtrusionLightingIntensity, aArgs );
 
                 implSetIntensity( nLevel, true );
             }
@@ -731,44 +792,39 @@ IMPL_LINK( ExtrusionLightingWindow, SelectHdl, void *, pControl )
             nDirection--;
 
             Sequence< PropertyValue > aArgs( 1 );
-            aArgs[0].Name = msExtrusionLightingDirection.copy(5);
-            aArgs[0].Value <<= (sal_Int32)nDirection;
+            aArgs[0].Name = OUString(g_sExtrusionLightingDirection).copy(5);
+            aArgs[0].Value <<= nDirection;
 
-            mrController.dispatchCommand( msExtrusionLightingDirection, aArgs );
+            mrController.dispatchCommand( g_sExtrusionLightingDirection, aArgs );
 
             implSetDirection( nDirection, true );
         }
 
     }
-
-    return 0;
 }
 
 
-
 ExtrusionLightingControl::ExtrusionLightingControl(
     const Reference< XComponentContext >& rxContext
 )   : svt::PopupWindowController( rxContext,
-                Reference< frame::XFrame >(),
-                OUString( ".uno:ExtrusionDirectionFloater" )
+                Reference< css::frame::XFrame >(),
+                ".uno:ExtrusionDirectionFloater"
     )
 {
 }
 
 
-
 VclPtr<vcl::Window> ExtrusionLightingControl::createPopupWindow( vcl::Window* pParent )
 {
-    return VclPtr<ExtrusionLightingWindow>::Create( *this, m_xFrame, pParent );
+    return VclPtr<ExtrusionLightingWindow>::Create( *this, pParent );
 }
 
 // XInitialization
 void SAL_CALL ExtrusionLightingControl::initialize( const css::uno::Sequence< css::uno::Any >& aArguments )
-    throw ( css::uno::Exception, css::uno::RuntimeException, std::exception )
 {
     svt::PopupWindowController::initialize( aArguments );
 
-    ToolBox* pToolBox = 0;
+    ToolBox* pToolBox = nullptr;
     sal_uInt16 nId = 0;
     if ( getToolboxId( nId, &pToolBox ) )
         pToolBox->SetItemBits( nId, pToolBox->GetItemBits( nId ) | ToolBoxItemBits::DROPDOWNONLY );
@@ -783,59 +839,54 @@ OUString SAL_CALL ExtrusionLightingControl_getImplementationName()
 }
 
 
-
-Sequence< OUString > SAL_CALL ExtrusionLightingControl_getSupportedServiceNames() throw( RuntimeException )
+Sequence< OUString > SAL_CALL ExtrusionLightingControl_getSupportedServiceNames()
 {
-    Sequence< OUString > aSNS( 1 );
-    aSNS.getArray()[0] = "com.sun.star.frame.ToolbarController";
+    Sequence<OUString> aSNS { "com.sun.star.frame.ToolbarController" };
     return aSNS;
 }
 
 
-
 Reference< XInterface > SAL_CALL SAL_CALL ExtrusionLightingControl_createInstance(
     const Reference< XMultiServiceFactory >& rSMgr
-)   throw( RuntimeException )
+)
 {
     return *new ExtrusionLightingControl( comphelper::getComponentContext(rSMgr) );
 }
 
 
-
-OUString SAL_CALL ExtrusionLightingControl::getImplementationName(  ) throw (RuntimeException, std::exception)
+OUString SAL_CALL ExtrusionLightingControl::getImplementationName(  )
 {
     return ExtrusionLightingControl_getImplementationName();
 }
 
 
-
-Sequence< OUString > SAL_CALL ExtrusionLightingControl::getSupportedServiceNames(  ) throw (RuntimeException, std::exception)
+Sequence< OUString > SAL_CALL ExtrusionLightingControl::getSupportedServiceNames(  )
 {
     return ExtrusionLightingControl_getSupportedServiceNames();
 }
 
+static const char g_sExtrusionSurface[] = ".uno:ExtrusionSurface";
+
 ExtrusionSurfaceWindow::ExtrusionSurfaceWindow(
     svt::ToolboxController& rController,
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
     vcl::Window* pParentWindow)
-    : ToolbarMenu(rFrame, pParentWindow, WB_MOVEABLE|WB_CLOSEABLE|WB_HIDE|WB_3DLOOK)
+    : ToolbarMenu(rController.getFrameInterface(), pParentWindow, WB_STDPOPUP)
     , mrController(rController)
-    , maImgSurface1(SVX_RES(RID_SVXIMG_WIRE_FRAME))
-    , maImgSurface2(SVX_RES(RID_SVXIMG_MATTE))
-    , maImgSurface3(SVX_RES(RID_SVXIMG_PLASTIC))
-    , maImgSurface4(SVX_RES(RID_SVXIMG_METAL))
-    , msExtrusionSurface(".uno:ExtrusionSurface")
+    , maImgSurface1(BitmapEx(RID_SVXBMP_WIRE_FRAME))
+    , maImgSurface2(BitmapEx(RID_SVXBMP_MATTE))
+    , maImgSurface3(BitmapEx(RID_SVXBMP_PLASTIC))
+    , maImgSurface4(BitmapEx(RID_SVXBMP_METAL))
 {
     SetSelectHdl( LINK( this, ExtrusionSurfaceWindow, SelectHdl ) );
 
-    appendEntry(0, SVX_RESSTR(RID_SVXSTR_WIREFRAME), maImgSurface1);
-    appendEntry(1, SVX_RESSTR(RID_SVXSTR_MATTE), maImgSurface2);
-    appendEntry(2, SVX_RESSTR(RID_SVXSTR_PLASTIC), maImgSurface3);
-    appendEntry(3, SVX_RESSTR(RID_SVXSTR_METAL), maImgSurface4);
+    appendEntry(0, SvxResId(RID_SVXSTR_WIREFRAME), maImgSurface1);
+    appendEntry(1, SvxResId(RID_SVXSTR_MATTE), maImgSurface2);
+    appendEntry(2, SvxResId(RID_SVXSTR_PLASTIC), maImgSurface3);
+    appendEntry(3, SvxResId(RID_SVXSTR_METAL), maImgSurface4);
 
     SetOutputSizePixel( getMenuSize() );
 
-    AddStatusListener( msExtrusionSurface );
+    AddStatusListener( g_sExtrusionSurface );
 }
 
 void ExtrusionSurfaceWindow::implSetSurface( int nSurface, bool bEnabled )
@@ -848,10 +899,10 @@ void ExtrusionSurfaceWindow::implSetSurface( int nSurface, bool bEnabled )
 }
 
 void ExtrusionSurfaceWindow::statusChanged(
-    const ::com::sun::star::frame::FeatureStateEvent& Event
-)   throw ( ::com::sun::star::uno::RuntimeException )
+    const css::frame::FeatureStateEvent& Event
+)
 {
-    if( Event.FeatureURL.Main.equals( msExtrusionSurface ) )
+    if( Event.FeatureURL.Main == g_sExtrusionSurface )
     {
         if( !Event.IsEnabled )
         {
@@ -867,8 +918,7 @@ void ExtrusionSurfaceWindow::statusChanged(
 }
 
 
-
-IMPL_LINK_NOARG(ExtrusionSurfaceWindow, SelectHdl)
+IMPL_LINK_NOARG(ExtrusionSurfaceWindow, SelectHdl, ToolbarMenu*, void)
 {
     if ( IsInPopupMode() )
         EndPopupMode();
@@ -877,44 +927,39 @@ IMPL_LINK_NOARG(ExtrusionSurfaceWindow, SelectHdl)
     if( nSurface >= 0 )
     {
         Sequence< PropertyValue > aArgs( 1 );
-        aArgs[0].Name = msExtrusionSurface.copy(5);
-        aArgs[0].Value <<= (sal_Int32)nSurface;
+        aArgs[0].Name = OUString(g_sExtrusionSurface).copy(5);
+        aArgs[0].Value <<= nSurface;
 
-        mrController.dispatchCommand( msExtrusionSurface, aArgs );
+        mrController.dispatchCommand( g_sExtrusionSurface, aArgs );
 
         implSetSurface( nSurface, true );
     }
-
-    return 0;
 }
 
 
-
 ExtrusionSurfaceControl::ExtrusionSurfaceControl(
     const Reference< XComponentContext >& rxContext
 )
 :   svt::PopupWindowController(
         rxContext,
-        Reference< frame::XFrame >(),
-        OUString( ".uno:ExtrusionSurfaceFloater" )
+        Reference< css::frame::XFrame >(),
+        ".uno:ExtrusionSurfaceFloater"
     )
 {
 }
 
 
-
 VclPtr<vcl::Window> ExtrusionSurfaceControl::createPopupWindow( vcl::Window* pParent )
 {
-    return VclPtr<ExtrusionSurfaceWindow>::Create( *this, m_xFrame, pParent );
+    return VclPtr<ExtrusionSurfaceWindow>::Create( *this, pParent );
 }
 
 // XInitialization
 void SAL_CALL ExtrusionSurfaceControl::initialize( const css::uno::Sequence< css::uno::Any >& aArguments )
-    throw ( css::uno::Exception, css::uno::RuntimeException, std::exception )
 {
     svt::PopupWindowController::initialize( aArguments );
 
-    ToolBox* pToolBox = 0;
+    ToolBox* pToolBox = nullptr;
     sal_uInt16 nId = 0;
     if ( getToolboxId( nId, &pToolBox ) )
         pToolBox->SetItemBits( nId, pToolBox->GetItemBits( nId ) | ToolBoxItemBits::DROPDOWNONLY );
@@ -929,33 +974,28 @@ OUString SAL_CALL ExtrusionSurfaceControl_getImplementationName()
 }
 
 
-
-Sequence< OUString > SAL_CALL ExtrusionSurfaceControl_getSupportedServiceNames() throw( RuntimeException )
+Sequence< OUString > SAL_CALL ExtrusionSurfaceControl_getSupportedServiceNames()
 {
-    Sequence< OUString > aSNS( 1 );
-    aSNS.getArray()[0] = "com.sun.star.frame.ToolbarController";
+    Sequence<OUString> aSNS { "com.sun.star.frame.ToolbarController" };
     return aSNS;
 }
 
 
-
 Reference< XInterface > SAL_CALL SAL_CALL ExtrusionSurfaceControl_createInstance(
     const Reference< XMultiServiceFactory >& rSMgr
-)   throw( RuntimeException )
+)
 {
     return *new ExtrusionSurfaceControl( comphelper::getComponentContext(rSMgr) );
 }
 
 
-
-OUString SAL_CALL ExtrusionSurfaceControl::getImplementationName(  ) throw (RuntimeException, std::exception)
+OUString SAL_CALL ExtrusionSurfaceControl::getImplementationName(  )
 {
     return ExtrusionSurfaceControl_getImplementationName();
 }
 
 
-
-Sequence< OUString > SAL_CALL ExtrusionSurfaceControl::getSupportedServiceNames(  ) throw (RuntimeException, std::exception)
+Sequence< OUString > SAL_CALL ExtrusionSurfaceControl::getSupportedServiceNames(  )
 {
     return ExtrusionSurfaceControl_getSupportedServiceNames();
 }
