@@ -37,8 +37,9 @@
 #include <tools/urlobj.hxx>
 #include <comphelper/processfactory.hxx>
 
-#include <svx/svxids.hrc>
 #include <svx/dialogs.hrc>
+#include <svx/svxids.hrc>
+#include <svx/strings.hrc>
 #include <editeng/brushitem.hxx>
 #include <editeng/sizeitem.hxx>
 #include <svx/sdgcpitm.hxx>
@@ -50,9 +51,9 @@
 #include <svx/svdograf.hxx>
 #include <svx/svdundo.hxx>
 #include <svx/svdtrans.hxx>
-#include "svx/grafctrl.hxx"
-#include "svx/tbxcolor.hxx"
-#include "bitmaps.hlst"
+#include <svx/grafctrl.hxx>
+#include <svx/tbxcolor.hxx>
+#include <bitmaps.hlst>
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::frame;
@@ -63,9 +64,8 @@ using namespace ::com::sun::star::lang;
 #include <svx/svxdlg.hxx>
 
 #define SYMBOL_TO_FIELD_OFFSET      4
-#define ITEMVALUE(ItemSet,Id,Cast)  static_cast<const Cast&>((ItemSet).Get(Id)).GetValue()
 #define TOOLBOX_NAME                "colorbar"
-
+#define RID_SVXSTR_UNDO_GRAFCROP    RID_SVXSTR_GRAFCROP
 
 class ImplGrafMetricField : public MetricField
 {
@@ -120,7 +120,6 @@ ImplGrafMetricField::ImplGrafMetricField( vcl::Window* pParent, const OUString&
         SetSpinSize( 1 );
     }
 
-    maIdle.SetPriority( TaskPriority::LOW );
     maIdle.SetInvokeHandler( LINK( this, ImplGrafMetricField, ImplModifyHdl ) );
 }
 
@@ -349,7 +348,7 @@ void ImplGrafModeControl::Select()
     {
         Sequence< PropertyValue > aArgs( 1 );
         aArgs[0].Name = "GrafMode";
-        aArgs[0].Value <<= sal_Int16( GetSelectEntryPos() );
+        aArgs[0].Value <<= sal_Int16( GetSelectedEntryPos() );
 
         /*  #i33380# DR 2004-09-03 Moved the following line above the Dispatch() call.
             This instance may be deleted in the meantime (i.e. when a dialog is opened
@@ -368,7 +367,7 @@ bool ImplGrafModeControl::PreNotify( NotifyEvent& rNEvt )
     MouseNotifyEvent nType = rNEvt.GetType();
 
     if( MouseNotifyEvent::MOUSEBUTTONDOWN == nType || MouseNotifyEvent::GETFOCUS == nType )
-        mnCurPos = GetSelectEntryPos();
+        mnCurPos = GetSelectedEntryPos();
 
     return ListBox::PreNotify( rNEvt );
 }
@@ -550,7 +549,7 @@ VclPtr<vcl::Window> SvxGrafModeToolBoxControl::CreateItemWindow( vcl::Window *pP
 void SvxGrafAttrHelper::ExecuteGrafAttr( SfxRequest& rReq, SdrView& rView )
 {
     SfxItemPool&    rPool = rView.GetModel()->GetItemPool();
-    SfxItemSet      aSet( rPool, SDRATTR_GRAF_FIRST, SDRATTR_GRAF_LAST );
+    SfxItemSet      aSet( rPool, svl::Items<SDRATTR_GRAF_FIRST, SDRATTR_GRAF_LAST>{} );
     OUString        aUndoStr;
     const bool      bUndo = rView.IsUndoEnabled();
 
@@ -669,7 +668,7 @@ void SvxGrafAttrHelper::ExecuteGrafAttr( SfxRequest& rReq, SdrView& rView )
                     ( pObj->GetGraphicType() != GraphicType::NONE ) &&
                     ( pObj->GetGraphicType() != GraphicType::Default ) )
                 {
-                    SfxItemSet          aGrfAttr( rPool, SDRATTR_GRAFCROP, SDRATTR_GRAFCROP, 0 );
+                    SfxItemSet          aGrfAttr( rPool, svl::Items<SDRATTR_GRAFCROP, SDRATTR_GRAFCROP>{} );
                     const MapUnit       eOldMetric = rPool.GetMetric( 0 );
                     const MapMode       aMap100( MapUnit::Map100thMM );
                     const MapMode       aMapTwip( MapUnit::MapTwip );
@@ -677,21 +676,22 @@ void SvxGrafAttrHelper::ExecuteGrafAttr( SfxRequest& rReq, SdrView& rView )
                     aGrfAttr.Put(pObj->GetMergedItemSet());
                     rPool.SetDefaultMetric( MapUnit::MapTwip );
 
-                    SfxItemSet  aCropDlgAttr( rPool,
-                                            SDRATTR_GRAFCROP, SDRATTR_GRAFCROP,
-                                            SID_ATTR_GRAF_GRAPHIC, SID_ATTR_GRAF_GRAPHIC,
-                                            SID_ATTR_PAGE_SIZE, SID_ATTR_PAGE_SIZE,
-                                            SID_ATTR_GRAF_FRMSIZE, SID_ATTR_GRAF_FRMSIZE,
-                                            SID_ATTR_GRAF_CROP, SID_ATTR_GRAF_CROP, 0 );
+                    SfxItemSet  aCropDlgAttr(
+                        rPool,
+                        svl::Items<
+                            SDRATTR_GRAFCROP, SDRATTR_GRAFCROP,
+                            SID_ATTR_PAGE_SIZE, SID_ATTR_PAGE_SIZE,
+                            SID_ATTR_GRAF_CROP, SID_ATTR_GRAF_FRMSIZE,
+                            SID_ATTR_GRAF_GRAPHIC, SID_ATTR_GRAF_GRAPHIC>{});
 
                     aCropDlgAttr.Put( SvxBrushItem( pObj->GetGraphic(), GPOS_MM, SID_ATTR_GRAF_GRAPHIC ) );
                     aCropDlgAttr.Put( SvxSizeItem( SID_ATTR_PAGE_SIZE,
-                                                Size( OutputDevice::LogicToLogic(
-                                                        Size( 200000, 200000 ), aMap100, aMapTwip ) ) ) );
+                                                OutputDevice::LogicToLogic(
+                                                        Size( 200000, 200000 ), aMap100, aMapTwip ) ) );
                     aCropDlgAttr.Put( SvxSizeItem( SID_ATTR_GRAF_FRMSIZE, OutputDevice::LogicToLogic(
                                                 pObj->GetLogicRect().GetSize(), aMap100, aMapTwip ) ) );
 
-                    const SdrGrafCropItem&  rCrop = static_cast<const SdrGrafCropItem&>( aGrfAttr.Get( SDRATTR_GRAFCROP ) );
+                    const SdrGrafCropItem&  rCrop = aGrfAttr.Get( SDRATTR_GRAFCROP );
                     Size                    aLTSize( OutputDevice::LogicToLogic(
                                                     Size( rCrop.GetLeft(), rCrop.GetTop() ), aMap100, aMapTwip ) );
                     Size                    aRBSize( OutputDevice::LogicToLogic(
@@ -725,7 +725,7 @@ void SvxGrafAttrHelper::ExecuteGrafAttr( SfxRequest& rReq, SdrView& rView )
                             // set crop attributes
                             if( SfxItemState::SET <= pOutAttr->GetItemState( SDRATTR_GRAFCROP ) )
                             {
-                                const SdrGrafCropItem& rNewCrop = static_cast<const SdrGrafCropItem&>( pOutAttr->Get( SDRATTR_GRAFCROP ) );
+                                const SdrGrafCropItem& rNewCrop = pOutAttr->Get( SDRATTR_GRAFCROP );
 
                                 aLTSize = OutputDevice::LogicToLogic( Size( rNewCrop.GetLeft(), rNewCrop.GetTop() ), aMapTwip, aMap100 );
                                 aRBSize = OutputDevice::LogicToLogic( Size( rNewCrop.GetRight(), rNewCrop.GetBottom() ), aMapTwip, aMap100 );
@@ -826,7 +826,7 @@ void SvxGrafAttrHelper::ExecuteGrafAttr( SfxRequest& rReq, SdrView& rView )
     }
 }
 
-void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView& rView )
+void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView const & rView )
 {
     SfxItemPool&    rPool = rView.GetModel()->GetItemPool();
     SfxItemSet      aAttrSet( rPool );
@@ -869,7 +869,7 @@ void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView& rView )
                     if( bEnableColors )
                     {
                         rSet.Put( SfxUInt16Item( nSlotId,
-                            sal::static_int_cast< sal_uInt16 >( ITEMVALUE( aAttrSet, SDRATTR_GRAFMODE, SdrGrafModeItem ) ) ) );
+                            sal::static_int_cast< sal_uInt16 >( aAttrSet.Get(SDRATTR_GRAFMODE).GetValue() ) ) );
                     }
                     else
                     {
@@ -885,8 +885,7 @@ void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView& rView )
                 {
                     if( bEnableColors )
                     {
-                        rSet.Put( SfxInt16Item( nSlotId,
-                            ITEMVALUE( aAttrSet, SDRATTR_GRAFRED, SdrGrafRedItem ) ) );
+                        rSet.Put( SfxInt16Item( nSlotId, aAttrSet.Get(SDRATTR_GRAFRED).GetValue() ) );
                     }
                     else
                     {
@@ -902,8 +901,7 @@ void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView& rView )
                 {
                     if( bEnableColors )
                     {
-                        rSet.Put( SfxInt16Item( nSlotId,
-                            ITEMVALUE( aAttrSet, SDRATTR_GRAFGREEN, SdrGrafGreenItem ) ) );
+                        rSet.Put( SfxInt16Item( nSlotId, aAttrSet.Get(SDRATTR_GRAFGREEN).GetValue()) );
                     }
                     else
                     {
@@ -919,8 +917,7 @@ void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView& rView )
                 {
                     if( bEnableColors )
                     {
-                        rSet.Put( SfxInt16Item( nSlotId,
-                            ITEMVALUE( aAttrSet, SDRATTR_GRAFBLUE, SdrGrafBlueItem ) ) );
+                        rSet.Put( SfxInt16Item( nSlotId, aAttrSet.Get(SDRATTR_GRAFBLUE).GetValue()) );
                     }
                     else
                     {
@@ -936,8 +933,7 @@ void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView& rView )
                 {
                     if( bEnableColors )
                     {
-                        rSet.Put( SfxInt16Item( nSlotId,
-                            ITEMVALUE( aAttrSet, SDRATTR_GRAFLUMINANCE, SdrGrafLuminanceItem ) ) );
+                        rSet.Put( SfxInt16Item( nSlotId, aAttrSet.Get(SDRATTR_GRAFLUMINANCE).GetValue()) );
                     }
                     else
                     {
@@ -954,7 +950,7 @@ void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView& rView )
                     if( bEnableColors )
                     {
                         rSet.Put( SfxInt16Item( nSlotId,
-                            ITEMVALUE( aAttrSet, SDRATTR_GRAFCONTRAST, SdrGrafContrastItem ) ) );
+                            aAttrSet.Get(SDRATTR_GRAFCONTRAST).GetValue()) );
                     }
                     else
                     {
@@ -971,7 +967,7 @@ void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView& rView )
                     if( bEnableColors )
                     {
                         rSet.Put( SfxUInt32Item( nSlotId,
-                            ITEMVALUE( aAttrSet, SDRATTR_GRAFGAMMA, SdrGrafGamma100Item ) ) );
+                            aAttrSet.Get(SDRATTR_GRAFGAMMA).GetValue() ) );
                     }
                     else
                     {
@@ -988,7 +984,7 @@ void SvxGrafAttrHelper::GetGrafAttrState( SfxItemSet& rSet, SdrView& rView )
                     if( bEnableTransparency )
                     {
                         rSet.Put( SfxUInt16Item( nSlotId,
-                            ITEMVALUE( aAttrSet, SDRATTR_GRAFTRANSPARENCE, SdrGrafTransparenceItem ) ) );
+                            aAttrSet.Get(SDRATTR_GRAFTRANSPARENCE).GetValue() ) );
                     }
                     else
                     {
