@@ -29,7 +29,8 @@
 #include <vcl/settings.hxx>
 #include <vcl/builderfactory.hxx>
 
-#include <svx/dialogs.hrc>
+#include <svx/strings.hrc>
+#include <svx/svxids.hrc>
 
 #define DELAY_TIMEOUT           100
 
@@ -38,17 +39,16 @@
 #include <svx/xlineit0.hxx>
 #include <svx/xlndsit.hxx>
 #include <svx/xtable.hxx>
-#include "svx/drawitem.hxx"
+#include <svx/drawitem.hxx>
 #include <svx/dialmgr.hxx>
-#include "svx/dlgutil.hxx"
+#include <svx/dlgutil.hxx>
 #include <svx/itemwin.hxx>
-#include "svx/linectrl.hxx"
+#include <svx/linectrl.hxx>
 #include <svtools/colorcfg.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::frame;
-using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::beans;
 
@@ -60,7 +60,7 @@ SvxLineBox::SvxLineBox( vcl::Window* pParent, const Reference< XFrame >& rFrame
     mpSh        ( nullptr ),
     mxFrame     ( rFrame )
 {
-    SetSizePixel( LogicToPixel( aLogicalSize, MapUnit::MapAppFont ));
+    SetSizePixel(LogicToPixel(aLogicalSize, MapMode(MapUnit::MapAppFont)));
     Show();
 
     aDelayTimer.SetTimeout( DELAY_TIMEOUT );
@@ -84,62 +84,62 @@ void SvxLineBox::Select()
     // Call the parent's Select() member to trigger accessibility events.
     LineLB::Select();
 
-    if ( !IsTravelSelect() )
+    if ( IsTravelSelect() )
+        return;
+
+    drawing::LineStyle eXLS;
+    sal_Int32 nPos = GetSelectedEntryPos();
+
+    switch ( nPos )
     {
-        drawing::LineStyle eXLS;
-        sal_Int32 nPos = GetSelectEntryPos();
-
-        switch ( nPos )
-        {
-            case 0:
-                eXLS = drawing::LineStyle_NONE;
-                break;
-
-            case 1:
-                eXLS = drawing::LineStyle_SOLID;
-                break;
-
-            default:
-            {
-                eXLS = drawing::LineStyle_DASH;
-
-                if ( nPos != LISTBOX_ENTRY_NOTFOUND &&
-                     SfxObjectShell::Current()  &&
-                     SfxObjectShell::Current()->GetItem( SID_DASH_LIST ) )
-                {
-                    // LineDashItem will only be sent if it also has a dash.
-                    // Notify cares!
-                    SvxDashListItem aItem( *static_cast<const SvxDashListItem*>(
-                        SfxObjectShell::Current()->GetItem( SID_DASH_LIST ) ) );
-                    XLineDashItem aLineDashItem( GetSelectEntry(),
-                        aItem.GetDashList()->GetDash( nPos - 2 )->GetDash() );
-
-                    Any a;
-                    Sequence< PropertyValue > aArgs( 1 );
-                    aArgs[0].Name = "LineDash";
-                    aLineDashItem.QueryValue ( a );
-                    aArgs[0].Value = a;
-                    SfxToolBoxControl::Dispatch( Reference< XDispatchProvider >( mxFrame->getController(), UNO_QUERY ),
-                                                 ".uno:LineDash",
-                                                 aArgs );
-                }
-            }
+        case 0:
+            eXLS = drawing::LineStyle_NONE;
             break;
+
+        case 1:
+            eXLS = drawing::LineStyle_SOLID;
+            break;
+
+        default:
+        {
+            eXLS = drawing::LineStyle_DASH;
+
+            if ( nPos != LISTBOX_ENTRY_NOTFOUND &&
+                 SfxObjectShell::Current()  &&
+                 SfxObjectShell::Current()->GetItem( SID_DASH_LIST ) )
+            {
+                // LineDashItem will only be sent if it also has a dash.
+                // Notify cares!
+                SvxDashListItem aItem( *static_cast<const SvxDashListItem*>(
+                    SfxObjectShell::Current()->GetItem( SID_DASH_LIST ) ) );
+                XLineDashItem aLineDashItem( GetSelectedEntry(),
+                    aItem.GetDashList()->GetDash( nPos - 2 )->GetDash() );
+
+                Any a;
+                Sequence< PropertyValue > aArgs( 1 );
+                aArgs[0].Name = "LineDash";
+                aLineDashItem.QueryValue ( a );
+                aArgs[0].Value = a;
+                SfxToolBoxControl::Dispatch( Reference< XDispatchProvider >( mxFrame->getController(), UNO_QUERY ),
+                                             ".uno:LineDash",
+                                             aArgs );
+            }
         }
-
-        XLineStyleItem aLineStyleItem( eXLS );
-        Any a;
-        Sequence< PropertyValue > aArgs( 1 );
-        aArgs[0].Name = "XLineStyle";
-        aLineStyleItem.QueryValue ( a );
-        aArgs[0].Value = a;
-        SfxToolBoxControl::Dispatch( Reference< XDispatchProvider >( mxFrame->getController(), UNO_QUERY ),
-                                     ".uno:XLineStyle",
-                                     aArgs );
-
-        nCurPos = GetSelectEntryPos();
-        ReleaseFocus_Impl();
+        break;
     }
+
+    XLineStyleItem aLineStyleItem( eXLS );
+    Any a;
+    Sequence< PropertyValue > aArgs( 1 );
+    aArgs[0].Name = "XLineStyle";
+    aLineStyleItem.QueryValue ( a );
+    aArgs[0].Value = a;
+    SfxToolBoxControl::Dispatch( Reference< XDispatchProvider >( mxFrame->getController(), UNO_QUERY ),
+                                 ".uno:XLineStyle",
+                                 aArgs );
+
+    nCurPos = GetSelectedEntryPos();
+    ReleaseFocus_Impl();
 }
 
 
@@ -151,7 +151,7 @@ bool SvxLineBox::PreNotify( NotifyEvent& rNEvt )
     {
         case MouseNotifyEvent::MOUSEBUTTONDOWN:
         case MouseNotifyEvent::GETFOCUS:
-            nCurPos = GetSelectEntryPos();
+            nCurPos = GetSelectedEntryPos();
         break;
         case MouseNotifyEvent::LOSEFOCUS:
             SelectEntryPos(nCurPos);
@@ -221,7 +221,7 @@ void SvxLineBox::DataChanged( const DataChangedEvent& rDCEvt )
     if ( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) &&
          (rDCEvt.GetFlags() & AllSettingsFlags::STYLE) )
     {
-        SetSizePixel(LogicToPixel(aLogicalSize, MapUnit::MapAppFont));
+        SetSizePixel(LogicToPixel(aLogicalSize, MapMode(MapUnit::MapAppFont)));
     }
 
     LineLB::DataChanged( rDCEvt );
@@ -250,7 +250,7 @@ SvxMetricField::SvxMetricField(
 {
     Size aSize( CalcMinimumSize() );
     SetSizePixel( aSize );
-    aLogicalSize = PixelToLogic(aSize, MapUnit::MapAppFont);
+    aLogicalSize = PixelToLogic(aSize, MapMode(MapUnit::MapAppFont));
     SetUnit( FUNIT_MM );
     SetDecimalDigits( 2 );
     SetMax( 5000 );
@@ -374,7 +374,7 @@ void SvxMetricField::DataChanged( const DataChangedEvent& rDCEvt )
     if ( (rDCEvt.GetType() == DataChangedEventType::SETTINGS) &&
          (rDCEvt.GetFlags() & AllSettingsFlags::STYLE) )
     {
-        SetSizePixel(LogicToPixel(aLogicalSize, MapUnit::MapAppFont));
+        SetSizePixel(LogicToPixel(aLogicalSize, MapMode(MapUnit::MapAppFont)));
     }
 
     MetricField::DataChanged( rDCEvt );
@@ -383,10 +383,9 @@ void SvxMetricField::DataChanged( const DataChangedEvent& rDCEvt )
 SvxFillTypeBox::SvxFillTypeBox( vcl::Window* pParent ) :
     FillTypeLB( pParent, WB_BORDER | WB_DROPDOWN | WB_AUTOHSCROLL | WB_TABSTOP ),
     nCurPos ( 0 ),
-    bSelect ( false ),
-    bRelease( true )
+    bSelect ( false )
 {
-    SetSizePixel( LogicToPixel( Size(40, 40 ),MapUnit::MapAppFont ));
+    SetSizePixel(LogicToPixel(Size(40, 40), MapMode(MapUnit::MapAppFont)));
     Fill();
     SelectEntryPos( (sal_Int32)drawing::FillStyle_SOLID );
     Show();
@@ -401,7 +400,7 @@ bool SvxFillTypeBox::PreNotify( NotifyEvent& rNEvt )
     if (!isDisposed())
     {
         if ( MouseNotifyEvent::MOUSEBUTTONDOWN == nType || MouseNotifyEvent::GETFOCUS == nType )
-            nCurPos = GetSelectEntryPos();
+            nCurPos = GetSelectedEntryPos();
         else if ( MouseNotifyEvent::LOSEFOCUS == nType
                   && Application::GetFocusWindow()
                   && !IsWindowOrChild( Application::GetFocusWindow(), true ) )
@@ -433,10 +432,9 @@ bool SvxFillTypeBox::EventNotify( NotifyEvent& rNEvt )
                 bHandled = true;
                 GetSelectHdl().Call( *this );
             break;
+
             case KEY_TAB:
-                bRelease = false;
                 GetSelectHdl().Call( *this );
-                bRelease = true;
                 break;
 
             case KEY_ESCAPE:
@@ -462,13 +460,11 @@ void SvxFillTypeBox::ReleaseFocus_Impl()
 }
 
 SvxFillAttrBox::SvxFillAttrBox( vcl::Window* pParent ) :
-    FillAttrLB( pParent, WB_BORDER | WB_DROPDOWN | WB_AUTOHSCROLL | WB_TABSTOP ),
-    nCurPos( 0 ),
-    bRelease( true )
-
+    ListBox(pParent, WB_BORDER | WB_DROPDOWN | WB_AUTOHSCROLL | WB_TABSTOP),
+    nCurPos( 0 )
 {
     SetPosPixel( Point( 90, 0 ) );
-    SetSizePixel( LogicToPixel( Size(50, 80 ), MapUnit::MapAppFont ));
+    SetSizePixel(LogicToPixel(Size(50, 80), MapMode(MapUnit::MapAppFont)));
     Show();
 }
 
@@ -479,15 +475,15 @@ bool SvxFillAttrBox::PreNotify( NotifyEvent& rNEvt )
     MouseNotifyEvent nType = rNEvt.GetType();
 
     if ( MouseNotifyEvent::MOUSEBUTTONDOWN == nType || MouseNotifyEvent::GETFOCUS == nType )
-        nCurPos = GetSelectEntryPos();
+        nCurPos = GetSelectedEntryPos();
 
-    return FillAttrLB::PreNotify( rNEvt );
+    return ListBox::PreNotify( rNEvt );
 }
 
 
 bool SvxFillAttrBox::EventNotify( NotifyEvent& rNEvt )
 {
-    bool bHandled = FillAttrLB::EventNotify( rNEvt );
+    bool bHandled = ListBox::EventNotify( rNEvt );
 
     if ( rNEvt.GetType() == MouseNotifyEvent::KEYINPUT )
     {
@@ -500,9 +496,7 @@ bool SvxFillAttrBox::EventNotify( NotifyEvent& rNEvt )
                 bHandled = true;
             break;
             case KEY_TAB:
-                bRelease = false;
                 GetSelectHdl().Call( *this );
-                bRelease = true;
             break;
             case KEY_ESCAPE:
                 SelectEntryPos( nCurPos );
@@ -526,4 +520,142 @@ void SvxFillAttrBox::ReleaseFocus_Impl()
     }
 }
 
+// Fills the listbox (provisional) with strings
+
+void SvxFillAttrBox::Fill( const XHatchListRef &pList )
+{
+    long nCount = pList->Count();
+    ListBox::SetUpdateMode( false );
+
+    for( long i = 0; i < nCount; i++ )
+    {
+        const XHatchEntry* pEntry = pList->GetHatch(i);
+        const Bitmap aBitmap = pList->GetUiBitmap( i );
+        if( !aBitmap.IsEmpty() )
+            ListBox::InsertEntry(pEntry->GetName(), Image(aBitmap));
+        else
+            InsertEntry( pEntry->GetName() );
+    }
+
+    AdaptDropDownLineCountToMaximum();
+    ListBox::SetUpdateMode( true );
+}
+
+// Fills the listbox (provisional) with strings
+
+void SvxFillAttrBox::Fill( const XGradientListRef &pList )
+{
+    long nCount = pList->Count();
+    ListBox::SetUpdateMode( false );
+
+    for( long i = 0; i < nCount; i++ )
+    {
+        const XGradientEntry* pEntry = pList->GetGradient(i);
+        const Bitmap aBitmap = pList->GetUiBitmap( i );
+        if( !aBitmap.IsEmpty() )
+            ListBox::InsertEntry(pEntry->GetName(), Image(aBitmap));
+        else
+            InsertEntry( pEntry->GetName() );
+    }
+
+    AdaptDropDownLineCountToMaximum();
+    ListBox::SetUpdateMode( true );
+}
+
+namespace
+{
+    void formatBitmapExToSize(BitmapEx& rBitmapEx, const Size& rSize)
+    {
+        if(!rBitmapEx.IsEmpty() && rSize.Width() > 0 && rSize.Height() > 0)
+        {
+            ScopedVclPtrInstance< VirtualDevice > pVirtualDevice;
+            pVirtualDevice->SetOutputSizePixel(rSize);
+
+            if(rBitmapEx.IsTransparent())
+            {
+                const StyleSettings& rStyleSettings = Application::GetSettings().GetStyleSettings();
+
+                if(rStyleSettings.GetPreviewUsesCheckeredBackground())
+                {
+                    const Point aNull(0, 0);
+                    static const sal_uInt32 nLen(8);
+                    static const Color aW(COL_WHITE);
+                    static const Color aG(0xef, 0xef, 0xef);
+
+                    pVirtualDevice->DrawCheckered(aNull, rSize, nLen, aW, aG);
+                }
+                else
+                {
+                    pVirtualDevice->SetBackground(rStyleSettings.GetFieldColor());
+                    pVirtualDevice->Erase();
+                }
+            }
+
+            if(rBitmapEx.GetSizePixel().Width() >= rSize.Width() && rBitmapEx.GetSizePixel().Height() >= rSize.Height())
+            {
+                rBitmapEx.Scale(rSize);
+                pVirtualDevice->DrawBitmapEx(Point(0, 0), rBitmapEx);
+            }
+            else
+            {
+                const Size aBitmapSize(rBitmapEx.GetSizePixel());
+
+                for(long y(0); y < rSize.Height(); y += aBitmapSize.Height())
+                {
+                    for(long x(0); x < rSize.Width(); x += aBitmapSize.Width())
+                    {
+                        pVirtualDevice->DrawBitmapEx(
+                            Point(x, y),
+                            rBitmapEx);
+                    }
+                }
+            }
+
+            rBitmapEx = pVirtualDevice->GetBitmap(Point(0, 0), rSize);
+        }
+    }
+} // end of anonymous namespace
+
+void SvxFillAttrBox::Fill( const XBitmapListRef &pList )
+{
+    const long nCount(pList->Count());
+    const XBitmapEntry* pEntry;
+    const StyleSettings& rStyleSettings = Application::GetSettings().GetStyleSettings();
+    const Size aSize(rStyleSettings.GetListBoxPreviewDefaultPixelSize());
+
+    ListBox::SetUpdateMode(false);
+
+    for(long i(0); i < nCount; i++)
+    {
+        pEntry = pList->GetBitmap( i );
+        maBitmapEx = pEntry->GetGraphicObject().GetGraphic().GetBitmapEx();
+        formatBitmapExToSize(maBitmapEx, aSize);
+        ListBox::InsertEntry(pEntry->GetName(), Image(maBitmapEx));
+    }
+
+    AdaptDropDownLineCountToMaximum();
+    ListBox::SetUpdateMode(true);
+}
+
+void SvxFillAttrBox::Fill( const XPatternListRef &pList )
+{
+    const long nCount(pList->Count());
+    const XBitmapEntry* pEntry;
+    const StyleSettings& rStyleSettings = Application::GetSettings().GetStyleSettings();
+    const Size aSize(rStyleSettings.GetListBoxPreviewDefaultPixelSize());
+
+    ListBox::SetUpdateMode(false);
+
+    for(long i(0); i < nCount; i++)
+    {
+        pEntry = pList->GetBitmap( i );
+        maBitmapEx = pEntry->GetGraphicObject().GetGraphic().GetBitmapEx();
+        formatBitmapExToSize(maBitmapEx, aSize);
+        ListBox::InsertEntry(pEntry->GetName(), Image(maBitmapEx));
+    }
+
+    AdaptDropDownLineCountToMaximum();
+    ListBox::SetUpdateMode(true);
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
