@@ -25,7 +25,6 @@
 #include <com/sun/star/xml/sax/Parser.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/xml/sax/XDocumentHandler.hpp>
-#include <com/sun/star/uno/Sequence.hxx>
 #include <com/sun/star/drawing/PolyPolygonBezierCoords.hpp>
 #include <com/sun/star/drawing/LineDash.hpp>
 #include <com/sun/star/awt/Gradient.hpp>
@@ -38,21 +37,21 @@
 #include <rtl/ustrbuf.hxx>
 #include <sax/tools/converter.hxx>
 #include <sfx2/docfile.hxx>
-#include "xmloff/xmlnmspe.hxx"
-#include "xmloff/nmspmap.hxx"
+#include <xmloff/xmlnmspe.hxx>
+#include <xmloff/nmspmap.hxx>
 
-#include "xmloff/xmltoken.hxx"
-#include "xmloff/xmlmetae.hxx"
-#include "xmloff/DashStyle.hxx"
-#include "xmloff/GradientStyle.hxx"
-#include "xmloff/HatchStyle.hxx"
-#include "xmloff/ImageStyle.hxx"
-#include "xmloff/MarkerStyle.hxx"
+#include <xmloff/xmltoken.hxx>
+#include <xmloff/xmlmetae.hxx>
+#include <xmloff/DashStyle.hxx>
+#include <xmloff/GradientStyle.hxx>
+#include <xmloff/HatchStyle.hxx>
+#include <xmloff/ImageStyle.hxx>
+#include <xmloff/MarkerStyle.hxx>
 #include <xmloff/xmlictxt.hxx>
-#include "svx/xmlgrhlp.hxx"
-#include "xmloff/attrlist.hxx"
+#include <svx/xmlgrhlp.hxx>
+#include <xmloff/attrlist.hxx>
 
-#include "xmlxtimp.hxx"
+#include <xmlxtimp.hxx>
 
 #include <cstdio>
 
@@ -63,41 +62,27 @@ using namespace com::sun::star::uno;
 using namespace com::sun::star::awt;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::xml::sax;
-using namespace ::rtl;
 using namespace ::xmloff::token;
 using namespace cppu;
 
-sal_Char const sXML_np__office[] = "__office";
-sal_Char const sXML_np__office_ooo[] = "___office";
-sal_Char const sXML_np__draw[] = "__draw";
-sal_Char const sXML_np__draw_ooo[] = "___draw";
-sal_Char const sXML_np__ooo[] = "__ooo";
-sal_Char const sXML_np__xlink[] = "__xlink";
+enum class SvxXMLTableImportContextEnum { Color, Marker, Dash, Hatch, Gradient, Bitmap };
 
-///////////////////////////////////////////////////////////////////////
-
-enum SvxXMLTableImportContextEnum { stice_unknown, stice_color, stice_marker, stice_dash, stice_hatch, stice_gradient, stice_bitmap };
-
-///////////////////////////////////////////////////////////////////////
 
 class SvxXMLTableImportContext : public SvXMLImportContext
 {
 public:
-    SvxXMLTableImportContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName, const uno::Reference< XAttributeList >& xAttrList, SvxXMLTableImportContextEnum eContext, const uno::Reference< XNameContainer >& xTable,
+    SvxXMLTableImportContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName, SvxXMLTableImportContextEnum eContext, const uno::Reference< XNameContainer >& xTable,
         bool bOOoFormat );
-    virtual ~SvxXMLTableImportContext();
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList );
-
-    SvxXMLXTableImport& getImport() const { return *(SvxXMLXTableImport*)&GetImport(); }
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList ) override;
 
 protected:
-    void importColor( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importMarker( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importDash( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importHatch( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importGradient( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
-    void importBitmap( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importColor( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importMarker( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importDash( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importHatch( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importGradient( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
+    void importBitmap( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName );
 
 private:
     uno::Reference< XNameContainer > mxTable;
@@ -105,26 +90,21 @@ private:
     bool mbOOoFormat;
 };
 
-///////////////////////////////////////////////////////////////////////
 
-SvxXMLTableImportContext::SvxXMLTableImportContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName, const uno::Reference< XAttributeList >&, SvxXMLTableImportContextEnum eContext, const uno::Reference< XNameContainer >& xTable, bool bOOoFormat )
+SvxXMLTableImportContext::SvxXMLTableImportContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName, SvxXMLTableImportContextEnum eContext, const uno::Reference< XNameContainer >& xTable, bool bOOoFormat )
 : SvXMLImportContext( rImport, nPrfx, rLName ), mxTable( xTable ), meContext( eContext ),
     mbOOoFormat( bOOoFormat )
 {
 }
 
-SvxXMLTableImportContext::~SvxXMLTableImportContext()
-{
-}
-
-SvXMLImportContext *SvxXMLTableImportContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& rAttrList )
+SvXMLImportContextRef SvxXMLTableImportContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& rAttrList )
 {
     if( XML_NAMESPACE_DRAW == nPrefix )
     {
         uno::Reference< XAttributeList > xAttrList( rAttrList );
         if( mbOOoFormat &&
-             (stice_dash == meContext || stice_hatch == meContext ||
-             stice_bitmap == meContext) )
+             (SvxXMLTableImportContextEnum::Dash == meContext || SvxXMLTableImportContextEnum::Hatch == meContext ||
+             SvxXMLTableImportContextEnum::Bitmap == meContext) )
         {
             SvXMLAttributeList *pAttrList = new SvXMLAttributeList( rAttrList );
             xAttrList = pAttrList;
@@ -137,7 +117,7 @@ SvXMLImportContext *SvxXMLTableImportContext::CreateChildContext( sal_uInt16 nPr
                     GetImport().GetNamespaceMap().GetKeyByAttrName( rAttrName,
                                                                 &aLocalName );
                 if( XML_NAMESPACE_XLINK == nPrefix_ &&
-                    stice_bitmap == meContext &&
+                    SvxXMLTableImportContextEnum::Bitmap == meContext &&
                     IsXMLToken( aLocalName, XML_HREF ) )
                 {
                     const OUString rValue = xAttrList->getValueByIndex( i );
@@ -145,11 +125,11 @@ SvXMLImportContext *SvxXMLTableImportContext::CreateChildContext( sal_uInt16 nPr
                         pAttrList->SetValueByIndex( i, rValue.copy( 1 ) );
                 }
                 else if( XML_NAMESPACE_DRAW == nPrefix_ &&
-                          ( ( stice_dash == meContext &&
+                          ( ( SvxXMLTableImportContextEnum::Dash == meContext &&
                               (IsXMLToken( aLocalName, XML_DOTS1_LENGTH ) ||
                                IsXMLToken( aLocalName, XML_DOTS2_LENGTH ) ||
                                IsXMLToken( aLocalName, XML_DISTANCE )) ) ||
-                            ( stice_hatch == meContext &&
+                            ( SvxXMLTableImportContextEnum::Hatch == meContext &&
                               IsXMLToken( aLocalName, XML_HATCH_DISTANCE ) ) ) )
                 {
                     const OUString rValue = xAttrList->getValueByIndex( i );
@@ -172,25 +152,23 @@ SvXMLImportContext *SvxXMLTableImportContext::CreateChildContext( sal_uInt16 nPr
 
             switch( meContext )
             {
-            case stice_color:
-                importColor( nPrefix, rLocalName, xAttrList, aAny, aName );
+            case SvxXMLTableImportContextEnum::Color:
+                importColor( xAttrList, aAny, aName );
                 break;
-            case stice_marker:
-                importMarker( nPrefix, rLocalName, xAttrList, aAny, aName  );
+            case SvxXMLTableImportContextEnum::Marker:
+                importMarker( xAttrList, aAny, aName  );
                 break;
-            case stice_dash:
-                importDash( nPrefix, rLocalName, xAttrList, aAny, aName  );
+            case SvxXMLTableImportContextEnum::Dash:
+                importDash( xAttrList, aAny, aName  );
                 break;
-            case stice_hatch:
-                importHatch( nPrefix, rLocalName, xAttrList, aAny, aName  );
+            case SvxXMLTableImportContextEnum::Hatch:
+                importHatch( xAttrList, aAny, aName  );
                 break;
-            case stice_gradient:
-                importGradient( nPrefix, rLocalName, xAttrList, aAny, aName  );
+            case SvxXMLTableImportContextEnum::Gradient:
+                importGradient( xAttrList, aAny, aName  );
                 break;
-            case stice_bitmap:
-                importBitmap( nPrefix, rLocalName, xAttrList, aAny, aName  );
-                break;
-            case stice_unknown:
+            case SvxXMLTableImportContextEnum::Bitmap:
+                importBitmap( xAttrList, aAny, aName  );
                 break;
             }
 
@@ -214,11 +192,8 @@ SvXMLImportContext *SvxXMLTableImportContext::CreateChildContext( sal_uInt16 nPr
     return new SvXMLImportContext( GetImport(), nPrefix, rLocalName );
 }
 
-void SvxXMLTableImportContext::importColor( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importColor( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
-    (void)nPrfx;
-    (void)rLocalName;
-
     const sal_Int16 nAttrCount = xAttrList.is() ? xAttrList->getLength() : 0;
     for( sal_Int16 i=0; i < nAttrCount; i++ )
     {
@@ -244,11 +219,8 @@ void SvxXMLTableImportContext::importColor( sal_uInt16 nPrfx, const OUString& rL
     }
 }
 
-void SvxXMLTableImportContext::importMarker( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importMarker( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
-    (void)nPrfx;
-    (void)rLocalName;
-
     try
     {
         XMLMarkerStyleImport aMarkerStyle( GetImport() );
@@ -260,11 +232,8 @@ void SvxXMLTableImportContext::importMarker( sal_uInt16 nPrfx, const OUString& r
     }
 }
 
-void SvxXMLTableImportContext::importDash( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importDash( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
-    (void)nPrfx;
-    (void)rLocalName;
-
     try
     {
         XMLDashStyleImport aDashStyle( GetImport() );
@@ -276,11 +245,8 @@ void SvxXMLTableImportContext::importDash( sal_uInt16 nPrfx, const OUString& rLo
     }
 }
 
-void SvxXMLTableImportContext::importHatch( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importHatch( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
-    (void)nPrfx;
-    (void)rLocalName;
-
     try
     {
         XMLHatchStyleImport aHatchStyle( GetImport() );
@@ -292,11 +258,8 @@ void SvxXMLTableImportContext::importHatch( sal_uInt16 nPrfx, const OUString& rL
     }
 }
 
-void SvxXMLTableImportContext::importGradient( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importGradient( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
-    (void)nPrfx;
-    (void)rLocalName;
-
     try
     {
         XMLGradientStyleImport aGradientStyle( GetImport() );
@@ -308,15 +271,12 @@ void SvxXMLTableImportContext::importGradient( sal_uInt16 nPrfx, const OUString&
     }
 }
 
-void SvxXMLTableImportContext::importBitmap( sal_uInt16 nPrfx, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
+void SvxXMLTableImportContext::importBitmap( const uno::Reference< XAttributeList >& xAttrList, Any& rAny, OUString& rName )
 {
-    (void)nPrfx;
-    (void)rLocalName;
-
     try
     {
         XMLImageStyle aImageStyle;
-        aImageStyle.importXML( xAttrList, rAny, rName, GetImport() );
+        XMLImageStyle::importXML( xAttrList, rAny, rName, GetImport() );
     }
     catch (const Exception&)
     {
@@ -324,28 +284,26 @@ void SvxXMLTableImportContext::importBitmap( sal_uInt16 nPrfx, const OUString& r
     }
 }
 
-///////////////////////////////////////////////////////////////////////
 
-// #110680#
 SvxXMLXTableImport::SvxXMLXTableImport(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > xContext,
+    const css::uno::Reference< css::uno::XComponentContext >& rContext,
     const uno::Reference< XNameContainer > & rTable,
-    uno::Reference< XGraphicObjectResolver >& xGrfResolver )
-:   SvXMLImport(xContext, 0),
+    uno::Reference< XGraphicObjectResolver > const & xGrfResolver )
+:   SvXMLImport(rContext, "", SvXMLImportFlags::NONE),
     mrTable( rTable )
 {
     SetGraphicResolver( xGrfResolver );
 
-    GetNamespaceMap().Add( OUString( sXML_np__ooo ), GetXMLToken(XML_N_OOO), XML_NAMESPACE_OOO );
-    GetNamespaceMap().Add( OUString( sXML_np__office ), GetXMLToken(XML_N_OFFICE), XML_NAMESPACE_OFFICE );
-    GetNamespaceMap().Add( OUString( sXML_np__draw ), GetXMLToken(XML_N_DRAW), XML_NAMESPACE_DRAW );
-    GetNamespaceMap().Add( OUString( sXML_np__xlink ), GetXMLToken(XML_N_XLINK), XML_NAMESPACE_XLINK );
+    GetNamespaceMap().Add( "__ooo", GetXMLToken(XML_N_OOO), XML_NAMESPACE_OOO );
+    GetNamespaceMap().Add( "__office", GetXMLToken(XML_N_OFFICE), XML_NAMESPACE_OFFICE );
+    GetNamespaceMap().Add( "__draw", GetXMLToken(XML_N_DRAW), XML_NAMESPACE_DRAW );
+    GetNamespaceMap().Add( "__xlink", GetXMLToken(XML_N_XLINK), XML_NAMESPACE_XLINK );
 
     // OOo namespaces for reading OOo 1.1 files
-    GetNamespaceMap().Add( OUString( sXML_np__office_ooo ),
+    GetNamespaceMap().Add( "___office",
                         GetXMLToken(XML_N_OFFICE_OOO),
                         XML_NAMESPACE_OFFICE );
-    GetNamespaceMap().Add( OUString( sXML_np__draw_ooo ),
+    GetNamespaceMap().Add( "___draw",
                         GetXMLToken(XML_N_DRAW_OOO),
                         XML_NAMESPACE_DRAW );
 }
@@ -355,8 +313,8 @@ SvxXMLXTableImport::~SvxXMLXTableImport() throw ()
 }
 
 static void openStorageStream( xml::sax::InputSource *pParserInput,
-                               SvXMLGraphicHelper   **ppGraphicHelper,
-                               uno::Reference < embed::XStorage > xStorage )
+                               rtl::Reference<SvXMLGraphicHelper>& rxGraphicHelper,
+                               const uno::Reference < embed::XStorage >& xStorage )
 {
     uno::Reference < io::XStream > xIStm;
     xIStm.set( xStorage->openStreamElement( "Content.xml", embed::ElementModes::READ ), uno::UNO_QUERY_THROW );
@@ -366,7 +324,7 @@ static void openStorageStream( xml::sax::InputSource *pParserInput,
         return;
     }
     pParserInput->aInputStream = xIStm->getInputStream();
-    *ppGraphicHelper = SvXMLGraphicHelper::Create( xStorage, GRAPHICHELPER_MODE_READ );
+    rxGraphicHelper = SvXMLGraphicHelper::Create( xStorage, SvXMLGraphicHelperMode::Read );
 }
 
 bool SvxXMLXTableImport::load( const OUString &rPath, const OUString &rReferer,
@@ -375,10 +333,10 @@ bool SvxXMLXTableImport::load( const OUString &rPath, const OUString &rReferer,
                                bool *bOptLoadedFromStorage ) throw()
 {
     bool bRet = true;
-    SvXMLGraphicHelper* pGraphicHelper = 0;
+    rtl::Reference<SvXMLGraphicHelper> xGraphicHelper;
 
     INetURLObject aURLObj( rPath );
-    bool bUseStorage = aURLObj.GetProtocol() == INET_PROT_NOT_VALID; // a relative path
+    bool bUseStorage = aURLObj.GetProtocol() == INetProtocol::NotValid; // a relative path
 
     try
     {
@@ -391,13 +349,13 @@ bool SvxXMLXTableImport::load( const OUString &rPath, const OUString &rReferer,
 
         if( !bUseStorage || !xStorage.is() )
         {
-            SfxMedium aMedium( rPath, rReferer, STREAM_READ | STREAM_NOCREATE );
+            SfxMedium aMedium( rPath, rReferer, StreamMode::READ | StreamMode::NOCREATE );
             aParserInput.sSystemId = aMedium.GetName();
 
             if( aMedium.IsStorage() )
             {
-                uno::Reference < embed::XStorage > xMediumStorage( aMedium.GetStorage( sal_False ), uno::UNO_QUERY_THROW );
-                openStorageStream( &aParserInput, &pGraphicHelper, xMediumStorage );
+                uno::Reference < embed::XStorage > xMediumStorage( aMedium.GetStorage( false ), uno::UNO_QUERY_THROW );
+                openStorageStream( &aParserInput, xGraphicHelper, xMediumStorage );
             }
             else
                 aParserInput.aInputStream = aMedium.GetInputStream();
@@ -414,10 +372,10 @@ bool SvxXMLXTableImport::load( const OUString &rPath, const OUString &rReferer,
             {
             }
             if( xSubStorage.is() )
-                openStorageStream( &aParserInput, &pGraphicHelper, xSubStorage );
+                openStorageStream( &aParserInput, xGraphicHelper, xSubStorage );
             else
             {
-                ::com::sun::star::uno::Reference< ::com::sun::star::io::XStream > xStream;
+                css::uno::Reference< css::io::XStream > xStream;
                 xStream = comphelper::OStorageHelper::GetStreamAtPath(
                         xStorage, rPath, embed::ElementModes::READ, aNasty );
                 if( !xStream.is() )
@@ -429,8 +387,8 @@ bool SvxXMLXTableImport::load( const OUString &rPath, const OUString &rReferer,
         }
 
         uno::Reference< XGraphicObjectResolver > xGrfResolver;
-        if (pGraphicHelper)
-            xGrfResolver = pGraphicHelper;
+        if (xGraphicHelper.is())
+            xGrfResolver = xGraphicHelper.get();
 
         try
         {
@@ -445,23 +403,21 @@ bool SvxXMLXTableImport::load( const OUString &rPath, const OUString &rReferer,
         xParser->setDocumentHandler( xHandler );
         xParser->parseStream( aParserInput );
 
-        if( pGraphicHelper )
-            SvXMLGraphicHelper::Destroy( pGraphicHelper );
+        if( xGraphicHelper )
+            xGraphicHelper->dispose();
     }
-    catch (const uno::Exception&)
+    catch (...)
     {
 //      thrown each time you load a document with property tables that are not
 //      on the current machine. FIXME: would be better to check a file exists
 //      before importing ...
-//        fprintf (stderr, "parsing etc. exception '%s'\n",
-//                 OUStringToOString(e.Message, RTL_TEXTENCODING_UTF8).getStr());
         bRet = false;
     }
 
     return bRet;
 }
 
-SvXMLImportContext *SvxXMLXTableImport::CreateContext( sal_uInt16 nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& xAttrList )
+SvXMLImportContext *SvxXMLXTableImport::CreateContext( sal_uInt16 nPrefix, const OUString& rLocalName, const uno::Reference< XAttributeList >& /*xAttrList*/ )
 {
     if( XML_NAMESPACE_OOO == nPrefix ||
         XML_NAMESPACE_OFFICE == nPrefix )
@@ -471,33 +427,33 @@ SvXMLImportContext *SvxXMLXTableImport::CreateContext( sal_uInt16 nPrefix, const
 
         if ( rLocalName == "color-table" )
         {
-            if( aType == ::getCppuType((const sal_Int32*)0) )
-                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, xAttrList, stice_color, mrTable, bOOoFormat );
+            if( aType == ::cppu::UnoType<sal_Int32>::get() )
+                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, SvxXMLTableImportContextEnum::Color, mrTable, bOOoFormat );
         }
         else if ( rLocalName == "marker-table" )
         {
-            if( aType == ::getCppuType((const drawing::PolyPolygonBezierCoords*)0) )
-                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, xAttrList, stice_marker, mrTable, bOOoFormat );
+            if( aType == cppu::UnoType<drawing::PolyPolygonBezierCoords>::get())
+                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, SvxXMLTableImportContextEnum::Marker, mrTable, bOOoFormat );
         }
         else if ( rLocalName == "dash-table" )
         {
-            if( aType == ::getCppuType((const drawing::LineDash*)0) )
-                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, xAttrList, stice_dash, mrTable, bOOoFormat );
+            if( aType == cppu::UnoType<drawing::LineDash>::get())
+                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, SvxXMLTableImportContextEnum::Dash, mrTable, bOOoFormat );
         }
         else if ( rLocalName == "hatch-table" )
         {
-            if( aType == ::getCppuType((const drawing::Hatch*)0) )
-                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, xAttrList, stice_hatch, mrTable, bOOoFormat );
+            if( aType == cppu::UnoType<drawing::Hatch>::get())
+                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, SvxXMLTableImportContextEnum::Hatch, mrTable, bOOoFormat );
         }
         else if ( rLocalName == "gradient-table" )
         {
-            if( aType == ::getCppuType((const awt::Gradient*)0))
-                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, xAttrList, stice_gradient, mrTable, bOOoFormat );
+            if( aType == cppu::UnoType<awt::Gradient>::get())
+                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, SvxXMLTableImportContextEnum::Gradient, mrTable, bOOoFormat );
         }
         else if ( rLocalName == "bitmap-table" )
         {
-            if( aType == ::getCppuType((const OUString*)0))
-                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, xAttrList, stice_bitmap, mrTable, bOOoFormat );
+            if( aType == ::cppu::UnoType<OUString>::get())
+                return new SvxXMLTableImportContext( *this, nPrefix, rLocalName, SvxXMLTableImportContextEnum::Bitmap, mrTable, bOOoFormat );
         }
     }
 
