@@ -29,9 +29,9 @@
 #include <cntfrm.hxx>
 #include <fmtcntnt.hxx>
 #include <ndindex.hxx>
-#include "fesh.hxx"
+#include <fesh.hxx>
 #include <hints.hxx>
-#include "accmap.hxx"
+#include <accmap.hxx>
 #include "accframebase.hxx"
 
 #include <crsrsh.hxx>
@@ -50,9 +50,8 @@ bool SwAccessibleFrameBase::IsSelected()
     assert(GetMap());
     const SwViewShell *pVSh = GetMap()->GetShell();
     assert(pVSh);
-    if( dynamic_cast<const SwFEShell*>( pVSh) !=  nullptr )
+    if( auto pFESh = dynamic_cast<const SwFEShell*>(pVSh) )
     {
-        const SwFEShell *pFESh = static_cast< const SwFEShell * >( pVSh );
         const SwFrame *pFlyFrame = pFESh->GetSelectedFlyFrame();
         if( pFlyFrame == GetFrame() )
             bRet = true;
@@ -82,7 +81,7 @@ void SwAccessibleFrameBase::GetStates(
     if( IsSelected() )
     {
         rStateSet.AddState( AccessibleStateType::SELECTED );
-        assert(bIsSelected && "bSelected out of sync");
+        assert(m_bIsSelected && "bSelected out of sync");
         ::rtl::Reference < SwAccessibleContext > xThis( this );
         GetMap()->SetCursorContext( xThis );
 
@@ -94,9 +93,9 @@ void SwAccessibleFrameBase::GetStates(
         rStateSet.AddState( AccessibleStateType::SELECTED );
 }
 
-sal_uInt8 SwAccessibleFrameBase::GetNodeType( const SwFlyFrame *pFlyFrame )
+SwNodeType SwAccessibleFrameBase::GetNodeType( const SwFlyFrame *pFlyFrame )
 {
-    sal_uInt8 nType = ND_TEXTNODE;
+    SwNodeType nType = SwNodeType::Text;
     if( pFlyFrame->Lower() )
     {
          if( pFlyFrame->Lower()->IsNoTextFrame() )
@@ -124,20 +123,18 @@ sal_uInt8 SwAccessibleFrameBase::GetNodeType( const SwFlyFrame *pFlyFrame )
 }
 
 SwAccessibleFrameBase::SwAccessibleFrameBase(
-        SwAccessibleMap* pInitMap,
+        std::shared_ptr<SwAccessibleMap> const& pInitMap,
         sal_Int16 nInitRole,
         const SwFlyFrame* pFlyFrame  ) :
     SwAccessibleContext( pInitMap, nInitRole, pFlyFrame ),
-    bIsSelected( false )
+    m_bIsSelected( false )
 {
-    SolarMutexGuard aGuard;
-
     const SwFrameFormat *pFrameFormat = pFlyFrame->GetFormat();
     const_cast< SwFrameFormat * >( pFrameFormat )->Add( this );
 
     SetName( pFrameFormat->GetName() );
 
-    bIsSelected = IsSelected();
+    m_bIsSelected = IsSelected();
 }
 
 void SwAccessibleFrameBase::InvalidateCursorPos_()
@@ -147,8 +144,8 @@ void SwAccessibleFrameBase::InvalidateCursorPos_()
 
     {
         osl::MutexGuard aGuard( m_Mutex );
-        bOldSelected = bIsSelected;
-        bIsSelected = bNewSelected;
+        bOldSelected = m_bIsSelected;
+        m_bIsSelected = bNewSelected;
     }
 
     if( bNewSelected )
@@ -193,7 +190,7 @@ void SwAccessibleFrameBase::InvalidateFocus_()
 
         {
             osl::MutexGuard aGuard( m_Mutex );
-            bSelected = bIsSelected;
+            bSelected = m_bIsSelected;
         }
         assert(bSelected && "focus object should be selected");
 
@@ -205,7 +202,7 @@ void SwAccessibleFrameBase::InvalidateFocus_()
 bool SwAccessibleFrameBase::HasCursor()
 {
     osl::MutexGuard aGuard( m_Mutex );
-    return bIsSelected;
+    return m_bIsSelected;
 }
 
 SwAccessibleFrameBase::~SwAccessibleFrameBase()
@@ -336,13 +333,13 @@ bool SwAccessibleFrameBase::GetSelectedState( )
                     sal_uLong nEndIndex = pEnd->nNode.GetIndex();
                     if( ( nHere >= nStartIndex ) && (nHere <= nEndIndex)  )
                     {
-                        if( rAnchor.GetAnchorId() == FLY_AS_CHAR )
+                        if( rAnchor.GetAnchorId() == RndStdIds::FLY_AS_CHAR )
                         {
                             if( ((nHere == nStartIndex) && (nIndex >= pStart->nContent.GetIndex())) || (nHere > nStartIndex) )
                                 if( ((nHere == nEndIndex) && (nIndex < pEnd->nContent.GetIndex())) || (nHere < nEndIndex) )
                                     return true;
                         }
-                        else if( rAnchor.GetAnchorId() == FLY_AT_PARA )
+                        else if( rAnchor.GetAnchorId() == RndStdIds::FLY_AT_PARA )
                         {
                             if( ((nHere > nStartIndex) || pStart->nContent.GetIndex() ==0 )
                                 && (nHere < nEndIndex ) )
