@@ -29,9 +29,6 @@
 #include <swcache.hxx>
 #include <swtblfmt.hxx>
 #include <svl/grabbagitem.hxx>
-#include <com/sun/star/beans/PropertyValues.hpp>
-
-//UUUU
 #include <svx/sdr/attribute/sdrallfillattributeshelper.hxx>
 #include <svx/unobrushitemhelper.hxx>
 #include <svx/xdef.hxx>
@@ -52,7 +49,7 @@ SwFormat::SwFormat( SwAttrPool& rPool, const sal_Char* pFormatNm,
 {
     m_bAutoUpdateFormat = false; // LAYER_IMPL
     m_bAutoFormat = true;
-    m_bWritten = m_bFormatInDTOR = m_bHidden = false;
+    m_bFormatInDTOR = m_bHidden = false;
 
     if( pDrvdFrame )
         m_aSet.SetParent( &pDrvdFrame->m_aSet );
@@ -71,7 +68,7 @@ SwFormat::SwFormat( SwAttrPool& rPool, const OUString& rFormatNm,
 {
     m_bAutoUpdateFormat = false; // LAYER_IMPL
     m_bAutoFormat = true;
-    m_bWritten = m_bFormatInDTOR = m_bHidden = false;
+    m_bFormatInDTOR = m_bHidden = false;
 
     if( pDrvdFrame )
         m_aSet.SetParent( &pDrvdFrame->m_aSet );
@@ -86,7 +83,7 @@ SwFormat::SwFormat( const SwFormat& rFormat )
     m_nPoolHelpId( rFormat.GetPoolHelpId() ),
     m_nPoolHlpFileId( rFormat.GetPoolHlpFileId() )
 {
-    m_bWritten = m_bFormatInDTOR = false; // LAYER_IMPL
+    m_bFormatInDTOR = false; // LAYER_IMPL
     m_bAutoFormat = rFormat.m_bAutoFormat;
     m_bHidden = rFormat.m_bHidden;
     m_bAutoUpdateFormat = rFormat.m_bAutoUpdateFormat;
@@ -175,7 +172,7 @@ void SwFormat::SetName( const OUString& rNewName, bool bBroadcast )
     in which <this> is defined. Currently this is important for DropCaps
     because that contains data that needs to be copied deeply.
 */
-void SwFormat::CopyAttrs( const SwFormat& rFormat, bool bReplace )
+void SwFormat::CopyAttrs( const SwFormat& rFormat )
 {
     // copy only array with attributes delta
     if ( IsInCache() )
@@ -188,13 +185,6 @@ void SwFormat::CopyAttrs( const SwFormat& rFormat, bool bReplace )
     // special treatments for some attributes
     SwAttrSet* pChgSet = const_cast<SwAttrSet*>(&rFormat.m_aSet);
 
-    if( !bReplace )     // refresh only those that are not set?
-    {
-        if( pChgSet == &rFormat.m_aSet )
-            pChgSet = new SwAttrSet( rFormat.m_aSet );
-        pChgSet->Differentiate( m_aSet );
-    }
-
     // copy only array with attributes delta
     if( pChgSet->GetPool() != m_aSet.GetPool() )
         pChgSet->CopyToModify( *this );
@@ -224,8 +214,6 @@ SwFormat::~SwFormat()
     // ones on DerivedFrom.
     if( HasWriterListeners() )
     {
-        OSL_ENSURE( DerivedFrom(), "SwFormat::~SwFormat: Def dependents!" );
-
         m_bFormatInDTOR = true;
 
         SwFormat* pParentFormat = DerivedFrom();
@@ -279,7 +267,7 @@ void SwFormat::Modify( const SfxPoolItem* pOldValue, const SfxPoolItem* pNewValu
                 else
                 {
                     // otherwise de-register at least from dying one
-                    DerivedFrom()->Remove( this );
+                    GetRegisteredIn()->Remove( this );
                     m_aSet.SetParent( nullptr );
                 }
             }
@@ -315,8 +303,6 @@ void SwFormat::Modify( const SfxPoolItem* pOldValue, const SfxPoolItem* pNewValu
         break;
     case RES_RESET_FMTWRITTEN:
         {
-            ResetWritten();
-
             // mba: here we don't use the additional stuff from NotifyClients().
             // should we?!
             // mba: move the code that ignores this event to the clients
@@ -368,11 +354,11 @@ bool SwFormat::SetDerivedFrom(SwFormat *pDerFrom)
     if ( (pDerFrom == DerivedFrom()) || (pDerFrom == this) )
         return false;
 
-    OSL_ENSURE( Which()==pDerFrom->Which()
-            || ( Which()==RES_CONDTXTFMTCOLL && pDerFrom->Which()==RES_TXTFMTCOLL)
-            || ( Which()==RES_TXTFMTCOLL && pDerFrom->Which()==RES_CONDTXTFMTCOLL)
-            || ( Which()==RES_FLYFRMFMT && pDerFrom->Which()==RES_FRMFMT ),
-            "SetDerivedFrom: derive apples from oranges?");
+    assert(    Which()==pDerFrom->Which()
+            || (Which()==RES_CONDTXTFMTCOLL && pDerFrom->Which()==RES_TXTFMTCOLL)
+            || (Which()==RES_TXTFMTCOLL && pDerFrom->Which()==RES_CONDTXTFMTCOLL)
+            || (Which()==RES_FLYFRMFMT && pDerFrom->Which()==RES_FRMFMT)
+            );
 
     if ( IsInCache() )
     {
@@ -400,7 +386,7 @@ const SfxPoolItem& SwFormat::GetFormatAttr( sal_uInt16 nWhich, bool bInParents )
 {
     if (RES_BACKGROUND == nWhich && supportsFullDrawingLayerFillAttributeSet())
     {
-        //UUUU FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
+        // FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
         SAL_INFO("sw.core", "Do no longer use SvxBrushItem, instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST] FillAttributes or makeBackgroundBrushItem (simple fallback is in place and used)");
         static SvxBrushItem aSvxBrushItem(RES_BACKGROUND);
 
@@ -419,7 +405,7 @@ SfxItemState SwFormat::GetItemState( sal_uInt16 nWhich, bool bSrchInParent, cons
 {
     if (RES_BACKGROUND == nWhich && supportsFullDrawingLayerFillAttributeSet())
     {
-        //UUUU FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
+        // FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
         SAL_INFO("sw.core", "Do no longer use SvxBrushItem, instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST] FillAttributes or SwFormat::GetBackgroundStat (simple fallback is in place and used)");
         const drawinglayer::attribute::SdrAllFillAttributesHelperPtr aFill = getSdrAllFillAttributesHelper();
 
@@ -450,11 +436,11 @@ SfxItemState SwFormat::GetItemState( sal_uInt16 nWhich, bool bSrchInParent, cons
     return m_aSet.GetItemState( nWhich, bSrchInParent, ppItem );
 }
 
-SfxItemState SwFormat::GetBackgroundState(SvxBrushItem &rItem, bool bSrchInParent) const
+SfxItemState SwFormat::GetBackgroundState(SvxBrushItem &rItem) const
 {
     if (supportsFullDrawingLayerFillAttributeSet())
     {
-        //UUUU FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
+        // FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
         const drawinglayer::attribute::SdrAllFillAttributesHelperPtr aFill = getSdrAllFillAttributesHelper();
 
         // check if the new fill attributes are used
@@ -463,7 +449,7 @@ SfxItemState SwFormat::GetBackgroundState(SvxBrushItem &rItem, bool bSrchInParen
             // if yes, fill the local SvxBrushItem using the new fill attributes
             // as good as possible to have an instance for the pointer to point
             // to and return as state that it is set
-            rItem = getSvxBrushItemFromSourceSet(m_aSet, RES_BACKGROUND, bSrchInParent);
+            rItem = getSvxBrushItemFromSourceSet(m_aSet, RES_BACKGROUND);
             return SfxItemState::SET;
         }
 
@@ -472,7 +458,7 @@ SfxItemState SwFormat::GetBackgroundState(SvxBrushItem &rItem, bool bSrchInParen
     }
 
     const SfxPoolItem* pItem = nullptr;
-    SfxItemState eRet = m_aSet.GetItemState(RES_BACKGROUND, bSrchInParent, &pItem);
+    SfxItemState eRet = m_aSet.GetItemState(RES_BACKGROUND, true, &pItem);
     if (pItem)
         rItem = *static_cast<const SvxBrushItem*>(pItem);
     return eRet;
@@ -488,12 +474,11 @@ bool SwFormat::SetFormatAttr( const SfxPoolItem& rAttr )
 
     bool bRet = false;
 
-    //UUUU
     if (RES_BACKGROUND == rAttr.Which() && supportsFullDrawingLayerFillAttributeSet())
     {
-        //UUUU FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
+        // FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
         SAL_INFO("sw.core", "Do no longer use SvxBrushItem, instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST] FillAttributes (simple fallback is in place and used)");
-        SfxItemSet aTempSet(*m_aSet.GetPool(), XATTR_FILL_FIRST, XATTR_FILL_LAST, 0, 0);
+        SfxItemSet aTempSet(*m_aSet.GetPool(), svl::Items<XATTR_FILL_FIRST, XATTR_FILL_LAST>{});
         const SvxBrushItem& rSource = static_cast< const SvxBrushItem& >(rAttr);
 
         // fill a local ItemSet with the attributes corresponding as good as possible
@@ -503,7 +488,8 @@ bool SwFormat::SetFormatAttr( const SfxPoolItem& rAttr )
 
         if(IsModifyLocked())
         {
-            if( ( bRet = m_aSet.Put( aTempSet ) ) )
+            bRet = m_aSet.Put( aTempSet );
+            if( bRet )
             {
                 m_aSet.SetModifyAtAttr( this );
             }
@@ -536,7 +522,8 @@ bool SwFormat::SetFormatAttr( const SfxPoolItem& rAttr )
           (RES_GRFFMTCOLL == nFormatWhich  ||
            RES_TXTFMTCOLL == nFormatWhich ) ) )
     {
-        if( ( bRet = (nullptr != m_aSet.Put( rAttr ))) )
+        bRet = nullptr != m_aSet.Put( rAttr );
+        if( bRet )
             m_aSet.SetModifyAtAttr( this );
         // #i71574#
         if ( nFormatWhich == RES_TXTFMTCOLL && rAttr.Which() == RES_PARATR_NUMRULE )
@@ -578,11 +565,11 @@ bool SwFormat::SetFormatAttr( const SfxItemSet& rSet )
 
     bool bRet = false;
 
-    //UUUU Use local copy to be able to apply needed changes, e.g. call
+    // Use local copy to be able to apply needed changes, e.g. call
     // CheckForUniqueItemForLineFillNameOrIndex which is needed for NameOrIndex stuff
     SfxItemSet aTempSet(rSet);
 
-    //UUUU Need to check for unique item for DrawingLayer items of type NameOrIndex
+    // Need to check for unique item for DrawingLayer items of type NameOrIndex
     // and evtl. correct that item to ensure unique names for that type. This call may
     // modify/correct entries inside of the given SfxItemSet
     if(GetDoc())
@@ -596,7 +583,7 @@ bool SwFormat::SetFormatAttr( const SfxItemSet& rSet )
 
         if(SfxItemState::SET == aTempSet.GetItemState(RES_BACKGROUND, false, &pSource))
         {
-            //UUUU FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
+            // FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
             SAL_INFO("sw.core", "Do no longer use SvxBrushItem, instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST] FillAttributes (simple fallback is in place and used)");
 
             // copy all items to be set anyways to a local ItemSet with is also prepared for the new
@@ -607,7 +594,8 @@ bool SwFormat::SetFormatAttr( const SfxItemSet& rSet )
 
             if(IsModifyLocked())
             {
-                if( ( bRet = m_aSet.Put( aTempSet ) ) )
+                bRet = m_aSet.Put( aTempSet );
+                if( bRet )
                 {
                     m_aSet.SetModifyAtAttr( this );
                 }
@@ -641,7 +629,8 @@ bool SwFormat::SetFormatAttr( const SfxItemSet& rSet )
            ( RES_GRFFMTCOLL == nFormatWhich ||
              RES_TXTFMTCOLL == nFormatWhich ) ) )
     {
-        if( ( bRet = m_aSet.Put( aTempSet )) )
+        bRet = m_aSet.Put( aTempSet );
+        if( bRet )
             m_aSet.SetModifyAtAttr( this );
         // #i71574#
         if ( nFormatWhich == RES_TXTFMTCOLL )
@@ -728,11 +717,6 @@ sal_uInt16 SwFormat::ResetAllFormatAttr()
     return aNew.Count();
 }
 
-bool SwFormat::GetInfo( SfxPoolItem& rInfo ) const
-{
-    return SwModify::GetInfo( rInfo );
-}
-
 void SwFormat::DelDiffs( const SfxItemSet& rSet )
 {
     if( !m_aSet.Count() )
@@ -793,10 +777,7 @@ void SwFormat::GetGrabBagItem(uno::Any& rVal) const
     if (m_pGrabBagItem.get())
         m_pGrabBagItem->QueryValue(rVal);
     else
-    {
-        uno::Sequence<beans::PropertyValue> aValue(0);
-        rVal = uno::makeAny(aValue);
-    }
+        rVal <<= uno::Sequence<beans::PropertyValue>();
 }
 
 void SwFormat::SetGrabBagItem(const uno::Any& rVal)
@@ -807,12 +788,11 @@ void SwFormat::SetGrabBagItem(const uno::Any& rVal)
     m_pGrabBagItem->PutValue(rVal, 0);
 }
 
-//UUUU
 SvxBrushItem SwFormat::makeBackgroundBrushItem(bool bInP) const
 {
     if (supportsFullDrawingLayerFillAttributeSet())
     {
-        //UUUU FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
+        // FALLBACKBREAKHERE should not be used; instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
         SAL_INFO("sw.core", "Do no longer use SvxBrushItem, instead use [XATTR_FILL_FIRST .. XATTR_FILL_LAST] FillAttributes (simple fallback is in place and used)");
 
         // fill the local static SvxBrushItem from the current ItemSet so that
@@ -824,7 +804,6 @@ SvxBrushItem SwFormat::makeBackgroundBrushItem(bool bInP) const
     return m_aSet.GetBackground(bInP);
 }
 
-//UUUU
 drawinglayer::attribute::SdrAllFillAttributesHelperPtr SwFormat::getSdrAllFillAttributesHelper() const
 {
     return drawinglayer::attribute::SdrAllFillAttributesHelperPtr();
