@@ -56,7 +56,7 @@ using namespace util;
 
 static OUString
 lcl_CleanStr(const SwTextNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
-             std::vector<sal_Int32> &rArr, bool const bRemoveSoftHyphen)
+             std::vector<sal_Int32> &rArr, bool const bRemoveSoftHyphen, bool const bRemoveCommentAnchors)
 {
     OUStringBuffer buf(rNd.GetText());
     rArr.clear();
@@ -80,7 +80,7 @@ lcl_CleanStr(const SwTextNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
 
         if ( bNewSoftHyphen )
         {
-            nSoftHyphen = (bRemoveSoftHyphen)
+            nSoftHyphen = bRemoveSoftHyphen
                     ?  rNd.GetText().indexOf(CHAR_SOFTHYPHEN, nSoftHyphen)
                     : -1;
         }
@@ -127,7 +127,6 @@ lcl_CleanStr(const SwTextNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
                 case RES_TXTATR_FLYCNT:
                 case RES_TXTATR_FTN:
                 case RES_TXTATR_FIELD:
-                case RES_TXTATR_ANNOTATION:
                 case RES_TXTATR_REFMARK:
                 case RES_TXTATR_TOXMARK:
                 case RES_TXTATR_META:
@@ -140,9 +139,7 @@ lcl_CleanStr(const SwTextNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
                         // simply removed if first. If at the end, we keep the
                         // replacement and remove afterwards all at a string's
                         // end (might be normal 0x7f).
-                        const bool bEmpty =
-                            ( pHt->Which() != RES_TXTATR_FIELD
-                              && pHt->Which() != RES_TXTATR_ANNOTATION )
+                        const bool bEmpty = pHt->Which() != RES_TXTATR_FIELD
                             || (static_txtattr_cast<SwTextField const*>(pHt)->GetFormatField().GetField()->ExpandField(true).isEmpty());
                         if ( bEmpty && nStart == nAkt )
                         {
@@ -155,12 +152,22 @@ lcl_CleanStr(const SwTextNode& rNd, sal_Int32 const nStart, sal_Int32& rEnd,
                             if ( bEmpty )
                                 aReplaced.push_back( nAkt );
                             buf[nAkt] = '\x7f';
-                           }
+                        }
                     }
                     break;
-                    default:
-                        OSL_FAIL( "unknown case in lcl_CleanStr" );
-                        break;
+                case RES_TXTATR_ANNOTATION:
+                    {
+                        if( bRemoveCommentAnchors )
+                        {
+                            rArr.push_back( nAkt );
+                            --rEnd;
+                            buf.remove( nAkt, 1 );
+                        }
+                    }
+                    break;
+                default:
+                    OSL_FAIL( "unknown case in lcl_CleanStr" );
+                    break;
                 }
             }
             ++n;
@@ -483,6 +490,8 @@ bool SwPaM::DoSearch( const i18nutil::SearchOptions2& rSearchOpt, utl::TextSearc
     // if the search string contains a soft hyphen,
     // we don't strip them from the text:
     bool bRemoveSoftHyphens = true;
+    // if the search string contains a comment, we don't strip them from the text
+    const bool bRemoveCommentAnchors = rSearchOpt.searchString.indexOf( CH_TXTATR_INWORD ) == -1;
 
     if ( bRegSearch )
     {
@@ -504,10 +513,10 @@ bool SwPaM::DoSearch( const i18nutil::SearchOptions2& rSearchOpt, utl::TextSearc
 
     if( bSrchForward )
         sCleanStr = lcl_CleanStr(*pNode->GetTextNode(), nStart, nEnd,
-                        aFltArr, bRemoveSoftHyphens);
+                        aFltArr, bRemoveSoftHyphens, bRemoveCommentAnchors);
     else
         sCleanStr = lcl_CleanStr(*pNode->GetTextNode(), nEnd, nStart,
-                        aFltArr, bRemoveSoftHyphens);
+                        aFltArr, bRemoveSoftHyphens, bRemoveCommentAnchors);
 
     SwScriptIterator* pScriptIter = nullptr;
     sal_uInt16 nSearchScript = 0;
@@ -594,7 +603,6 @@ bool SwPaM::DoSearch( const i18nutil::SearchOptions2& rSearchOpt, utl::TextSearc
         }
         else
         {
-            nStart = nProxyStart;
             nEnd = nProxyEnd;
         }
         nStart = nEnd;
@@ -671,7 +679,7 @@ int SwFindParaText::Find( SwPaM* pCursor, SwMoveFnCollection const & fnMove,
             const_cast<SwPaM*>(pRegion)->GetRingContainer().merge( m_rCursor.GetRingContainer() );
         }
 
-        std::unique_ptr<OUString> pRepl( (bRegExp)
+        std::unique_ptr<OUString> pRepl( bRegExp
                 ? ReplaceBackReferences( m_rSearchOpt, pCursor ) : nullptr );
         bool const bReplaced =
             m_rCursor.GetDoc()->getIDocumentContentOperations().ReplaceRange(
@@ -750,15 +758,25 @@ OUString *ReplaceBackReferences( const i18nutil::SearchOptions2& rSearchOpt, SwP
         SearchAlgorithms2::REGEXP == rSearchOpt.AlgorithmType2 )
     {
         const SwContentNode* pTextNode = pPam->GetContentNode();
-        if( pTextNode && pTextNode->IsTextNode() && pTextNode == pPam->GetContentNode( false ) )
+        const bool bParaEnd = rSearchOpt.searchString == "$" || rSearchOpt.searchString == "^$" || rSearchOpt.searchString == "$^";
+        if ( pTextNode && pTextNode->IsTextNode() && (bParaEnd || pTextNode == pPam->GetContentNode( false )) )
         {
             utl::TextSearch aSText( utl::TextSearch::UpgradeToSearchOptions2( rSearchOpt) );
-            const OUString& rStr = pTextNode->GetTextNode()->GetText();
+            OUString rStr = pTextNode->GetTextNode()->GetText();
             sal_Int32 nStart = pPam->Start()->nContent.GetIndex();
             sal_Int32 nEnd = pPam->End()->nContent.GetIndex();
             SearchResult aResult;
-            if( aSText.SearchForward( rStr, &nStart, &nEnd, &aResult ) )
+            if ( bParaEnd || aSText.SearchForward( rStr, &nStart, &nEnd, &aResult ) )
             {
+                if ( bParaEnd )
+                {
+                    rStr = "\\n";
+                    aResult.subRegExpressions = 1;
+                    aResult.startOffset.realloc(1);
+                    aResult.endOffset.realloc(1);
+                    aResult.startOffset[0] = 0;
+                    aResult.endOffset[0] = rStr.getLength();
+                }
                 OUString aReplaceStr( rSearchOpt.replaceString );
                 aSText.ReplaceBackReferences( aReplaceStr, rStr, aResult );
                 pRet = new OUString( aReplaceStr );
