@@ -19,6 +19,7 @@
 
 #ifdef DBG_UTIL
 
+#include <editeng/nlbkitem.hxx>
 #include <rtl/ustring.hxx>
 #include <svl/poolitem.hxx>
 #include <svl/itemiter.hxx>
@@ -41,7 +42,6 @@
 #include <paratr.hxx>
 #include <SwNodeNum.hxx>
 #include <dbgoutsw.hxx>
-#include <SwRewriter.hxx>
 #include <iostream>
 #include <cstdio>
 
@@ -93,17 +93,9 @@ const char * dbg_out(const OUString & aStr)
     return aDbgOutResult.getStr();
 }
 
-struct CompareUShort
+map<sal_uInt16,OUString> & GetItemWhichMap()
 {
-    bool operator()(sal_uInt16 a, sal_uInt16 b) const
-    {
-        return a < b;
-    }
-};
-
-map<sal_uInt16,OUString,CompareUShort> & GetItemWhichMap()
-{
-    static map<sal_uInt16,OUString,CompareUShort> aItemWhichMap;
+    static map<sal_uInt16,OUString> aItemWhichMap;
     static bool bInitialized = false;
 
     if (! bInitialized)
@@ -361,19 +353,19 @@ const char * dbg_out(const SwPosition & rPos)
 
 static OUString lcl_dbg_out(const SwPaM & rPam)
 {
-   OUString aStr("[ Pt: ");
+    OUString aStr("[ Pt: ");
 
-   aStr += lcl_dbg_out(*rPam.GetPoint());
+    aStr += lcl_dbg_out(*rPam.GetPoint());
 
-   if (rPam.HasMark())
-   {
-       aStr += ", Mk: ";
-       aStr += lcl_dbg_out(*rPam.GetMark());
-   }
+    if (rPam.HasMark())
+    {
+        aStr += ", Mk: ";
+        aStr += lcl_dbg_out(*rPam.GetMark());
+    }
 
-   aStr += " ]";
+    aStr += " ]";
 
-   return aStr;
+    return aStr;
 }
 
 const char * dbg_out(const SwPaM & rPam)
@@ -625,7 +617,7 @@ static OUString lcl_dbg_out(const SwNode & rNode)
             const SwNumRuleItem & rItem =
                 static_cast<const SwNumRuleItem &>
                 (pColl->GetFormatAttr(RES_PARATR_NUMRULE));
-            const OUString sNumruleName = rItem.GetValue();
+            const OUString& sNumruleName = rItem.GetValue();
 
             if (!sNumruleName.isEmpty())
             {
@@ -776,16 +768,8 @@ const char * dbg_out(SwNodes & rNodes)
 
 static OUString lcl_dbg_out(const SwUndo & rUndo)
 {
-    OUString aStr("[ ");
-
-    aStr += OUString::number(
-                static_cast<SfxUndoAction const&>(rUndo).GetId());
-    aStr += ": ";
-
-    aStr += rUndo.GetComment();
-    aStr += " ]";
-
-    return aStr;
+    return "[ " + OUString::number((int)rUndo.GetId())
+                + ": " + rUndo.GetComment() + " ]";
 }
 
 const char * dbg_out(const SwUndo & rUndo)
@@ -793,7 +777,7 @@ const char * dbg_out(const SwUndo & rUndo)
     return dbg_out(lcl_dbg_out(rUndo));
 }
 
-static OUString lcl_dbg_out(SwOutlineNodes & rNodes)
+static OUString lcl_dbg_out(SwOutlineNodes const & rNodes)
 {
     OUString aStr("[\n");
 
@@ -808,27 +792,11 @@ static OUString lcl_dbg_out(SwOutlineNodes & rNodes)
     return aStr;
 }
 
-const char * dbg_out(SwOutlineNodes & rNodes)
+const char * dbg_out( SwOutlineNodes const & rNodes)
 {
     return dbg_out(lcl_dbg_out(rNodes));
 }
 
-//FIXME: this method seems to do nothing at all
-static OUString lcl_dbg_out(const SwRewriter & rRewriter)
-{
-    (void) rRewriter;
-    OUString aResult;
-
-    //aResult = rRewriter.ToString();
-
-    return aResult;
-}
-
-const char * dbg_out(const SwRewriter & rRewriter)
-{
-    return dbg_out(lcl_dbg_out(rRewriter));
-}
-
 static OUString lcl_dbg_out(const SvxNumberFormat & rFormat)
 {
     OUString aResult;
