@@ -83,7 +83,7 @@ bool SwDoc::GenerateHTMLDoc( const OUString& rPath,
 }
 
 // two helpers for outline mode
-SwNodePtr GetStartNode( SwOutlineNodes* pOutlNds, int nOutlineLevel, sal_uInt16* nOutl )
+SwNodePtr GetStartNode( SwOutlineNodes const * pOutlNds, int nOutlineLevel, SwOutlineNodes::size_type* nOutl )
 {
     SwNodePtr pNd;
 
@@ -96,7 +96,7 @@ SwNodePtr GetStartNode( SwOutlineNodes* pOutlNds, int nOutlineLevel, sal_uInt16*
     return nullptr;
 }
 
-SwNodePtr GetEndNode( SwOutlineNodes* pOutlNds, int nOutlineLevel, sal_uInt16* nOutl )
+SwNodePtr GetEndNode( SwOutlineNodes const * pOutlNds, int nOutlineLevel, SwOutlineNodes::size_type* nOutl )
 {
     SwNodePtr pNd;
 
@@ -116,7 +116,7 @@ SwNodePtr GetEndNode( SwOutlineNodes* pOutlNds, int nOutlineLevel, sal_uInt16* n
 }
 
 // two helpers for collection mode
-SwNodePtr GetStartNode( const SwOutlineNodes* pOutlNds, const SwTextFormatColl* pSplitColl, sal_uInt16* nOutl )
+SwNodePtr GetStartNode( const SwOutlineNodes* pOutlNds, const SwTextFormatColl* pSplitColl, SwOutlineNodes::size_type* nOutl )
 {
     SwNodePtr pNd;
     for( ; *nOutl < pOutlNds->size(); ++(*nOutl) )
@@ -129,7 +129,7 @@ SwNodePtr GetStartNode( const SwOutlineNodes* pOutlNds, const SwTextFormatColl*
     return nullptr;
 }
 
-SwNodePtr GetEndNode( const SwOutlineNodes* pOutlNds, const SwTextFormatColl* pSplitColl, sal_uInt16* nOutl )
+SwNodePtr GetEndNode( const SwOutlineNodes* pOutlNds, const SwTextFormatColl* pSplitColl, SwOutlineNodes::size_type* nOutl )
 {
     SwNodePtr pNd;
 
@@ -160,7 +160,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
         ( SPLITDOC_TO_GLOBALDOC == eDocType && GetDocumentSettingManager().get(DocumentSettingId::GLOBAL_DOCUMENT) ) )
         return false;
 
-    sal_uInt16 nOutl = 0;
+    SwOutlineNodes::size_type nOutl = 0;
     SwOutlineNodes* pOutlNds = const_cast<SwOutlineNodes*>(&GetNodes().GetOutLineNds());
     std::unique_ptr<SwOutlineNodes> xTmpOutlNds;
     SwNodePtr pStartNd;
@@ -198,7 +198,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
         }
     }
 
-    const SfxFilter* pFilter;
+    std::shared_ptr<const SfxFilter> pFilter;
     switch( eDocType )
     {
     case SPLITDOC_TO_HTML:
@@ -216,7 +216,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
 
     // Deactivate Undo/Redline in any case
     GetIDocumentUndoRedo().DoUndo(false);
-    getIDocumentRedlineAccess().SetRedlineMode_intern( (RedlineMode_t)(getIDocumentRedlineAccess().GetRedlineMode() & ~nsRedlineMode_t::REDLINE_ON));
+    getIDocumentRedlineAccess().SetRedlineFlags_intern( getIDocumentRedlineAccess().GetRedlineFlags() & ~RedlineFlags::On );
 
     OUString sExt = pFilter->GetSuffixes().getToken(0, ',');
     if( sExt.isEmpty() )
@@ -234,7 +234,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
     INetURLObject aEntry(rPath);
     OUString sLeading(aEntry.GetBase());
     aEntry.removeSegment();
-    OUString sPath = aEntry.GetMainURL( INetURLObject::NO_DECODE );
+    OUString sPath = aEntry.GetMainURL( INetURLObject::DecodeMechanism::NONE );
     utl::TempFile aTemp(sLeading, true, &sExt, &sPath);
     aTemp.EnableKillingFile();
 
@@ -302,7 +302,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
 
                     SwNodeRange aRg( *pStartNd, 0, aEndIdx.GetNode() );
                     SwNodeIndex aTmpIdx( pDoc->GetNodes().GetEndOfContent() );
-                    GetNodes()._Copy( aRg, aTmpIdx, false );
+                    GetNodes().Copy_( aRg, aTmpIdx, false );
 
                     // Delete the initial TextNode
                     SwNodeIndex aIdx( pDoc->GetNodes().GetEndOfExtras(), 2 );
@@ -319,7 +319,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
                     utl::TempFile aTempFile2(sLeading, true, &sExt, &sPath);
                     sFileName = aTempFile2.GetURL();
                     SfxMedium* pTmpMed = new SfxMedium( sFileName,
-                                                STREAM_STD_READWRITE );
+                                                StreamMode::STD_READWRITE );
                     pTmpMed->SetFilter( pFilter );
 
                     // We need to have a Layout for the HTMLFilter, so that
@@ -327,7 +327,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
                     if( SPLITDOC_TO_HTML == eDocType &&
                         !pDoc->GetSpzFrameFormats()->empty() )
                     {
-                            SfxViewFrame::LoadHiddenDocument( *xDocSh, 0 );
+                            SfxViewFrame::LoadHiddenDocument( *xDocSh, SFX_INTERFACE_NONE );
                     }
                     xDocSh->DoSaveAs( *pTmpMed );
                     xDocSh->DoSaveCompleted( pTmpMed );
@@ -359,11 +359,11 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
                             SwNodeIndex aEIdx( aTmp.GetPoint()->nNode );
 
                             // Try to move past the end
-                            if( !aTmp.Move( fnMoveForward, fnGoNode ) )
+                            if( !aTmp.Move( fnMoveForward, GoInNode ) )
                             {
                                 // well then, back to the beginning
                                 aTmp.Exchange();
-                                if( !aTmp.Move( fnMoveBackward, fnGoNode ))
+                                if( !aTmp.Move( fnMoveBackward, GoInNode ))
                                 {
                                     OSL_FAIL( "no more Nodes!" );
                                 }
@@ -379,8 +379,8 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
                                 SwPosition const*const pAPos =
                                     pAnchor->GetContentAnchor();
                                 if (pAPos &&
-                                    ((FLY_AT_PARA == pAnchor->GetAnchorId()) ||
-                                     (FLY_AT_CHAR == pAnchor->GetAnchorId())) &&
+                                    ((RndStdIds::FLY_AT_PARA == pAnchor->GetAnchorId()) ||
+                                     (RndStdIds::FLY_AT_CHAR == pAnchor->GetAnchorId())) &&
                                     aSIdx <= pAPos->nNode &&
                                     pAPos->nNode < aEIdx )
                                 {
@@ -401,7 +401,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
                         // it has to be a bug!
                         if( !pOutlNds->Seek_Entry( pStartNd, &nOutl ))
                             pStartNd = nullptr;
-                        ++nOutl;
+                        ++nOutl ;
                     }
                     break;
 
@@ -410,7 +410,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
                         const OUString sNm( INetURLObject( sFileName ).GetName() );
                         SwSectionData aSectData( FILE_LINK_SECTION,
                                         GetUniqueSectionName( &sNm ));
-                        SwSectionFormat* pFormat = MakeSectionFormat( nullptr );
+                        SwSectionFormat* pFormat = MakeSectionFormat();
                         aSectData.SetLinkFileName(sFileName);
                         aSectData.SetProtectFlag(true);
 
@@ -437,7 +437,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
                             {
                                 SwNodeRange aRg( *pStartNd, *pSectEnd );
                                 SwNodeIndex aIdx( *pSectEnd, 1 );
-                                GetNodes()._MoveNodes( aRg, GetNodes(), aIdx );
+                                GetNodes().MoveNodes( aRg, GetNodes(), aIdx );
                             }
                             pSectNd = pStartNd->FindSectionNode();
                         }
@@ -452,7 +452,7 @@ bool SwDoc::SplitDoc( sal_uInt16 eDocType, const OUString& rPath, bool bOutline,
                             {
                                 SwNodeRange aRg( *pSectNd, 1, aEndIdx, 1 );
                                 SwNodeIndex aIdx( *pSectNd );
-                                GetNodes()._MoveNodes( aRg, GetNodes(), aIdx );
+                                GetNodes().MoveNodes( aRg, GetNodes(), aIdx );
                             }
 
                             pSectNd = pStartNd->FindSectionNode();
