@@ -18,11 +18,10 @@
  */
 
 #include <hintids.hxx>
+#include <o3tl/make_unique.hxx>
 #include <rtl/math.hxx>
 #include <unotools/collatorwrapper.hxx>
 #include <unotools/localedatawrapper.hxx>
-#include <com/sun/star/lang/XMultiServiceFactory.hpp>
-#include <com/sun/star/i18n/CollatorOptions.hpp>
 #include <comphelper/processfactory.hxx>
 #include <editeng/unolingu.hxx>
 #include <docary.hxx>
@@ -49,6 +48,7 @@
 #include <unochart.hxx>
 
 #include <set>
+#include <utility>
 
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star;
@@ -63,12 +63,12 @@ LocaleDataWrapper*  SwSortElement::pLclData = nullptr;
 
 // List of all sorted elements
 
-typedef ::std::multiset<SwSortTextElement> SwSortTextElements;
-typedef ::std::multiset<SwSortBoxElement> SwSortBoxElements;
+typedef std::multiset<SwSortTextElement> SwSortTextElements;
+typedef std::multiset<SwSortBoxElement> SwSortBoxElements;
 
 /// Construct a SortElement for the Sort
 void SwSortElement::Init( SwDoc* pD, const SwSortOptions& rOpt,
-                            FlatFndBox* pFltBx )
+                            FlatFndBox const * pFltBx )
 {
     OSL_ENSURE( !pDoc && !pOptions && !pBox, "Who forgot to call Finit?" );
     pDoc = pD;
@@ -76,13 +76,10 @@ void SwSortElement::Init( SwDoc* pD, const SwSortOptions& rOpt,
     pBox = pFltBx;
 
     LanguageType nLang = rOpt.nLanguage;
-    switch ( nLang )
-    {
-    case LANGUAGE_NONE:
-    case LANGUAGE_DONTKNOW:
+    if ( nLang.anyOf(
+        LANGUAGE_NONE,
+        LANGUAGE_DONTKNOW))
         nLang = GetAppLanguage();
-        break;
-    }
     pLocale = new lang::Locale( LanguageTag::convertToLocale( nLang ) );
 
     pSortCollator = new CollatorWrapper( ::comphelper::getProcessComponentContext() );
@@ -90,11 +87,16 @@ void SwSortElement::Init( SwDoc* pD, const SwSortOptions& rOpt,
 
 void SwSortElement::Finit()
 {
-    delete pOptions, pOptions = nullptr;
-    delete pLocale, pLocale = nullptr;
-    delete pLastAlgorithm, pLastAlgorithm = nullptr;
-    delete pSortCollator, pSortCollator = nullptr;
-    delete pLclData, pLclData = nullptr;
+    delete pOptions;
+    pOptions = nullptr;
+    delete pLocale;
+    pLocale = nullptr;
+    delete pLastAlgorithm;
+    pLastAlgorithm = nullptr;
+    delete pSortCollator;
+    pSortCollator = nullptr;
+    delete pLclData;
+    pLclData = nullptr;
     pDoc = nullptr;
     pBox = nullptr;
 }
@@ -110,10 +112,7 @@ double SwSortElement::StrToDouble( const OUString& rStr )
 
     rtl_math_ConversionStatus eStatus;
     sal_Int32 nEnd;
-    double nRet = ::rtl::math::stringToDouble( rStr,
-                                    pLclData->getNumDecimalSep()[0],
-                                    pLclData->getNumThousandSep()[0],
-                                    &eStatus, &nEnd );
+    double nRet = pLclData->stringToDouble( rStr, true, &eStatus, &nEnd );
 
     if( rtl_math_ConversionStatus_Ok != eStatus || nEnd == 0 )
         nRet = 0.0;
@@ -126,11 +125,17 @@ int SwSortElement::keycompare(const SwSortElement& rCmp, sal_uInt16 nKey) const
     // The actual comparison
     const SwSortElement *pOrig, *pCmp;
 
-    const SwSortKey* pSrtKey = pOptions->aKeys[ nKey ];
+    const SwSortKey* pSrtKey = pOptions->aKeys[ nKey ].get();
     if( pSrtKey->eSortOrder == SRT_ASCENDING )
-        pOrig = this, pCmp = &rCmp;
+    {
+        pOrig = this;
+        pCmp = &rCmp;
+    }
     else
-        pOrig = &rCmp, pCmp = this;
+    {
+        pOrig = &rCmp;
+        pCmp = this;
+    }
 
     if( pSrtKey->bIsNumeric )
     {
@@ -158,11 +163,6 @@ int SwSortElement::keycompare(const SwSortElement& rCmp, sal_uInt16 nKey) const
     return nCmp;
 }
 
-bool SwSortElement::operator==(const SwSortElement& ) const
-{
-    return false;
-}
-
 bool SwSortElement::operator<(const SwSortElement& rCmp) const
 {
     // The actual comparison
@@ -236,7 +236,7 @@ SwSortBoxElement::~SwSortBoxElement()
 /// Get Key for a cell
 OUString SwSortBoxElement::GetKey(sal_uInt16 nKey) const
 {
-    const _FndBox* pFndBox;
+    const FndBox_* pFndBox;
     sal_uInt16 nCol = pOptions->aKeys[nKey]->nColumnId-1;
 
     if( SRT_ROWS == pOptions->eDirection )
@@ -265,7 +265,7 @@ OUString SwSortBoxElement::GetKey(sal_uInt16 nKey) const
 
 double SwSortBoxElement::GetValue( sal_uInt16 nKey ) const
 {
-    const _FndBox* pFndBox;
+    const FndBox_* pFndBox;
     sal_uInt16 nCol = pOptions->aKeys[nKey]->nColumnId-1;
 
     if( SRT_ROWS == pOptions->eDirection )
@@ -300,7 +300,7 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
         SwFormatAnchor const*const pAnchor = &pFormat->GetAnchor();
         SwPosition const*const pAPos = pAnchor->GetContentAnchor();
 
-        if (pAPos && (FLY_AT_PARA == pAnchor->GetAnchorId()) &&
+        if (pAPos && (RndStdIds::FLY_AT_PARA == pAnchor->GetAnchorId()) &&
             pStart->nNode <= pAPos->nNode && pAPos->nNode <= pEnd->nNode )
             return false;
     }
@@ -318,7 +318,7 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
     bool const bUndo = GetIDocumentUndoRedo().DoesUndo();
     if( bUndo )
     {
-        GetIDocumentUndoRedo().StartUndo( UNDO_START, nullptr );
+        GetIDocumentUndoRedo().StartUndo( SwUndoId::START, nullptr );
     }
 
     SwPaM* pRedlPam = nullptr;
@@ -333,7 +333,7 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
         if( pCNd )
             pRedlPam->GetMark()->nContent = pCNd->Len();
 
-        if( getIDocumentRedlineAccess().IsRedlineOn() && !IDocumentRedlineAccess::IsShowOriginal( getIDocumentRedlineAccess().GetRedlineMode() ) )
+        if( getIDocumentRedlineAccess().IsRedlineOn() && !IDocumentRedlineAccess::IsShowOriginal( getIDocumentRedlineAccess().GetRedlineFlags() ) )
         {
             if( bUndo )
             {
@@ -343,7 +343,7 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
             // First copy the range
             SwNodeIndex aEndIdx( pEnd->nNode, 1 );
             SwNodeRange aRg( pStart->nNode, aEndIdx );
-            GetNodes()._Copy( aRg, aEndIdx );
+            GetNodes().Copy_( aRg, aEndIdx );
 
             // range is new from pEnd->nNode+1 to aEndIdx
             getIDocumentRedlineAccess().DeleteRedline( *pRedlPam, true, USHRT_MAX );
@@ -369,7 +369,8 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
         else
         {
             getIDocumentRedlineAccess().DeleteRedline( *pRedlPam, true, USHRT_MAX );
-            delete pRedlPam, pRedlPam = nullptr;
+            delete pRedlPam;
+            pRedlPam = nullptr;
         }
     }
 
@@ -460,12 +461,13 @@ bool SwDoc::SortText(const SwPaM& rPaM, const SwSortOptions& rOpt)
         if( pRedlUndo )
             pRedlUndo->SetOffset( aSttIdx );
 
-        delete pRedlPam, pRedlPam = nullptr;
+        delete pRedlPam;
+        pRedlPam = nullptr;
     }
     GetIDocumentUndoRedo().DoUndo( bUndo );
     if( bUndo )
     {
-        GetIDocumentUndoRedo().EndUndo( UNDO_END, nullptr );
+        GetIDocumentUndoRedo().EndUndo( SwUndoId::END, nullptr );
     }
 
     return true;
@@ -482,9 +484,9 @@ bool SwDoc::SortTable(const SwSelBoxes& rBoxes, const SwSortOptions& rOpt)
 
     // We begin sorting
     // Find all Boxes/Lines
-    _FndBox aFndBox( nullptr, nullptr );
+    FndBox_ aFndBox( nullptr, nullptr );
     {
-        _FndPara aPara( rBoxes, &aFndBox );
+        FndPara aPara( rBoxes, &aFndBox );
         ForEach_FndLineCopyCol( pTableNd->GetTable().GetTabLines(), &aPara );
     }
 
@@ -603,10 +605,10 @@ void MoveRow(SwDoc* pDoc, const FlatFndBox& rBox, sal_uInt16 nS, sal_uInt16 nT,
 {
     for( sal_uInt16 i=0; i < rBox.GetCols(); ++i )
     {   // Get old cell position and remember it
-        const _FndBox* pSource = rBox.GetBox(i, nS);
+        const FndBox_* pSource = rBox.GetBox(i, nS);
 
         // new cell position
-        const _FndBox* pTarget = rBox.GetBox(i, nT);
+        const FndBox_* pTarget = rBox.GetBox(i, nT);
 
         const SwTableBox* pT = pTarget->GetBox();
         const SwTableBox* pS = pSource->GetBox();
@@ -647,10 +649,10 @@ void MoveCol(SwDoc* pDoc, const FlatFndBox& rBox, sal_uInt16 nS, sal_uInt16 nT,
 {
     for(sal_uInt16 i=0; i < rBox.GetRows(); ++i)
     {   // Get old cell position and remember it
-        const _FndBox* pSource = rBox.GetBox(nS, i);
+        const FndBox_* pSource = rBox.GetBox(nS, i);
 
         // new cell position
-        const _FndBox* pTarget = rBox.GetBox(nT, i);
+        const FndBox_* pTarget = rBox.GetBox(nT, i);
 
         // and move it
         const SwTableBox* pT = pTarget->GetBox();
@@ -739,15 +741,14 @@ void MoveCell(SwDoc* pDoc, const SwTableBox* pSource, const SwTableBox* pTar,
 }
 
 /// Generate two-dimensional array of FndBoxes
-FlatFndBox::FlatFndBox(SwDoc* pDocPtr, const _FndBox& rBox) :
+FlatFndBox::FlatFndBox(SwDoc* pDocPtr, const FndBox_& rBox) :
     pDoc(pDocPtr),
     rBoxRef(rBox),
-    pArr(nullptr),
-    ppItemSets(nullptr),
     nRow(0),
     nCol(0)
 { // If the array is symmetric
-    if( (bSym = CheckLineSymmetry(rBoxRef)) )
+    bSym = CheckLineSymmetry(rBoxRef);
+    if( bSym )
     {
         // Determine column/row count
         nCols = GetColCount(rBoxRef);
@@ -755,9 +756,8 @@ FlatFndBox::FlatFndBox(SwDoc* pDocPtr, const _FndBox& rBox) :
 
         // Create linear array
         size_t nCount = static_cast<size_t>(nRows) * nCols;
-        pArr = new const _FndBox*[nCount];
-        _FndBox** ppTmp = const_cast<_FndBox**>(pArr);
-        memset(ppTmp, 0, sizeof(const _FndBox*) * nCount);
+        pArr = o3tl::make_unique<FndBox_ const *[]>(nCount);
+        memset(pArr.get(), 0, sizeof(const FndBox_*) * nCount);
 
         FillFlat( rBoxRef );
     }
@@ -765,22 +765,17 @@ FlatFndBox::FlatFndBox(SwDoc* pDocPtr, const _FndBox& rBox) :
 
 FlatFndBox::~FlatFndBox()
 {
-    _FndBox** ppTmp = const_cast<_FndBox**>(pArr);
-    delete [] ppTmp;
-
-    if( ppItemSets )
-        delete [] ppItemSets;
 }
 
 /// All Lines of a Box need to have same number of Boxes
-bool FlatFndBox::CheckLineSymmetry(const _FndBox& rBox)
+bool FlatFndBox::CheckLineSymmetry(const FndBox_& rBox)
 {
     const FndLines_t &rLines = rBox.GetLines();
     FndBoxes_t::size_type nBoxes {0};
 
     for (FndLines_t::size_type i=0; i < rLines.size(); ++i)
     {
-        const _FndLine* pLn = rLines[i].get();
+        const FndLine_* pLn = rLines[i].get();
         const FndBoxes_t& rBoxes = pLn->GetBoxes();
 
         // Number of Boxes of all Lines is unequal -> no symmetry
@@ -795,14 +790,14 @@ bool FlatFndBox::CheckLineSymmetry(const _FndBox& rBox)
 }
 
 /// Check Box for symmetry (All Boxes of a Line need to have same number of Lines)
-bool FlatFndBox::CheckBoxSymmetry(const _FndLine& rLn)
+bool FlatFndBox::CheckBoxSymmetry(const FndLine_& rLn)
 {
     const FndBoxes_t &rBoxes = rLn.GetBoxes();
     FndLines_t::size_type nLines {0};
 
     for (FndBoxes_t::size_type i = 0; i < rBoxes.size(); ++i)
     {
-        _FndBox const*const pBox = rBoxes[i].get();
+        FndBox_ const*const pBox = rBoxes[i].get();
         const FndLines_t& rLines = pBox->GetLines();
 
         // Number of Lines of all Boxes is unequal -> no symmetry
@@ -817,7 +812,7 @@ bool FlatFndBox::CheckBoxSymmetry(const _FndLine& rLn)
 }
 
 /// Maximum count of Columns (Boxes)
-sal_uInt16 FlatFndBox::GetColCount(const _FndBox& rBox)
+sal_uInt16 FlatFndBox::GetColCount(const FndBox_& rBox)
 {
     const FndLines_t& rLines = rBox.GetLines();
     // Iterate over Lines
@@ -842,7 +837,7 @@ sal_uInt16 FlatFndBox::GetColCount(const _FndBox& rBox)
 }
 
 /// Maximum count of Rows (Lines)
-sal_uInt16 FlatFndBox::GetRowCount(const _FndBox& rBox)
+sal_uInt16 FlatFndBox::GetRowCount(const FndBox_& rBox)
 {
     const FndLines_t& rLines = rBox.GetLines();
     if( rLines.empty() )
@@ -867,7 +862,7 @@ sal_uInt16 FlatFndBox::GetRowCount(const _FndBox& rBox)
 }
 
 /// Create a linear array of atomic FndBoxes
-void FlatFndBox::FillFlat(const _FndBox& rBox, bool bLastBox)
+void FlatFndBox::FillFlat(const FndBox_& rBox, bool bLastBox)
 {
     bool bModRow = false;
     const FndLines_t& rLines = rBox.GetLines();
@@ -882,13 +877,13 @@ void FlatFndBox::FillFlat(const _FndBox& rBox, bool bLastBox)
         for( FndBoxes_t::size_type j = 0; j < rBoxes.size(); ++j )
         {
             // Check the Box if it's an atomic one
-            const _FndBox *const pBox = rBoxes[j].get();
+            const FndBox_ *const pBox = rBoxes[j].get();
 
             if( pBox->GetLines().empty() )
             {
                 // save it
                 sal_uInt16 nOff = nRow * nCols + nCol;
-                *(pArr + nOff) = pBox;
+                pArr[nOff] = pBox;
 
                 // Save the Formula/Format/Value values
                 const SwFrameFormat* pFormat = pBox->GetBox()->GetFrameFormat();
@@ -896,17 +891,18 @@ void FlatFndBox::FillFlat(const _FndBox& rBox, bool bLastBox)
                     SfxItemState::SET == pFormat->GetItemState( RES_BOXATR_FORMULA ) ||
                     SfxItemState::SET == pFormat->GetItemState( RES_BOXATR_VALUE ) )
                 {
-                    SfxItemSet* pSet = new SfxItemSet( pDoc->GetAttrPool(),
-                                    RES_BOXATR_FORMAT, RES_BOXATR_VALUE,
-                                    RES_VERT_ORIENT, RES_VERT_ORIENT, 0 );
+                    auto pSet = o3tl::make_unique<SfxItemSet>(
+                        pDoc->GetAttrPool(),
+                        svl::Items<
+                            RES_VERT_ORIENT, RES_VERT_ORIENT,
+                            RES_BOXATR_FORMAT, RES_BOXATR_VALUE>{});
                     pSet->Put( pFormat->GetAttrSet() );
-                    if( !ppItemSets )
+                    if( ppItemSets.empty() )
                     {
                         size_t nCount = static_cast<size_t>(nRows) * nCols;
-                        ppItemSets = new SfxItemSet*[nCount];
-                        memset(ppItemSets, 0, sizeof(SfxItemSet*) * nCount);
+                        ppItemSets.resize(nCount);
                     }
-                    *(ppItemSets + nOff ) = pSet;
+                    ppItemSets[nOff] = std::move(pSet);
                 }
 
                 bModRow = true;
@@ -927,10 +923,10 @@ void FlatFndBox::FillFlat(const _FndBox& rBox, bool bLastBox)
 }
 
 /// Access a specific Cell
-const _FndBox* FlatFndBox::GetBox(sal_uInt16 n_Col, sal_uInt16 n_Row) const
+const FndBox_* FlatFndBox::GetBox(sal_uInt16 n_Col, sal_uInt16 n_Row) const
 {
     sal_uInt16 nOff = n_Row * nCols + n_Col;
-    const _FndBox* pTmp = *(pArr + nOff);
+    const FndBox_* pTmp = pArr[nOff];
 
     OSL_ENSURE(n_Col < nCols && n_Row < nRows && pTmp, "invalid array access");
     return pTmp;
@@ -938,9 +934,9 @@ const _FndBox* FlatFndBox::GetBox(sal_uInt16 n_Col, sal_uInt16 n_Row) const
 
 const SfxItemSet* FlatFndBox::GetItemSet(sal_uInt16 n_Col, sal_uInt16 n_Row) const
 {
-    OSL_ENSURE( !ppItemSets || ( n_Col < nCols && n_Row < nRows), "invalid array access");
+    OSL_ENSURE( ppItemSets.empty() || ( n_Col < nCols && n_Row < nRows), "invalid array access");
 
-    return ppItemSets ? *(ppItemSets + (n_Row * nCols + n_Col )) : nullptr;
+    return !ppItemSets.empty() ? ppItemSets[unsigned(n_Row * nCols) + n_Col].get() : nullptr;
 }
 
 sal_uInt16 SwMovedBoxes::GetPos(const SwTableBox* pTableBox) const
