@@ -23,12 +23,12 @@
 #include <swtable.hxx>
 #include <ftnfrm.hxx>
 #include <sectfrm.hxx>
-#include "frmfmt.hxx"
-#include "cntfrm.hxx"
-#include "tabfrm.hxx"
-#include "frmtool.hxx"
-#include "section.hxx"
-#include "node2lay.hxx"
+#include <frmfmt.hxx>
+#include <cntfrm.hxx>
+#include <tabfrm.hxx>
+#include <frmtool.hxx>
+#include <section.hxx>
+#include <node2lay.hxx>
 
 /**
  * The SwNode2LayImpl class does the actual work, the SwNode2Layout class is
@@ -42,6 +42,10 @@ class SwNode2LayImpl
     sal_uLong nIndex;        // The Index of the to-be-inserted Nodes
     bool bMaster    : 1; // true => only Master, false => only Frames without Follow
     bool bInit      : 1; // Did we already call First() at SwClient?
+
+    SwNode2LayImpl(const SwNode2LayImpl&) = delete;
+    SwNode2LayImpl& operator=(const SwNode2LayImpl&) = delete;
+
 public:
     SwNode2LayImpl( const SwNode& rNode, sal_uLong nIdx, bool bSearch );
     ~SwNode2LayImpl() { delete pIter; delete pUpperFrames; }
@@ -51,9 +55,7 @@ public:
     // Inserts a Frame under every pUpper of the array
     void RestoreUpperFrames( SwNodes& rNds, sal_uLong nStt, sal_uLong nEnd );
 
-    SwFrame* GetFrame( const Point* pDocPos = nullptr,
-                    const SwPosition *pPos = nullptr,
-                    const bool bCalcFrame = true ) const;
+    SwFrame* GetFrame( const Point* pDocPos ) const;
 };
 
 SwNode* GoNextWithFrame(const SwNodes& rNodes, SwNodeIndex *pIdx)
@@ -141,7 +143,7 @@ SwNode2LayImpl::SwNode2LayImpl( const SwNode& rNode, sal_uLong nIdx, bool bSearc
         {
             SwNodeIndex aTmp( *rNode.EndOfSectionNode(), +1 );
             pNd = GoPreviousWithFrame( &aTmp );
-            if( !bSearch && pNd && rNode.GetIndex() > pNd->GetIndex() )
+            if( pNd && rNode.GetIndex() > pNd->GetIndex() )
                 pNd = nullptr; // Do not go over the limits
             bMaster = false;
         }
@@ -388,7 +390,7 @@ void SwNode2LayImpl::RestoreUpperFrames( SwNodes& rNds, sal_uLong nStt, sal_uLon
                     static_cast<SwSectionFrame*>(pNxt)->UnlockJoin();
                 pUp = static_cast<SwLayoutFrame*>((*pUpperFrames)[x++]);
                 OSL_ENSURE( pUp->GetUpper() || pUp->IsFlyFrame(), "Lost Upper" );
-                ::_InsertCnt( pUp, pDoc, pNd->GetIndex(), false, nStt+1, pNxt );
+                ::InsertCnt_( pUp, pDoc, pNd->GetIndex(), false, nStt+1, pNxt );
                 pNxt = pUp->GetLastLower();
                 (*pUpperFrames)[x-2] = pNxt;
             }
@@ -407,17 +409,15 @@ void SwNode2LayImpl::RestoreUpperFrames( SwNodes& rNds, sal_uLong nStt, sal_uLon
             // #i18103# - invalidate size of section in order to
             // assure, that the section is formatted, unless it was 'Collocked'
             // from its 'collection' until its 'restoration'.
-            pSctFrame->_InvalidateSize();
+            pSctFrame->InvalidateSize_();
         }
     }
 }
 
-SwFrame* SwNode2LayImpl::GetFrame( const Point* pDocPos,
-                                const SwPosition *pPos,
-                                const bool bCalcFrame ) const
+SwFrame* SwNode2LayImpl::GetFrame( const Point* pDocPos ) const
 {
     // test if change of member pIter -> pMod broke anything
-    return pMod ? ::GetFrameOfModify( nullptr, *pMod, USHRT_MAX, pDocPos, pPos, bCalcFrame ) : nullptr;
+    return pMod ? ::GetFrameOfModify( nullptr, *pMod, FRM_ALL, pDocPos, nullptr ) : nullptr;
 }
 
 SwNode2Layout::SwNode2Layout( const SwNode& rNd, sal_uLong nIdx )
@@ -451,11 +451,9 @@ SwNode2Layout::~SwNode2Layout()
 {
 }
 
-SwFrame* SwNode2Layout::GetFrame( const Point* pDocPos,
-                              const SwPosition *pPos,
-                              const bool bCalcFrame ) const
+SwFrame* SwNode2Layout::GetFrame( const Point* pDocPos ) const
 {
-    return pImpl->GetFrame( pDocPos, pPos, bCalcFrame );
+    return pImpl->GetFrame( pDocPos );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
