@@ -17,34 +17,36 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "hintids.hxx"
+#include <hintids.hxx>
 #include <editeng/protitem.hxx>
 #include <svx/svdpagv.hxx>
 #include <svx/fmmodel.hxx>
 #include <sot/exchange.hxx>
 #include <svx/sdrundomanager.hxx>
+#include <tools/globname.hxx>
 #include <editeng/outliner.hxx>
 #include <com/sun/star/embed/EmbedMisc.hpp>
 
-#include "swtypes.hxx"
-#include "pagefrm.hxx"
-#include "rootfrm.hxx"
-#include "cntfrm.hxx"
-#include "flyfrm.hxx"
-#include "frmfmt.hxx"
-#include "dflyobj.hxx"
-#include "dcontact.hxx"
-#include "textboxhelper.hxx"
-#include "frmatr.hxx"
-#include "viewsh.hxx"
-#include "viewimp.hxx"
-#include "dview.hxx"
-#include "dpage.hxx"
-#include "doc.hxx"
-#include "mdiexp.hxx"
+#include <swtypes.hxx>
+#include <pagefrm.hxx>
+#include <rootfrm.hxx>
+#include <cntfrm.hxx>
+#include <flyfrm.hxx>
+#include <frmfmt.hxx>
+#include <dflyobj.hxx>
+#include <dcontact.hxx>
+#include <textboxhelper.hxx>
+#include <frmatr.hxx>
+#include <viewsh.hxx>
+#include <viewimp.hxx>
+#include <dview.hxx>
+#include <dpage.hxx>
+#include <doc.hxx>
+#include <mdiexp.hxx>
 #include <ndole.hxx>
+#include <ndgrf.hxx>
 #include <fmtanchr.hxx>
-#include "shellres.hxx"
+#include <shellres.hxx>
 #include <IDocumentUndoRedo.hxx>
 #include <DocumentSettingManager.hxx>
 #include <IDocumentLayoutAccess.hxx>
@@ -63,51 +65,49 @@ class SwSdrHdl : public SdrHdl
 {
 public:
     SwSdrHdl(const Point& rPnt, bool bTopRight ) :
-        SdrHdl( rPnt, bTopRight ? HDL_ANCHOR_TR : HDL_ANCHOR ) {}
-    virtual bool IsFocusHdl() const SAL_OVERRIDE;
+        SdrHdl( rPnt, bTopRight ? SdrHdlKind::Anchor_TR : SdrHdlKind::Anchor ) {}
+    virtual bool IsFocusHdl() const override;
 };
 
 bool SwSdrHdl::IsFocusHdl() const
 {
-    if( HDL_ANCHOR == eKind || HDL_ANCHOR_TR == eKind )
+    if( SdrHdlKind::Anchor == eKind || SdrHdlKind::Anchor_TR == eKind )
         return true;
     return SdrHdl::IsFocusHdl();
 }
 
-static const SwFrm *lcl_FindAnchor( const SdrObject *pObj, bool bAll )
+static const SwFrame *lcl_FindAnchor( const SdrObject *pObj, bool bAll )
 {
-    const SwVirtFlyDrawObj *pVirt = pObj->ISA(SwVirtFlyDrawObj) ?
-                                            static_cast<const SwVirtFlyDrawObj*>(pObj) : 0;
+    const SwVirtFlyDrawObj *pVirt = dynamic_cast< const SwVirtFlyDrawObj *>( pObj ) !=  nullptr ?
+                                            static_cast<const SwVirtFlyDrawObj*>(pObj) : nullptr;
     if ( pVirt )
     {
-        if ( bAll || !pVirt->GetFlyFrm()->IsFlyInCntFrm() )
-            return pVirt->GetFlyFrm()->GetAnchorFrm();
+        if ( bAll || !pVirt->GetFlyFrame()->IsFlyInContentFrame() )
+            return pVirt->GetFlyFrame()->GetAnchorFrame();
     }
     else
     {
         const SwDrawContact *pCont = static_cast<const SwDrawContact*>(GetUserCall(pObj));
         if ( pCont )
-            return pCont->GetAnchorFrm( pObj );
+            return pCont->GetAnchorFrame( pObj );
     }
-    return 0;
+    return nullptr;
 }
 
 SwDrawView::SwDrawView( SwViewShellImp &rI, SdrModel *pMd, OutputDevice *pOutDev) :
     FmFormView( static_cast<FmFormModel*>(pMd), pOutDev ),
-    rImp( rI )
+    m_rImp( rI )
 {
     SetPageVisible( false );
     SetBordVisible( false );
     SetGridVisible( false );
     SetHlplVisible( false );
     SetGlueVisible( false );
-    SetFrameDragSingles( true );
-    SetVirtualObjectBundling( true );
-    SetSwapAsynchron( true );
+    SetFrameDragSingles();
+    SetSwapAsynchron();
 
     EnableExtendedKeyInputDispatcher( false );
     EnableExtendedMouseEventDispatcher( false );
-    EnableExtendedCommandEventDispatcher( false );
 
     SetHitTolerancePixel( GetMarkHdlSizePixel()/2 );
 
@@ -145,9 +145,9 @@ SdrObject* impLocalHitCorrection(SdrObject* pRetval, const Point& rPnt, sal_uInt
 
         if(pSwVirtFlyDrawObj)
         {
-            if(pSwVirtFlyDrawObj->GetFlyFrm()->Lower() && pSwVirtFlyDrawObj->GetFlyFrm()->Lower()->IsNoTextFrm())
+            if(pSwVirtFlyDrawObj->GetFlyFrame()->Lower() && pSwVirtFlyDrawObj->GetFlyFrame()->Lower()->IsNoTextFrame())
             {
-                // the old method used IsNoTextFrm (should be for SW's own OLE and
+                // the old method used IsNoTextFrame (should be for SW's own OLE and
                 // graphic's) to accept hit only based on outer bounds; nothing to do
             }
             else
@@ -175,7 +175,7 @@ SdrObject* impLocalHitCorrection(SdrObject* pRetval, const Point& rPnt, sal_uInt
                     if(aInnerBound.isInside(basegfx::B2DPoint(rPnt.X(), rPnt.Y())))
                     {
                         // exclude this hit
-                        pRetval = 0;
+                        pRetval = nullptr;
                     }
                 }
             }
@@ -185,7 +185,7 @@ SdrObject* impLocalHitCorrection(SdrObject* pRetval, const Point& rPnt, sal_uInt
     return pRetval;
 }
 
-SdrObject* SwDrawView::CheckSingleSdrObjectHit(const Point& rPnt, sal_uInt16 nTol, SdrObject* pObj, SdrPageView* pPV, SdrSearchOptions nOptions, const SetOfByte* pMVisLay) const
+SdrObject* SwDrawView::CheckSingleSdrObjectHit(const Point& rPnt, sal_uInt16 nTol, SdrObject* pObj, SdrPageView* pPV, SdrSearchOptions nOptions, const SdrLayerIDSet* pMVisLay) const
 {
     // call parent
     SdrObject* pRetval = FmFormView::CheckSingleSdrObjectHit(rPnt, nTol, pObj, pPV, nOptions, pMVisLay);
@@ -217,16 +217,16 @@ void SwDrawView::AddCustomHdl()
     }
     const SwFormatAnchor &rAnchor = pFrameFormat->GetAnchor();
 
-    if (FLY_AS_CHAR == rAnchor.GetAnchorId())
+    if (RndStdIds::FLY_AS_CHAR == rAnchor.GetAnchorId())
         return;
 
-    const SwFrm* pAnch;
-    if(0 == (pAnch = CalcAnchor()))
+    const SwFrame* pAnch;
+    if(nullptr == (pAnch = CalcAnchor()))
         return;
 
-    Point aPos(aAnchorPoint);
+    Point aPos(m_aAnchorPoint);
 
-    if ( FLY_AT_CHAR == rAnchor.GetAnchorId() )
+    if ( RndStdIds::FLY_AT_CHAR == rAnchor.GetAnchorId() )
     {
         // #i28701# - use last character rectangle saved at object
         // in order to avoid a format of the anchor frame
@@ -247,24 +247,24 @@ SdrObject* SwDrawView::GetMaxToTopObj( SdrObject* pObj ) const
 {
     if ( GetUserCall(pObj) )
     {
-        const SwFrm *pAnch = ::lcl_FindAnchor( pObj, false );
+        const SwFrame *pAnch = ::lcl_FindAnchor( pObj, false );
         if ( pAnch )
         {
             //The topmost Obj within the anchor must not be overtaken.
-            const SwFlyFrm *pFly = pAnch->FindFlyFrm();
+            const SwFlyFrame *pFly = pAnch->FindFlyFrame();
             if ( pFly )
             {
-                const SwPageFrm *pPage = pFly->FindPageFrm();
+                const SwPageFrame *pPage = pFly->FindPageFrame();
                 if ( pPage->GetSortedObjs() )
                 {
                     size_t nOrdNum = 0;
-                    for ( size_t i = 0; i < pPage->GetSortedObjs()->size(); ++i )
+                    for (SwAnchoredObject* i : *pPage->GetSortedObjs())
                     {
-                        const SdrObject *pO = (*pPage->GetSortedObjs())[i]->GetDrawObj();
+                        const SdrObject *pO = i->GetDrawObj();
 
                         if ( pO->GetOrdNumDirect() > nOrdNum )
                         {
-                            const SwFrm *pTmpAnch = ::lcl_FindAnchor( pO, false );
+                            const SwFrame *pTmpAnch = ::lcl_FindAnchor( pO, false );
                             if ( pFly->IsAnLower( pTmpAnch ) )
                             {
                                 nOrdNum = pO->GetOrdNumDirect();
@@ -284,37 +284,37 @@ SdrObject* SwDrawView::GetMaxToTopObj( SdrObject* pObj ) const
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 SdrObject* SwDrawView::GetMaxToBtmObj(SdrObject* pObj) const
 {
     if ( GetUserCall(pObj) )
     {
-        const SwFrm *pAnch = ::lcl_FindAnchor( pObj, false );
+        const SwFrame *pAnch = ::lcl_FindAnchor( pObj, false );
         if ( pAnch )
         {
             //The Fly of the anchor must not be "flying under".
-            const SwFlyFrm *pFly = pAnch->FindFlyFrm();
+            const SwFlyFrame *pFly = pAnch->FindFlyFrame();
             if ( pFly )
             {
-                SdrObject *pRet = (SdrObject*)pFly->GetVirtDrawObj();
-                return pRet != pObj ? pRet : 0;
+                SdrObject *pRet = const_cast<SdrObject*>(static_cast<SdrObject const *>(pFly->GetVirtDrawObj()));
+                return pRet != pObj ? pRet : nullptr;
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
 /// determine maximal order number for a 'child' object of given 'parent' object
-sal_uInt32 SwDrawView::_GetMaxChildOrdNum( const SwFlyFrm& _rParentObj,
+sal_uInt32 SwDrawView::GetMaxChildOrdNum( const SwFlyFrame& _rParentObj,
                                            const SdrObject* _pExclChildObj )
 {
     sal_uInt32 nMaxChildOrdNum = _rParentObj.GetDrawObj()->GetOrdNum();
 
     const SdrPage* pDrawPage = _rParentObj.GetDrawObj()->GetPage();
     OSL_ENSURE( pDrawPage,
-            "<SwDrawView::_GetMaxChildOrdNum(..) - missing drawing page at parent object - crash!" );
+            "<SwDrawView::GetMaxChildOrdNum(..) - missing drawing page at parent object - crash!" );
 
     const size_t nObjCount = pDrawPage->GetObjCount();
     for ( size_t i = nObjCount-1; i > _rParentObj.GetDrawObj()->GetOrdNum() ; --i )
@@ -339,14 +339,14 @@ sal_uInt32 SwDrawView::_GetMaxChildOrdNum( const SwFlyFrm& _rParentObj,
 }
 
 /// method to move 'repeated' objects of the given moved object to the according level
-void SwDrawView::_MoveRepeatedObjs( const SwAnchoredObject& _rMovedAnchoredObj,
+void SwDrawView::MoveRepeatedObjs( const SwAnchoredObject& _rMovedAnchoredObj,
                                     const std::vector<SdrObject*>& _rMovedChildObjs ) const
 {
     // determine 'repeated' objects of already moved object <_rMovedAnchoredObj>
-    std::list<SwAnchoredObject*> aAnchoredObjs;
+    std::vector<SwAnchoredObject*> aAnchoredObjs;
     {
         const SwContact* pContact = ::GetUserCall( _rMovedAnchoredObj.GetDrawObj() );
-        assert(pContact && "SwDrawView::_MoveRepeatedObjs(..) - missing contact object -> crash.");
+        assert(pContact && "SwDrawView::MoveRepeatedObjs(..) - missing contact object -> crash.");
         pContact->GetAnchoredObjs( aAnchoredObjs );
     }
 
@@ -366,16 +366,16 @@ void SwDrawView::_MoveRepeatedObjs( const SwAnchoredObject& _rMovedAnchoredObj,
                                             nNewPos );
                 pDrawPage->RecalcObjOrdNums();
                 // adjustments for accessibility API
-                if ( pAnchoredObj->ISA(SwFlyFrm) )
+                if ( dynamic_cast< const SwFlyFrame *>( pAnchoredObj ) !=  nullptr )
                 {
-                    const SwFlyFrm *pTmpFlyFrm = static_cast<SwFlyFrm*>(pAnchoredObj);
-                    rImp.DisposeAccessibleFrm( pTmpFlyFrm );
-                    rImp.AddAccessibleFrm( pTmpFlyFrm );
+                    const SwFlyFrame *pTmpFlyFrame = static_cast<SwFlyFrame*>(pAnchoredObj);
+                    m_rImp.DisposeAccessibleFrame( pTmpFlyFrame );
+                    m_rImp.AddAccessibleFrame( pTmpFlyFrame );
                 }
                 else
                 {
-                    rImp.DisposeAccessibleObj( pAnchoredObj->GetDrawObj() );
-                    rImp.AddAccessibleObj( pAnchoredObj->GetDrawObj() );
+                    m_rImp.DisposeAccessibleObj(pAnchoredObj->GetDrawObj(), true);
+                    m_rImp.AddAccessibleObj( pAnchoredObj->GetDrawObj() );
                 }
             }
             aAnchoredObjs.pop_back();
@@ -388,7 +388,7 @@ void SwDrawView::_MoveRepeatedObjs( const SwAnchoredObject& _rMovedAnchoredObj,
             SdrObject* pChildObj = (*aObjIter);
             {
                 const SwContact* pContact = ::GetUserCall( pChildObj );
-                assert(pContact && "SwDrawView::_MoveRepeatedObjs(..) - missing contact object -> crash.");
+                assert(pContact && "SwDrawView::MoveRepeatedObjs(..) - missing contact object -> crash.");
                 pContact->GetAnchoredObjs( aAnchoredObjs );
             }
             // move 'repeated' ones to the same order number as the already moved one.
@@ -402,16 +402,16 @@ void SwDrawView::_MoveRepeatedObjs( const SwAnchoredObject& _rMovedAnchoredObj,
                                                 nTmpNewPos );
                     pDrawPage->RecalcObjOrdNums();
                     // adjustments for accessibility API
-                    if ( pAnchoredObj->ISA(SwFlyFrm) )
+                    if ( dynamic_cast< const SwFlyFrame *>( pAnchoredObj ) !=  nullptr )
                     {
-                        const SwFlyFrm *pTmpFlyFrm = static_cast<SwFlyFrm*>(pAnchoredObj);
-                        rImp.DisposeAccessibleFrm( pTmpFlyFrm );
-                        rImp.AddAccessibleFrm( pTmpFlyFrm );
+                        const SwFlyFrame *pTmpFlyFrame = static_cast<SwFlyFrame*>(pAnchoredObj);
+                        m_rImp.DisposeAccessibleFrame( pTmpFlyFrame );
+                        m_rImp.AddAccessibleFrame( pTmpFlyFrame );
                     }
                     else
                     {
-                        rImp.DisposeAccessibleObj( pAnchoredObj->GetDrawObj() );
-                        rImp.AddAccessibleObj( pAnchoredObj->GetDrawObj() );
+                        m_rImp.DisposeAccessibleObj(pAnchoredObj->GetDrawObj(), true);
+                        m_rImp.AddAccessibleObj( pAnchoredObj->GetDrawObj() );
                     }
                 }
                 aAnchoredObjs.pop_back();
@@ -438,8 +438,8 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
 
     SwAnchoredObject* pMovedAnchoredObj =
                                 ::GetUserCall( pObj )->GetAnchoredObj( pObj );
-    const SwFlyFrm* pParentAnchoredObj =
-                                pMovedAnchoredObj->GetAnchorFrm()->FindFlyFrm();
+    const SwFlyFrame* pParentAnchoredObj =
+                                pMovedAnchoredObj->GetAnchorFrame()->FindFlyFrame();
 
     const bool bMovedForward = nOldPos < nNewPos;
 
@@ -449,7 +449,7 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
         if ( bMovedForward )
         {
             const size_t nMaxChildOrdNumWithoutMoved =
-                    _GetMaxChildOrdNum( *pParentAnchoredObj, pMovedAnchoredObj->GetDrawObj() );
+                    GetMaxChildOrdNum( *pParentAnchoredObj, pMovedAnchoredObj->GetDrawObj() );
             if ( nNewPos > nMaxChildOrdNumWithoutMoved+1 )
             {
                 // set position to the top of the 'child' object group
@@ -507,11 +507,11 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
 
     // On move forward, assure that object is moved before its own children.
     // Only Writer fly frames can have children.
-    if ( pMovedAnchoredObj->ISA(SwFlyFrm) &&
+    if ( dynamic_cast< const SwFlyFrame *>( pMovedAnchoredObj ) !=  nullptr &&
          bMovedForward && nNewPos < nObjCount - 1 )
     {
         sal_uInt32 nMaxChildOrdNum =
-                    _GetMaxChildOrdNum( *(static_cast<const SwFlyFrm*>(pMovedAnchoredObj)) );
+                    GetMaxChildOrdNum( *static_cast<const SwFlyFrame*>(pMovedAnchoredObj) );
         if ( nNewPos < nMaxChildOrdNum )
         {
             // determine position before the object before its top 'child' object
@@ -537,7 +537,7 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
     {
         size_t nTmpNewPos( nNewPos );
         const SwFrameFormat* pParentFrameFormat =
-                pParentAnchoredObj ? &(pParentAnchoredObj->GetFrameFormat()) : 0L;
+                pParentAnchoredObj ? &(pParentAnchoredObj->GetFrameFormat()) : nullptr;
         const SdrObject* pTmpObj = pDrawPage->GetObj( nNewPos + 1 );
         while ( pTmpObj )
         {
@@ -545,9 +545,9 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
             // If object is anchored inside a invisible part of the document
             // (e.g. page header, whose page style isn't applied, or hidden
             // section), no anchor frame exists.
-            const SwFrm* pTmpAnchorFrm = lcl_FindAnchor( pTmpObj, true );
-            const SwFlyFrm* pTmpParentObj = pTmpAnchorFrm
-                                            ? pTmpAnchorFrm->FindFlyFrm() : 0L;
+            const SwFrame* pTmpAnchorFrame = lcl_FindAnchor( pTmpObj, true );
+            const SwFlyFrame* pTmpParentObj = pTmpAnchorFrame
+                                            ? pTmpAnchorFrame->FindFlyFrame() : nullptr;
             if ( pTmpParentObj &&
                  &(pTmpParentObj->GetFrameFormat()) != pParentFrameFormat )
             {
@@ -578,13 +578,13 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
     std::vector< SdrObject* > aMovedChildObjs;
 
     // move 'children' accordingly
-    if ( pMovedAnchoredObj->ISA(SwFlyFrm) )
+    if ( dynamic_cast< const SwFlyFrame *>( pMovedAnchoredObj ) !=  nullptr )
     {
-        const SwFlyFrm* pFlyFrm = static_cast<SwFlyFrm*>(pMovedAnchoredObj);
+        const SwFlyFrame* pFlyFrame = static_cast<SwFlyFrame*>(pMovedAnchoredObj);
 
         // adjustments for accessibility API
-        rImp.DisposeAccessibleFrm( pFlyFrm );
-        rImp.AddAccessibleFrm( pFlyFrm );
+        m_rImp.DisposeAccessibleFrame( pFlyFrame );
+        m_rImp.AddAccessibleFrame( pFlyFrame );
 
         const sal_uInt32 nChildNewPos = bMovedForward ? nNewPos : nNewPos+1;
         size_t i = bMovedForward ? nOldPos : nObjCount-1;
@@ -598,12 +598,12 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
             // If object is anchored inside a invisible part of the document
             // (e.g. page header, whose page style isn't applied, or hidden
             // section), no anchor frame exists.
-            const SwFrm* pTmpAnchorFrm = lcl_FindAnchor( pTmpObj, true );
-            const SwFlyFrm* pTmpParentObj = pTmpAnchorFrm
-                                            ? pTmpAnchorFrm->FindFlyFrm() : 0L;
+            const SwFrame* pTmpAnchorFrame = lcl_FindAnchor( pTmpObj, true );
+            const SwFlyFrame* pTmpParentObj = pTmpAnchorFrame
+                                            ? pTmpAnchorFrame->FindFlyFrame() : nullptr;
             if ( pTmpParentObj &&
-                 ( ( pTmpParentObj == pFlyFrm ) ||
-                   ( pFlyFrm->IsUpperOf( *pTmpParentObj ) ) ) )
+                 ( ( pTmpParentObj == pFlyFrame ) ||
+                   ( pFlyFrame->IsUpperOf( *pTmpParentObj ) ) ) )
             {
                 // move child object.,
                 pDrawPage->SetObjectOrdNum( i, nChildNewPos );
@@ -611,17 +611,17 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
                 // collect 'child' object
                 aMovedChildObjs.push_back( pTmpObj );
                 // adjustments for accessibility API
-                if ( pTmpObj->ISA(SwVirtFlyDrawObj) )
+                if ( dynamic_cast< const SwVirtFlyDrawObj *>( pTmpObj ) !=  nullptr )
                 {
-                    const SwFlyFrm *pTmpFlyFrm =
-                        static_cast<SwVirtFlyDrawObj*>(pTmpObj)->GetFlyFrm();
-                    rImp.DisposeAccessibleFrm( pTmpFlyFrm );
-                    rImp.AddAccessibleFrm( pTmpFlyFrm );
+                    const SwFlyFrame *pTmpFlyFrame =
+                        static_cast<SwVirtFlyDrawObj*>(pTmpObj)->GetFlyFrame();
+                    m_rImp.DisposeAccessibleFrame( pTmpFlyFrame );
+                    m_rImp.AddAccessibleFrame( pTmpFlyFrame );
                 }
                 else
                 {
-                    rImp.DisposeAccessibleObj( pTmpObj );
-                    rImp.AddAccessibleObj( pTmpObj );
+                    m_rImp.DisposeAccessibleObj(pTmpObj, true);
+                    m_rImp.AddAccessibleObj( pTmpObj );
                 }
             }
             else
@@ -639,15 +639,15 @@ void SwDrawView::ObjOrderChanged( SdrObject* pObj, sal_uLong nOldPos,
     else
     {
         // adjustments for accessibility API
-        rImp.DisposeAccessibleObj( pObj );
-        rImp.AddAccessibleObj( pObj );
+        m_rImp.DisposeAccessibleObj(pObj, true);
+        m_rImp.AddAccessibleObj( pObj );
     }
 
-    _MoveRepeatedObjs( *pMovedAnchoredObj, aMovedChildObjs );
+    MoveRepeatedObjs( *pMovedAnchoredObj, aMovedChildObjs );
 }
 
 bool SwDrawView::TakeDragLimit( SdrDragMode eMode,
-                                            Rectangle& rRect ) const
+                                            tools::Rectangle& rRect ) const
 {
     const SdrMarkList &rMrkList = GetMarkedObjectList();
     bool bRet = false;
@@ -655,7 +655,7 @@ bool SwDrawView::TakeDragLimit( SdrDragMode eMode,
     {
         const SdrObject *pObj = rMrkList.GetMark( 0 )->GetMarkedSdrObj();
         SwRect aRect;
-        if( ::CalcClipRect( pObj, aRect, eMode == SDRDRAG_MOVE ) )
+        if( ::CalcClipRect( pObj, aRect, eMode == SdrDragMode::Move ) )
         {
             rRect = aRect.SVRect();
             bRet = true;
@@ -664,36 +664,36 @@ bool SwDrawView::TakeDragLimit( SdrDragMode eMode,
     return bRet;
 }
 
-const SwFrm* SwDrawView::CalcAnchor()
+const SwFrame* SwDrawView::CalcAnchor()
 {
     const SdrMarkList &rMrkList = GetMarkedObjectList();
     if ( rMrkList.GetMarkCount() != 1 )
-        return NULL;
+        return nullptr;
 
     SdrObject* pObj = rMrkList.GetMark( 0 )->GetMarkedSdrObj();
 
     //Search for paragraph bound objects, otherwise only the
     //current anchor. Search only if we currently drag.
-    const SwFrm* pAnch;
-    Rectangle aMyRect;
-    const bool bFly = pObj->ISA(SwVirtFlyDrawObj);
+    const SwFrame* pAnch;
+    tools::Rectangle aMyRect;
+    const bool bFly = dynamic_cast< const SwVirtFlyDrawObj *>( pObj ) !=  nullptr;
     if ( bFly )
     {
-        pAnch = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrm()->GetAnchorFrm();
-        aMyRect = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrm()->Frm().SVRect();
+        pAnch = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrame()->GetAnchorFrame();
+        aMyRect = static_cast<SwVirtFlyDrawObj*>(pObj)->GetFlyFrame()->getFrameArea().SVRect();
     }
     else
     {
         SwDrawContact *pC = static_cast<SwDrawContact*>(GetUserCall(pObj));
         // determine correct anchor position for 'virtual' drawing objects.
         // #i26791#
-        pAnch = pC->GetAnchorFrm( pObj );
+        pAnch = pC->GetAnchorFrame( pObj );
         if( !pAnch )
         {
             pC->ConnectToLayout();
             // determine correct anchor position for 'virtual' drawing objects.
             // #i26791#
-            pAnch = pC->GetAnchorFrm( pObj );
+            pAnch = pC->GetAnchorFrame( pObj );
         }
         aMyRect = pObj->GetSnapRect();
     }
@@ -707,52 +707,52 @@ const SwFrm* SwDrawView::CalcAnchor()
     if ( IsAction() )
     {
         if ( !TakeDragObjAnchorPos( aPt, bTopRight ) )
-            return NULL;
+            return nullptr;
     }
     else
     {
-        Rectangle aRect = pObj->GetSnapRect();
+        tools::Rectangle aRect = pObj->GetSnapRect();
         aPt = bTopRight ? aRect.TopRight() : aRect.TopLeft();
     }
 
     if ( aPt != aMyPt )
     {
-        if ( pAnch && pAnch->IsContentFrm() )
+        if ( pAnch && pAnch->IsContentFrame() )
         {
             // allow drawing objects in header/footer,
             // but exclude control objects.
             bool bBodyOnly = CheckControlLayer( pObj );
-            pAnch = ::FindAnchor( static_cast<const SwContentFrm*>(pAnch), aPt, bBodyOnly );
+            pAnch = ::FindAnchor( static_cast<const SwContentFrame*>(pAnch), aPt, bBodyOnly );
         }
         else if ( !bFly )
         {
             const SwRect aRect( aPt.getX(), aPt.getY(), 1, 1 );
 
             SwDrawContact* pContact = static_cast<SwDrawContact*>(GetUserCall(pObj));
-            if ( pContact->GetAnchorFrm( pObj ) &&
-                 pContact->GetAnchorFrm( pObj )->IsPageFrm() )
-                pAnch = pContact->GetPageFrm();
+            if ( pContact->GetAnchorFrame( pObj ) &&
+                 pContact->GetAnchorFrame( pObj )->IsPageFrame() )
+                pAnch = pContact->GetPageFrame();
             else
                 pAnch = pContact->FindPage( aRect );
         }
     }
     if( pAnch && !pAnch->IsProtected() )
-        aAnchorPoint = pAnch->GetFrmAnchorPos( ::HasWrap( pObj ) );
+        m_aAnchorPoint = pAnch->GetFrameAnchorPos( ::HasWrap( pObj ) );
     else
-        pAnch = 0;
+        pAnch = nullptr;
     return pAnch;
 }
 
 void SwDrawView::ShowDragAnchor()
 {
-    SdrHdl* pHdl = maHdlList.GetHdl(HDL_ANCHOR);
+    SdrHdl* pHdl = maHdlList.GetHdl(SdrHdlKind::Anchor);
     if ( ! pHdl )
-        pHdl = maHdlList.GetHdl(HDL_ANCHOR_TR);
+        pHdl = maHdlList.GetHdl(SdrHdlKind::Anchor_TR);
 
     if(pHdl)
     {
         CalcAnchor();
-        pHdl->SetPos(aAnchorPoint);
+        pHdl->SetPos(m_aAnchorPoint);
     }
 }
 
@@ -795,10 +795,10 @@ void SwDrawView::ModelHasChanged()
     }
 }
 
-void SwDrawView::MakeVisible( const Rectangle &rRect, vcl::Window & )
+void SwDrawView::MakeVisible( const tools::Rectangle &rRect, vcl::Window & )
 {
-    OSL_ENSURE( rImp.GetShell()->GetWin(), "MakeVisible, unknown Window");
-    rImp.GetShell()->MakeVisible( SwRect( rRect ) );
+    OSL_ENSURE( m_rImp.GetShell()->GetWin(), "MakeVisible, unknown Window");
+    m_rImp.GetShell()->MakeVisible( SwRect( rRect ) );
 }
 
 void SwDrawView::CheckPossibilities()
@@ -815,22 +815,28 @@ void SwDrawView::CheckPossibilities()
     const SdrMarkList &rMrkList = GetMarkedObjectList();
     bool bProtect = false;
     bool bSzProtect = false;
+    bool bRotate(false);
+
     for ( size_t i = 0; !bProtect && i < rMrkList.GetMarkCount(); ++i )
     {
         const SdrObject *pObj = rMrkList.GetMark( i )->GetMarkedSdrObj();
-        const SwFrm *pFrm = NULL;
-        if ( pObj->ISA(SwVirtFlyDrawObj) )
+        const SwFrame *pFrame = nullptr;
+        if ( auto pVirtFlyDrawObj = dynamic_cast< const SwVirtFlyDrawObj *>( pObj ) )
         {
-            const SwFlyFrm *pFly = static_cast<const SwVirtFlyDrawObj*>(pObj)->GetFlyFrm();
+            const SwFlyFrame *pFly = pVirtFlyDrawObj->GetFlyFrame();
             if ( pFly  )
             {
-                pFrm = pFly->GetAnchorFrm();
-                if ( pFly->Lower() && pFly->Lower()->IsNoTextFrm() )
+                pFrame = pFly->GetAnchorFrame();
+                if ( pFly->Lower() && pFly->Lower()->IsNoTextFrame() )
                 {
-                    SwOLENode *pNd = const_cast<SwContentFrm*>(static_cast<const SwContentFrm*>(pFly->Lower()))->GetNode()->GetOLENode();
-                    if ( pNd )
+                    const SwContentFrame* pCntFr(static_cast<const SwContentFrame*>(pFly->Lower()));
+                    const SwOLENode* pOLENd = pCntFr->GetNode()->GetOLENode();
+                    const SwGrfNode* pGrfNd = pCntFr->GetNode()->GetGrfNode();
+
+                    if ( pOLENd )
                     {
-                        uno::Reference < embed::XEmbeddedObject > xObj = pNd->GetOLEObj().GetOleRef();
+                        const uno::Reference < embed::XEmbeddedObject > xObj = const_cast< SwOLEObj& >(pOLENd->GetOLEObj()).GetOleRef();
+
                         if ( xObj.is() )
                         {
                             // --> improvement for the future, when more
@@ -842,12 +848,19 @@ void SwDrawView::CheckPossibilities()
                             // #i972: protect position if it is a Math object anchored 'as char' and baseline alignment is activated
                             SwDoc* pDoc = Imp().GetShell()->GetDoc();
                             const bool bProtectMathPos = SotExchange::IsMath( xObj->getClassID() )
-                                    && FLY_AS_CHAR == pFly->GetFormat()->GetAnchor().GetAnchorId()
+                                    && RndStdIds::FLY_AS_CHAR == pFly->GetFormat()->GetAnchor().GetAnchorId()
                                     && pDoc->GetDocumentSettingManager().get( DocumentSettingId::MATH_BASELINE_ALIGNMENT );
                             if (bProtectMathPos)
                                 bMoveProtect = true;
                         }
                     }
+                    else if(pGrfNd)
+                    {
+                        // RotGrfFlyFrame: GraphicNode allows rotation(s). The loop ew are in stops
+                        // as soon as bMoveProtect is set, but since rotation is valid only with
+                        // a single object selected this makes no difference
+                        bRotate = true;
+                    }
                 }
             }
         }
@@ -855,10 +868,10 @@ void SwDrawView::CheckPossibilities()
         {
             SwDrawContact *pC = static_cast<SwDrawContact*>(GetUserCall(pObj));
             if ( pC )
-                pFrm = pC->GetAnchorFrm( pObj );
+                pFrame = pC->GetAnchorFrame( pObj );
         }
-        if ( pFrm )
-            bProtect = pFrm->IsProtected(); //Frames, areas etc.
+        if ( pFrame )
+            bProtect = pFrame->IsProtected(); //Frames, areas etc.
         {
             SwFrameFormat* pFrameFormat( ::FindFrameFormat( const_cast<SdrObject*>(pObj) ) );
             if ( !pFrameFormat )
@@ -866,7 +879,7 @@ void SwDrawView::CheckPossibilities()
                 OSL_FAIL( "<SwDrawView::CheckPossibilities()> - missing frame format" );
                 bProtect = true;
             }
-            else if ((FLY_AS_CHAR == pFrameFormat->GetAnchor().GetAnchorId()) &&
+            else if ((RndStdIds::FLY_AS_CHAR == pFrameFormat->GetAnchor().GetAnchorId()) &&
                       rMrkList.GetMarkCount() > 1 )
             {
                 bProtect = true;
@@ -875,6 +888,10 @@ void SwDrawView::CheckPossibilities()
     }
     bMoveProtect    |= bProtect;
     bResizeProtect  |= bProtect || bSzProtect;
+
+    // RotGrfFlyFrame: allow rotation when SwGrfNode is selected and not size protected
+    bRotateFreeAllowed |= bRotate && !bProtect;
+    bRotate90Allowed |= bRotateFreeAllowed;
 }
 
 /// replace marked <SwDrawVirtObj>-objects by its reference object for delete marked objects.
@@ -899,7 +916,7 @@ void SwDrawView::ReplaceMarkedDrawVirtObjs( SdrMarkView& _rMarkView )
         while ( !aMarkedObjs.empty() )
         {
             SdrObject* pMarkObj = aMarkedObjs.back();
-            if ( pMarkObj->ISA(SwDrawVirtObj) )
+            if ( dynamic_cast< const SwDrawVirtObj *>( pMarkObj ) !=  nullptr )
             {
                 SdrObject* pRefObj = &(static_cast<SwDrawVirtObj*>(pMarkObj)->ReferencedObj());
                 if ( !_rMarkView.IsObjMarked( pRefObj )  )
@@ -919,19 +936,24 @@ void SwDrawView::ReplaceMarkedDrawVirtObjs( SdrMarkView& _rMarkView )
     }
 }
 
+SfxViewShell* SwDrawView::GetSfxViewShell() const
+{
+    return m_rImp.GetShell()->GetSfxViewShell();
+}
+
 void SwDrawView::DeleteMarked()
 {
     SwDoc* pDoc = Imp().GetShell()->GetDoc();
-    SwRootFrm *pTmpRoot = pDoc->getIDocumentLayoutAccess().GetCurrentLayout();
+    SwRootFrame *pTmpRoot = pDoc->getIDocumentLayoutAccess().GetCurrentLayout();
     if ( pTmpRoot )
         pTmpRoot->StartAllAction();
-    pDoc->GetIDocumentUndoRedo().StartUndo(UNDO_EMPTY, NULL);
+    pDoc->GetIDocumentUndoRedo().StartUndo(SwUndoId::EMPTY, nullptr);
     // replace marked <SwDrawVirtObj>-objects by its reference objects.
     {
-        SdrPageView* pDrawPageView = rImp.GetPageView();
+        SdrPageView* pDrawPageView = m_rImp.GetPageView();
         if ( pDrawPageView )
         {
-            SdrMarkView* pMarkView = PTR_CAST( SdrMarkView, &(pDrawPageView->GetView()) );
+            SdrMarkView* pMarkView = &(pDrawPageView->GetView());
             if ( pMarkView )
             {
                 ReplaceMarkedDrawVirtObjs( *pMarkView );
@@ -947,7 +969,7 @@ void SwDrawView::DeleteMarked()
         SdrObject *pObject = rMarkList.GetMark(i)->GetMarkedSdrObj();
         SwDrawContact* pDrawContact = static_cast<SwDrawContact*>(GetUserCall(pObject));
         SwFrameFormat* pFormat = pDrawContact->GetFormat();
-        if (SwFrameFormat* pTextBox = SwTextBoxHelper::findTextBox(pFormat))
+        if (SwFrameFormat* pTextBox = SwTextBoxHelper::getOtherTextBoxFormat(pFormat, RES_DRAWFRMFMT))
             aTextBoxesToDelete.push_back(pTextBox);
     }
 
@@ -960,7 +982,7 @@ void SwDrawView::DeleteMarked()
         for (std::vector<SwFrameFormat*>::iterator i = aTextBoxesToDelete.begin(); i != aTextBoxesToDelete.end(); ++i)
             pDoc->getIDocumentLayoutAccess().DelLayoutFormat(*i);
     }
-    pDoc->GetIDocumentUndoRedo().EndUndo(UNDO_EMPTY, NULL);
+    pDoc->GetIDocumentUndoRedo().EndUndo(SwUndoId::EMPTY, nullptr);
     if( pTmpRoot )
         pTmpRoot->EndAllAction();
 }
@@ -970,7 +992,7 @@ SdrUndoManager* SwDrawView::getSdrUndoManagerForEnhancedTextEdit() const
 {
     SwDoc* pDoc = Imp().GetShell()->GetDoc();
 
-    return pDoc ? dynamic_cast< SdrUndoManager* >(&(pDoc->GetUndoManager())) : 0;
+    return pDoc ? dynamic_cast< SdrUndoManager* >(&(pDoc->GetUndoManager())) : nullptr;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
