@@ -18,7 +18,7 @@
  */
 
 #include <hintids.hxx>
-#include <vcl/cmdevt.hxx>
+#include <vcl/commandevent.hxx>
 #include <unotools/charclass.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/string.hxx>
@@ -41,6 +41,7 @@
 #include <frame.hxx>
 #include <cntfrm.hxx>
 #include <pam.hxx>
+#include <pamtyp.hxx>
 #include <ndtxt.hxx>
 #include <grfatr.hxx>
 #include <flyfrm.hxx>
@@ -53,7 +54,6 @@
 #include <txtfrm.hxx>
 #include <rootfrm.hxx>
 #include <extinput.hxx>
-#include <crsskip.hxx>
 #include <scriptinfo.hxx>
 #include <unocrsrhelper.hxx>
 #include <section.hxx>
@@ -72,7 +72,6 @@ void SwEditShell::Insert( sal_Unicode c, bool bOnlyCurrCursor )
     {
         const bool bSuccess = GetDoc()->getIDocumentContentOperations().InsertString(rPaM, OUString(c));
         OSL_ENSURE( bSuccess, "Doc->Insert() failed." );
-        (void) bSuccess;
 
         SaveTableBoxContent( rPaM.GetPoint() );
         if( bOnlyCurrCursor )
@@ -88,7 +87,7 @@ void SwEditShell::Insert2(const OUString &rStr, const bool bForceExpandHints )
     StartAllAction();
     {
         const SwInsertFlags nInsertFlags =
-            (bForceExpandHints)
+            bForceExpandHints
             ? (SwInsertFlags::FORCEHINTEXPAND | SwInsertFlags::EMPTYEXPAND)
             : SwInsertFlags::EMPTYEXPAND;
 
@@ -116,7 +115,7 @@ void SwEditShell::Insert2(const OUString &rStr, const bool bForceExpandHints )
     }
 
     // calculate cursor bidi level
-    SwCursor* pTmpCursor = _GetCursor();
+    SwCursor* pTmpCursor = GetCursor_();
     const bool bDoNotSetBidiLevel = ! pTmpCursor ||
                                 ( dynamic_cast<SwUnoCursor*>(pTmpCursor) !=  nullptr );
 
@@ -178,7 +177,7 @@ void SwEditShell::Overwrite(const OUString &rStr)
 long SwEditShell::SplitNode( bool bAutoFormat, bool bCheckTableStart )
 {
     StartAllAction();
-    GetDoc()->GetIDocumentUndoRedo().StartUndo(UNDO_EMPTY, nullptr);
+    GetDoc()->GetIDocumentUndoRedo().StartUndo(SwUndoId::EMPTY, nullptr);
 
     for(SwPaM& rPaM : GetCursor()->GetRingContainer())
     {
@@ -187,7 +186,7 @@ long SwEditShell::SplitNode( bool bAutoFormat, bool bCheckTableStart )
         GetDoc()->getIDocumentContentOperations().SplitNode( *rPaM.GetPoint(), bCheckTableStart );
     }
 
-    GetDoc()->GetIDocumentUndoRedo().EndUndo(UNDO_EMPTY, nullptr);
+    GetDoc()->GetIDocumentUndoRedo().EndUndo(SwUndoId::EMPTY, nullptr);
 
     if( bAutoFormat )
         AutoFormatBySplitNode();
@@ -195,14 +194,14 @@ long SwEditShell::SplitNode( bool bAutoFormat, bool bCheckTableStart )
     ClearTableBoxContent();
 
     EndAllAction();
-    return 1L;
+    return 1;
 }
 
 bool SwEditShell::AppendTextNode()
 {
     bool bRet = false;
     StartAllAction();
-    GetDoc()->GetIDocumentUndoRedo().StartUndo(UNDO_EMPTY, nullptr);
+    GetDoc()->GetIDocumentUndoRedo().StartUndo(SwUndoId::EMPTY, nullptr);
 
     for(SwPaM& rPaM : GetCursor()->GetRingContainer())
     {
@@ -210,7 +209,7 @@ bool SwEditShell::AppendTextNode()
         bRet = GetDoc()->getIDocumentContentOperations().AppendTextNode( *rPaM.GetPoint()) || bRet;
     }
 
-    GetDoc()->GetIDocumentUndoRedo().EndUndo(UNDO_EMPTY, nullptr);
+    GetDoc()->GetIDocumentUndoRedo().EndUndo(SwUndoId::EMPTY, nullptr);
 
     ClearTableBoxContent();
 
@@ -219,7 +218,7 @@ bool SwEditShell::AppendTextNode()
 }
 
 // the returned SwGrfNode pointer is used in GetGraphic() and GetGraphicSize()
-SwGrfNode * SwEditShell::_GetGrfNode() const
+SwGrfNode * SwEditShell::GetGrfNode_() const
 {
     SwGrfNode *pGrfNode = nullptr;
     SwPaM* pCursor = GetCursor();
@@ -234,35 +233,41 @@ SwGrfNode * SwEditShell::_GetGrfNode() const
 // GetMark is not set or points to the same Graphic
 const Graphic* SwEditShell::GetGraphic( bool bWait ) const
 {
-    SwGrfNode* pGrfNode = _GetGrfNode();
+    SwGrfNode* pGrfNode = GetGrfNode_();
     const Graphic* pGrf( nullptr );
     if ( pGrfNode )
     {
-        pGrf = &(pGrfNode->GetGrf(bWait && GRAPHIC_DEFAULT == pGrfNode->GetGrf().GetType()));
+        pGrf = &(pGrfNode->GetGrf(bWait && GraphicType::Default == pGrfNode->GetGrf().GetType()));
     }
     return pGrf;
 }
 
-bool SwEditShell::IsGrfSwapOut( bool bOnlyLinked ) const
+bool SwEditShell::IsLinkedGrfSwapOut() const
 {
-    SwGrfNode *pGrfNode = _GetGrfNode();
+    SwGrfNode *pGrfNode = GetGrfNode_();
     return pGrfNode &&
-        (bOnlyLinked ? ( pGrfNode->IsLinkedFile() &&
-                        ( GRAPHIC_DEFAULT == pGrfNode->GetGrfObj().GetType()||
-                          pGrfNode->GetGrfObj().IsSwappedOut()))
-                     : pGrfNode->GetGrfObj().IsSwappedOut());
+        ( pGrfNode->IsLinkedFile() &&
+          ( GraphicType::Default == pGrfNode->GetGrfObj().GetType() ||
+            pGrfNode->GetGrfObj().IsSwappedOut()));
 }
 
 const GraphicObject* SwEditShell::GetGraphicObj() const
 {
-    SwGrfNode* pGrfNode = _GetGrfNode();
+    SwGrfNode* pGrfNode = GetGrfNode_();
     return pGrfNode ? &(pGrfNode->GetGrfObj()) : nullptr;
 }
 
-sal_uInt16 SwEditShell::GetGraphicType() const
+const GraphicAttr* SwEditShell::GetGraphicAttr( GraphicAttr& rGA ) const
 {
-    SwGrfNode *pGrfNode = _GetGrfNode();
-    return static_cast<sal_uInt16>(pGrfNode ? pGrfNode->GetGrfObj().GetType() : GRAPHIC_NONE);
+    SwGrfNode* pGrfNode = GetGrfNode_();
+    const SwFrame* pFrame = GetCurrFrame(false);
+    return pGrfNode ? &(pGrfNode->GetGraphicAttr( rGA, pFrame )) : nullptr;
+}
+
+GraphicType SwEditShell::GetGraphicType() const
+{
+    SwGrfNode *pGrfNode = GetGrfNode_();
+    return pGrfNode ? pGrfNode->GetGrfObj().GetType() : GraphicType::NONE;
 }
 
 // returns the size of a graphic in <rSz> if CurrentCursor->GetPoint() points to a SwGrfNode and
@@ -284,10 +289,10 @@ bool SwEditShell::GetGrfSize(Size& rSz) const
 
 /// Read again if graphic is not OK and replace old one
 void SwEditShell::ReRead( const OUString& rGrfName, const OUString& rFltName,
-                    const Graphic* pGraphic, const GraphicObject* pGrfObj )
+                    const Graphic* pGraphic )
 {
     StartAllAction();
-    mpDoc->getIDocumentContentOperations().ReRead( *GetCursor(), rGrfName, rFltName, pGraphic, pGrfObj );
+    mxDoc->getIDocumentContentOperations().ReRead( *GetCursor(), rGrfName, rFltName, pGraphic, nullptr );
     EndAllAction();
 }
 
@@ -301,7 +306,7 @@ void SwEditShell::GetGrfNms( OUString* pGrfName, OUString* pFltName,
         SwDoc::GetGrfNms( *pFormat, pGrfName, pFltName );
     else
     {
-        SwGrfNode *pGrfNode = _GetGrfNode();
+        SwGrfNode *pGrfNode = GetGrfNode_();
         if( pGrfNode && pGrfNode->IsLinkedFile() )
             pGrfNode->GetFileFilterNms( pGrfName, pFltName );
     }
@@ -455,7 +460,7 @@ OUString SwEditShell::GetDropText( const sal_Int32 nChars ) const
         SwPaM* pTemp = pCursor;
         while ( bPrev )
         {
-            SwPaM* pPrev2 = dynamic_cast< SwPaM* >( pTemp->GetPrev() );
+            SwPaM* pPrev2 = pTemp->GetPrev();
             bPrev = ( pPrev2 && pPrev2 != pLast );
             if ( bPrev )
             {
@@ -555,7 +560,7 @@ OUString SwEditShell::Calculate()
                         aFormel += sVar;
                 }
                 else
-                    aFormel += OUString(ch);
+                    aFormel += OUStringLiteral1(ch);
             }
         }
     }
@@ -565,7 +570,7 @@ OUString SwEditShell::Calculate()
 
 sfx2::LinkManager& SwEditShell::GetLinkManager()
 {
-    return mpDoc->getIDocumentLinksAdministration().GetLinkManager();
+    return mxDoc->getIDocumentLinksAdministration().GetLinkManager();
 }
 
 void *SwEditShell::GetIMapInventor() const
@@ -578,7 +583,7 @@ void *SwEditShell::GetIMapInventor() const
 Graphic SwEditShell::GetIMapGraphic() const
 {
     // returns always a graphic if the cursor is in a Fly
-    SET_CURR_SHELL( const_cast<SwViewShell*>(static_cast<SwViewShell const *>(this)) );
+    SET_CURR_SHELL( const_cast<SwEditShell*>(this) );
     Graphic aRet;
     SwPaM* pCursor = GetCursor();
     if ( !pCursor->HasMark() )
@@ -587,7 +592,7 @@ Graphic SwEditShell::GetIMapGraphic() const
         if( rNd.IsGrfNode() )
         {
             SwGrfNode & rGrfNode(static_cast<SwGrfNode&>(rNd));
-            aRet = rGrfNode.GetGrf(GRAPHIC_DEFAULT == rGrfNode.GetGrf().GetType());
+            aRet = rGrfNode.GetGrf(GraphicType::Default == rGrfNode.GetGrf().GetType());
         }
         else if ( rNd.IsOLENode() )
         {
@@ -609,7 +614,7 @@ bool SwEditShell::InsertURL( const SwFormatINetFormat& rFormat, const OUString&
     if( rFormat.GetValue().isEmpty() || ( rStr.isEmpty() && !HasSelection() ) )
         return false;
     StartAllAction();
-    GetDoc()->GetIDocumentUndoRedo().StartUndo( UNDO_UI_INSERT_URLTXT, nullptr);
+    GetDoc()->GetIDocumentUndoRedo().StartUndo( SwUndoId::UI_INSERT_URLTXT, nullptr);
     bool bInsText = true;
 
     if( !rStr.isEmpty() )
@@ -621,7 +626,7 @@ bool SwEditShell::InsertURL( const SwFormatINetFormat& rFormat, const OUString&
             bool bDelText = true;
             if( !pCursor->IsMultiSelection() )
             {
-                // einfach Selection -> Text ueberpruefen
+                // simple selection -> check the text
                 const OUString sText(comphelper::string::stripEnd(GetSelText(), ' '));
                 if( sText == rStr )
                     bDelText = bInsText = false;
@@ -652,7 +657,7 @@ bool SwEditShell::InsertURL( const SwFormatINetFormat& rFormat, const OUString&
         ClearMark();
     if( bInsText )
         DontExpandFormat();
-    GetDoc()->GetIDocumentUndoRedo().EndUndo( UNDO_UI_INSERT_URLTXT, nullptr );
+    GetDoc()->GetIDocumentUndoRedo().EndUndo( SwUndoId::UI_INSERT_URLTXT, nullptr );
     EndAllAction();
     return true;
 }
@@ -675,12 +680,12 @@ void SwEditShell::GetINetAttrs( SwGetINetAttrs& rArr )
                 OUString sText( pTextNd->GetExpandText( rAttr.GetStart(),
                                     *rAttr.GetEnd() - rAttr.GetStart() ) );
 
-                sText = comphelper::string::remove(sText, 0x0a);
+                sText = sText.replaceAll(OUStringLiteral1(0x0a), "");
                 sText = comphelper::string::strip(sText, ' ');
 
                 if( !sText.isEmpty() )
                 {
-                    rArr.push_back(SwGetINetAttr(sText, rAttr));
+                    rArr.emplace_back(sText, rAttr);
                 }
             }
         }
@@ -731,9 +736,9 @@ void SwEditShell::SetNumberingRestart()
     for(int i = 0; i < 2; i++)
     {
         if(!i)
-            MakeFindRange(DOCPOS_START, DOCPOS_END, pCursor); // body content
+            MakeFindRange(SwDocPositions::Start, SwDocPositions::End, pCursor); // body content
         else
-            MakeFindRange(DOCPOS_OTHERSTART, DOCPOS_OTHEREND, pCursor); // extra content
+            MakeFindRange(SwDocPositions::OtherStart, SwDocPositions::OtherEnd, pCursor); // extra content
         SwPosition* pSttPos = pCursor->Start(), *pEndPos = pCursor->End();
         sal_uLong nCurrNd = pSttPos->nNode.GetIndex();
         sal_uLong nEndNd = pEndPos->nNode.GetIndex();
@@ -747,7 +752,7 @@ void SwEditShell::SetNumberingRestart()
                 SwNode* pNd = GetDoc()->GetNodes()[ nCurrNd ];
                 switch( pNd->GetNodeType() )
                 {
-                case ND_TEXTNODE:
+                case SwNodeType::Text:
                     if( nullptr != ( pContentFrame = static_cast<SwTextNode*>(pNd)->getLayoutFrame( GetLayout() )) )
                     {
                         // skip hidden frames - ignore protection!
@@ -788,15 +793,12 @@ void SwEditShell::SetNumberingRestart()
                         }
                     }
                     break;
-                case ND_SECTIONNODE:
+                case SwNodeType::Section:
                     // skip hidden sections  - ignore protection!
                     if(static_cast<SwSectionNode*>(pNd)->GetSection().IsHidden() )
                         nCurrNd = pNd->EndOfSectionIndex();
                     break;
-                case ND_ENDNODE:
-                    {
-                        break;
-                    }
+                default: break;
                 }
 
                 bGoOn = nCurrNd < nEndNd;
@@ -805,11 +807,11 @@ void SwEditShell::SetNumberingRestart()
         }
     }
 
-    Pop(false);
+    Pop(PopMode::DeleteCurrent);
     EndAllAction();
 }
 
-sal_uInt16 SwEditShell::GetLineCount( bool bActPos )
+sal_uInt16 SwEditShell::GetLineCount()
 {
     sal_uInt16 nRet = 0;
     CalcLayout();
@@ -818,49 +820,15 @@ sal_uInt16 SwEditShell::GetLineCount( bool bActPos )
     SwNodeIndex aStart( rPtIdx );
     SwContentNode* pCNd;
     SwContentFrame *pContentFrame = nullptr;
-    sal_uLong nTmpPos;
 
-    if( !bActPos )
-        aStart = 0;
-    else if( rPtIdx > ( nTmpPos = GetDoc()->GetNodes().GetEndOfExtras().GetIndex()) )
-        // BodyArea => Start is EndOfIcons + 1
-        aStart = nTmpPos + 1;
-    else
-    {
-        if( nullptr != ( pCNd = pPam->GetContentNode() ) &&
-            nullptr != ( pContentFrame = pCNd->getLayoutFrame( GetLayout() ) ) )
-        {
-            const SwStartNode *pTmp;
-            if( pContentFrame->IsInFly() )                        // Fly
-                pTmp = pCNd->FindFlyStartNode();
-            else if( pContentFrame->IsInFootnote() )                   // Footnote
-                pTmp = pCNd->FindFootnoteStartNode();
-            else
-            {                                               // Footer/Header
-                const sal_uInt16 nTyp = FRM_HEADER | FRM_FOOTER;
-                SwFrame* pFrame = pContentFrame;
-                while( pFrame && !(pFrame->GetType() & nTyp) )
-                    pFrame = pFrame->GetUpper();
-                OSL_ENSURE( pFrame, "Wo bin ich?" );
-                if( pFrame && ( pFrame->GetType() & FRM_FOOTER ) )
-                    pTmp = pCNd->FindFooterStartNode();
-                else
-                    pTmp = pCNd->FindHeaderStartNode();
-            }
-            OSL_ENSURE( pTmp, "Missing StartNode" );
-            aStart  = *pTmp;
-        }
-        OSL_ENSURE( pCNd && pContentFrame, "Missing Layout-Information" );
-    }
+    aStart = 0;
 
     while( nullptr != ( pCNd = GetDoc()->GetNodes().GoNextSection(
-                &aStart, true, false )) && ( !bActPos || aStart <= rPtIdx ) )
+                &aStart, true, false )) )
     {
         if( nullptr != ( pContentFrame = pCNd->getLayoutFrame( GetLayout() ) ) && pContentFrame->IsTextFrame() )
         {
-            const sal_Int32 nActPos = bActPos && aStart == rPtIdx ?
-                pPam->GetPoint()->nContent.GetIndex() : COMPLETE_STRING;
-            nRet = nRet + static_cast<SwTextFrame*>(pContentFrame)->GetLineCount( nActPos );
+            nRet = nRet + static_cast<SwTextFrame*>(pContentFrame)->GetLineCount( COMPLETE_STRING );
         }
     }
     return nRet;
@@ -919,13 +887,13 @@ void SwEditShell::SetLineNumberInfo(const SwLineNumberInfo& rInfo)
     StartAllAction();
     SET_CURR_SHELL( this );
     GetDoc()->SetLineNumberInfo(rInfo);
-    AddPaintRect( GetLayout()->Frame() );
+    AddPaintRect( GetLayout()->getFrameArea() );
     EndAllAction();
 }
 
-sal_uInt16 SwEditShell::GetLinkUpdMode(bool bDocSettings) const
+sal_uInt16 SwEditShell::GetLinkUpdMode() const
 {
-    return getIDocumentSettingAccess().getLinkUpdateMode( !bDocSettings );
+    return getIDocumentSettingAccess().getLinkUpdateMode( false );
 }
 
 void SwEditShell::SetLinkUpdMode( sal_uInt16 nMode )
@@ -934,28 +902,24 @@ void SwEditShell::SetLinkUpdMode( sal_uInt16 nMode )
 }
 
 // Interface for TextInputData - (for text input of japanese/chinese characters)
-SwExtTextInput* SwEditShell::CreateExtTextInput(LanguageType eInputLanguage)
+void SwEditShell::CreateExtTextInput(LanguageType eInputLanguage)
 {
     SwExtTextInput* pRet = GetDoc()->CreateExtTextInput( *GetCursor() );
     pRet->SetLanguage(eInputLanguage);
     pRet->SetOverwriteCursor( SwCursorShell::IsOverwriteCursor() );
-    return pRet;
 }
 
-OUString SwEditShell::DeleteExtTextInput( SwExtTextInput* pDel, bool bInsText )
+OUString SwEditShell::DeleteExtTextInput( bool bInsText )
 {
+    const SwPosition& rPos = *GetCursor()->GetPoint();
+    SwExtTextInput* pDel = GetDoc()->GetExtTextInput( rPos.nNode.GetNode(),
+                                      rPos.nContent.GetIndex() );
     if( !pDel )
     {
-        const SwPosition& rPos = *GetCursor()->GetPoint();
-        pDel = GetDoc()->GetExtTextInput( rPos.nNode.GetNode(),
-                                          rPos.nContent.GetIndex() );
-        if( !pDel )
-        {
-            //JP 25.10.2001: under UNIX the cursor is moved before the Input-
-            //              Engine event comes in. So take any - normally there
-            //              exist only one at the time. -- Task 92016
-            pDel = GetDoc()->GetExtTextInput();
-        }
+        //JP 25.10.2001: under UNIX the cursor is moved before the Input-
+        //              Engine event comes in. So take any - normally there
+        //              exist only one at the time. -- Task 92016
+        pDel = GetDoc()->GetExtTextInput();
     }
     OUString sRet;
     if( pDel )
@@ -984,35 +948,36 @@ void SwEditShell::SetExtTextInputData( const CommandExtTextInputData& rData )
 {
     const SwPosition& rPos = *GetCursor()->GetPoint();
     SwExtTextInput* pInput = GetDoc()->GetExtTextInput( rPos.nNode.GetNode() );
-    if( pInput )
-    {
-        StartAllAction();
-        SET_CURR_SHELL( this );
+    if( !pInput )
+        return;
 
-        if( !rData.IsOnlyCursorChanged() )
-            pInput->SetInputData( rData );
-        // position cursor
-        const SwPosition& rStt = *pInput->Start();
-        const sal_Int32 nNewCursorPos = rStt.nContent.GetIndex() + rData.GetCursorPos();
+    StartAllAction();
+    SET_CURR_SHELL( this );
 
-        // ugly but works
-        ShowCursor();
-        const sal_Int32 nDiff = nNewCursorPos - rPos.nContent.GetIndex();
-        if( 0 > nDiff )
-            Left( (sal_Int32)-nDiff, CRSR_SKIP_CHARS );
-        else if( 0 < nDiff )
-            Right( (sal_Int32)nDiff, CRSR_SKIP_CHARS );
+    if( !rData.IsOnlyCursorChanged() )
+        pInput->SetInputData( rData );
+    // position cursor
+    const SwPosition& rStt = *pInput->Start();
+    const sal_Int32 nNewCursorPos = rStt.nContent.GetIndex() + rData.GetCursorPos();
 
-        SetOverwriteCursor( rData.IsCursorOverwrite() );
+    // ugly but works
+    ShowCursor();
+    const sal_Int32 nDiff = nNewCursorPos - rPos.nContent.GetIndex();
+    if( 0 > nDiff )
+        Left( -nDiff, CRSR_SKIP_CHARS );
+    else if( 0 < nDiff )
+        Right( nDiff, CRSR_SKIP_CHARS );
 
-        EndAllAction();
+    SetOverwriteCursor( rData.IsCursorOverwrite() );
+
+    EndAllAction();
+
+    if( !rData.IsCursorVisible() )  // must be called after the EndAction
+        HideCursor();
 
-        if( !rData.IsCursorVisible() )  // must be called after the EndAction
-            HideCursor();
-    }
 }
 
-void SwEditShell::TransliterateText( sal_uInt32 nType )
+void SwEditShell::TransliterateText( TransliterationFlags nType )
 {
     utl::TransliterationWrapper aTrans( ::comphelper::getProcessComponentContext(), nType );
     StartAllAction();
@@ -1021,13 +986,13 @@ void SwEditShell::TransliterateText( sal_uInt32 nType )
     SwPaM* pCursor = GetCursor();
     if( pCursor->GetNext() != pCursor )
     {
-        GetDoc()->GetIDocumentUndoRedo().StartUndo(UNDO_EMPTY, nullptr);
+        GetDoc()->GetIDocumentUndoRedo().StartUndo(SwUndoId::EMPTY, nullptr);
         for(SwPaM& rPaM : GetCursor()->GetRingContainer())
         {
             if( rPaM.HasMark() )
                 GetDoc()->getIDocumentContentOperations().TransliterateText( rPaM, aTrans );
         }
-        GetDoc()->GetIDocumentUndoRedo().EndUndo(UNDO_EMPTY, nullptr);
+        GetDoc()->GetIDocumentUndoRedo().EndUndo(SwUndoId::EMPTY, nullptr);
     }
     else
         GetDoc()->getIDocumentContentOperations().TransliterateText( *pCursor, aTrans );
