@@ -17,9 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "rootfrm.hxx"
-#include "cntfrm.hxx"
-#include "flyfrm.hxx"
+#include <rootfrm.hxx>
+#include <cntfrm.hxx>
+#include <flyfrm.hxx>
 
 void SwFrame::Format( vcl::RenderContext* /*pRenderContext*/, const SwBorderAttrs * )
 {
@@ -69,7 +69,7 @@ void SwFlyFrame::Paste( SwFrame *, SwFrame * )
 #endif
 
 bool SwFrame::GetCharRect( SwRect&, const SwPosition&,
-                         SwCursorMoveState* ) const
+                         SwCursorMoveState*, bool ) const
 {
     OSL_FAIL( "GetCharRect() of the base called." );
     return false;
