@@ -25,8 +25,11 @@
 #include <unotools/streamwrap.hxx>
 #include <comphelper/processfactory.hxx>
 #include <com/sun/star/xml/sax/InputSource.hpp>
+#include <com/sun/star/io/IOException.hpp>
 #include <com/sun/star/io/XActiveDataSource.hpp>
 #include <com/sun/star/xml/sax/Parser.hpp>
+#include <com/sun/star/xml/sax/FastParser.hpp>
+#include <com/sun/star/xml/sax/FastToken.hpp>
 #include <com/sun/star/xml/sax/Writer.hpp>
 #include <com/sun/star/document/XStorageBasedDocument.hpp>
 #include <doc.hxx>
@@ -35,6 +38,7 @@
 #include <SwXMLTextBlocks.hxx>
 #include <SwXMLBlockImport.hxx>
 #include <SwXMLBlockExport.hxx>
+#include <xmloff/xmlnmspe.hxx>
 #include <swevent.hxx>
 #include <swerror.h>
 
@@ -43,12 +47,14 @@ const char XMLN_BLOCKLIST[] = "BlockList.xml";
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::container;
+using namespace css::xml::sax;
+using namespace xmloff::token;
 
 using ::xmloff::token::XML_BLOCK_LIST;
 using ::xmloff::token::XML_UNFORMATTED_TEXT;
 using ::xmloff::token::GetXMLToken;
 
-sal_uLong SwXMLTextBlocks::GetDoc( sal_uInt16 nIdx )
+ErrCode SwXMLTextBlocks::GetDoc( sal_uInt16 nIdx )
 {
     OUString aFolderName ( GetPackageName ( nIdx ) );
 
@@ -58,16 +64,16 @@ sal_uLong SwXMLTextBlocks::GetDoc( sal_uInt16 nIdx )
         {
             xRoot = xBlkRoot->openStorageElement( aFolderName, embed::ElementModes::READ );
             xMedium = new SfxMedium( xRoot, GetBaseURL(), OUString( "writer8" ) );
-            SwReader aReader( *xMedium, aFolderName, pDoc );
-            ReadXML->SetBlockMode( sal_True );
+            SwReader aReader( *xMedium, aFolderName, m_xDoc.get() );
+            ReadXML->SetBlockMode( true );
             aReader.Read( *ReadXML );
-            ReadXML->SetBlockMode( sal_False );
-            // Ole objects fails to display when inserted into document
-            // because the ObjectReplacement folder ( and contents are missing )
+            ReadXML->SetBlockMode( false );
+            // Ole objects fail to display when inserted into the document, as
+            // the ObjectReplacement folder and contents are missing
             OUString sObjReplacements( "ObjectReplacements" );
             if ( xRoot->hasByName( sObjReplacements ) )
             {
-                uno::Reference< document::XStorageBasedDocument > xDocStor( pDoc->GetDocShell()->GetModel(), uno::UNO_QUERY_THROW );
+                uno::Reference< document::XStorageBasedDocument > xDocStor( m_xDoc->GetDocShell()->GetModel(), uno::UNO_QUERY_THROW );
                 uno::Reference< embed::XStorage > xStr( xDocStor->getDocumentStorage() );
                 if ( xStr.is() )
                 {
@@ -82,7 +88,7 @@ sal_uLong SwXMLTextBlocks::GetDoc( sal_uInt16 nIdx )
         {
         }
 
-        xRoot = 0;
+        xRoot = nullptr;
     }
     else
     {
@@ -96,17 +102,21 @@ sal_uLong SwXMLTextBlocks::GetDoc( sal_uInt16 nIdx )
                 comphelper::getProcessComponentContext();
 
             xml::sax::InputSource aParserInput;
-            aParserInput.sSystemId = aNames[nIdx]->aPackageName;
+            aParserInput.sSystemId = m_aNames[nIdx]->aPackageName;
 
             aParserInput.aInputStream = xStream->getInputStream();
 
             // get filter
-            // uno::Reference< xml::sax::XDocumentHandler > xFilter = new SwXMLTextBlockImport( *this, aCur, sal_True );
-            uno::Reference< xml::sax::XDocumentHandler > xFilter = new SwXMLTextBlockImport( xContext, *this, aCur, sal_True );
+            uno::Reference< xml::sax::XFastDocumentHandler > xFilter = new SwXMLTextBlockImport( xContext, m_aCurrentText, true );
+            uno::Reference< xml::sax::XFastTokenHandler > xTokenHandler = new SwXMLTextBlockTokenHandler();
 
             // connect parser and filter
-            uno::Reference< xml::sax::XParser > xParser = xml::sax::Parser::create(xContext);
-            xParser->setDocumentHandler( xFilter );
+            uno::Reference< xml::sax::XFastParser > xParser = xml::sax::FastParser::create(xContext);
+            xParser->setFastDocumentHandler( xFilter );
+            xParser->setTokenHandler( xTokenHandler );
+
+            xParser->registerNamespace( "http://openoffice.org/2000/text", FastToken::NAMESPACE | XML_NAMESPACE_TEXT );
+            xParser->registerNamespace( "http://openoffice.org/2000/office", FastToken::NAMESPACE | XML_NAMESPACE_OFFICE );
 
             // parse
             try
@@ -126,56 +136,49 @@ sal_uLong SwXMLTextBlocks::GetDoc( sal_uInt16 nIdx )
                 // re throw ?
             }
 
-            bInfoChanged = sal_False;
-            MakeBlockText(aCur);
+            m_bInfoChanged = false;
+            MakeBlockText(m_aCurrentText);
         }
         catch( uno::Exception& )
         {
         }
 
-        xRoot = 0;
+        xRoot = nullptr;
     }
-    return 0;
+    return ERRCODE_NONE;
 }
 
 // event description for autotext events; this constant should really be
 // taken from unocore/unoevents.cxx or ui/unotxt.cxx
 const struct SvEventDescription aAutotextEvents[] =
 {
-    { SW_EVENT_START_INS_GLOSSARY,  "OnInsertStart" },
-    { SW_EVENT_END_INS_GLOSSARY,    "OnInsertDone" },
-    { 0, NULL }
+    { SvMacroItemId::SwStartInsGlossary,  "OnInsertStart" },
+    { SvMacroItemId::SwEndInsGlossary,    "OnInsertDone" },
+    { SvMacroItemId::NONE, nullptr }
 };
 
-sal_uLong SwXMLTextBlocks::GetMacroTable( sal_uInt16 nIdx,
-                                      SvxMacroTableDtor& rMacroTbl,
-                                      sal_Bool bFileAlreadyOpen )
+ErrCode SwXMLTextBlocks::GetMacroTable( sal_uInt16 nIdx,
+                                      SvxMacroTableDtor& rMacroTable )
 {
     // set current auto text
+    m_aShort = m_aNames[nIdx]->aShort;
+    m_aLong = m_aNames[nIdx]->aLong;
+    aPackageName = m_aNames[nIdx]->aPackageName;
 
-    aShort = aNames[nIdx]->aShort;
-    aLong = aNames[nIdx]->aLong;
-    aPackageName = aNames[nIdx]->aPackageName;
-
-    sal_uLong nRet = 0;
+    ErrCode nRet = ERRCODE_NONE;
 
     // open stream in proper sub-storage
-    if( !bFileAlreadyOpen )
-    {
-        CloseFile();
-        nRet = OpenFile ( sal_True );
-    }
-    if ( 0 == nRet )
+    CloseFile();
+    nRet = OpenFile();
+    if ( ERRCODE_NONE == nRet )
     {
         try
         {
             xRoot = xBlkRoot->openStorageElement( aPackageName, embed::ElementModes::READ );
-            long nTmp = SOT_FORMATSTR_ID_STARWRITER_60;
-            bool bOasis = ( SotStorage::GetVersion( xRoot ) > nTmp );
+            bool bOasis = SotStorage::GetVersion( xRoot ) > SOFFICE_FILEFORMAT_60;
 
-            OUString sStreamName("atevent.xml");
             uno::Reference < io::XStream > xDocStream = xRoot->openStreamElement(
-                sStreamName, embed::ElementModes::READ );
+                "atevent.xml", embed::ElementModes::READ );
             OSL_ENSURE(xDocStream.is(), "Can't create stream");
             if ( xDocStream.is() )
             {
@@ -183,7 +186,7 @@ sal_uLong SwXMLTextBlocks::GetMacroTable( sal_uInt16 nIdx,
 
                 // prepare ParserInputSrouce
                 xml::sax::InputSource aParserInput;
-                aParserInput.sSystemId = aName;
+                aParserInput.sSystemId = m_aName;
                 aParserInput.aInputStream = xInputStream;
 
                 // get service factory
@@ -211,19 +214,12 @@ sal_uLong SwXMLTextBlocks::GetMacroTable( sal_uInt16 nIdx,
                         sFilterComponent, aFilterArguments, xContext),
                     UNO_QUERY );
                 OSL_ENSURE( xFilter.is(),
-                            "can't instantiate atevents filter");
+                            "can't instantiate atevent filter");
                 if ( xFilter.is() )
                 {
                     // connect parser and filter
                     xParser->setDocumentHandler( xFilter );
 
-                    // connect model and filter
-                    uno::Reference<document::XImporter> xImporter( xFilter,
-                                                            UNO_QUERY );
-
-                    // we don't need a model
-                    // xImporter->setTargetDocument( xModelComponent );
-
                     // parse the stream
                     try
                     {
@@ -244,8 +240,8 @@ sal_uLong SwXMLTextBlocks::GetMacroTable( sal_uInt16 nIdx,
                     }
 
                     // and finally, copy macro into table
-                    if (0 == nRet)
-                        pDescriptor->copyMacrosIntoTable(rMacroTbl);
+                    if (ERRCODE_NONE == nRet)
+                        pDescriptor->copyMacrosIntoTable(rMacroTable);
                 }
                 else
                     nRet = ERR_SWG_READ_ERROR;
@@ -265,22 +261,21 @@ sal_uLong SwXMLTextBlocks::GetMacroTable( sal_uInt16 nIdx,
     return nRet;
 }
 
-
-sal_uLong SwXMLTextBlocks::GetBlockText( const OUString& rShort, OUString& rText )
+ErrCode SwXMLTextBlocks::GetBlockText( const OUString& rShort, OUString& rText )
 {
-    sal_uLong n = 0;
-    sal_Bool bTextOnly = sal_True;
     OUString aFolderName = GeneratePackageName ( rShort );
     OUString aStreamName = aFolderName + ".xml";
-    rText = "";
+    rText.clear();
 
     try
     {
+        bool bTextOnly = true;
+
         xRoot = xBlkRoot->openStorageElement( aFolderName, embed::ElementModes::READ );
         uno::Reference < container::XNameAccess > xAccess( xRoot, uno::UNO_QUERY );
         if ( !xAccess->hasByName( aStreamName ) || !xRoot->isStreamElement( aStreamName ) )
         {
-            bTextOnly = sal_False;
+            bTextOnly = false;
             aStreamName = "content.xml";
         }
 
@@ -289,17 +284,20 @@ sal_uLong SwXMLTextBlocks::GetBlockText( const OUString& rShort, OUString& rText
             comphelper::getProcessComponentContext();
 
         xml::sax::InputSource aParserInput;
-        aParserInput.sSystemId = aName;
+        aParserInput.sSystemId = m_aName;
         aParserInput.aInputStream = xContents->getInputStream();
 
         // get filter
-        // #110680#
-        // uno::Reference< xml::sax::XDocumentHandler > xFilter = new SwXMLTextBlockImport( *this, rText, bTextOnly );
-        uno::Reference< xml::sax::XDocumentHandler > xFilter = new SwXMLTextBlockImport( xContext, *this, rText, bTextOnly );
+        uno::Reference< xml::sax::XFastDocumentHandler > xFilter = new SwXMLTextBlockImport( xContext, rText, bTextOnly );
+        uno::Reference< xml::sax::XFastTokenHandler > xTokenHandler = new SwXMLTextBlockTokenHandler();
 
         // connect parser and filter
-        uno::Reference< xml::sax::XParser > xParser = xml::sax::Parser::create(xContext);
-        xParser->setDocumentHandler( xFilter );
+        uno::Reference< xml::sax::XFastParser > xParser = xml::sax::FastParser::create(xContext);
+        xParser->setFastDocumentHandler( xFilter );
+        xParser->setTokenHandler( xTokenHandler );
+
+        xParser->registerNamespace( "urn:oasis:names:tc:opendocument:xmlns:office:1.0", FastToken::NAMESPACE | XML_NAMESPACE_OFFICE );
+        xParser->registerNamespace( "urn:oasis:names:tc:opendocument:xmlns:text:1.0", FastToken::NAMESPACE | XML_NAMESPACE_TEXT );
 
         // parse
         try
@@ -319,17 +317,17 @@ sal_uLong SwXMLTextBlocks::GetBlockText( const OUString& rShort, OUString& rText
             // re throw ?
         }
 
-        xRoot = 0;
+        xRoot = nullptr;
     }
     catch ( uno::Exception& )
     {
         OSL_FAIL( "Tried to open non-existent folder or stream!");
     }
 
-    return n;
+    return ERRCODE_NONE;
 }
 
-sal_uLong SwXMLTextBlocks::PutBlockText( const OUString& rShort, const OUString& ,
+ErrCode SwXMLTextBlocks::PutBlockText( const OUString& rShort,
                                          const OUString& rText,  const OUString& rPackageName )
 {
     GetIndex ( rShort );
@@ -340,26 +338,22 @@ sal_uLong SwXMLTextBlocks::PutBlockText( const OUString& rShort, const OUString&
         xBlkRoot->Commit ( );
     }
     */
-    OUString aFolderName( rPackageName );
-    OUString aStreamName = aFolderName + ".xml";
+    OUString aStreamName = rPackageName + ".xml";
 
     uno::Reference< uno::XComponentContext > xContext =
         comphelper::getProcessComponentContext();
 
     uno::Reference < xml::sax::XWriter > xWriter = xml::sax::Writer::create(xContext);
-    sal_uLong nRes = 0;
+    ErrCode nRes = ERRCODE_NONE;
 
     try
     {
-    xRoot = xBlkRoot->openStorageElement( aFolderName, embed::ElementModes::WRITE );
+    xRoot = xBlkRoot->openStorageElement( rPackageName, embed::ElementModes::WRITE );
     uno::Reference < io::XStream > xDocStream = xRoot->openStreamElement( aStreamName,
                 embed::ElementModes::WRITE | embed::ElementModes::TRUNCATE );
 
     uno::Reference < beans::XPropertySet > xSet( xDocStream, uno::UNO_QUERY );
-    OUString aMime ( "text/xml" );
-    Any aAny;
-    aAny <<= aMime;
-    xSet->setPropertyValue("MediaType", aAny );
+    xSet->setPropertyValue("MediaType", Any(OUString( "text/xml" )) );
     uno::Reference < io::XOutputStream > xOut = xDocStream->getOutputStream();
        uno::Reference<io::XActiveDataSource> xSrc(xWriter, uno::UNO_QUERY);
        xSrc->setOutputStream(xOut);
@@ -367,15 +361,15 @@ sal_uLong SwXMLTextBlocks::PutBlockText( const OUString& rShort, const OUString&
        uno::Reference<xml::sax::XDocumentHandler> xHandler(xWriter,
         uno::UNO_QUERY);
 
-   SwXMLTextBlockExport aExp( xContext, *this, GetXMLToken ( XML_UNFORMATTED_TEXT ), xHandler);
+    rtl::Reference<SwXMLTextBlockExport> xExp( new SwXMLTextBlockExport( xContext, *this, GetXMLToken ( XML_UNFORMATTED_TEXT ), xHandler) );
 
-    aExp.exportDoc( rText );
+    xExp->exportDoc( rText );
 
     uno::Reference < embed::XTransactedObject > xTrans( xRoot, uno::UNO_QUERY );
     if ( xTrans.is() )
         xTrans->commit();
 
-    if (! (nFlags & SWXML_NOROOTCOMMIT) )
+    if (! (nFlags & SwXmlFlags::NoRootCommit) )
     {
         uno::Reference < embed::XTransactedObject > xTmpTrans( xBlkRoot, uno::UNO_QUERY );
         if ( xTmpTrans.is() )
@@ -387,7 +381,7 @@ sal_uLong SwXMLTextBlocks::PutBlockText( const OUString& rShort, const OUString&
         nRes = ERR_SWG_WRITE_ERROR;
     }
 
-    xRoot = 0;
+    xRoot = nullptr;
 
     //TODO/LATER: error handling
     /*
@@ -395,16 +389,16 @@ sal_uLong SwXMLTextBlocks::PutBlockText( const OUString& rShort, const OUString&
     sal_uLong nRes = 0;
     if( nErr == SVSTREAM_DISK_FULL )
         nRes = ERR_W4W_WRITE_FULL;
-    else if( nErr != SVSTREAM_OK )
+    else if( nErr != ERRCODE_NONE )
         nRes = ERR_SWG_WRITE_ERROR;
     */
-    if( !nRes )         // damit ueber GetText & nCur aufs Doc zugegriffen
+    if( !nRes ) // So that we can access the Doc via GetText & nCur
         MakeBlockText( rText );
 
     return nRes;
 }
 
-void SwXMLTextBlocks::ReadInfo( void )
+void SwXMLTextBlocks::ReadInfo()
 {
     try
     {
@@ -422,11 +416,14 @@ void SwXMLTextBlocks::ReadInfo( void )
         aParserInput.aInputStream = xDocStream->getInputStream();
 
         // get filter
-        uno::Reference< xml::sax::XDocumentHandler > xFilter = new SwXMLBlockListImport( xContext, *this );
+        uno::Reference< xml::sax::XFastDocumentHandler > xFilter = new SwXMLBlockListImport( xContext, *this );
+        uno::Reference< xml::sax::XFastTokenHandler > xTokenHandler = new SwXMLBlockListTokenHandler();
 
         // connect parser and filter
-        uno::Reference< xml::sax::XParser > xParser = xml::sax::Parser::create( xContext );
-        xParser->setDocumentHandler( xFilter );
+        uno::Reference< xml::sax::XFastParser > xParser = xml::sax::FastParser::create(xContext);
+        xParser->setFastDocumentHandler( xFilter );
+        xParser->registerNamespace( "http://openoffice.org/2001/block-list", FastToken::NAMESPACE | XML_NAMESPACE_BLOCKLIST );
+        xParser->setTokenHandler( xTokenHandler );
 
         // parse
         try
@@ -451,9 +448,9 @@ void SwXMLTextBlocks::ReadInfo( void )
     {
     }
 }
-void SwXMLTextBlocks::WriteInfo( void )
+void SwXMLTextBlocks::WriteInfo()
 {
-    if ( xBlkRoot.is() || 0 == OpenFile ( sal_False ) )
+    if ( xBlkRoot.is() || ERRCODE_NONE == OpenFile ( false ) )
     {
         uno::Reference< uno::XComponentContext > xContext =
             comphelper::getProcessComponentContext();
@@ -475,19 +472,16 @@ void SwXMLTextBlocks::WriteInfo( void )
                     embed::ElementModes::WRITE | embed::ElementModes::TRUNCATE );
 
         uno::Reference < beans::XPropertySet > xSet( xDocStream, uno::UNO_QUERY );
-        OUString aMime ( "text/xml" );
-        Any aAny;
-        aAny <<= aMime;
-        xSet->setPropertyValue("MediaType", aAny );
+        xSet->setPropertyValue("MediaType", Any(OUString( "text/xml" )) );
         uno::Reference < io::XOutputStream > xOut = xDocStream->getOutputStream();
         uno::Reference<io::XActiveDataSource> xSrc(xWriter, uno::UNO_QUERY);
         xSrc->setOutputStream(xOut);
 
         uno::Reference<xml::sax::XDocumentHandler> xHandler(xWriter, uno::UNO_QUERY);
 
-        SwXMLBlockListExport aExp( xContext, *this, OUString(XMLN_BLOCKLIST), xHandler);
+        rtl::Reference<SwXMLBlockListExport> xExp(new SwXMLBlockListExport( xContext, *this, XMLN_BLOCKLIST, xHandler) );
 
-        aExp.exportDoc( XML_BLOCK_LIST );
+        xExp->exportDoc( XML_BLOCK_LIST );
 
         uno::Reference < embed::XTransactedObject > xTrans( xBlkRoot, uno::UNO_QUERY );
         if ( xTrans.is() )
@@ -497,58 +491,49 @@ void SwXMLTextBlocks::WriteInfo( void )
         {
         }
 
-        bInfoChanged = sal_False;
+        m_bInfoChanged = false;
         return;
     }
 }
 
-sal_uLong SwXMLTextBlocks::SetMacroTable(
+ErrCode SwXMLTextBlocks::SetMacroTable(
     sal_uInt16 nIdx,
-    const SvxMacroTableDtor& rMacroTbl,
-    sal_Bool bFileAlreadyOpen )
+    const SvxMacroTableDtor& rMacroTable )
 {
     // set current autotext
-    aShort = aNames[nIdx]->aShort;
-    aLong = aNames[nIdx]->aLong;
-    aPackageName = aNames[nIdx]->aPackageName;
+    m_aShort = m_aNames[nIdx]->aShort;
+    m_aLong = m_aNames[nIdx]->aLong;
+    aPackageName = m_aNames[nIdx]->aPackageName;
 
     // start XML autotext event export
-    sal_uLong nRes = 0;
+    ErrCode nRes = ERRCODE_NONE;
 
     uno::Reference< uno::XComponentContext > xContext =
         comphelper::getProcessComponentContext();
 
     // Get model
     uno::Reference< lang::XComponent > xModelComp(
-        pDoc->GetDocShell()->GetModel(), UNO_QUERY );
+        m_xDoc->GetDocShell()->GetModel(), UNO_QUERY );
     OSL_ENSURE( xModelComp.is(), "XMLWriter::Write: got no model" );
     if( !xModelComp.is() )
         return ERR_SWG_WRITE_ERROR;
 
     // open stream in proper sub-storage
-    if( !bFileAlreadyOpen )
-    {
-        CloseFile();    // close (it may be open in read-only-mode)
-        nRes = OpenFile ( sal_False );
-    }
+    CloseFile(); // close (it may be open in read-only-mode)
+    nRes = OpenFile ( false );
 
-    if ( 0 == nRes )
+    if ( ERRCODE_NONE == nRes )
     {
         try
         {
             xRoot = xBlkRoot->openStorageElement( aPackageName, embed::ElementModes::WRITE );
-            OUString sStreamName("atevent.xml" );
-            long nTmp = SOT_FORMATSTR_ID_STARWRITER_60;
-            bool bOasis = ( SotStorage::GetVersion( xRoot ) > nTmp );
+            bool bOasis = SotStorage::GetVersion( xRoot ) > SOFFICE_FILEFORMAT_60;
 
-            uno::Reference < io::XStream > xDocStream = xRoot->openStreamElement( sStreamName,
+            uno::Reference < io::XStream > xDocStream = xRoot->openStreamElement( "atevent.xml",
                         embed::ElementModes::WRITE | embed::ElementModes::TRUNCATE );
 
             uno::Reference < beans::XPropertySet > xSet( xDocStream, uno::UNO_QUERY );
-            OUString aMime( "text/xml" );
-            Any aAny;
-            aAny <<= aMime;
-            xSet->setPropertyValue("MediaType", aAny );
+            xSet->setPropertyValue("MediaType", Any(OUString( "text/xml" )) );
             uno::Reference < io::XOutputStream > xOutputStream = xDocStream->getOutputStream();
 
             // get XML writer
@@ -562,14 +547,13 @@ sal_uLong SwXMLTextBlocks::SetMacroTable(
 
             // construct events object
             uno::Reference<XNameAccess> xEvents =
-                new SvMacroTableEventDescriptor(rMacroTbl,aAutotextEvents);
+                new SvMacroTableEventDescriptor(rMacroTable,aAutotextEvents);
 
             // prepare arguments (prepend doc handler to given arguments)
             Sequence<Any> aParams(2);
             aParams[0] <<= xDocHandler;
             aParams[1] <<= xEvents;
 
-
             // get filter component
             OUString sFilterComponent = bOasis
                 ? OUString("com.sun.star.comp.Writer.XMLOasisAutotextEventsExporter")
@@ -598,22 +582,18 @@ sal_uLong SwXMLTextBlocks::SetMacroTable(
             if ( xTmpTrans.is() )
                 xTmpTrans->commit();
 
-            if ( !bFileAlreadyOpen )
-            {
-                uno::Reference < embed::XTransactedObject > xTrans( xBlkRoot, uno::UNO_QUERY );
-                if ( xTrans.is() )
-                    xTrans->commit();
-            }
+            uno::Reference < embed::XTransactedObject > xTrans( xBlkRoot, uno::UNO_QUERY );
+            if ( xTrans.is() )
+                xTrans->commit();
 
-            xRoot = 0;
+            xRoot = nullptr;
         }
         catch ( uno::Exception& )
         {
             nRes = ERR_SWG_WRITE_ERROR;
         }
 
-        if( !bFileAlreadyOpen )
-            CloseFile();
+        CloseFile();
     }
     else
         nRes = ERR_SWG_WRITE_ERROR;
