@@ -17,34 +17,34 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "ndtxt.hxx"
-#include "pam.hxx"
-#include "frmtool.hxx"
-#include "viewopt.hxx"
-#include "paratr.hxx"
-#include "rootfrm.hxx"
-#include "pagefrm.hxx"
-#include "colfrm.hxx"
-#include "swtypes.hxx"
+#include <ndtxt.hxx>
+#include <pam.hxx>
+#include <frmtool.hxx>
+#include <viewopt.hxx>
+#include <paratr.hxx>
+#include <rootfrm.hxx>
+#include <pagefrm.hxx>
+#include <colfrm.hxx>
+#include <swtypes.hxx>
 #include <sfx2/printer.hxx>
 #include <editeng/lrspitem.hxx>
 #include <editeng/tstpitem.hxx>
 #include <editeng/ulspitem.hxx>
 #include <editeng/lspcitem.hxx>
-#include <pormulti.hxx>
+#include "pormulti.hxx"
 #include <doc.hxx>
 #include <IDocumentDeviceAccess.hxx>
 #include <sortedobjs.hxx>
 
 #include <unicode/ubidi.h>
 
-#include "txtfrm.hxx"
+#include <txtfrm.hxx>
 #include "inftxt.hxx"
 #include "itrtxt.hxx"
-#include "crstate.hxx"
-#include "viewsh.hxx"
-#include "swfntcch.hxx"
-#include "flyfrm.hxx"
+#include <crstate.hxx>
+#include <viewsh.hxx>
+#include <swfntcch.hxx>
+#include <flyfrm.hxx>
 
 #define MIN_OFFSET_STEP 10
 
@@ -112,7 +112,7 @@ bool sw_ChangeOffset( SwTextFrame* pFrame, sal_Int32 nNew )
         SwFlyFrame *pFly = pFrame->FindFlyFrame();
         // Attention: if e.g. in a column frame the size is still invalid
         // we must not scroll around just like that
-        if ( ( pFly && pFly->IsValid() &&
+        if ( ( pFly && pFly->isFrameAreaDefinitionValid() &&
              !pFly->GetNextLink() && !pFly->GetPrevLink() ) ||
              ( !pFly && pFrame->IsInTab() ) )
         {
@@ -129,8 +129,8 @@ bool sw_ChangeOffset( SwTextFrame* pFrame, sal_Int32 nNew )
                 pFrame->SetOfst( nNew );
                 pFrame->SetPara( nullptr );
                 pFrame->GetFormatted();
-                if( pFrame->Frame().HasArea() )
-                    pFrame->getRootFrame()->GetCurrShell()->InvalidateWindows( pFrame->Frame() );
+                if( pFrame->getFrameArea().HasArea() )
+                    pFrame->getRootFrame()->GetCurrShell()->InvalidateWindows( pFrame->getFrameArea() );
                 return true;
             }
         }
@@ -173,7 +173,7 @@ SwTextFrame *SwTextFrame::GetFrameAtPos( const SwPosition &rPos )
  */
 
 bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
-                            SwCursorMoveState *pCMS ) const
+                            SwCursorMoveState *pCMS, bool bAllowFarAway ) const
 {
     OSL_ENSURE( ! IsVertical() || ! IsSwapped(),"SwTextFrame::GetCharRect with swapped frame" );
 
@@ -192,34 +192,37 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
     SwTextFrame *pFrame = GetAdjFrameAtPos( const_cast<SwTextFrame*>(this), rPos, bRightMargin,
                                      bNoScroll );
     pFrame->GetFormatted();
-    const SwFrame* pTmpFrame = static_cast<SwFrame*>(pFrame->GetUpper());
 
-    SWRECTFN ( pFrame )
-    const SwTwips nUpperMaxY = (pTmpFrame->*fnRect->fnGetPrtBottom)();
-    const SwTwips nFrameMaxY = (pFrame->*fnRect->fnGetPrtBottom)();
+    const SwFrame* pTmpFrame = static_cast<SwFrame*>(pFrame->GetUpper());
+    if (pTmpFrame->getFrameArea().Top() == FAR_AWAY && !bAllowFarAway)
+        return false;
+
+    SwRectFnSet aRectFnSet(pFrame);
+    const SwTwips nUpperMaxY = aRectFnSet.GetPrtBottom(*pTmpFrame);
+    const SwTwips nFrameMaxY = aRectFnSet.GetPrtBottom(*pFrame);
 
     // nMaxY is an absolute value
-    SwTwips nMaxY = bVert ?
-                    ( bVertL2R ? std::min( nFrameMaxY, nUpperMaxY ) : std::max( nFrameMaxY, nUpperMaxY ) ) :
+    SwTwips nMaxY = aRectFnSet.IsVert() ?
+                    ( aRectFnSet.IsVertL2R() ? std::min( nFrameMaxY, nUpperMaxY ) : std::max( nFrameMaxY, nUpperMaxY ) ) :
                     std::min( nFrameMaxY, nUpperMaxY );
 
     bool bRet = false;
 
-    if ( pFrame->IsEmpty() || ! (pFrame->Prt().*fnRect->fnGetHeight)() )
+    if ( pFrame->IsEmpty() || ! aRectFnSet.GetHeight(pFrame->getFramePrintArea()) )
     {
-        Point aPnt1 = pFrame->Frame().Pos() + pFrame->Prt().Pos();
+        Point aPnt1 = pFrame->getFrameArea().Pos() + pFrame->getFramePrintArea().Pos();
         SwTextNode* pTextNd = const_cast<SwTextFrame*>(this)->GetTextNode();
         short nFirstOffset;
         pTextNd->GetFirstLineOfsWithNum( nFirstOffset );
 
         Point aPnt2;
-        if ( bVert )
+        if ( aRectFnSet.IsVert() )
         {
             if( nFirstOffset > 0 )
                 aPnt1.Y() += nFirstOffset;
-            if ( aPnt1.X() < nMaxY && !bVertL2R )
+            if ( aPnt1.X() < nMaxY && !aRectFnSet.IsVertL2R() )
                 aPnt1.X() = nMaxY;
-            aPnt2.X() = aPnt1.X() + pFrame->Prt().Width();
+            aPnt2.X() = aPnt1.X() + pFrame->getFramePrintArea().Width();
             aPnt2.Y() = aPnt1.Y();
             if( aPnt2.X() < nMaxY )
                 aPnt2.X() = nMaxY;
@@ -232,7 +235,7 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
             if( aPnt1.Y() > nMaxY )
                 aPnt1.Y() = nMaxY;
             aPnt2.X() = aPnt1.X();
-            aPnt2.Y() = aPnt1.Y() + pFrame->Prt().Height();
+            aPnt2.Y() = aPnt1.Y() + pFrame->getFramePrintArea().Height();
             if( aPnt2.Y() > nMaxY )
                 aPnt2.Y() = nMaxY;
         }
@@ -242,7 +245,7 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
         if ( pCMS )
         {
             pCMS->m_aRealHeight.X() = 0;
-            pCMS->m_aRealHeight.Y() = bVert ? -rOrig.Width() : rOrig.Height();
+            pCMS->m_aRealHeight.Y() = aRectFnSet.IsVert() ? -rOrig.Width() : rOrig.Height();
         }
 
         if ( pFrame->IsRightToLeft() )
@@ -256,7 +259,7 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
             return false;
 
         SwFrameSwapper aSwapper( pFrame, true );
-        if ( bVert )
+        if ( aRectFnSet.IsVert() )
             nMaxY = pFrame->SwitchVerticalToHorizontal( nMaxY );
 
         bool bGoOn = true;
@@ -278,11 +281,11 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
             if ( pFrame->IsRightToLeft() )
                 pFrame->SwitchLTRtoRTL( rOrig );
 
-            if ( bVert )
+            if ( aRectFnSet.IsVert() )
                 pFrame->SwitchHorizontalToVertical( rOrig );
 
             if( pFrame->IsUndersized() && pCMS && !pFrame->GetNext() &&
-                (rOrig.*fnRect->fnGetBottom)() == nUpperMaxY &&
+                aRectFnSet.GetBottom(rOrig) == nUpperMaxY &&
                 pFrame->GetOfst() < nOffset &&
                 !pFrame->IsFollow() && !bNoScroll &&
                 pFrame->GetTextNode()->GetText().getLength() != nNextOfst)
@@ -304,7 +307,7 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
                 }
             }
 
-            if ( bVert )
+            if ( aRectFnSet.IsVert() )
             {
                 if ( pCMS->m_bRealHeight )
                 {
@@ -330,19 +333,19 @@ bool SwTextFrame::GetCharRect( SwRect& rOrig, const SwPosition &rPos,
     {
         SwPageFrame *pPage = pFrame->FindPageFrame();
         OSL_ENSURE( pPage, "Text escaped from page?" );
-        const SwTwips nOrigTop = (rOrig.*fnRect->fnGetTop)();
-        const SwTwips nPageTop = (pPage->Frame().*fnRect->fnGetTop)();
-        const SwTwips nPageBott = (pPage->Frame().*fnRect->fnGetBottom)();
+        const SwTwips nOrigTop = aRectFnSet.GetTop(rOrig);
+        const SwTwips nPageTop = aRectFnSet.GetTop(pPage->getFrameArea());
+        const SwTwips nPageBott = aRectFnSet.GetBottom(pPage->getFrameArea());
 
         // We have the following situation: if the frame is in an invalid
         // sectionframe, it's possible that the frame is outside the page.
         // If we restrict the cursor position to the page area, we enforce
         // the formatting of the page, of the section frame and the frame itself.
-        if( (*fnRect->fnYDiff)( nPageTop, nOrigTop ) > 0 )
-            (rOrig.*fnRect->fnSetTop)( nPageTop );
+        if( aRectFnSet.YDiff( nPageTop, nOrigTop ) > 0 )
+            aRectFnSet.SetTop( rOrig, nPageTop );
 
-        if ( (*fnRect->fnYDiff)( nOrigTop, nPageBott ) > 0 )
-            (rOrig.*fnRect->fnSetTop)( nPageBott );
+        if ( aRectFnSet.YDiff( nOrigTop, nPageBott ) > 0 )
+            aRectFnSet.SetTop( rOrig, nPageBott );
     }
 
     return bRet;
@@ -364,30 +367,30 @@ bool SwTextFrame::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
     pFrame->GetFormatted();
     const SwFrame* pTmpFrame = static_cast<SwFrame*>(pFrame->GetUpper());
 
-    SWRECTFN( pTmpFrame )
-    SwTwips nUpperMaxY = (pTmpFrame->*fnRect->fnGetPrtBottom)();
+    SwRectFnSet aRectFnSet(pTmpFrame);
+    SwTwips nUpperMaxY = aRectFnSet.GetPrtBottom(*pTmpFrame);
 
     // nMaxY is in absolute value
     SwTwips nMaxY;
-    if ( bVert )
+    if ( aRectFnSet.IsVert() )
     {
-        if ( bVertL2R )
-            nMaxY = std::min( (pFrame->*fnRect->fnGetPrtBottom)(), nUpperMaxY );
+        if ( aRectFnSet.IsVertL2R() )
+            nMaxY = std::min( aRectFnSet.GetPrtBottom(*pFrame), nUpperMaxY );
         else
-            nMaxY = std::max( (pFrame->*fnRect->fnGetPrtBottom)(), nUpperMaxY );
+            nMaxY = std::max( aRectFnSet.GetPrtBottom(*pFrame), nUpperMaxY );
     }
     else
-        nMaxY = std::min( (pFrame->*fnRect->fnGetPrtBottom)(), nUpperMaxY );
-    if ( pFrame->IsEmpty() || ! (pFrame->Prt().*fnRect->fnGetHeight)() )
+        nMaxY = std::min( aRectFnSet.GetPrtBottom(*pFrame), nUpperMaxY );
+    if ( pFrame->IsEmpty() || ! aRectFnSet.GetHeight(pFrame->getFramePrintArea()) )
     {
-        Point aPnt1 = pFrame->Frame().Pos() + pFrame->Prt().Pos();
+        Point aPnt1 = pFrame->getFrameArea().Pos() + pFrame->getFramePrintArea().Pos();
         Point aPnt2;
-        if ( bVert )
+        if ( aRectFnSet.IsVert() )
         {
-            if ( aPnt1.X() < nMaxY && !bVertL2R )
+            if ( aPnt1.X() < nMaxY && !aRectFnSet.IsVertL2R() )
                 aPnt1.X() = nMaxY;
 
-            aPnt2.X() = aPnt1.X() + pFrame->Prt().Width();
+            aPnt2.X() = aPnt1.X() + pFrame->getFramePrintArea().Width();
             aPnt2.Y() = aPnt1.Y();
             if( aPnt2.X() < nMaxY )
                 aPnt2.X() = nMaxY;
@@ -397,7 +400,7 @@ bool SwTextFrame::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
             if( aPnt1.Y() > nMaxY )
                 aPnt1.Y() = nMaxY;
             aPnt2.X() = aPnt1.X();
-            aPnt2.Y() = aPnt1.Y() + pFrame->Prt().Height();
+            aPnt2.Y() = aPnt1.Y() + pFrame->getFramePrintArea().Height();
             if( aPnt2.Y() > nMaxY )
                 aPnt2.Y() = nMaxY;
         }
@@ -410,7 +413,7 @@ bool SwTextFrame::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
             return false;
 
         SwFrameSwapper aSwapper( pFrame, true );
-        if ( bVert )
+        if ( aRectFnSet.IsVert() )
             nMaxY = pFrame->SwitchVerticalToHorizontal( nMaxY );
 
         SwTextSizeInfo aInf( pFrame );
@@ -428,7 +431,7 @@ bool SwTextFrame::GetAutoPos( SwRect& rOrig, const SwPosition &rPos ) const
             if ( pFrame->IsRightToLeft() )
                 pFrame->SwitchLTRtoRTL( rOrig );
 
-            if ( bVert )
+            if ( aRectFnSet.IsVert() )
                 pFrame->SwitchHorizontalToVertical( rOrig );
 
             return true;
@@ -457,30 +460,30 @@ bool SwTextFrame::GetTopOfLine( SwTwips& _onTopOfLine,
     }
     else
     {
-        SWRECTFN( this )
-        if ( IsEmpty() || !(Prt().*fnRect->fnGetHeight)() )
+        SwRectFnSet aRectFnSet(this);
+        if ( IsEmpty() || !aRectFnSet.GetHeight(getFramePrintArea()) )
         {
             // consider upper space amount considered
             // for previous frame and the page grid.
-            _onTopOfLine = (this->*fnRect->fnGetPrtTop)();
+            _onTopOfLine = aRectFnSet.GetPrtTop(*this);
         }
         else
         {
             // determine formatted text frame that contains the requested position
             SwTextFrame* pFrame = &(const_cast<SwTextFrame*>(this)->GetFrameAtOfst( nOffset ));
             pFrame->GetFormatted();
-            SWREFRESHFN( pFrame )
+            aRectFnSet.Refresh(pFrame);
             // If proportional line spacing is applied
             // to the text frame, the top of the anchor character is also the
             // top of the line.
             // Otherwise the line layout determines the top of the line
             const SvxLineSpacingItem& rSpace = GetAttrSet()->GetLineSpacing();
-            if ( rSpace.GetInterLineSpaceRule() == SVX_INTER_LINE_SPACE_PROP )
+            if ( rSpace.GetInterLineSpaceRule() == SvxInterLineSpaceRule::Prop )
             {
                 SwRect aCharRect;
                 if ( GetAutoPos( aCharRect, _rPos ) )
                 {
-                    _onTopOfLine = (aCharRect.*fnRect->fnGetTop)();
+                    _onTopOfLine = aRectFnSet.GetTop(aCharRect);
                 }
                 else
                 {
@@ -497,7 +500,7 @@ bool SwTextFrame::GetTopOfLine( SwTwips& _onTopOfLine,
                 aLine.CharCursorToLine( nOffset );
                 // determine top of line
                 _onTopOfLine = aLine.Y();
-                if ( bVert )
+                if ( aRectFnSet.IsVert() )
                 {
                     _onTopOfLine = pFrame->SwitchHorizontalToVertical( _onTopOfLine );
                 }
@@ -535,6 +538,7 @@ struct SwFillData
     SwFillCursorPos &Fill() const { return *pCMS->m_pFill; }
     void SetTab( sal_uInt16 nNew ) { pCMS->m_pFill->nTabCnt = nNew; }
     void SetSpace( sal_uInt16 nNew ) { pCMS->m_pFill->nSpaceCnt = nNew; }
+    void SetSpaceOnly( sal_uInt16 nNew ) { pCMS->m_pFill->nSpaceOnlyCnt = nNew; }
     void SetOrient( const sal_Int16 eNew ){ pCMS->m_pFill->eOrient = eNew; }
 };
 
@@ -553,15 +557,15 @@ bool SwTextFrame::GetCursorOfst_(SwPosition* pPos, const Point& rPoint,
 
     if ( IsVertical() )
     {
-        SwitchVerticalToHorizontal( (Point&)rPoint );
+        SwitchVerticalToHorizontal( const_cast<Point&>(rPoint) );
         const_cast<SwTextFrame*>(this)->SwapWidthAndHeight();
     }
 
     if ( IsRightToLeft() )
-        SwitchRTLtoLTR( (Point&)rPoint );
+        SwitchRTLtoLTR( const_cast<Point&>(rPoint) );
 
     SwFillData *pFillData = ( pCMS && pCMS->m_pFill ) ?
-                        new SwFillData( pCMS, pPos, Frame(), rPoint ) : nullptr;
+                        new SwFillData( pCMS, pPos, getFrameArea(), rPoint ) : nullptr;
 
     if ( IsEmpty() )
     {
@@ -570,7 +574,7 @@ bool SwTextFrame::GetCursorOfst_(SwPosition* pPos, const Point& rPoint,
         pPos->nContent.Assign( pTextNd, 0 );
         if( pCMS && pCMS->m_bFieldInfo )
         {
-            SwTwips nDiff = rPoint.X() - Frame().Left() - Prt().Left();
+            SwTwips nDiff = rPoint.X() - getFrameArea().Left() - getFramePrintArea().Left();
             if( nDiff > 50 || nDiff < 0 )
                 pCMS->m_bPosCorr = true;
         }
@@ -581,7 +585,7 @@ bool SwTextFrame::GetCursorOfst_(SwPosition* pPos, const Point& rPoint,
         SwTextCursor  aLine( const_cast<SwTextFrame*>(this), &aInf );
 
         // See comment in AdjustFrame()
-        SwTwips nMaxY = Frame().Top() + Prt().Top() + Prt().Height();
+        SwTwips nMaxY = getFrameArea().Top() + getFramePrintArea().Top() + getFramePrintArea().Height();
         aLine.TwipsToLine( rPoint.Y() );
         while( aLine.Y() + aLine.GetLineHeight() > nMaxY )
         {
@@ -612,7 +616,7 @@ bool SwTextFrame::GetCursorOfst_(SwPosition* pPos, const Point& rPoint,
             if( pFillData )
             {
                 if (pTextNd->GetText().getLength() > nOffset ||
-                    rPoint.Y() < Frame().Top() )
+                    rPoint.Y() < getFrameArea().Top() )
                     pFillData->bInner = true;
                 pFillData->bFirstLine = aLine.GetLineNr() < 2;
                 if (pTextNd->GetText().getLength())
@@ -624,7 +628,7 @@ bool SwTextFrame::GetCursorOfst_(SwPosition* pPos, const Point& rPoint,
         }
     }
     bool bChgFillData = false;
-    if( pFillData && FindPageFrame()->Frame().IsInside( aOldPoint ) )
+    if( pFillData && FindPageFrame()->getFrameArea().IsInside( aOldPoint ) )
     {
         FillCursorPos( *pFillData );
         bChgFillData = true;
@@ -648,7 +652,7 @@ bool SwTextFrame::GetCursorOfst_(SwPosition* pPos, const Point& rPoint,
                 pFillData->SetOrient( text::HoriOrientation::LEFT );
     }
 
-    (Point&)rPoint = aOldPoint;
+    const_cast<Point&>(rPoint) = aOldPoint;
     delete pFillData;
 
     return true;
@@ -689,7 +693,7 @@ bool SwTextFrame::LeftMargin(SwPaM *pPam) const
             nIndx = 0;
         }
     }
-    pPam->GetPoint()->nContent = SwIndex( pFrame->GetTextNode(), nIndx );
+    pPam->GetPoint()->nContent.Assign(pFrame->GetTextNode(), nIndx);
     SwTextCursor::SetRightMargin( false );
     return true;
 }
@@ -730,7 +734,7 @@ bool SwTextFrame::RightMargin(SwPaM *pPam, bool bAPI) const
                 --nRightMargin;
         }
     }
-    pPam->GetPoint()->nContent = SwIndex( pFrame->GetTextNode(), nRightMargin );
+    pPam->GetPoint()->nContent.Assign(pFrame->GetTextNode(), nRightMargin);
     SwTextCursor::SetRightMargin( !bAPI );
     return true;
 }
@@ -744,9 +748,9 @@ class SwSetToRightMargin
 {
     bool bRight;
 public:
-    inline SwSetToRightMargin() : bRight( false ) { }
-    inline ~SwSetToRightMargin() { SwTextCursor::SetRightMargin( bRight ); }
-    inline void SetRight( const bool bNew ) { bRight = bNew; }
+    SwSetToRightMargin() : bRight( false ) { }
+    ~SwSetToRightMargin() { SwTextCursor::SetRightMargin( bRight ); }
+    void SetRight( const bool bNew ) { bRight = bNew; }
 };
 
 bool SwTextFrame::UnitUp_( SwPaM *pPam, const SwTwips nOffset,
@@ -839,8 +843,7 @@ bool SwTextFrame::UnitUp_( SwPaM *pPam, const SwTwips nOffset,
                     nTmpOfst = nStart;
                     aSet.SetRight( true );
                 }
-                pPam->GetPoint()->nContent =
-                      SwIndex( const_cast<SwTextFrame*>(this)->GetTextNode(), nTmpOfst );
+                pPam->GetPoint()->nContent.Assign(const_cast<SwTextFrame*>(this)->GetTextNode(), nTmpOfst);
                 return true;
             }
 
@@ -878,7 +881,7 @@ bool SwTextFrame::UnitUp_( SwPaM *pPam, const SwTwips nOffset,
             }
             if ( !pPrevPrev )
                 return pTmpPrev->SwContentFrame::UnitUp( pPam, nOffset, bSetInReadOnly );
-            aCharBox.Pos().Y() = pPrevPrev->Frame().Bottom() - 1;
+            aCharBox.Pos().Y() = pPrevPrev->getFrameArea().Bottom() - 1;
             return pPrevPrev->GetKeyCursorOfst( pPam->GetPoint(), aCharBox.Pos() );
         }
     }
@@ -1081,7 +1084,7 @@ void SwTextFrame::PrepareVisualMove( sal_Int32& nPos, sal_uInt8& nCursorLevel,
 
     UErrorCode nError = U_ZERO_ERROR;
     UBiDi* pBidi = ubidi_openSized( nLen, 0, &nError );
-    ubidi_setPara( pBidi, reinterpret_cast<const UChar *>(pLineString), nLen, nDefaultDir, nullptr, &nError ); // UChar != sal_Unicode in MinGW
+    ubidi_setPara( pBidi, reinterpret_cast<const UChar *>(pLineString), nLen, nDefaultDir, nullptr, &nError );
 
     sal_Int32 nTmpPos = 0;
     bool bOutOfBounds = false;
@@ -1199,8 +1202,7 @@ bool SwTextFrame::UnitDown_(SwPaM *pPam, const SwTwips nOffset,
                 // We make sure that we move down.
                 if( nTmpOfst <= nStart && ! bFirstOfDouble )
                     nTmpOfst = nStart + 1;
-                pPam->GetPoint()->nContent =
-                      SwIndex( const_cast<SwTextFrame*>(this)->GetTextNode(), nTmpOfst );
+                pPam->GetPoint()->nContent.Assign(const_cast<SwTextFrame*>(this)->GetTextNode(), nTmpOfst);
 
                 if ( IsVertical() )
                     const_cast<SwTextFrame*>(this)->SwapWidthAndHeight();
@@ -1237,7 +1239,7 @@ bool SwTextFrame::UnitDown_(SwPaM *pPam, const SwTwips nOffset,
                     if( nFormat <= GetOfst() )
                     {
                         nFormat = std::min( sal_Int32( GetOfst() + MIN_OFFSET_STEP ),
-                                       static_cast<sal_Int32>(nTmpLen) );
+                                       nTmpLen );
                         if( nFormat <= GetOfst() )
                             break;
                     }
@@ -1256,7 +1258,7 @@ bool SwTextFrame::UnitDown_(SwPaM *pPam, const SwTwips nOffset,
     // We take a shortcut for follows
     if( pTmpFollow )
     {
-        aCharBox.Pos().Y() = pTmpFollow->Frame().Top() + 1;
+        aCharBox.Pos().Y() = pTmpFollow->getFrameArea().Top() + 1;
         return static_cast<const SwTextFrame*>(pTmpFollow)->GetKeyCursorOfst( pPam->GetPoint(),
                                                      aCharBox.Pos() );
     }
@@ -1302,7 +1304,7 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
         const SwFrame* pFrame = static_cast<const SwLayoutFrame*>(pTmp->Lower())->Lower();
         sal_uInt16 nNextCol = 0;
         // In which column do we end up in?
-        while( rFill.X() > pTmp->Frame().Right() && pTmp->GetNext() )
+        while( rFill.X() > pTmp->getFrameArea().Right() && pTmp->GetNext() )
         {
             pTmp = static_cast<const SwColumnFrame*>(pTmp->GetNext());
             if( static_cast<const SwLayoutFrame*>(pTmp->Lower())->Lower() ) // ColumnFrames now with BodyFrame
@@ -1324,7 +1326,7 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
             }
             else
             {
-                while( pFrame->GetNext() && pFrame->Frame().Bottom() < rFill.Y() )
+                while( pFrame->GetNext() && pFrame->getFrameArea().Bottom() < rFill.Y() )
                     pFrame = pFrame->GetNext();
             }
             // No filling, if the last frame in the targeted column does
@@ -1342,11 +1344,11 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
                 }
                 if( nNextCol )
                 {
-                    rFill.aFrame = pTmp->Prt();
-                    rFill.aFrame += pTmp->Frame().Pos();
+                    rFill.aFrame = pTmp->getFramePrintArea();
+                    rFill.aFrame += pTmp->getFrameArea().Pos();
                 }
                 else
-                    rFill.aFrame = pFrame->Frame();
+                    rFill.aFrame = pFrame->getFrameArea();
                 static_cast<const SwTextFrame*>(pFrame)->FillCursorPos( rFill );
             }
             return;
@@ -1355,7 +1357,7 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
     SwFont *pFnt;
     SwTextFormatColl* pColl = GetTextNode()->GetTextColl();
     SwTwips nFirst = GetTextNode()->GetSwAttrSet().GetULSpace().GetLower();
-    SwTwips nDiff = rFill.Y() - Frame().Bottom();
+    SwTwips nDiff = rFill.Y() - getFrameArea().Bottom();
     if( nDiff < nFirst )
         nDiff = -1;
     else
@@ -1401,7 +1403,7 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
             nFirst = nFirst - nDist;
         else
             nFirst = 0;
-        nDist = std::max( nDist, long( GetLineSpace() ) );
+        nDist = std::max( nDist, GetLineSpace() );
         nDist += nLineHeight;
         nDiff -= nFirst;
 
@@ -1507,6 +1509,7 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
                     SwTwips nLeftTab;
                     SwTwips nRightTab = nLeft;
                     sal_uInt16 nSpaceCnt = 0;
+                    sal_uInt16 nSpaceOnlyCnt = 0;
                     sal_uInt16 nTabCnt = 0;
                     sal_uInt16 nIdx = 0;
                     do
@@ -1550,7 +1553,7 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
                     }
                     while( rFill.X() > nRightTab );
                     --nTabCnt;
-                    if( FILL_TAB != rFill.Mode() )
+                    if( FILL_TAB_SPACE == rFill.Mode() )
                     {
                         if( nSpace > 0 )
                         {
@@ -1601,6 +1604,16 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
                             }
                         }
                     }
+                    else if( FILL_SPACE == rFill.Mode() )
+                    {
+                        SwTwips nLeftSpace = nLeft;
+                        while( nLeftSpace < rFill.X() )
+                        {
+                            nLeftSpace += nSpace;
+                            ++nSpaceOnlyCnt;
+                        }
+                        rRect.Left( nLeftSpace );
+                    }
                     else
                     {
                         if( rFill.X() - nLeftTab < nRightTab - rFill.X() )
@@ -1623,6 +1636,7 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
                     }
                     rFill.SetTab( nTabCnt );
                     rFill.SetSpace( nSpaceCnt );
+                    rFill.SetSpaceOnly( nSpaceOnlyCnt );
                     if( bFill )
                     {
                         if( std::abs( rFill.X() - nCenter ) <=
@@ -1631,6 +1645,7 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
                             rFill.SetOrient( text::HoriOrientation::CENTER );
                             rFill.SetTab( 0 );
                             rFill.SetSpace( 0 );
+                            rFill.SetSpaceOnly( 0 );
                             rRect.Left( nCenter );
                         }
                         if( !rFill.bEmpty )
@@ -1650,13 +1665,13 @@ void SwTextFrame::FillCursorPos( SwFillData& rFill ) const
                          pUp->GetUpper()->GetUpper()->IsSctFrame() )
                     pUp = pUp->GetUpper()->GetUpper()->GetUpper();
             }
-            SWRECTFN( this )
-            SwTwips nLimit = (pUp->*fnRect->fnGetPrtBottom)();
+            SwRectFnSet aRectFnSet(this);
+            SwTwips nLimit = aRectFnSet.GetPrtBottom(*pUp);
             SwTwips nRectBottom = rRect.Bottom();
-            if ( bVert )
+            if ( aRectFnSet.IsVert() )
                 nRectBottom = SwitchHorizontalToVertical( nRectBottom );
 
-            if( (*fnRect->fnYDiff)( nLimit, nRectBottom ) < 0 )
+            if( aRectFnSet.YDiff( nLimit, nRectBottom ) < 0 )
                 bFill = false;
             else
                 rRect.Width( 1 );
