@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <com/sun/star/uno/Sequence.h>
 #include <unotools/linguprops.hxx>
 #include <unotools/lingucfg.hxx>
 #include <hintids.hxx>
@@ -38,6 +37,7 @@
 #include <editeng/unolingu.hxx>
 #include <breakit.hxx>
 #include <editeng/forbiddenruleitem.hxx>
+#include <paintfrm.hxx>
 #include <txatbase.hxx>
 #include <fmtinfmt.hxx>
 #include <swmodule.hxx>
@@ -50,24 +50,21 @@
 #include <IDocumentDeviceAccess.hxx>
 #include <paratr.hxx>
 #include <rootfrm.hxx>
-#include <inftxt.hxx>
+#include "inftxt.hxx"
 #include <blink.hxx>
 #include <noteurl.hxx>
-#include <porftn.hxx>
-#include <porrst.hxx>
-#include <itratr.hxx>
+#include "porftn.hxx"
+#include "porrst.hxx"
+#include "itratr.hxx"
 #include <accessibilityoptions.hxx>
 #include <wrong.hxx>
 #include <doc.hxx>
 #include <pam.hxx>
 #include <SwGrammarMarkUp.hxx>
-#include "numrule.hxx"
+#include <numrule.hxx>
 #include <EnhancedPDFExportHelper.hxx>
 #include <docufld.hxx>
-
-//UUUU
 #include <frmfmt.hxx>
-
 #include <unomid.h>
 
 using namespace ::com::sun::star;
@@ -75,13 +72,13 @@ using namespace ::com::sun::star::linguistic2;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::beans;
 
-#define CHAR_UNDERSCORE ((sal_Unicode)0x005F)
-#define CHAR_LEFT_ARROW ((sal_Unicode)0x25C0)
-#define CHAR_RIGHT_ARROW ((sal_Unicode)0x25B6)
-#define CHAR_TAB ((sal_Unicode)0x2192)
-#define CHAR_TAB_RTL ((sal_Unicode)0x2190)
-#define CHAR_LINEBREAK ((sal_Unicode)0x21B5)
-#define CHAR_LINEBREAK_RTL ((sal_Unicode)0x21B3)
+#define CHAR_UNDERSCORE u'_'
+#define CHAR_LEFT_ARROW u'\x25C0'
+#define CHAR_RIGHT_ARROW u'\x25B6'
+#define CHAR_TAB u'\x2192'
+#define CHAR_TAB_RTL u'\x2190'
+#define CHAR_LINEBREAK u'\x21B5'
+#define CHAR_LINEBREAK_RTL u'\x21B3'
 
 #define DRAW_SPECIAL_OPTIONS_CENTER 1
 #define DRAW_SPECIAL_OPTIONS_ROTATE 2
@@ -89,7 +86,7 @@ using namespace ::com::sun::star::beans;
 SwLineInfo::SwLineInfo()
     : pRuler( nullptr ),
       pSpace( nullptr ),
-      nVertAlign( 0 ),
+      nVertAlign( SvxParaVertAlignItem::Align::Automatic ),
       nDefTabStop( 0 ),
       bListTabStopIncluded( false ),
       nListTabStopPosition( 0 )
@@ -98,27 +95,26 @@ SwLineInfo::SwLineInfo()
 
 SwLineInfo::~SwLineInfo()
 {
-    delete pRuler;
 }
+
 void SwLineInfo::CtorInitLineInfo( const SwAttrSet& rAttrSet,
                                    const SwTextNode& rTextNode )
 {
-    delete pRuler;
-    pRuler = new SvxTabStopItem( rAttrSet.GetTabStops() );
+    pRuler.reset( new SvxTabStopItem( rAttrSet.GetTabStops() ) );
     if ( rTextNode.GetListTabStopPosition( nListTabStopPosition ) )
     {
         bListTabStopIncluded = true;
 
         // insert the list tab stop into SvxTabItem instance <pRuler>
         const SvxTabStop aListTabStop( nListTabStopPosition,
-                                       SVX_TAB_ADJUST_LEFT );
+                                       SvxTabAdjust::Left );
         pRuler->Insert( aListTabStop );
 
         // remove default tab stops, which are before the inserted list tab stop
         for ( sal_uInt16 i = 0; i < pRuler->Count(); i++ )
         {
             if ( (*pRuler)[i].GetTabPos() < nListTabStopPosition &&
-                 (*pRuler)[i].GetAdjustment() == SVX_TAB_ADJUST_DEFAULT )
+                 (*pRuler)[i].GetAdjustment() == SvxTabAdjust::Default )
             {
                 pRuler->Remove(i);
                 continue;
@@ -132,7 +128,7 @@ void SwLineInfo::CtorInitLineInfo( const SwAttrSet& rAttrSet,
         for ( sal_uInt16 i = 0; i < pRuler->Count(); i++ )
         {
             if ( (*pRuler)[i].GetTabPos() == 0 &&
-                 (*pRuler)[i].GetAdjustment() == SVX_TAB_ADJUST_DEFAULT )
+                 (*pRuler)[i].GetAdjustment() == SvxTabAdjust::Default )
             {
                 pRuler->Remove(i);
                 break;
@@ -247,8 +243,8 @@ SwTextSizeInfo::SwTextSizeInfo( const SwTextSizeInfo &rNew )
 #endif
 }
 
-void SwTextSizeInfo::CtorInitTextSizeInfo( OutputDevice* pRenderContext, SwTextFrame *pFrame, SwFont *pNewFnt,
-                   const sal_Int32 nNewIdx, const sal_Int32 nNewLen )
+void SwTextSizeInfo::CtorInitTextSizeInfo( OutputDevice* pRenderContext, SwTextFrame *pFrame,
+                   const sal_Int32 nNewIdx )
 {
     m_pKanaComp = nullptr;
     m_nKanaIdx = 0;
@@ -285,14 +281,14 @@ void SwTextSizeInfo::CtorInitTextSizeInfo( OutputDevice* pRenderContext, SwTextF
     // Set default layout mode ( LTR or RTL ).
     if ( m_pFrame->IsRightToLeft() )
     {
-        m_pOut->SetLayoutMode( TEXT_LAYOUT_BIDI_STRONG | TEXT_LAYOUT_BIDI_RTL );
-        m_pRef->SetLayoutMode( TEXT_LAYOUT_BIDI_STRONG | TEXT_LAYOUT_BIDI_RTL );
+        m_pOut->SetLayoutMode( ComplexTextLayoutFlags::BiDiStrong | ComplexTextLayoutFlags::BiDiRtl );
+        m_pRef->SetLayoutMode( ComplexTextLayoutFlags::BiDiStrong | ComplexTextLayoutFlags::BiDiRtl );
         m_nDirection = DIR_RIGHT2LEFT;
     }
     else
     {
-        m_pOut->SetLayoutMode( TEXT_LAYOUT_BIDI_STRONG );
-        m_pRef->SetLayoutMode( TEXT_LAYOUT_BIDI_STRONG );
+        m_pOut->SetLayoutMode( ComplexTextLayoutFlags::BiDiStrong );
+        m_pRef->SetLayoutMode( ComplexTextLayoutFlags::BiDiStrong );
         m_nDirection = DIR_LEFT2RIGHT;
     }
 
@@ -309,12 +305,12 @@ void SwTextSizeInfo::CtorInitTextSizeInfo( OutputDevice* pRenderContext, SwTextF
     SetSnapToGrid( pNd->GetSwAttrSet().GetParaGrid().GetValue() &&
                    m_pFrame->IsInDocBody() );
 
-    m_pFnt = pNewFnt;
+    m_pFnt = nullptr;
     m_pUnderFnt = nullptr;
     m_pText = &pNd->GetText();
 
     m_nIdx = nNewIdx;
-    m_nLen = nNewLen;
+    m_nLen = COMPLETE_STRING;
     m_bNotEOL = false;
     m_bStopUnderflow = m_bFootnoteInside = m_bOtherThanFootnoteInside = false;
     m_bMulti = m_bFirstMulti = m_bRuby = m_bHanging = m_bScriptSpace =
@@ -324,7 +320,7 @@ void SwTextSizeInfo::CtorInitTextSizeInfo( OutputDevice* pRenderContext, SwTextF
 }
 
 SwTextSizeInfo::SwTextSizeInfo( const SwTextSizeInfo &rNew, const OUString* pText,
-                              const sal_Int32 nIndex, const sal_Int32 nLength )
+                              const sal_Int32 nIndex )
     : SwTextInfo( rNew ),
       m_pKanaComp(rNew.GetpKanaComp()),
       m_pVsh(const_cast<SwTextSizeInfo&>(rNew).GetVsh()),
@@ -336,7 +332,7 @@ SwTextSizeInfo::SwTextSizeInfo( const SwTextSizeInfo &rNew, const OUString* pTex
       m_pOpt(&rNew.GetOpt()),
       m_pText(pText),
       m_nIdx(nIndex),
-      m_nLen(nLength),
+      m_nLen(COMPLETE_STRING),
       m_nKanaIdx( rNew.GetKanaIdx() ),
       m_bOnWin( rNew.OnWin() ),
       m_bNotEOL( rNew.NotEOL() ),
@@ -359,12 +355,10 @@ SwTextSizeInfo::SwTextSizeInfo( const SwTextSizeInfo &rNew, const OUString* pTex
     SetLen( GetMinLen( *this ) );
 }
 
-SwTextSizeInfo::SwTextSizeInfo( SwTextFrame *pTextFrame, SwFont *pTextFnt,
-               const sal_Int32 nIndex,
-               const sal_Int32 nLength )
+SwTextSizeInfo::SwTextSizeInfo( SwTextFrame *pTextFrame, const sal_Int32 nIndex )
     : m_bOnWin(false)
 {
-    CtorInitTextSizeInfo( pTextFrame->getRootFrame()->GetCurrShell()->GetOut(), pTextFrame, pTextFnt, nIndex, nLength );
+    CtorInitTextSizeInfo( pTextFrame->getRootFrame()->GetCurrShell()->GetOut(), pTextFrame, nIndex );
 }
 
 void SwTextSizeInfo::SelectFont()
@@ -389,15 +383,14 @@ SwPosSize SwTextSizeInfo::GetTextSize( OutputDevice* pOutDev,
                                      const SwScriptInfo* pSI,
                                      const OUString& rText,
                                      const sal_Int32 nIndex,
-                                     const sal_Int32 nLength,
-                                     const sal_uInt16 nComp) const
+                                     const sal_Int32 nLength) const
 {
     SwDrawTextInfo aDrawInf( m_pVsh, *pOutDev, pSI, rText, nIndex, nLength );
     aDrawInf.SetFrame( m_pFrame );
     aDrawInf.SetFont( m_pFnt );
     aDrawInf.SetSnapToGrid( SnapToGrid() );
-    aDrawInf.SetKanaComp( nComp );
-    return SwPosSize(m_pFnt->_GetTextSize( aDrawInf ));
+    aDrawInf.SetKanaComp( 0 );
+    return SwPosSize(m_pFnt->GetTextSize_( aDrawInf ));
 }
 
 SwPosSize SwTextSizeInfo::GetTextSize() const
@@ -407,7 +400,7 @@ SwPosSize SwTextSizeInfo::GetTextSize() const
 
     // in some cases, compression is not allowed or suppressed for
     // performance reasons
-    sal_uInt16 nComp =( SW_CJK == GetFont()->GetActual() &&
+    sal_uInt16 nComp =( SwFontScript::CJK == GetFont()->GetActual() &&
                     rSI.CountCompChg() &&
                     ! IsMulti() ) ?
                     GetKanaComp() :
@@ -418,7 +411,7 @@ SwPosSize SwTextSizeInfo::GetTextSize() const
     aDrawInf.SetFont( m_pFnt );
     aDrawInf.SetSnapToGrid( SnapToGrid() );
     aDrawInf.SetKanaComp( nComp );
-    return SwPosSize(m_pFnt->_GetTextSize( aDrawInf ));
+    return SwPosSize(m_pFnt->GetTextSize_( aDrawInf ));
 }
 
 void SwTextSizeInfo::GetTextSize( const SwScriptInfo* pSI, const sal_Int32 nIndex,
@@ -432,7 +425,7 @@ void SwTextSizeInfo::GetTextSize( const SwScriptInfo* pSI, const sal_Int32 nInde
     aDrawInf.SetFont( m_pFnt );
     aDrawInf.SetSnapToGrid( SnapToGrid() );
     aDrawInf.SetKanaComp( nComp );
-    SwPosSize aSize( m_pFnt->_GetTextSize( aDrawInf ) );
+    SwPosSize aSize( m_pFnt->GetTextSize_( aDrawInf ) );
     nMaxSizeDiff = (sal_uInt16)aDrawInf.GetKanaDiff();
     nMinSize = aSize.Width();
 }
@@ -478,27 +471,22 @@ sal_Int32 SwTextSizeInfo::GetTextBreak( const long nLineWidth,
     return m_pFnt->GetTextBreak( aDrawInf, nLineWidth );
 }
 
-bool SwTextSizeInfo::_HasHint( const SwTextNode* pTextNode, sal_Int32 nPos )
+bool SwTextSizeInfo::HasHint_( const SwTextNode* pTextNode, sal_Int32 nPos )
 {
     return pTextNode->GetTextAttrForCharAt(nPos);
 }
 
 void SwTextPaintInfo::CtorInitTextPaintInfo( OutputDevice* pRenderContext, SwTextFrame *pFrame, const SwRect &rPaint )
 {
-    CtorInitTextSizeInfo( pRenderContext, pFrame );
-    aTextFly.CtorInitTextFly( pFrame ),
+    CtorInitTextSizeInfo( pRenderContext, pFrame, 0 );
+    aTextFly.CtorInitTextFly( pFrame );
     aPaintRect = rPaint;
     nSpaceIdx = 0;
     pSpaceAdd = nullptr;
     pWrongList = nullptr;
     pGrammarCheckList = nullptr;
     pSmartTags = nullptr;
-
-#if OSL_DEBUG_LEVEL > 1
-    pBrushItem = reinterpret_cast<SvxBrushItem*>(-1);
-#else
     pBrushItem = nullptr;
-#endif
 }
 
 SwTextPaintInfo::SwTextPaintInfo( const SwTextPaintInfo &rInf, const OUString* pText )
@@ -532,8 +520,6 @@ SwTextPaintInfo::SwTextPaintInfo( SwTextFrame *pFrame, const SwRect &rPaint )
     CtorInitTextPaintInfo( pFrame->getRootFrame()->GetCurrShell()->GetOut(), pFrame, rPaint );
 }
 
-extern Color aGlobalRetoucheColor;
-
 /// Returns if the current background color is dark.
 static bool lcl_IsDarkBackground( const SwTextPaintInfo& rInf )
 {
@@ -542,15 +528,13 @@ static bool lcl_IsDarkBackground( const SwTextPaintInfo& rInf )
     {
         const SvxBrushItem* pItem;
         SwRect aOrigBackRect;
-
-        //UUUU
         drawinglayer::attribute::SdrAllFillAttributesHelperPtr aFillAttributes;
 
         // Consider, that [GetBackgroundBrush(...)] can set <pCol>
         // See implementation in /core/layout/paintfrm.cxx
         // There is a background color, if there is a background brush and
         // its color is *not* "no fill"/"auto fill".
-        if( rInf.GetTextFrame()->GetBackgroundBrush( aFillAttributes, pItem, pCol, aOrigBackRect, false ) )
+        if( rInf.GetTextFrame()->GetBackgroundBrush( aFillAttributes, pItem, pCol, aOrigBackRect, false, /*bConsiderTextBox=*/false ) )
         {
             if ( !pCol )
                 pCol = &pItem->GetColor();
@@ -569,7 +553,7 @@ static bool lcl_IsDarkBackground( const SwTextPaintInfo& rInf )
     return pCol->IsDark();
 }
 
-void SwTextPaintInfo::_DrawText( const OUString &rText, const SwLinePortion &rPor,
+void SwTextPaintInfo::DrawText_( const OUString &rText, const SwLinePortion &rPor,
                                 const sal_Int32 nStart, const sal_Int32 nLength,
                                 const bool bKern, const bool bWrong,
                                 const bool bSmartTag,
@@ -593,7 +577,7 @@ void SwTextPaintInfo::_DrawText( const OUString &rText, const SwLinePortion &rPo
             if ( GetTextFrame()->IsRightToLeft() )
                 GetTextFrame()->SwitchLTRtoRTL( aPoint );
 
-            if ( TEXT_LAYOUT_BIDI_STRONG != GetOut()->GetLayoutMode() )
+            if ( ComplexTextLayoutFlags::BiDiStrong != GetOut()->GetLayoutMode() )
                 aPoint.X() -= rPor.Width();
 
             if ( GetTextFrame()->IsVertical() )
@@ -633,9 +617,6 @@ void SwTextPaintInfo::_DrawText( const OUString &rText, const SwLinePortion &rPo
     SwDrawTextInfo aDrawInf( m_pFrame->getRootFrame()->GetCurrShell(), *m_pOut, pSI, rText, nStart, nLength,
                              rPor.Width(), bBullet );
 
-    aDrawInf.SetLeft( GetPaintRect().Left() );
-    aDrawInf.SetRight( GetPaintRect().Right());
-
     aDrawInf.SetUnderFnt( m_pUnderFnt );
 
     const long nSpaceAdd = ( rPor.IsBlankPortion() || rPor.IsDropPortion() ||
@@ -694,8 +675,8 @@ void SwTextPaintInfo::_DrawText( const OUString &rText, const SwLinePortion &rPo
         }
         if( aFontPos.X() < 0 )
             aFontPos.X() = 0;
-        if( aFontPos.X() < 0 )
-            aFontPos.X() = 0;
+        if( aFontPos.Y() < 0 )
+            aFontPos.Y() = 0;
     }
 
     if( GetTextFly().IsOn() )
@@ -717,13 +698,13 @@ void SwTextPaintInfo::_DrawText( const OUString &rText, const SwLinePortion &rPo
     {
         aDrawInf.SetPos( aFontPos );
         if( bKern )
-            m_pFnt->_DrawStretchText( aDrawInf );
+            m_pFnt->DrawStretchText_( aDrawInf );
         else
         {
             aDrawInf.SetWrong( bTmpWrong ? pWrongList : nullptr );
             aDrawInf.SetGrammarCheck( bTmpGrammarCheck ? pGrammarCheckList : nullptr );
             aDrawInf.SetSmartTags( bTmpSmart ? pSmartTags : nullptr );
-            m_pFnt->_DrawText( aDrawInf );
+            m_pFnt->DrawText_( aDrawInf );
         }
     }
 }
@@ -752,22 +733,22 @@ void SwTextPaintInfo::CalcRect( const SwLinePortion& rPor,
         aSize.Height() = nTmp;
         if ( 1 == GetDirection() )
         {
-            aPoint.A() = X() - rPor.GetAscent();
-            aPoint.B() = Y() - aSize.Height();
+            aPoint.X() = X() - rPor.GetAscent();
+            aPoint.Y() = Y() - aSize.Height();
         }
         else
         {
-            aPoint.A() = X() - rPor.Height() + rPor.GetAscent();
-            aPoint.B() = Y();
+            aPoint.X() = X() - rPor.Height() + rPor.GetAscent();
+            aPoint.Y() = Y();
         }
     }
     else
     {
-        aPoint.A() = X();
+        aPoint.X() = X();
         if ( GetTextFrame()->IsVertLR() )
-            aPoint.B() = Y() - rPor.Height() + rPor.GetAscent();
+            aPoint.Y() = Y() - rPor.Height() + rPor.GetAscent();
         else
-            aPoint.B() = Y() - rPor.GetAscent();
+            aPoint.Y() = Y() - rPor.GetAscent();
     }
 
     // Adjust x coordinate if we are inside a bidi portion
@@ -776,7 +757,7 @@ void SwTextPaintInfo::CalcRect( const SwLinePortion& rPor,
                              (  bFrameDir && DIR_LEFT2RIGHT == GetDirection() );
 
     if ( bCounterDir )
-        aPoint.A() -= aSize.Width();
+        aPoint.X() -= aSize.Width();
 
     SwRect aRect( aPoint, aSize );
 
@@ -842,31 +823,31 @@ static void lcl_DrawSpecial( const SwTextPaintInfo& rInf, const SwLinePortion& r
     const SwFont* pOldFnt = rInf.GetFont();
 
     // Font is generated only once:
-    static SwFont* m_pFnt = nullptr;
-    if ( ! m_pFnt )
+    static SwFont* s_pFnt = nullptr;
+    if ( ! s_pFnt )
     {
-        m_pFnt = new SwFont( *pOldFnt );
-        m_pFnt->SetFamily( FAMILY_DONTKNOW, m_pFnt->GetActual() );
-        m_pFnt->SetName( numfunc::GetDefBulletFontname(), m_pFnt->GetActual() );
-        m_pFnt->SetStyleName( aEmptyOUStr, m_pFnt->GetActual() );
-        m_pFnt->SetCharSet( RTL_TEXTENCODING_SYMBOL, m_pFnt->GetActual() );
+        s_pFnt = new SwFont( *pOldFnt );
+        s_pFnt->SetFamily( FAMILY_DONTKNOW, s_pFnt->GetActual() );
+        s_pFnt->SetName( numfunc::GetDefBulletFontname(), s_pFnt->GetActual() );
+        s_pFnt->SetStyleName( aEmptyOUStr, s_pFnt->GetActual() );
+        s_pFnt->SetCharSet( RTL_TEXTENCODING_SYMBOL, s_pFnt->GetActual() );
     }
 
     // Some of the current values are set at the font:
     if ( ! bRotate )
-        m_pFnt->SetVertical( 0, rInf.GetTextFrame()->IsVertical() );
+        s_pFnt->SetVertical( 0, rInf.GetTextFrame()->IsVertical() );
     else
-        m_pFnt->SetVertical( pOldFnt->GetOrientation() );
+        s_pFnt->SetVertical( pOldFnt->GetOrientation() );
 
-    m_pFnt->SetColor(rCol);
+    s_pFnt->SetColor(rCol);
 
     Size aFontSize( 0, SPECIAL_FONT_HEIGHT );
-    m_pFnt->SetSize( aFontSize, m_pFnt->GetActual() );
+    s_pFnt->SetSize( aFontSize, s_pFnt->GetActual() );
 
-    const_cast<SwTextPaintInfo&>(rInf).SetFont( m_pFnt );
+    const_cast<SwTextPaintInfo&>(rInf).SetFont( s_pFnt );
 
     // The maximum width depends on the current orientation
-    const sal_uInt16 nDir = m_pFnt->GetOrientation( rInf.GetTextFrame()->IsVertical() );
+    const sal_uInt16 nDir = s_pFnt->GetOrientation( rInf.GetTextFrame()->IsVertical() );
     SwTwips nMaxWidth;
     if (nDir == 900 || nDir == 2700)
         nMaxWidth = rRect.Height();
@@ -885,14 +866,14 @@ static void lcl_DrawSpecial( const SwTextPaintInfo& rInf, const SwLinePortion& r
         const SwTwips nOldWidth = aFontSize.Width();
 
         // new height for font
-        const sal_uInt8 nAct = m_pFnt->GetActual();
-        aFontSize.Height() = ( 100 * m_pFnt->GetSize( nAct ).Height() ) / nFactor;
-        aFontSize.Width() = ( 100 * m_pFnt->GetSize( nAct).Width() ) / nFactor;
+        const SwFontScript nAct = s_pFnt->GetActual();
+        aFontSize.Height() = ( 100 * s_pFnt->GetSize( nAct ).Height() ) / nFactor;
+        aFontSize.Width() = ( 100 * s_pFnt->GetSize( nAct).Width() ) / nFactor;
 
         if ( !aFontSize.Width() && !aFontSize.Height() )
             break;
 
-        m_pFnt->SetSize( aFontSize, nAct );
+        s_pFnt->SetSize( aFontSize, nAct );
 
         aFontSize = rInf.GetTextSize( aTmp ).SvLSize();
 
@@ -934,27 +915,15 @@ static void lcl_DrawSpecial( const SwTextPaintInfo& rInf, const SwLinePortion& r
     const_cast<SwTextPaintInfo&>(rInf).SetPos( aOldPos );
 }
 
-void SwTextPaintInfo::DrawRect( const SwRect &rRect, bool bNoGraphic,
-                               bool bRetouche ) const
+void SwTextPaintInfo::DrawRect( const SwRect &rRect, bool bRetouche ) const
 {
     if ( OnWin() || !bRetouche )
     {
         if( aTextFly.IsOn() )
             const_cast<SwTextPaintInfo*>(this)->GetTextFly().
-                DrawFlyRect( m_pOut, rRect, *this, bNoGraphic );
-        else if ( bNoGraphic )
-            m_pOut->DrawRect( rRect.SVRect() );
+                DrawFlyRect( m_pOut, rRect );
         else
-        {
-            if(pBrushItem != reinterpret_cast<SvxBrushItem*>(-1))
-            {
-                ::DrawGraphic( pBrushItem, m_pOut, aItemRect, rRect );
-            }
-            else
-            {
-                OSL_ENSURE(false, "DrawRect: Uninitialized BrushItem!" );
-            }
-        }
+            m_pOut->DrawRect( rRect.SVRect() );
     }
 }
 
@@ -1032,51 +1001,52 @@ void SwTextPaintInfo::DrawRedArrow( const SwLinePortion &rPor ) const
     }
 }
 
-void SwTextPaintInfo::DrawPostIts( const SwLinePortion&, bool bScript ) const
+void SwTextPaintInfo::DrawPostIts( bool bScript ) const
 {
-    if( OnWin() && m_pOpt->IsPostIts() )
+    if( !OnWin() || !m_pOpt->IsPostIts() )
+        return;
+
+    Size aSize;
+    Point aTmp;
+
+    const sal_uInt16 nPostItsWidth = SwViewOption::GetPostItsWidth( GetOut() );
+    const sal_uInt16 nFontHeight = m_pFnt->GetHeight( m_pVsh, *GetOut() );
+    const sal_uInt16 nFontAscent = m_pFnt->GetAscent( m_pVsh, *GetOut() );
+
+    switch ( m_pFnt->GetOrientation( GetTextFrame()->IsVertical() ) )
     {
-        Size aSize;
-        Point aTmp;
-
-        const sal_uInt16 nPostItsWidth = SwViewOption::GetPostItsWidth( GetOut() );
-        const sal_uInt16 nFontHeight = m_pFnt->GetHeight( m_pVsh, *GetOut() );
-        const sal_uInt16 nFontAscent = m_pFnt->GetAscent( m_pVsh, *GetOut() );
-
-        switch ( m_pFnt->GetOrientation( GetTextFrame()->IsVertical() ) )
-        {
-        case 0 :
-            aSize.Width() = nPostItsWidth;
-            aSize.Height() = nFontHeight;
-            aTmp.X() = aPos.X();
-            aTmp.Y() = aPos.Y() - nFontAscent;
-            break;
-        case 900 :
-            aSize.Height() = nPostItsWidth;
-            aSize.Width() = nFontHeight;
-            aTmp.X() = aPos.X() - nFontAscent;
-            aTmp.Y() = aPos.Y();
-            break;
-        case 2700 :
-            aSize.Height() = nPostItsWidth;
-            aSize.Width() = nFontHeight;
-            aTmp.X() = aPos.X() - nFontHeight +
-                                  nFontAscent;
-            aTmp.Y() = aPos.Y();
-            break;
-        }
-
-        SwRect aTmpRect( aTmp, aSize );
-
-        if ( GetTextFrame()->IsRightToLeft() )
-            GetTextFrame()->SwitchLTRtoRTL( aTmpRect );
-
-        if ( GetTextFrame()->IsVertical() )
-            GetTextFrame()->SwitchHorizontalToVertical( aTmpRect );
-
-        const Rectangle aRect( aTmpRect.SVRect() );
-        SwViewOption::PaintPostIts( const_cast<OutputDevice*>(GetOut()), aRect, bScript );
+    case 0 :
+        aSize.Width() = nPostItsWidth;
+        aSize.Height() = nFontHeight;
+        aTmp.X() = aPos.X();
+        aTmp.Y() = aPos.Y() - nFontAscent;
+        break;
+    case 900 :
+        aSize.Height() = nPostItsWidth;
+        aSize.Width() = nFontHeight;
+        aTmp.X() = aPos.X() - nFontAscent;
+        aTmp.Y() = aPos.Y();
+        break;
+    case 2700 :
+        aSize.Height() = nPostItsWidth;
+        aSize.Width() = nFontHeight;
+        aTmp.X() = aPos.X() - nFontHeight +
+                              nFontAscent;
+        aTmp.Y() = aPos.Y();
+        break;
     }
+
+    SwRect aTmpRect( aTmp, aSize );
+
+    if ( GetTextFrame()->IsRightToLeft() )
+        GetTextFrame()->SwitchLTRtoRTL( aTmpRect );
+
+    if ( GetTextFrame()->IsVertical() )
+        GetTextFrame()->SwitchHorizontalToVertical( aTmpRect );
+
+    const tools::Rectangle aRect( aTmpRect.SVRect() );
+    SwViewOption::PaintPostIts( const_cast<OutputDevice*>(GetOut()), aRect, bScript );
+
 }
 
 void SwTextPaintInfo::DrawCheckBox(const SwFieldFormCheckboxPortion &rPor, bool bChecked) const
@@ -1096,7 +1066,7 @@ void SwTextPaintInfo::DrawCheckBox(const SwFieldFormCheckboxPortion &rPor, bool
             pOut->Pop();
         }
         const int delta=10;
-        Rectangle r(aIntersect.Left()+delta, aIntersect.Top()+delta, aIntersect.Right()-delta, aIntersect.Bottom()-delta);
+        tools::Rectangle r(aIntersect.Left()+delta, aIntersect.Top()+delta, aIntersect.Right()-delta, aIntersect.Bottom()-delta);
         m_pOut->Push( PushFlags::LINECOLOR | PushFlags::FILLCOLOR );
         m_pOut->SetLineColor( Color(0, 0, 0));
         m_pOut->SetFillColor();
@@ -1159,10 +1129,10 @@ void SwTextPaintInfo::DrawBackBrush( const SwLinePortion &rPor ) const
             }
             bool bIsStartMark=(1==GetLen() && CH_TXT_ATR_FIELDSTART==GetText()[GetIdx()]);
             if(pFieldmark) {
-                OSL_TRACE("Found Fieldmark");
-                SAL_INFO("sw.core", pFieldmark->ToString() << "\n");
+                SAL_INFO("sw.core", "Found Fieldmark " << pFieldmark->ToString());
             }
-            if(bIsStartMark) OSL_TRACE("Found StartMark");
+            if(bIsStartMark)
+                SAL_INFO("sw.core", "Found StartMark");
             if (OnWin() && (pFieldmark!=nullptr || bIsStartMark) &&
                     SwViewOption::IsFieldShadings() &&
                     !GetOpt().IsPagePreview())
@@ -1200,12 +1170,88 @@ void SwTextPaintInfo::DrawBackBrush( const SwLinePortion &rPor ) const
             aFillColor = *m_pFnt->GetBackColor();
         }
 
+        // tdf#104349 do not highlight portions of space chars before end of line if the compatibility option is enabled
+        // for LTR mode only
+        if ( !GetTextFrame()->IsRightToLeft() )
+        {
+            if ( GetTextFrame()->GetNode()->getIDocumentSettingAccess()->get( DocumentSettingId::MS_WORD_COMP_TRAILING_BLANKS ) )
+            {
+                bool           draw = false;
+                bool           full = false;
+                SwLinePortion *pPos = const_cast<SwLinePortion *>(&rPor);
+                sal_Int32      nIdx = GetIdx();
+                sal_Int32      nLen;
+
+                do
+                {
+                    nLen = pPos->GetLen();
+                    for ( int i = nIdx; i < (nIdx + nLen); ++i )
+                    {
+                        if ( i < GetText().getLength() && GetText()[i] == CH_TXTATR_NEWLINE )
+                        {
+                            if ( i >= (GetIdx() + rPor.GetLen()) )
+                            {
+                                goto drawcontinue;
+                            }
+                        }
+                        if ( i >= GetText().getLength() || GetText()[i] != CH_BLANK )
+                        {
+                            draw = true;
+                            if ( i >= (GetIdx() + rPor.GetLen()) )
+                            {
+                                full = true;
+                                goto drawcontinue;
+                            }
+                        }
+                    }
+                    nIdx += nLen;
+                    pPos = pPos->GetPortion();
+                } while ( pPos );
+
+            drawcontinue:
+
+                if ( !draw )
+                    return;
+
+                if ( !full )
+                {
+                    pPos = const_cast<SwLinePortion *>(&rPor);
+                    nIdx = GetIdx();
+
+                    nLen = pPos->GetLen();
+                    for ( int i = (nIdx + nLen - 1); i >= nIdx; --i )
+                    {
+                        if ( i < GetText().getLength() && GetText()[i] == CH_TXTATR_NEWLINE )
+                        {
+                            continue;
+                        }
+                        if ( i >= GetText().getLength() || GetText()[i] != CH_BLANK )
+                        {
+                            sal_uInt16 nOldWidth = rPor.Width();
+                            sal_uInt16 nNewWidth = GetTextSize( m_pOut, nullptr, GetText(), nIdx, (i + 1 - nIdx) ).Width();
+
+                            const_cast<SwLinePortion&>(rPor).Width( nNewWidth );
+                            CalcRect( rPor, nullptr, &aIntersect, true );
+                            const_cast<SwLinePortion&>(rPor).Width( nOldWidth );
+
+                            if ( !aIntersect.HasArea() )
+                            {
+                                return;
+                            }
+
+                            break;
+                        }
+                    }
+                }
+            }
+        }
+
         pTmpOut->Push( PushFlags::LINECOLOR | PushFlags::FILLCOLOR );
 
         pTmpOut->SetFillColor(aFillColor);
         pTmpOut->SetLineColor();
 
-        DrawRect( aIntersect, true, false );
+        DrawRect( aIntersect, false );
 
         pTmpOut->Pop();
     }
@@ -1258,9 +1304,15 @@ void SwTextPaintInfo::DrawViewOpt( const SwLinePortion &rPor,
                 bDraw = true;
             }
             break;
-        case POR_TAB:       if ( GetOpt().IsTab() )     bDraw = true; break;
-        case POR_SOFTHYPH:  if ( GetOpt().IsSoftHyph() )bDraw = true; break;
-        case POR_BLANK:     if ( GetOpt().IsHardBlank())bDraw = true; break;
+        case POR_TAB:
+            if ( GetOpt().IsTab() )     bDraw = true;
+            break;
+        case POR_SOFTHYPH:
+            if ( GetOpt().IsSoftHyph() )bDraw = true;
+            break;
+        case POR_BLANK:
+            if ( GetOpt().IsHardBlank())bDraw = true;
+            break;
         default:
             {
                 OSL_ENSURE( false, "SwTextPaintInfo::DrawViewOpt: don't know how to draw this" );
@@ -1272,7 +1324,7 @@ void SwTextPaintInfo::DrawViewOpt( const SwLinePortion &rPor,
     }
 }
 
-void SwTextPaintInfo::_NotifyURL( const SwLinePortion &rPor ) const
+void SwTextPaintInfo::NotifyURL_( const SwLinePortion &rPor ) const
 {
     OSL_ENSURE( pNoteURL, "NotifyURL: pNoteURL gone with the wind!" );
 
@@ -1356,9 +1408,6 @@ void SwTextFormatInfo::CtorInitTextFormatInfo( OutputDevice* pRenderContext, SwT
     m_bInterHyph = bNewInterHyph;
 
     //! needs to be done in this order
-    m_nMinLeading     = 2;
-    m_nMinTrailing    = 2;
-    m_nMinWordLength  = 0;
     m_bAutoHyph = InitHyph();
 
     m_bIgnoreFly = false;
@@ -1449,7 +1498,6 @@ void SwTextFormatInfo::Init()
     m_pRoot = nullptr;
     m_pLast = nullptr;
     m_pFly = nullptr;
-    m_pLastField = nullptr;
     m_pLastTab = nullptr;
     m_pUnderflow = nullptr;
     m_cTabDecimal = 0;
@@ -1484,7 +1532,6 @@ SwTextFormatInfo::SwTextFormatInfo( const SwTextFormatInfo& rInf,
     m_pRoot = &rLay;
     m_pLast = &rLay;
     m_pFly = nullptr;
-    m_pLastField = nullptr;
     m_pUnderflow = nullptr;
     m_pRest = nullptr;
     m_pLastTab = nullptr;
@@ -1501,9 +1548,6 @@ SwTextFormatInfo::SwTextFormatInfo( const SwTextFormatInfo& rInf,
     m_nLineNetHeight = 0;
     m_nForcedLeftMargin = 0;
 
-    m_nMinLeading = 0;
-    m_nMinTrailing = 0;
-    m_nMinWordLength = 0;
     m_bFull = false;
     m_bFootnoteDone = true;
     m_bErgoDone = true;
@@ -1530,7 +1574,7 @@ SwTextFormatInfo::SwTextFormatInfo( const SwTextFormatInfo& rInf,
     SetFirstMulti( rInf.IsFirstMulti() );
 }
 
-bool SwTextFormatInfo::_CheckFootnotePortion( SwLineLayout* pCurr )
+bool SwTextFormatInfo::CheckFootnotePortion_( SwLineLayout const * pCurr )
 {
     const sal_uInt16 nHeight = pCurr->GetRealHeight();
     for( SwLinePortion *pPor = pCurr->GetPortion(); pPor; pPor = pPor->GetPortion() )
@@ -1552,7 +1596,7 @@ sal_Int32 SwTextFormatInfo::ScanPortionEnd( const sal_Int32 nStart,
     sal_Int32 i = nStart;
 
     // Used for decimal tab handling:
-    const sal_Unicode cTabDec = GetLastTab() ? (sal_Unicode)GetTabDecimal() : 0;
+    const sal_Unicode cTabDec = GetLastTab() ? GetTabDecimal() : 0;
     const sal_Unicode cThousandSep  = ',' == cTabDec ? '.' : ',';
 
     // #i45951# German (Switzerland) uses ' as thousand separator
@@ -1570,7 +1614,7 @@ sal_Int32 SwTextFormatInfo::ScanPortionEnd( const sal_Int32 nStart,
         case CH_TXTATR_INWORD:
             if( !HasHint( i ))
                 break;
-            // no break;
+            SAL_FALLTHROUGH;
 
         case CHAR_SOFTHYPHEN:
         case CHAR_HARDHYPHEN:
@@ -1807,7 +1851,7 @@ SwFontSave::~SwFontSave()
         if( pIter )
         {
             pIter->SetFnt( pFnt );
-            pIter->nPos = COMPLETE_STRING;
+            pIter->m_nPosition = COMPLETE_STRING;
         }
     }
 }
