@@ -44,46 +44,45 @@
 #include <dcontact.hxx>
 #include <fldbas.hxx>
 #include <pam.hxx>
-#include <itratr.hxx>
+#include "itratr.hxx"
 #include <htmltbl.hxx>
 #include <swtable.hxx>
-#include <redlnitr.hxx>
+#include "redlnitr.hxx"
 #include <fmtsrnd.hxx>
-#include <itrtxt.hxx>
+#include "itrtxt.hxx"
 #include <breakit.hxx>
 #include <com/sun/star/i18n/WordType.hpp>
-#include <com/sun/star/i18n/ScriptType.hpp>
 #include <editeng/lrspitem.hxx>
 #include <calbck.hxx>
 
 using namespace ::com::sun::star::i18n;
 using namespace ::com::sun::star;
 
-void SwAttrIter::Chg( SwTextAttr *pHt )
+void SwAttrIter::Chg( SwTextAttr const *pHt )
 {
-    assert(pHt && pFnt && "No attribute of font available for change");
-    if( pRedln && pRedln->IsOn() )
-        pRedln->ChangeTextAttr( pFnt, *pHt, true );
+    assert(pHt && m_pFont && "No attribute of font available for change");
+    if( m_pRedline && m_pRedline->IsOn() )
+        m_pRedline->ChangeTextAttr( m_pFont, *pHt, true );
     else
-        aAttrHandler.PushAndChg( *pHt, *pFnt );
-    nChgCnt++;
+        m_aAttrHandler.PushAndChg( *pHt, *m_pFont );
+    m_nChgCnt++;
 }
 
-void SwAttrIter::Rst( SwTextAttr *pHt )
+void SwAttrIter::Rst( SwTextAttr const *pHt )
 {
-    assert(pHt && pFnt && "No attribute of font available for reset");
+    assert(pHt && m_pFont && "No attribute of font available for reset");
     // get top from stack after removing pHt
-    if( pRedln && pRedln->IsOn() )
-        pRedln->ChangeTextAttr( pFnt, *pHt, false );
+    if( m_pRedline && m_pRedline->IsOn() )
+        m_pRedline->ChangeTextAttr( m_pFont, *pHt, false );
     else
-        aAttrHandler.PopAndChg( *pHt, *pFnt );
-    nChgCnt--;
+        m_aAttrHandler.PopAndChg( *pHt, *m_pFont );
+    m_nChgCnt--;
 }
 
 SwAttrIter::~SwAttrIter()
 {
-    delete pRedln;
-    delete pFnt;
+    delete m_pRedline;
+    delete m_pFont;
 }
 
 /**
@@ -103,25 +102,25 @@ SwAttrIter::~SwAttrIter()
  */
 SwTextAttr *SwAttrIter::GetAttr( const sal_Int32 nPosition ) const
 {
-    return (m_pTextNode) ? m_pTextNode->GetTextAttrForCharAt(nPosition) : 0;
+    return (m_pTextNode) ? m_pTextNode->GetTextAttrForCharAt(nPosition) : nullptr;
 }
 
 bool SwAttrIter::SeekAndChgAttrIter( const sal_Int32 nNewPos, OutputDevice* pOut )
 {
-    bool bChg = nStartIndex && nNewPos == nPos ? pFnt->IsFntChg() : Seek( nNewPos );
-    if ( pLastOut.get() != pOut )
+    bool bChg = m_nStartIndex && nNewPos == m_nPosition ? m_pFont->IsFntChg() : Seek( nNewPos );
+    if ( m_pLastOut.get() != pOut )
     {
-        pLastOut = pOut;
-        pFnt->SetFntChg( true );
+        m_pLastOut = pOut;
+        m_pFont->SetFntChg( true );
         bChg = true;
     }
     if( bChg )
     {
         // if the change counter is zero, we know the MagicNo of the wanted font
-        if ( !nChgCnt && !nPropFont )
-            pFnt->SetMagic( aMagicNo[ pFnt->GetActual() ],
-                aFntIdx[ pFnt->GetActual() ], pFnt->GetActual() );
-        pFnt->ChgPhysFnt( pShell, *pOut );
+        if ( !m_nChgCnt && !m_nPropFont )
+            m_pFont->SetMagic( m_aMagicNo[ m_pFont->GetActual() ],
+                m_aFontIdx[ m_pFont->GetActual() ], m_pFont->GetActual() );
+        m_pFont->ChgPhysFnt( m_pViewShell, *pOut );
     }
 
     return bChg;
@@ -130,63 +129,63 @@ bool SwAttrIter::SeekAndChgAttrIter( const sal_Int32 nNewPos, OutputDevice* pOut
 bool SwAttrIter::IsSymbol( const sal_Int32 nNewPos )
 {
     Seek( nNewPos );
-    if ( !nChgCnt && !nPropFont )
-        pFnt->SetMagic( aMagicNo[ pFnt->GetActual() ],
-            aFntIdx[ pFnt->GetActual() ], pFnt->GetActual() );
-    return pFnt->IsSymbol( pShell );
+    if ( !m_nChgCnt && !m_nPropFont )
+        m_pFont->SetMagic( m_aMagicNo[ m_pFont->GetActual() ],
+            m_aFontIdx[ m_pFont->GetActual() ], m_pFont->GetActual() );
+    return m_pFont->IsSymbol( m_pViewShell );
 }
 
 bool SwAttrIter::SeekStartAndChgAttrIter( OutputDevice* pOut, const bool bParaFont )
 {
-    if ( pRedln && pRedln->ExtOn() )
-        pRedln->LeaveExtend( *pFnt, 0 );
+    if ( m_pRedline && m_pRedline->ExtOn() )
+        m_pRedline->LeaveExtend( *m_pFont, 0 );
 
     // reset font to its original state
-    aAttrHandler.Reset();
-    aAttrHandler.ResetFont( *pFnt );
+    m_aAttrHandler.Reset();
+    m_aAttrHandler.ResetFont( *m_pFont );
 
-    nStartIndex = 0;
-    nEndIndex = 0;
-    nPos = 0;
-    nChgCnt = 0;
-    if( nPropFont )
-        pFnt->SetProportion( nPropFont );
-    if( pRedln )
+    m_nStartIndex = 0;
+    m_nEndIndex = 0;
+    m_nPosition = 0;
+    m_nChgCnt = 0;
+    if( m_nPropFont )
+        m_pFont->SetProportion( m_nPropFont );
+    if( m_pRedline )
     {
-        pRedln->Clear( pFnt );
+        m_pRedline->Clear( m_pFont );
         if( !bParaFont )
-            nChgCnt = nChgCnt + pRedln->Seek( *pFnt, 0, USHRT_MAX );
+            m_nChgCnt = m_nChgCnt + m_pRedline->Seek( *m_pFont, 0, USHRT_MAX );
         else
-            pRedln->Reset();
+            m_pRedline->Reset();
     }
 
-    if ( pHints && !bParaFont )
+    if ( m_pHints && !bParaFont )
     {
         SwTextAttr *pTextAttr;
         // While we've not reached the end of the StartArray && the TextAttribute starts at position 0...
-        while ( ( nStartIndex < pHints->GetStartCount() ) &&
-                !((pTextAttr=pHints->GetStart(nStartIndex))->GetStart()) )
+        while ( ( m_nStartIndex < m_pHints->Count() ) &&
+                !((pTextAttr = m_pHints->Get(m_nStartIndex))->GetStart()) )
         {
             // open the TextAttributes
             Chg( pTextAttr );
-            nStartIndex++;
+            m_nStartIndex++;
         }
     }
 
-    bool bChg = pFnt->IsFntChg();
-    if ( pLastOut.get() != pOut )
+    bool bChg = m_pFont->IsFntChg();
+    if ( m_pLastOut.get() != pOut )
     {
-        pLastOut = pOut;
-        pFnt->SetFntChg( true );
+        m_pLastOut = pOut;
+        m_pFont->SetFntChg( true );
         bChg = true;
     }
     if( bChg )
     {
         // if the application counter is zero, we know the MagicNo of the wanted font
-        if ( !nChgCnt && !nPropFont )
-            pFnt->SetMagic( aMagicNo[ pFnt->GetActual() ],
-                aFntIdx[ pFnt->GetActual() ], pFnt->GetActual() );
-        pFnt->ChgPhysFnt( pShell, *pOut );
+        if ( !m_nChgCnt && !m_nPropFont )
+            m_pFont->SetMagic( m_aMagicNo[ m_pFont->GetActual() ],
+                m_aFontIdx[ m_pFont->GetActual() ], m_pFont->GetActual() );
+        m_pFont->ChgPhysFnt( m_pViewShell, *pOut );
     }
     return bChg;
 }
@@ -196,99 +195,99 @@ void SwAttrIter::SeekFwd( const sal_Int32 nNewPos )
 {
     SwTextAttr *pTextAttr;
 
-    if ( nStartIndex ) // If attributes have been opened at all ...
+    if ( m_nStartIndex ) // If attributes have been opened at all ...
     {
         // Close attributes that are currently open, but stop at nNewPos+1
 
         // As long as we've not yet reached the end of EndArray and the
         // TextAttribute ends before or at the new position ...
-        while ( ( nEndIndex < pHints->GetEndCount() ) &&
-                (*(pTextAttr=pHints->GetEnd(nEndIndex))->GetAnyEnd()<=nNewPos))
+        while ( ( m_nEndIndex < m_pHints->Count() ) &&
+                (*(pTextAttr=m_pHints->GetSortedByEnd(m_nEndIndex))->GetAnyEnd()<=nNewPos))
         {
-            // Close the TextAttributes, whoes StartPos were before or at
+            // Close the TextAttributes, whose StartPos were before or at
             // the old nPos and are currently open
-            if (pTextAttr->GetStart() <= nPos)  Rst( pTextAttr );
-            nEndIndex++;
+            if (pTextAttr->GetStart() <= m_nPosition)  Rst( pTextAttr );
+            m_nEndIndex++;
         }
     }
-    else // skip the not opended ends
+    else // skip the not opened ends
     {
-        while ( (nEndIndex < pHints->GetEndCount()) &&
-                (*pHints->GetEnd(nEndIndex)->GetAnyEnd() <= nNewPos) )
+        while ( (m_nEndIndex < m_pHints->Count()) &&
+                (*m_pHints->GetSortedByEnd(m_nEndIndex)->GetAnyEnd() <= nNewPos) )
         {
-            nEndIndex++;
+            m_nEndIndex++;
         }
     }
 
     // As long as we've not yet reached the end of EndArray and the
-    // TextAttribute ends before or at the new position ...
-    while ( ( nStartIndex < pHints->GetStartCount() ) &&
-            ((pTextAttr=pHints->GetStart(nStartIndex))->GetStart()<=nNewPos) )
+    // TextAttribute ends before or at the new position...
+    while ( ( m_nStartIndex < m_pHints->Count() ) &&
+            ((pTextAttr=m_pHints->Get(m_nStartIndex))->GetStart()<=nNewPos) )
     {
 
         // open the TextAttributes, whose ends lie behind the new position
         if ( *pTextAttr->GetAnyEnd() > nNewPos )  Chg( pTextAttr );
-        nStartIndex++;
+        m_nStartIndex++;
     }
 
 }
 
 bool SwAttrIter::Seek( const sal_Int32 nNewPos )
 {
-    if ( pRedln && pRedln->ExtOn() )
-        pRedln->LeaveExtend( *pFnt, nNewPos );
+    if ( m_pRedline && m_pRedline->ExtOn() )
+        m_pRedline->LeaveExtend( *m_pFont, nNewPos );
 
-    if( pHints )
+    if( m_pHints )
     {
-        if( !nNewPos || nNewPos < nPos )
+        if( !nNewPos || nNewPos < m_nPosition )
         {
-            if( pRedln )
-                pRedln->Clear( NULL );
+            if( m_pRedline )
+                m_pRedline->Clear( nullptr );
 
             // reset font to its original state
-            aAttrHandler.Reset();
-            aAttrHandler.ResetFont( *pFnt );
+            m_aAttrHandler.Reset();
+            m_aAttrHandler.ResetFont( *m_pFont );
 
-            if( nPropFont )
-                pFnt->SetProportion( nPropFont );
-            nStartIndex = 0;
-            nEndIndex = 0;
-            nPos = 0;
-            nChgCnt = 0;
+            if( m_nPropFont )
+                m_pFont->SetProportion( m_nPropFont );
+            m_nStartIndex = 0;
+            m_nEndIndex = 0;
+            m_nPosition = 0;
+            m_nChgCnt = 0;
 
             // Attention!
             // resetting the font here makes it necessary to apply any
             // changes for extended input directly to the font
-            if ( pRedln && pRedln->ExtOn() )
+            if ( m_pRedline && m_pRedline->ExtOn() )
             {
-                pRedln->UpdateExtFont( *pFnt );
-                ++nChgCnt;
+                m_pRedline->UpdateExtFont( *m_pFont );
+                ++m_nChgCnt;
             }
         }
         SeekFwd( nNewPos );
     }
 
-    pFnt->SetActual( SwScriptInfo::WhichFont( nNewPos, 0, pScriptInfo ) );
+    m_pFont->SetActual( SwScriptInfo::WhichFont( nNewPos, nullptr, m_pScriptInfo ) );
 
-    if( pRedln )
-        nChgCnt = nChgCnt + pRedln->Seek( *pFnt, nNewPos, nPos );
-    nPos = nNewPos;
+    if( m_pRedline )
+        m_nChgCnt = m_nChgCnt + m_pRedline->Seek( *m_pFont, nNewPos, m_nPosition );
+    m_nPosition = nNewPos;
 
-    if( nPropFont )
-        pFnt->SetProportion( nPropFont );
+    if( m_nPropFont )
+        m_pFont->SetProportion( m_nPropFont );
 
-    return pFnt->IsFntChg();
+    return m_pFont->IsFntChg();
 }
 
 sal_Int32 SwAttrIter::GetNextAttr( ) const
 {
     sal_Int32 nNext = COMPLETE_STRING;
-    if( pHints )
+    if( m_pHints )
     {
         // are there attribute starts left?
-        for (size_t i = nStartIndex; i < pHints->GetStartCount(); ++i)
+        for (size_t i = m_nStartIndex; i < m_pHints->Count(); ++i)
         {
-            SwTextAttr *const pAttr(pHints->GetStart(i));
+            SwTextAttr *const pAttr(m_pHints->Get(i));
             if (!pAttr->IsFormatIgnoreStart())
             {
                 nNext = pAttr->GetStart();
@@ -296,9 +295,9 @@ sal_Int32 SwAttrIter::GetNextAttr( ) const
             }
         }
         // are there attribute ends left?
-        for (size_t i = nEndIndex; i < pHints->GetEndCount(); ++i)
+        for (size_t i = m_nEndIndex; i < m_pHints->Count(); ++i)
         {
-            SwTextAttr *const pAttr(pHints->GetEnd(i));
+            SwTextAttr *const pAttr(m_pHints->GetSortedByEnd(i));
             if (!pAttr->IsFormatIgnoreEnd())
             {
                 sal_Int32 const nNextEnd = *pAttr->GetAnyEnd();
@@ -307,10 +306,10 @@ sal_Int32 SwAttrIter::GetNextAttr( ) const
             }
         }
     }
-    if (m_pTextNode!=NULL) {
+    if (m_pTextNode!=nullptr) {
         // TODO: maybe use hints like FieldHints for this instead of looking at the text...
         const sal_Int32 l = nNext<m_pTextNode->Len() ? nNext : m_pTextNode->Len();
-        sal_Int32 p=nPos;
+        sal_Int32 p=m_nPosition;
         const sal_Unicode* aStr = m_pTextNode->GetText().getStr();
         while (p<l)
         {
@@ -325,13 +324,13 @@ sal_Int32 SwAttrIter::GetNextAttr( ) const
                 break;
             }
         }
-        if ((p<l && p>nPos) || nNext<=p)
+        if ((p<l && p>m_nPosition) || nNext<=p)
         nNext=p;
         else
         nNext=p+1;
     }
-    if( pRedln )
-        return pRedln->GetNextRedln( nNext );
+    if( m_pRedline )
+        return m_pRedline->GetNextRedln( nNext );
     return nNext;
 }
 
@@ -341,14 +340,13 @@ public:
     VclPtr<OutputDevice> pOut;
     SwViewShell const * pSh;
     sal_uLong &rMin;
-    sal_uLong &rMax;
     sal_uLong &rAbsMin;
     long nRowWidth;
     long nWordWidth;
     long nWordAdd;
     sal_Int32 nNoLineBreak;
-    SwMinMaxArgs( OutputDevice* pOutI, SwViewShell const * pShI, sal_uLong& rMinI, sal_uLong &rMaxI, sal_uLong &rAbsI )
-        : pOut( pOutI ), pSh( pShI ), rMin( rMinI ), rMax( rMaxI ), rAbsMin( rAbsI )
+    SwMinMaxArgs( OutputDevice* pOutI, SwViewShell const * pShI, sal_uLong& rMinI, sal_uLong &rAbsI )
+        : pOut( pOutI ), pSh( pShI ), rMin( rMinI ), rAbsMin( rAbsI )
         { nRowWidth = nWordWidth = nWordAdd = 0; nNoLineBreak = COMPLETE_STRING; }
     void Minimum( long nNew ) const { if( (long)rMin < nNew ) rMin = nNew; }
     void NewWord() { nWordAdd = nWordWidth = 0; }
@@ -361,37 +359,23 @@ static bool lcl_MinMaxString( SwMinMaxArgs& rArg, SwFont* pFnt, const OUString &
     while( nIdx < nEnd )
     {
         sal_Int32 nStop = nIdx;
-        bool bClear = false;
         LanguageType eLang = pFnt->GetLanguage();
-        if( g_pBreakIt->GetBreakIter().is() )
-        {
-            bClear = CH_BLANK == rText[ nStop ];
-            Boundary aBndry( g_pBreakIt->GetBreakIter()->getWordBoundary( rText, nIdx,
-                             g_pBreakIt->GetLocale( eLang ),
-                             WordType::DICTIONARY_WORD, true ) );
-            nStop = aBndry.endPos;
-            if( nIdx <= aBndry.startPos && nIdx && nIdx-1 != rArg.nNoLineBreak )
-                rArg.NewWord();
-            if( nStop == nIdx )
-                ++nStop;
-            if( nStop > nEnd )
-                nStop = nEnd;
-        }
-        else
-        {
-            while( nStop < nEnd && CH_BLANK != rText[ nStop ] )
-                ++nStop;
-            bClear = nStop == nIdx;
-            if ( bClear )
-            {
-                rArg.NewWord();
-                while( nStop < nEnd && CH_BLANK == rText[ nStop ] )
-                    ++nStop;
-            }
-        }
+        assert(g_pBreakIt && g_pBreakIt->GetBreakIter().is());
 
-        SwDrawTextInfo aDrawInf( rArg.pSh, *rArg.pOut, 0, rText, nIdx, nStop - nIdx );
-        long nAktWidth = pFnt->_GetTextSize( aDrawInf ).Width();
+        bool bClear = CH_BLANK == rText[ nStop ];
+        Boundary aBndry( g_pBreakIt->GetBreakIter()->getWordBoundary( rText, nIdx,
+                         g_pBreakIt->GetLocale( eLang ),
+                         WordType::DICTIONARY_WORD, true ) );
+        nStop = aBndry.endPos;
+        if( nIdx <= aBndry.startPos && nIdx && nIdx-1 != rArg.nNoLineBreak )
+            rArg.NewWord();
+        if( nStop == nIdx )
+            ++nStop;
+        if( nStop > nEnd )
+            nStop = nEnd;
+
+        SwDrawTextInfo aDrawInf( rArg.pSh, *rArg.pOut, nullptr, rText, nIdx, nStop - nIdx );
+        long nAktWidth = pFnt->GetTextSize_( aDrawInf ).Width();
         rArg.nRowWidth += nAktWidth;
         if( bClear )
             rArg.NewWord();
@@ -413,8 +397,7 @@ bool SwTextNode::IsSymbol( const sal_Int32 nBegin ) const
     SwScriptInfo aScriptInfo;
     SwAttrIter aIter( *const_cast<SwTextNode*>(this), aScriptInfo );
     aIter.Seek( nBegin );
-    return aIter.GetFnt()->IsSymbol(
-        const_cast<SwViewShell *>(getIDocumentLayoutAccess()->GetCurrentViewShell()) );
+    return aIter.GetFnt()->IsSymbol( getIDocumentLayoutAccess().GetCurrentViewShell() );
 }
 
 class SwMinMaxNodeArgs
@@ -434,8 +417,8 @@ static void lcl_MinMaxNode( SwFrameFormat* pNd, SwMinMaxNodeArgs* pIn )
 {
     const SwFormatAnchor& rFormatA = pNd->GetAnchor();
 
-    if ((FLY_AT_PARA != rFormatA.GetAnchorId()) &&
-        (FLY_AT_CHAR != rFormatA.GetAnchorId()))
+    if ((RndStdIds::FLY_AT_PARA != rFormatA.GetAnchorId()) &&
+        (RndStdIds::FLY_AT_CHAR != rFormatA.GetAnchorId()))
     {
         return;
     }
@@ -446,7 +429,7 @@ static void lcl_MinMaxNode( SwFrameFormat* pNd, SwMinMaxNodeArgs* pIn )
         return;
 
     long nMin, nMax;
-    SwHTMLTableLayout *pLayout = 0;
+    SwHTMLTableLayout *pLayout = nullptr;
     const bool bIsDrawFrameFormat = pNd->Which()==RES_DRAWFRMFMT;
     if( !bIsDrawFrameFormat )
     {
@@ -490,7 +473,7 @@ static void lcl_MinMaxNode( SwFrameFormat* pNd, SwMinMaxNodeArgs* pIn )
         }
         else
         {
-            const SwFormatFrmSize &rSz = pNd->GetFrmSize();
+            const SwFormatFrameSize &rSz = pNd->GetFrameSize();
             nMin = rSz.GetWidth();
         }
         nMax = nMin;
@@ -503,7 +486,7 @@ static void lcl_MinMaxNode( SwFrameFormat* pNd, SwMinMaxNodeArgs* pIn )
     nMax += rLR.GetLeft();
     nMax += rLR.GetRight();
 
-    if( SURROUND_THROUGHT == pNd->GetSurround().GetSurround() )
+    if( css::text::WrapTextMode_THROUGH == pNd->GetSurround().GetSurround() )
     {
         pIn->Minimum( nMin );
         return;
@@ -556,19 +539,17 @@ static void lcl_MinMaxNode( SwFrameFormat* pNd, SwMinMaxNodeArgs* pIn )
  * Changing this method very likely requires changing of GetScalingOfSelectedText
  */
 void SwTextNode::GetMinMaxSize( sal_uLong nIndex, sal_uLong& rMin, sal_uLong &rMax,
-                               sal_uLong& rAbsMin, OutputDevice* pOut ) const
+                               sal_uLong& rAbsMin ) const
 {
     SwViewShell const * pSh = GetDoc()->getIDocumentLayoutAccess().GetCurrentViewShell();
+    OutputDevice* pOut = nullptr;
+    if( pSh )
+        pOut = pSh->GetWin();
     if( !pOut )
-    {
-        if( pSh )
-            pOut = pSh->GetWin();
-        if( !pOut )
-            pOut = Application::GetDefaultDevice();
-    }
+        pOut = Application::GetDefaultDevice();
 
     MapMode aOldMap( pOut->GetMapMode() );
-    pOut->SetMapMode( MapMode( MAP_TWIP ) );
+    pOut->SetMapMode( MapMode( MapUnit::MapTwip ) );
 
     rMin = 0;
     rMax = 0;
@@ -617,14 +598,14 @@ void SwTextNode::GetMinMaxSize( sal_uLong nIndex, sal_uLong& rMin, sal_uLong &rM
     sal_Int32 nLen = m_Text.getLength();
     long nAktWidth = 0;
     long nAdd = 0;
-    SwMinMaxArgs aArg( pOut, pSh, rMin, rMax, rAbsMin );
+    SwMinMaxArgs aArg( pOut, pSh, rMin, rAbsMin );
     while( nIdx < nLen )
     {
         sal_Int32 nNextChg = aIter.GetNextAttr();
         sal_Int32 nStop = aScriptInfo.NextScriptChg( nIdx );
         if( nNextChg > nStop )
             nNextChg = nStop;
-        SwTextAttr *pHint = NULL;
+        SwTextAttr *pHint = nullptr;
         sal_Unicode cChar = CH_BLANK;
         nStop = nIdx;
         while( nStop < nLen && nStop < nNextChg &&
@@ -634,7 +615,7 @@ void SwTextNode::GetMinMaxSize( sal_uLong nIndex, sal_uLong& rMin, sal_uLong &rM
                !pHint )
         {
             if( ( CH_TXTATR_BREAKWORD != cChar && CH_TXTATR_INWORD != cChar )
-                || ( 0 == ( pHint = aIter.GetAttr( nStop ) ) ) )
+                || ( nullptr == ( pHint = aIter.GetAttr( nStop ) ) ) )
                 ++nStop;
         }
         if ( lcl_MinMaxString( aArg, aIter.GetFnt(), m_Text, nIdx, nStop ) )
@@ -667,9 +648,9 @@ void SwTextNode::GetMinMaxSize( sal_uLong nIndex, sal_uLong& rMin, sal_uLong &rM
             case CHAR_HARDHYPHEN:
             {
                 OUString sTmp( cChar );
-                SwDrawTextInfo aDrawInf( getIDocumentLayoutAccess()->GetCurrentViewShell(),
-                    *pOut, 0, sTmp, 0, 1, 0, false );
-                nAktWidth = aIter.GetFnt()->_GetTextSize( aDrawInf ).Width();
+                SwDrawTextInfo aDrawInf( getIDocumentLayoutAccess().GetCurrentViewShell(),
+                    *pOut, nullptr, sTmp, 0, 1, 0, false );
+                nAktWidth = aIter.GetFnt()->GetTextSize_( aDrawInf ).Width();
                 aArg.nWordWidth += nAktWidth;
                 aArg.nRowWidth += nAktWidth;
                 if( (long)rAbsMin < aArg.nWordWidth )
@@ -703,11 +684,11 @@ void SwTextNode::GetMinMaxSize( sal_uLong nIndex, sal_uLong& rMin, sal_uLong &rM
                         }
                         else
                         {
-                            const SwFormatFrmSize& rTmpSize = pFrameFormat->GetFrmSize();
+                            const SwFormatFrameSize& rTmpSize = pFrameFormat->GetFrameSize();
                             if( RES_FLYFRMFMT == pFrameFormat->Which()
                                 && rTmpSize.GetWidthPercent() )
                             {
-                                // This is a hack for the wollowing situation: In the paragraph there's a
+                                // This is a hack for the following situation: In the paragraph there's a
                                 // text frame with relative size. Then let's take 0.5 cm as minimum width
                                 // and USHRT_MAX as maximum width
                                 // It were cleaner and maybe necessary later on to iterate over the content
@@ -717,7 +698,7 @@ void SwTextNode::GetMinMaxSize( sal_uLong nIndex, sal_uLong& rMin, sal_uLong &rM
                                     rMax = USHRT_MAX;
                             }
                             else
-                                nAktWidth = pFrameFormat->GetFrmSize().GetWidth();
+                                nAktWidth = pFrameFormat->GetFrameSize().GetWidth();
                         }
                         nAktWidth += rLR.GetLeft();
                         nAktWidth += rLR.GetRight();
@@ -791,7 +772,7 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
     const
 {
     SwViewShell const * pSh = GetDoc()->getIDocumentLayoutAccess().GetCurrentViewShell();
-    OutputDevice* pOut = NULL;
+    OutputDevice* pOut = nullptr;
 
     if ( pSh )
         pOut = &pSh->GetRefDev();
@@ -801,18 +782,17 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
         if ( getIDocumentSettingAccess()->get(DocumentSettingId::HTML_MODE) )
             pOut = Application::GetDefaultDevice();
         else
-            pOut = getIDocumentDeviceAccess()->getReferenceDevice( true );
+            pOut = getIDocumentDeviceAccess().getReferenceDevice( true );
     }
 
     OSL_ENSURE( pOut, "GetScalingOfSelectedText without outdev" );
 
     MapMode aOldMap( pOut->GetMapMode() );
-    pOut->SetMapMode( MapMode( MAP_TWIP ) );
+    pOut->SetMapMode( MapMode( MapUnit::MapTwip ) );
 
     if ( nStt == nEnd )
     {
-        if ( !g_pBreakIt->GetBreakIter().is() )
-            return 100;
+        assert(g_pBreakIt && g_pBreakIt->GetBreakIter().is());
 
         SwScriptInfo aScriptInfo;
         SwAttrIter aIter( *const_cast<SwTextNode*>(this), aScriptInfo );
@@ -866,7 +846,7 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
 
         sal_Int32 nStop = nIdx;
         sal_Unicode cChar = CH_BLANK;
-        SwTextAttr* pHint = NULL;
+        SwTextAttr* pHint = nullptr;
 
         // stop at special characters in [ nIdx, nNextChg ]
         while( nStop < nEnd && nStop < nNextChg )
@@ -880,7 +860,7 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
                 CHAR_SOFTHYPHEN == cChar ||
                 (
                   (CH_TXTATR_BREAKWORD == cChar || CH_TXTATR_INWORD == cChar) &&
-                  (0 == (pHint = aIter.GetAttr(nStop)))
+                  (nullptr == (pHint = aIter.GetAttr(nStop)))
                 )
                )
             {
@@ -893,8 +873,8 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
         // calculate text widths up to cChar
         if ( nStop > nIdx )
         {
-            SwDrawTextInfo aDrawInf( pSh, *pOut, 0, GetText(), nIdx, nStop - nIdx );
-            nProWidth += aIter.GetFnt()->_GetTextSize( aDrawInf ).Width();
+            SwDrawTextInfo aDrawInf( pSh, *pOut, nullptr, GetText(), nIdx, nStop - nIdx );
+            nProWidth += aIter.GetFnt()->GetTextSize_( aDrawInf ).Width();
         }
 
         nIdx = nStop;
@@ -910,8 +890,8 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
         {
             // tab receives width of one space
             OUString sTmp( CH_BLANK );
-            SwDrawTextInfo aDrawInf( pSh, *pOut, 0, sTmp, 0, 1 );
-            nProWidth += aIter.GetFnt()->_GetTextSize( aDrawInf ).Width();
+            SwDrawTextInfo aDrawInf( pSh, *pOut, nullptr, sTmp, 0, 1 );
+            nProWidth += aIter.GetFnt()->GetTextSize_( aDrawInf ).Width();
             nIdx++;
         }
         else if ( cChar == CHAR_SOFTHYPHEN )
@@ -919,8 +899,8 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
         else if ( cChar == CHAR_HARDBLANK || cChar == CHAR_HARDHYPHEN )
         {
             OUString sTmp( cChar );
-            SwDrawTextInfo aDrawInf( pSh, *pOut, 0, sTmp, 0, 1 );
-            nProWidth += aIter.GetFnt()->_GetTextSize( aDrawInf ).Width();
+            SwDrawTextInfo aDrawInf( pSh, *pOut, nullptr, sTmp, 0, 1 );
+            nProWidth += aIter.GetFnt()->GetTextSize_( aDrawInf ).Width();
             nIdx++;
         }
         else if ( pHint && ( cChar == CH_TXTATR_BREAKWORD || cChar == CH_TXTATR_INWORD ) )
@@ -930,9 +910,9 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
             case RES_TXTATR_FTN :
                 {
                     const OUString aText = pHint->GetFootnote().GetNumStr();
-                    SwDrawTextInfo aDrawInf( pSh, *pOut, 0, aText, 0, aText.getLength() );
+                    SwDrawTextInfo aDrawInf( pSh, *pOut, nullptr, aText, 0, aText.getLength() );
 
-                    nProWidth += aIter.GetFnt()->_GetTextSize( aDrawInf ).Width();
+                    nProWidth += aIter.GetFnt()->GetTextSize_( aDrawInf ).Width();
                     break;
                 }
 
@@ -941,9 +921,9 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
                 {
                     SwField *pField = const_cast<SwField*>(pHint->GetFormatField().GetField());
                     OUString const aText = pField->ExpandField(true);
-                    SwDrawTextInfo aDrawInf( pSh, *pOut, 0, aText, 0, aText.getLength() );
+                    SwDrawTextInfo aDrawInf( pSh, *pOut, nullptr, aText, 0, aText.getLength() );
 
-                    nProWidth += aIter.GetFnt()->_GetTextSize( aDrawInf ).Width();
+                    nProWidth += aIter.GetFnt()->GetTextSize_( aDrawInf ).Width();
                     break;
                 }
 
@@ -959,24 +939,24 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
     nWidth = std::max( nWidth, nProWidth );
 
     // search for a text frame this node belongs to
-    SwIterator<SwTextFrm,SwTextNode> aFrmIter( *this );
-    SwTextFrm* pFrm = 0;
-    for( SwTextFrm* pTmpFrm = aFrmIter.First(); pTmpFrm; pTmpFrm = aFrmIter.Next() )
+    SwIterator<SwTextFrame,SwTextNode> aFrameIter( *this );
+    SwTextFrame* pFrame = nullptr;
+    for( SwTextFrame* pTmpFrame = aFrameIter.First(); pTmpFrame; pTmpFrame = aFrameIter.Next() )
     {
-            if ( pTmpFrm->GetOfst() <= nStt &&
-                ( !pTmpFrm->GetFollow() ||
-                   pTmpFrm->GetFollow()->GetOfst() > nStt ) )
+            if ( pTmpFrame->GetOfst() <= nStt &&
+                ( !pTmpFrame->GetFollow() ||
+                   pTmpFrame->GetFollow()->GetOfst() > nStt ) )
             {
-                pFrm = pTmpFrm;
+                pFrame = pTmpFrame;
                 break;
             }
         }
 
     // search for the line containing nStt
-    if ( pFrm && pFrm->HasPara() )
+    if ( pFrame && pFrame->HasPara() )
     {
-        SwTextInfo aInf( pFrm );
-        SwTextIter aLine( pFrm, &aInf );
+        SwTextInfo aInf( pFrame );
+        SwTextIter aLine( pFrame, &aInf );
         aLine.CharToLine( nStt );
         pOut->SetMapMode( aOldMap );
         return (sal_uInt16)( nWidth ?
@@ -988,9 +968,9 @@ sal_uInt16 SwTextNode::GetScalingOfSelectedText( sal_Int32 nStt, sal_Int32 nEnd
     aIter.SeekAndChgAttrIter( nStt, pOut );
     pOut->SetMapMode( aOldMap );
 
-    SwDrawTextInfo aDrawInf( pSh, *pOut, 0, GetText(), nStt, 1 );
+    SwDrawTextInfo aDrawInf( pSh, *pOut, nullptr, GetText(), nStt, 1 );
     return (sal_uInt16)
-           ( nWidth ? ((100 * aIter.GetFnt()->_GetTextSize( aDrawInf ).Height()) / nWidth ) : 0 );
+           ( nWidth ? ((100 * aIter.GetFnt()->GetTextSize_( aDrawInf ).Height()) / nWidth ) : 0 );
 }
 
 SwTwips SwTextNode::GetWidthOfLeadingTabs() const
@@ -1015,18 +995,18 @@ SwTwips SwTextNode::GetWidthOfLeadingTabs() const
         aPos.nContent += nIdx;
 
         // Find the non-follow text frame:
-        SwIterator<SwTextFrm,SwTextNode> aIter( *this );
-        for( SwTextFrm* pFrm = aIter.First(); pFrm; pFrm = aIter.Next() )
+        SwIterator<SwTextFrame,SwTextNode> aIter( *this );
+        for( SwTextFrame* pFrame = aIter.First(); pFrame; pFrame = aIter.Next() )
         {
             // Only consider master frames:
-            if ( !pFrm->IsFollow() )
+            if ( !pFrame->IsFollow() )
             {
-                SWRECTFN( pFrm )
+                SwRectFnSet aRectFnSet(pFrame);
                 SwRect aRect;
-                pFrm->GetCharRect( aRect, aPos );
-                nRet = pFrm->IsRightToLeft() ?
-                            (pFrm->*fnRect->fnGetPrtRight)() - (aRect.*fnRect->fnGetRight)() :
-                            (aRect.*fnRect->fnGetLeft)() - (pFrm->*fnRect->fnGetPrtLeft)();
+                pFrame->GetCharRect( aRect, aPos );
+                nRet = pFrame->IsRightToLeft() ?
+                            aRectFnSet.GetPrtRight(*pFrame) - aRectFnSet.GetRight(aRect) :
+                            aRectFnSet.GetLeft(aRect) - aRectFnSet.GetPrtLeft(*pFrame);
                 break;
             }
         }
