@@ -17,13 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "hintids.hxx"
-#include "ndtxt.hxx"
-#include "frmfmt.hxx"
-#include "paratr.hxx"
-#include "flyfrm.hxx"
-#include "pam.hxx"
-#include "swselectionlist.hxx"
+#include <hintids.hxx>
+#include <ndtxt.hxx>
+#include <frmfmt.hxx>
+#include <paratr.hxx>
+#include <flyfrm.hxx>
+#include <pam.hxx>
+#include <swselectionlist.hxx>
 #include <sortedobjs.hxx>
 #include <editeng/protitem.hxx>
 #include <editeng/adjustitem.hxx>
@@ -37,14 +37,14 @@
 #include <pagefrm.hxx>
 
 #include "itrtxt.hxx"
-#include "txtfrm.hxx"
-#include "flyfrms.hxx"
+#include <txtfrm.hxx>
+#include <flyfrms.hxx>
 #include "porglue.hxx"
 #include "porfld.hxx"
 #include "porfly.hxx"
 #include "pordrop.hxx"
-#include "crstate.hxx"
-#include <pormulti.hxx>
+#include <crstate.hxx>
+#include "pormulti.hxx"
 #include <numrule.hxx>
 #include <com/sun/star/i18n/ScriptType.hpp>
 
@@ -187,8 +187,8 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
     if ( m_pFrame->IsRightToLeft() )
     {
         // this calculation is identical this the calculation for L2R layout - see below
-        nLeft = m_pFrame->Frame().Left() +
-                m_pFrame->Prt().Left() +
+        nLeft = m_pFrame->getFrameArea().Left() +
+                m_pFrame->getFramePrintArea().Left() +
                 nLMWithNum -
                 pNode->GetLeftMarginWithNum() -
                 // #i95907#
@@ -206,8 +206,8 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
              !pNode->getIDocumentSettingAccess()->get(DocumentSettingId::IGNORE_FIRST_LINE_INDENT_IN_NUMBERING) )
         {
             // this calculation is identical this the calculation for R2L layout - see above
-            nLeft = m_pFrame->Frame().Left() +
-                    m_pFrame->Prt().Left() +
+            nLeft = m_pFrame->getFrameArea().Left() +
+                    m_pFrame->getFramePrintArea().Left() +
                     nLMWithNum -
                     pNode->GetLeftMarginWithNum() -
                     // #i95907#
@@ -218,13 +218,13 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
         }
         else
         {
-            nLeft = m_pFrame->Frame().Left() +
+            nLeft = m_pFrame->getFrameArea().Left() +
                     std::max( long( rSpace.GetTextLeft() + nLMWithNum ),
-                         m_pFrame->Prt().Left() );
+                         m_pFrame->getFramePrintArea().Left() );
         }
     }
 
-    nRight = m_pFrame->Frame().Left() + m_pFrame->Prt().Left() + m_pFrame->Prt().Width();
+    nRight = m_pFrame->getFrameArea().Left() + m_pFrame->getFramePrintArea().Left() + m_pFrame->getFramePrintArea().Width();
 
     if( nLeft >= nRight &&
          // #i53066# Omit adjustment of nLeft for numbered
@@ -233,7 +233,7 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
           !m_pFrame->IsInTab() ||
           !nLMWithNum ) )
     {
-        nLeft = m_pFrame->Prt().Left() + m_pFrame->Frame().Left();
+        nLeft = m_pFrame->getFramePrintArea().Left() + m_pFrame->getFrameArea().Left();
         if( nLeft >= nRight )   // e.g. with large paragraph indentations in slim table columns
             nRight = nLeft + 1; // einen goennen wir uns immer
     }
@@ -257,24 +257,24 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
             {
                 switch( pSpace->GetLineSpaceRule() )
                 {
-                    case SVX_LINE_SPACE_AUTO:
+                    case SvxLineSpaceRule::Auto:
                     break;
-                    case SVX_LINE_SPACE_MIN:
+                    case SvxLineSpaceRule::Min:
                     {
                         if( nFirstLineOfs < pSpace->GetLineHeight() )
                             nFirstLineOfs = pSpace->GetLineHeight();
                         break;
                     }
-                    case SVX_LINE_SPACE_FIX:
+                    case SvxLineSpaceRule::Fix:
                         nFirstLineOfs = pSpace->GetLineHeight();
                     break;
                     default: OSL_FAIL( ": unknown LineSpaceRule" );
                 }
                 switch( pSpace->GetInterLineSpaceRule() )
                 {
-                    case SVX_INTER_LINE_SPACE_OFF:
+                    case SvxInterLineSpaceRule::Off:
                     break;
-                    case SVX_INTER_LINE_SPACE_PROP:
+                    case SvxInterLineSpaceRule::Prop:
                     {
                         long nTmp = pSpace->GetPropLineSpace();
                         // 50% is the minimum, at 0% we switch to
@@ -289,7 +289,7 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
                         nFirstLineOfs = nTmp;
                         break;
                     }
-                    case SVX_INTER_LINE_SPACE_FIX:
+                    case SvxInterLineSpaceRule::Fix:
                     {
                         nFirstLineOfs += pSpace->GetInterLineSpace();
                         break;
@@ -311,9 +311,9 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
         }
         else
         {
-              nFirst = m_pFrame->Frame().Left() +
+              nFirst = m_pFrame->getFrameArea().Left() +
                      std::max( rSpace.GetTextLeft() + nLMWithNum+ nFirstLineOfs,
-                          m_pFrame->Prt().Left() );
+                          m_pFrame->getFramePrintArea().Left() );
         }
 
         // Note: <SwTextFrame::GetAdditionalFirstLineOffset()> returns a negative
@@ -326,32 +326,24 @@ void SwTextMargin::CtorInitTextMargin( SwTextFrame *pNewFrame, SwTextSizeInfo *p
             nFirst = nRight - 1;
     }
     const SvxAdjustItem& rAdjust = m_pFrame->GetTextNode()->GetSwAttrSet().GetAdjust();
-    nAdjust = static_cast<sal_uInt16>(rAdjust.GetAdjust());
+    nAdjust = rAdjust.GetAdjust();
 
     // left is left and right is right
     if ( m_pFrame->IsRightToLeft() )
     {
-        if ( SVX_ADJUST_LEFT == nAdjust )
-            nAdjust = SVX_ADJUST_RIGHT;
-        else if ( SVX_ADJUST_RIGHT == nAdjust )
-            nAdjust = SVX_ADJUST_LEFT;
+        if ( SvxAdjust::Left == nAdjust )
+            nAdjust = SvxAdjust::Right;
+        else if ( SvxAdjust::Right == nAdjust )
+            nAdjust = SvxAdjust::Left;
     }
 
-    m_bOneBlock = rAdjust.GetOneWord() == SVX_ADJUST_BLOCK;
-    m_bLastBlock = rAdjust.GetLastBlock() == SVX_ADJUST_BLOCK;
-    m_bLastCenter = rAdjust.GetLastBlock() == SVX_ADJUST_CENTER;
+    m_bOneBlock = rAdjust.GetOneWord() == SvxAdjust::Block;
+    m_bLastBlock = rAdjust.GetLastBlock() == SvxAdjust::Block;
+    m_bLastCenter = rAdjust.GetLastBlock() == SvxAdjust::Center;
 
     // #i91133#
     mnTabLeft = pNode->GetLeftMarginForTabCalculation();
 
-#if OSL_DEBUG_LEVEL > 1
-    static bool bOne = false;
-    static bool bLast = false;
-    static bool bCenter = false;
-    bOneBlock |= bOne;
-    bLastBlock |= bLast;
-    bLastCenter |= bCenter;
-#endif
     DropInit();
 }
 
@@ -376,14 +368,14 @@ void SwTextMargin::DropInit()
 SwTwips SwTextMargin::GetLineStart() const
 {
     SwTwips nRet = GetLeftMargin();
-    if( GetAdjust() != SVX_ADJUST_LEFT &&
+    if( GetAdjust() != SvxAdjust::Left &&
         !m_pCurr->GetFirstPortion()->IsMarginPortion() )
     {
         // If the first portion is a Margin, then the
         // adjustment is expressed by the portions.
-        if( GetAdjust() == SVX_ADJUST_RIGHT )
+        if( GetAdjust() == SvxAdjust::Right )
             nRet = Right() - CurrWidth();
-        else if( GetAdjust() == SVX_ADJUST_CENTER )
+        else if( GetAdjust() == SvxAdjust::Center )
             nRet += (GetLineWidth() - CurrWidth()) / 2;
     }
     return nRet;
@@ -471,7 +463,7 @@ bool SwTextCursor::GetEndCharRect( SwRect* pOrig, const sal_Int32 nOfst,
 // pCMS is used for restricting the cursor, if there are different font
 // heights in one line ( first value = offset to y of pOrig, second
 // value = real height of (shortened) cursor
-void SwTextCursor::_GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
+void SwTextCursor::GetCharRect_( SwRect* pOrig, const sal_Int32 nOfst,
     SwCursorMoveState* pCMS )
 {
     const OUString aText = GetInfo().GetText();
@@ -655,7 +647,7 @@ void SwTextCursor::_GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
                         {
                              pLastBidiPor = static_cast<SwBidiPortion*>(pPor);
                              nLastBidiPorWidth = pLastBidiPor->Width() +
-                                                 pLastBidiPor->CalcSpacing( nSpaceAdd, aInf );;
+                                                 pLastBidiPor->CalcSpacing( nSpaceAdd, aInf );
                         }
                     }
 
@@ -769,7 +761,7 @@ void SwTextCursor::_GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
                                 static_cast<SwBidiPortion*>(pPor)->GetLevel() % 2 );
                         }
 
-                        _GetCharRect( pOrig, nOfst, pCMS );
+                        GetCharRect_( pOrig, nOfst, pCMS );
 
                         if ( bChgHeight )
                         {
@@ -784,8 +776,6 @@ void SwTextCursor::_GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
                         {
                             // the recursion may have damaged our font size
                             SetPropFont( nOldProp );
-                            if ( !nOldProp )
-                                nOldProp = 100;
                             GetInfo().GetFont()->SetProportion( 100 );
 
                             if ( m_pCurr == &static_cast<SwMultiPortion*>(pPor)->GetRoot() )
@@ -833,7 +823,7 @@ void SwTextCursor::_GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
                                 // correct for reverse (270 degree) portions
                                 if( static_cast<SwMultiPortion*>(pPor)->IsRevers() )
                                 {
-                                    if ( SvxParaVertAlignItem::AUTOMATIC ==
+                                    if ( SvxParaVertAlignItem::Align::Automatic ==
                                          GetLineInfo().GetVertAlign() )
                                         // if vertical alignment is set to auto,
                                         // we switch from base line alignment
@@ -887,7 +877,7 @@ void SwTextCursor::_GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
                         {
                             SeekAndChg( aInf );
                             const bool bOldOnWin = aInf.OnWin();
-                            aInf.SetOnWin( false ); // keine BULLETs!
+                            aInf.SetOnWin( false ); // no BULLETs!
                             SwTwips nTmp = nX;
                             aInf.SetKanaComp( pKanaComp );
                             aInf.SetKanaIdx( nKanaIdx );
@@ -899,7 +889,7 @@ void SwTextCursor::_GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
                             {
                                 pPor->SetLen( pPor->GetLen() + 1 );
                                 aInf.SetLen( pPor->GetLen() );
-                                aInf.SetOnWin( false ); // keine BULLETs!
+                                aInf.SetOnWin( false ); // no BULLETs!
                                 nTmp += pPor->GetTextSize( aInf ).Width();
                                 aInf.SetOnWin( bOldOnWin );
                                 if ( pPor->InSpaceGrp() && nSpaceAdd )
@@ -1078,7 +1068,7 @@ void SwTextCursor::_GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
                         pPor->SetLen( 1 );
                         aInf.SetLen( pPor->GetLen() );
                         SeekAndChg( aInf );
-                        aInf.SetOnWin( false ); // keine BULLETs!
+                        aInf.SetOnWin( false ); // no BULLETs!
                         aInf.SetKanaComp( pKanaComp );
                         aInf.SetKanaIdx( nKanaIdx );
                         nTmp = pPor->GetTextSize( aInf ).Width();
@@ -1199,9 +1189,8 @@ bool SwTextCursor::GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
     GetAdjusted();
 
     const Point aCharPos( GetTopLeft() );
-    bool bRet = true;
 
-    _GetCharRect( pOrig, nFindOfst, pCMS );
+    GetCharRect_( pOrig, nFindOfst, pCMS );
 
     // This actually would have to be "-1 LogicToPixel", but that seems too
     // expensive, so it's a value (-12), that should hopefully be OK.
@@ -1243,18 +1232,18 @@ bool SwTextCursor::GetCharRect( SwRect* pOrig, const sal_Int32 nOfst,
                 pCMS->m_aRealHeight.Y() = nMax - nTmp;
         }
     }
-    long nOut = pOrig->Right() - GetTextFrame()->Frame().Right();
+    long nOut = pOrig->Right() - GetTextFrame()->getFrameArea().Right();
     if( nOut > 0 )
     {
-        if( GetTextFrame()->Frame().Width() < GetTextFrame()->Prt().Left()
-                                   + GetTextFrame()->Prt().Width() )
-            nOut += GetTextFrame()->Frame().Width() - GetTextFrame()->Prt().Left()
-                    - GetTextFrame()->Prt().Width();
+        if( GetTextFrame()->getFrameArea().Width() < GetTextFrame()->getFramePrintArea().Left()
+                                   + GetTextFrame()->getFramePrintArea().Width() )
+            nOut += GetTextFrame()->getFrameArea().Width() - GetTextFrame()->getFramePrintArea().Left()
+                    - GetTextFrame()->getFramePrintArea().Width();
         if( nOut > 0 )
             pOrig->Pos().X() -= nOut + 10;
     }
 
-    return bRet;
+    return true;
 }
 
 // Return: Offset in String
@@ -1270,7 +1259,8 @@ sal_Int32 SwTextCursor::GetCursorOfst( SwPosition *pPos, const Point &rPoint,
     // x is the horizontal offset within the line.
     SwTwips x = rPoint.X();
     const SwTwips nLeftMargin  = GetLineStart();
-    SwTwips nRightMargin = GetLineEnd() + GetCurr()->GetHangingMargin();
+    SwTwips nRightMargin = GetLineEnd() +
+        ( GetCurr()->IsHanging() ? GetCurr()->GetHangingMargin() : 0 );
     if( nRightMargin == nLeftMargin )
         nRightMargin += 30;
 
@@ -1414,7 +1404,7 @@ sal_Int32 SwTextCursor::GetCursorOfst( SwPosition *pPos, const Point &rPoint,
     if( bFieldInfo && ( nWidth30 < nX || bRightOver || bLeftOver ||
         ( pPor->InNumberGrp() && !pPor->IsFootnoteNumPortion() ) ||
         ( pPor->IsMarginPortion() && nWidth > nX + 30 ) ) )
-        static_cast<SwCursorMoveState*>(pCMS)->m_bPosCorr = true;
+        pCMS->m_bPosCorr = true;
 
     // #i27615#
     if (pCMS)
@@ -1435,16 +1425,16 @@ sal_Int32 SwTextCursor::GetCursorOfst( SwPosition *pPos, const Point &rPoint,
         if( pCMS )
         {
             if( pPor->IsFlyPortion() && bFieldInfo )
-                static_cast<SwCursorMoveState*>(pCMS)->m_bPosCorr = true;
+                pCMS->m_bPosCorr = true;
 
             if (!bRightOver && nX)
             {
                 if( pPor->IsFootnoteNumPortion())
-                    static_cast<SwCursorMoveState*>(pCMS)->m_bFootnoteNoInfo = true;
+                    pCMS->m_bFootnoteNoInfo = true;
                 else if (pPor->InNumberGrp() ) // #i23726#
                 {
-                    static_cast<SwCursorMoveState*>(pCMS)->m_nInNumPostionOffset = nX;
-                    static_cast<SwCursorMoveState*>(pCMS)->m_bInNumPortion = true;
+                    pCMS->m_nInNumPortionOffset = nX;
+                    pCMS->m_bInNumPortion = true;
                 }
             }
         }
@@ -1555,7 +1545,7 @@ sal_Int32 SwTextCursor::GetCursorOfst( SwPosition *pPos, const Point &rPoint,
                  ! static_cast<SwMultiPortion*>(pPor)->OnTop() )
                 nTmpY = 0;
 
-            SwTextCursorSave aSave( const_cast<SwTextCursor*>(static_cast<const SwTextCursor*>(this)), static_cast<SwMultiPortion*>(pPor),
+            SwTextCursorSave aSave( const_cast<SwTextCursor*>(this), static_cast<SwMultiPortion*>(pPor),
                  nTmpY, nX, nCurrStart, nSpaceAdd );
 
             SwLayoutModeModifier aLayoutModeModifier( *GetInfo().GetOut() );
@@ -1665,12 +1655,12 @@ sal_Int32 SwTextCursor::GetCursorOfst( SwPosition *pPos, const Point &rPoint,
                 aDrawInf.SetSnapToGrid( aSizeInf.SnapToGrid() );
                 aDrawInf.SetPosMatchesBounds( pCMS && pCMS->m_bPosMatchesBounds );
 
-                if ( SW_CJK == aSizeInf.GetFont()->GetActual() &&
+                if ( SwFontScript::CJK == aSizeInf.GetFont()->GetActual() &&
                      pPara->GetScriptInfo().CountCompChg() &&
                     ! pPor->InFieldGrp() )
                     aDrawInf.SetKanaComp( nKanaComp );
 
-                nLength = aSizeInf.GetFont()->_GetCursorOfst( aDrawInf );
+                nLength = aSizeInf.GetFont()->GetCursorOfst_( aDrawInf );
 
                 // get position inside field portion?
                 if ( pPor->InFieldGrp() && pCMS && pCMS->m_pSpecialPos )
@@ -1681,7 +1671,7 @@ sal_Int32 SwTextCursor::GetCursorOfst( SwPosition *pPos, const Point &rPoint,
 
                 // set cursor bidi level
                 if ( pCMS )
-                    static_cast<SwCursorMoveState*>(pCMS)->m_nCursorBidiLevel =
+                    pCMS->m_nCursorBidiLevel =
                         aDrawInf.GetCursorBidiLevel();
 
                 if( bFieldInfo && nLength == pPor->GetLen() &&
@@ -1694,13 +1684,13 @@ sal_Int32 SwTextCursor::GetCursorOfst( SwPosition *pPos, const Point &rPoint,
         }
         else
         {
-            if( bChgNode && pPos && pPor->IsFlyCntPortion()
-                && !static_cast<SwFlyCntPortion*>(pPor)->IsDraw() )
+            sw::FlyContentPortion* pFlyPor(nullptr);
+            if(bChgNode && pPos && (pFlyPor = dynamic_cast<sw::FlyContentPortion*>(pPor)))
             {
                 // JP 24.11.94: if the Position is not in Fly, then
                 //              we many not return with COMPLETE_STRING as value!
                 //              (BugId: 9692 + Change in feshview)
-                SwFlyInContentFrame *pTmp = static_cast<SwFlyCntPortion*>(pPor)->GetFlyFrame();
+                SwFlyInContentFrame *pTmp = pFlyPor->GetFlyFrame();
                 SwFrame* pLower = pTmp->GetLower();
                 bool bChgNodeInner = pLower
                     && (pLower->IsTextFrame() || pLower->IsLayoutFrame());
@@ -1712,11 +1702,10 @@ sal_Int32 SwTextCursor::GetCursorOfst( SwPosition *pPos, const Point &rPoint,
                 if ( m_pFrame->IsVertical() )
                     m_pFrame->SwitchHorizontalToVertical( aTmpPoint );
 
-                if( bChgNodeInner && pTmp->Frame().IsInside( aTmpPoint ) &&
+                if( bChgNodeInner && pTmp->getFrameArea().IsInside( aTmpPoint ) &&
                     !( pTmp->IsProtected() ) )
                 {
-                    nLength = static_cast<SwFlyCntPortion*>(pPor)->
-                              GetFlyCursorOfst( nX, aTmpPoint, pPos, pCMS );
+                    pFlyPor->GetFlyCursorOfst(aTmpPoint, *pPos, pCMS);
                     // After a change of the frame, our font must be still
                     // available for/in the OutputDevice.
                     // For comparison: Paint and new SwFlyCntPortion !
@@ -1763,7 +1752,7 @@ sal_Int32 SwTextCursor::GetCursorOfst( SwPosition *pPos, const Point &rPoint,
 bool SwTextFrame::FillSelection( SwSelectionList& rSelList, const SwRect& rRect ) const
 {
     bool bRet = false;
-    // PaintArea() instead Frame() for negative indents
+    // PaintArea() instead getFrameArea() for negative indents
     SwRect aTmpFrame( PaintArea() );
     if( !rRect.IsOver( aTmpFrame ) )
         return false;
@@ -1788,11 +1777,11 @@ bool SwTextFrame::FillSelection( SwSelectionList& rSelList, const SwRect& rRect
             SwTextInfo aInf( const_cast<SwTextFrame*>(this) );
             SwTextIter aLine( const_cast<SwTextFrame*>(this), &aInf );
             // We have to care for top-to-bottom layout, where right becomes top etc.
-            SWRECTFN( this )
-            SwTwips nTop = (aRect.*fnRect->fnGetTop)();
-            SwTwips nBottom = (aRect.*fnRect->fnGetBottom)();
-            SwTwips nLeft = (aRect.*fnRect->fnGetLeft)();
-            SwTwips nRight = (aRect.*fnRect->fnGetRight)();
+            SwRectFnSet aRectFnSet(this);
+            SwTwips nTop = aRectFnSet.GetTop(aRect);
+            SwTwips nBottom = aRectFnSet.GetBottom(aRect);
+            SwTwips nLeft = aRectFnSet.GetLeft(aRect);
+            SwTwips nRight = aRectFnSet.GetRight(aRect);
             SwTwips nY = aLine.Y(); // Top position of the first line
             SwTwips nLastY = nY;
             while( nY < nTop && aLine.Next() ) // line above rectangle
@@ -1816,7 +1805,7 @@ bool SwTextFrame::FillSelection( SwSelectionList& rSelList, const SwRect& rRect
                 {
                     nLastY += nY;
                     nLastY /= 2;
-                    if( bVert )
+                    if( aRectFnSet.IsVert() )
                     {
                         aPoint.X() = nLastY;
                         aPoint.Y() = nLeft;
@@ -1831,7 +1820,7 @@ bool SwTextFrame::FillSelection( SwSelectionList& rSelList, const SwRect& rRect
                     SwCursorMoveState aState( MV_UPDOWN );
                     if( GetCursorOfst( &aPosL, aPoint, &aState ) )
                     {
-                        if( bVert )
+                        if( aRectFnSet.IsVert() )
                         {
                             aPoint.X() = nLastY;
                             aPoint.Y() = nRight;
@@ -1873,9 +1862,8 @@ bool SwTextFrame::FillSelection( SwSelectionList& rSelList, const SwRect& rRect
     if( GetDrawObjs() )
     {
         const SwSortedObjs &rObjs = *GetDrawObjs();
-        for ( size_t i = 0; i < rObjs.size(); ++i )
+        for (SwAnchoredObject* pAnchoredObj : rObjs)
         {
-            const SwAnchoredObject* pAnchoredObj = rObjs[i];
             if( dynamic_cast< const SwFlyFrame *>( pAnchoredObj ) ==  nullptr )
                 continue;
             const SwFlyFrame* pFly = static_cast<const SwFlyFrame*>(pAnchoredObj);
