@@ -17,19 +17,19 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <ctype.h>
-
 #include <com/sun/star/i18n/ScriptType.hpp>
 #include <i18nlangtag/mslangid.hxx>
 #include <hintids.hxx>
 #include <EnhancedPDFExportHelper.hxx>
 #include <SwPortionHandler.hxx>
-#include <porlay.hxx>
-#include <inftxt.hxx>
-#include <guess.hxx>
-#include <porglue.hxx>
-#include <portab.hxx>
-#include <porfld.hxx>
+#include "porlay.hxx"
+#include "inftxt.hxx"
+#include "guess.hxx"
+#include "porglue.hxx"
+#include "portab.hxx"
+#include "porfld.hxx"
+#include <pagefrm.hxx>
+#include <tgrditem.hxx>
 #include <wrong.hxx>
 #include <viewsh.hxx>
 #include <IDocumentSettingAccess.hxx>
@@ -75,7 +75,7 @@ static sal_Int32 lcl_AddSpace( const SwTextSizeInfo &rInf, const OUString* pStr,
     // first we get the script type
     if ( pSI )
         nScript = pSI->ScriptType( nPos );
-    else if ( g_pBreakIt->GetBreakIter().is() )
+    else
         nScript = (sal_uInt8)g_pBreakIt->GetBreakIter()->getScriptType( *pStr, nPos );
 
     // Note: rInf.GetIdx() can differ from nPos,
@@ -99,7 +99,7 @@ static sal_Int32 lcl_AddSpace( const SwTextSizeInfo &rInf, const OUString* pStr,
                            pPor->IsPostItsPortion() ) )
                 pPor = pPor->GetPortion();
 
-            nCnt += nEnd - nPos;
+            nCnt += SwScriptInfo::CountCJKCharacters( *pStr, nPos, nEnd, aLang );
 
             if ( !pPor || pPor->IsHolePortion() || pPor->InFixMargGrp() ||
                   pPor->IsBreakPortion() )
@@ -112,7 +112,8 @@ static sal_Int32 lcl_AddSpace( const SwTextSizeInfo &rInf, const OUString* pStr,
     // Kashida Justification: Insert Kashidas
     if ( nEnd > nPos && pSI && COMPLEX == nScript )
     {
-        if ( SwScriptInfo::IsArabicText( *pStr, nPos, nEnd - nPos ) && pSI->CountKashida() )
+        if ( SwScriptInfo::IsArabicText( *pStr, nPos, nEnd - nPos ) && rInf.GetOut()->GetMinKashida()
+            && pSI->CountKashida() )
         {
             const sal_Int32 nKashRes = pSI->KashidaJustify( nullptr, nullptr, nPos, nEnd - nPos );
             // i60591: need to check result of KashidaJustify
@@ -177,18 +178,18 @@ static sal_Int32 lcl_AddSpace( const SwTextSizeInfo &rInf, const OUString* pStr,
         if ( pPor && pPor->IsKernPortion() )
             pPor = pPor->GetPortion();
 
-        if ( ! g_pBreakIt->GetBreakIter().is() || ! pPor || pPor->InFixMargGrp() )
+        if (!pPor || pPor->InFixMargGrp())
             return nCnt;
 
         // next character is inside a field?
         if ( CH_TXTATR_BREAKWORD == rInf.GetChar( nPos ) && pPor->InExpGrp() )
         {
             bool bOldOnWin = rInf.OnWin();
-            ((SwTextSizeInfo &)rInf).SetOnWin( false );
+            const_cast<SwTextSizeInfo &>(rInf).SetOnWin( false );
 
             OUString aStr;
             pPor->GetExpText( rInf, aStr );
-            ((SwTextSizeInfo &)rInf).SetOnWin( bOldOnWin );
+            const_cast<SwTextSizeInfo &>(rInf).SetOnWin( bOldOnWin );
 
             nNextScript = (sal_uInt8)g_pBreakIt->GetBreakIter()->getScriptType( aStr, 0 );
         }
@@ -271,13 +272,13 @@ void SwTextPortion::BreakUnderflow( SwTextFormatInfo &rInf )
     rInf.SetUnderflow( this );
 }
 
-static bool lcl_HasContent( const SwFieldPortion& rField, SwTextFormatInfo &rInf )
+static bool lcl_HasContent( const SwFieldPortion& rField, SwTextFormatInfo const &rInf )
 {
     OUString aText;
     return rField.GetExpText( rInf, aText ) && !aText.isEmpty();
 }
 
-bool SwTextPortion::_Format( SwTextFormatInfo &rInf )
+bool SwTextPortion::Format_( SwTextFormatInfo &rInf )
 {
     // 5744: If only the hyphen does not fit anymore, we still need to wrap
     // the word, or else return true!
@@ -321,7 +322,7 @@ bool SwTextPortion::_Format( SwTextFormatInfo &rInf )
     if ( !bFull )
     {
         Width( aGuess.BreakWidth() );
-        // Vorsicht !
+        // Caution!
         if( !InExpGrp() || InFieldGrp() )
             SetLen( rInf.GetLen() );
 
@@ -340,9 +341,8 @@ bool SwTextPortion::_Format( SwTextFormatInfo &rInf )
     {
         Width( aGuess.BreakWidth() );
         SetLen( aGuess.BreakPos() - rInf.GetIdx() );
-        Insert( aGuess.GetHangingPortion() );
         aGuess.GetHangingPortion()->SetAscent( GetAscent() );
-        aGuess.ClearHangingPortion();
+        Insert( aGuess.ReleaseHangingPortion() );
     }
     // breakPos >= index
     else if ( aGuess.BreakPos() >= rInf.GetIdx() && aGuess.BreakPos() != COMPLETE_STRING )
@@ -450,7 +450,7 @@ bool SwTextPortion::Format( SwTextFormatInfo &rInf )
         "SwTextPortion::Format: missing real width" );
     OSL_ENSURE( Height(), "SwTextPortion::Format: missing height" );
 
-    return _Format( rInf );
+    return Format_( rInf );
 }
 
 // Format end of line
@@ -463,33 +463,36 @@ bool SwTextPortion::Format( SwTextFormatInfo &rInf )
 // rInf.nIdx points to the next word, nIdx-1 is the portion's last char
 void SwTextPortion::FormatEOL( SwTextFormatInfo &rInf )
 {
-    if( ( !GetPortion() || ( GetPortion()->IsKernPortion() &&
-        !GetPortion()->GetPortion() ) ) && GetLen() &&
+    if( !(
+        ( !GetPortion() || ( GetPortion()->IsKernPortion() &&
+          !GetPortion()->GetPortion() ) ) &&
+        GetLen() &&
         rInf.GetIdx() < rInf.GetText().getLength() &&
-        1 < rInf.GetIdx() && ' ' == rInf.GetChar( rInf.GetIdx() - 1 )
-        && !rInf.GetLast()->IsHolePortion() )
-    {
-        // calculate number of blanks
-        sal_Int32 nX = rInf.GetIdx() - 1;
-        sal_Int32 nHoleLen = 1;
-        while( nX && nHoleLen < GetLen() && CH_BLANK == rInf.GetChar( --nX ) )
-            nHoleLen++;
+        1 < rInf.GetIdx() && ' ' == rInf.GetChar( rInf.GetIdx() - 1 ) &&
+        !rInf.GetLast()->IsHolePortion()) )
+        return;
+
+    // calculate number of blanks
+    sal_Int32 nX = rInf.GetIdx() - 1;
+    sal_Int32 nHoleLen = 1;
+    while( nX && nHoleLen < GetLen() && CH_BLANK == rInf.GetChar( --nX ) )
+        nHoleLen++;
+
+    // First set ourselves and the insert, because there could be
+    // a SwLineLayout
+    sal_uInt16 nBlankSize;
+    if( nHoleLen == GetLen() )
+        nBlankSize = Width();
+    else
+        nBlankSize = nHoleLen * rInf.GetTextSize(OUString(' ')).Width();
+    Width( Width() - nBlankSize );
+    rInf.X( rInf.X() - nBlankSize );
+    SetLen( GetLen() - nHoleLen );
+    SwLinePortion *pHole = new SwHolePortion( *this );
+    static_cast<SwHolePortion *>( pHole )->SetBlankWidth( nBlankSize );
+    static_cast<SwHolePortion *>( pHole )->SetLen( nHoleLen );
+    Insert( pHole );
 
-        // First set ourselves and the insert, because there could be
-        // a SwLineLayout
-        sal_uInt16 nBlankSize;
-        if( nHoleLen == GetLen() )
-            nBlankSize = Width();
-        else
-            nBlankSize = nHoleLen * rInf.GetTextSize(OUString(' ')).Width();
-        Width( Width() - nBlankSize );
-        rInf.X( rInf.X() - nBlankSize );
-        SetLen( GetLen() - nHoleLen );
-        SwLinePortion *pHole = new SwHolePortion( *this );
-        static_cast<SwHolePortion *>( pHole )->SetBlankWidth( nBlankSize );
-        static_cast<SwHolePortion *>( pHole )->SetLen( nHoleLen );
-        Insert( pHole );
-    }
 }
 
 sal_Int32 SwTextPortion::GetCursorOfst( const sal_uInt16 nOfst ) const
@@ -548,7 +551,7 @@ void SwTextPortion::Paint( const SwTextPaintInfo &rInf ) const
         const bool bSmartTags = nullptr != pSmarttags;
 
         if ( bWrong || bSmartTags || bGrammarCheck )
-            rInf.DrawMarkedText( *this, rInf.GetLen(), false, bWrong, bSmartTags, bGrammarCheck );
+            rInf.DrawMarkedText( *this, rInf.GetLen(), bWrong, bSmartTags, bGrammarCheck );
         else
             rInf.DrawText( *this, rInf.GetLen() );
     }
@@ -566,6 +569,14 @@ sal_Int32 SwTextPortion::GetSpaceCnt( const SwTextSizeInfo &rInf,
 {
     sal_Int32 nCnt = 0;
     sal_Int32 nPos = 0;
+
+    if ( rInf.SnapToGrid() )
+    {
+        SwTextGridItem const*const pGrid(GetGridItem(rInf.GetTextFrame()->FindPageFrame()));
+        if (pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && pGrid->IsSnapToChars())
+            return 0;
+    }
+
     if ( InExpGrp() )
     {
         if( !IsBlankPortion() && !InNumberGrp() && !IsCombinedPortion() )
@@ -573,11 +584,11 @@ sal_Int32 SwTextPortion::GetSpaceCnt( const SwTextSizeInfo &rInf,
             // OnWin() likes to return a blank instead of an empty string from
             // time to time. We cannot use that here at all, however.
             bool bOldOnWin = rInf.OnWin();
-            ((SwTextSizeInfo &)rInf).SetOnWin( false );
+            const_cast<SwTextSizeInfo &>(rInf).SetOnWin( false );
 
             OUString aStr;
             GetExpText( rInf, aStr );
-            ((SwTextSizeInfo &)rInf).SetOnWin( bOldOnWin );
+            const_cast<SwTextSizeInfo &>(rInf).SetOnWin( bOldOnWin );
 
             nCnt = nCnt + lcl_AddSpace( rInf, &aStr, *this );
             nPos = aStr.getLength();
@@ -596,6 +607,13 @@ long SwTextPortion::CalcSpacing( long nSpaceAdd, const SwTextSizeInfo &rInf ) co
 {
     sal_Int32 nCnt = 0;
 
+    if ( rInf.SnapToGrid() )
+    {
+        SwTextGridItem const*const pGrid(GetGridItem(rInf.GetTextFrame()->FindPageFrame()));
+        if (pGrid && GRID_LINES_CHARS == pGrid->GetGridType() && pGrid->IsSnapToChars())
+            return 0;
+    }
+
     if ( InExpGrp() )
     {
         if( !IsBlankPortion() && !InNumberGrp() && !IsCombinedPortion() )
@@ -603,11 +621,11 @@ long SwTextPortion::CalcSpacing( long nSpaceAdd, const SwTextSizeInfo &rInf ) co
             // OnWin() likes to return a blank instead of an empty string from
             // time to time. We cannot use that here at all, however.
             bool bOldOnWin = rInf.OnWin();
-            ((SwTextSizeInfo &)rInf).SetOnWin( false );
+            const_cast<SwTextSizeInfo &>(rInf).SetOnWin( false );
 
             OUString aStr;
             GetExpText( rInf, aStr );
-            ((SwTextSizeInfo &)rInf).SetOnWin( bOldOnWin );
+            const_cast<SwTextSizeInfo &>(rInf).SetOnWin( bOldOnWin );
             if( nSpaceAdd > 0 )
                 nCnt = nCnt + lcl_AddSpace( rInf, &aStr, *this );
             else
@@ -649,8 +667,6 @@ void SwTextPortion::HandlePortion( SwPortionHandler& rPH ) const
 
 SwTextInputFieldPortion::SwTextInputFieldPortion()
     : SwTextPortion()
-    , mbContainsInputFieldStart( false )
-    , mbContainsInputFieldEnd( false )
 {
     SetWhichPor( POR_INPUTFLD );
 }
@@ -665,8 +681,7 @@ void SwTextInputFieldPortion::Paint( const SwTextPaintInfo &rInf ) const
     if ( Width() )
     {
         rInf.DrawViewOpt( *this, POR_INPUTFLD );
-        SwTextSlot aPaintText( &rInf, this, true, true,
-                             ContainsOnlyDummyChars() ? OUString(" ") : OUString() );
+        SwTextSlot aPaintText( &rInf, this, true, true, OUString() );
         SwTextPortion::Paint( rInf );
     }
 }
@@ -700,27 +715,6 @@ SwPosSize SwTextInputFieldPortion::GetTextSize( const SwTextSizeInfo &rInf ) con
     return rInf.GetTextSize();
 }
 
-sal_uInt16 SwTextInputFieldPortion::GetViewWidth( const SwTextSizeInfo &rInf ) const
-{
-    if( !Width()
-        && ContainsOnlyDummyChars()
-        && !rInf.GetOpt().IsPagePreview()
-        && !rInf.GetOpt().IsReadonly()
-        && SwViewOption::IsFieldShadings() )
-    {
-        return rInf.GetTextSize( " " ).Width();
-    }
-
-    return SwTextPortion::GetViewWidth( rInf );
-}
-
-bool SwTextInputFieldPortion::ContainsOnlyDummyChars() const
-{
-    return GetLen() <= 2
-           && mbContainsInputFieldStart
-           && mbContainsInputFieldEnd;
-}
-
 SwHolePortion::SwHolePortion( const SwTextPortion &rPor )
     : nBlankWidth( 0 )
 {
@@ -745,13 +739,13 @@ void SwHolePortion::Paint( const SwTextPaintInfo &rInf ) const
     const SwFont* pOrigFont = rInf.GetFont();
     SwFont* pHoleFont = nullptr;
     SwFontSave* pFontSave = nullptr;
-    if( pOrigFont->GetUnderline() != UNDERLINE_NONE
-    ||  pOrigFont->GetOverline() != UNDERLINE_NONE
+    if( pOrigFont->GetUnderline() != LINESTYLE_NONE
+    ||  pOrigFont->GetOverline() != LINESTYLE_NONE
     ||  pOrigFont->GetStrikeout() != STRIKEOUT_NONE )
     {
         pHoleFont = new SwFont( *pOrigFont );
-        pHoleFont->SetUnderline( UNDERLINE_NONE );
-        pHoleFont->SetOverline( UNDERLINE_NONE );
+        pHoleFont->SetUnderline( LINESTYLE_NONE );
+        pHoleFont->SetOverline( LINESTYLE_NONE );
         pHoleFont->SetStrikeout( STRIKEOUT_NONE );
         pFontSave = new SwFontSave( rInf, pHoleFont );
     }
