@@ -69,7 +69,7 @@ void SwUndoFormatAttrHelper::Modify( const SfxPoolItem* pOld, const SfxPoolItem*
 {
     if( pOld ) {
         if ( pOld->Which() == RES_OBJECTDYING ) {
-            CheckRegistration( pOld, pNew );
+            CheckRegistration( pOld );
         } else if ( pNew ) {
             if( POOLATTR_END >= pOld->Which() ) {
                 if ( GetUndo() ) {
@@ -81,7 +81,7 @@ void SwUndoFormatAttrHelper::Modify( const SfxPoolItem* pOld, const SfxPoolItem*
             } else if ( RES_ATTRSET_CHG == pOld->Which() ) {
                 if ( GetUndo() ) {
                     SfxItemIter aIter(
-                        *(static_cast<const SwAttrSetChg*>(pOld))->GetChgSet() );
+                        *static_cast<const SwAttrSetChg*>(pOld)->GetChgSet() );
                     const SfxPoolItem* pItem = aIter.GetCurItem();
                     while ( pItem ) {
                         m_pUndo->PutAttr( *pItem );
@@ -102,7 +102,7 @@ void SwUndoFormatAttrHelper::Modify( const SfxPoolItem* pOld, const SfxPoolItem*
 SwUndoFormatAttr::SwUndoFormatAttr( const SfxItemSet& rOldSet,
                               SwFormat& rChgFormat,
                               bool bSaveDrawPt )
-    : SwUndo( UNDO_INSFMTATTR )
+    : SwUndo( SwUndoId::INSFMTATTR, rChgFormat.GetDoc() )
     , m_pFormat( &rChgFormat )
     // #i56253#
     , m_pOldSet( new SfxItemSet( rOldSet ) )
@@ -115,7 +115,7 @@ SwUndoFormatAttr::SwUndoFormatAttr( const SfxItemSet& rOldSet,
 
 SwUndoFormatAttr::SwUndoFormatAttr( const SfxPoolItem& rItem, SwFormat& rChgFormat,
                               bool bSaveDrawPt )
-    : SwUndo( UNDO_INSFMTATTR )
+    : SwUndo( SwUndoId::INSFMTATTR, rChgFormat.GetDoc() )
     , m_pFormat( &rChgFormat )
     , m_pOldSet( m_pFormat->GetAttrSet().Clone( false ) )
     , m_nNodeIndex( 0 )
@@ -133,14 +133,15 @@ void SwUndoFormatAttr::Init()
         SaveFlyAnchor( m_bSaveDrawPt );
     } else if ( RES_FRMFMT == m_nFormatWhich ) {
         SwDoc* pDoc = m_pFormat->GetDoc();
-        if ( pDoc->GetTableFrameFormats()->Contains( m_pFormat )) {
+        if (pDoc->GetTableFrameFormats()->ContainsFormat(dynamic_cast<const SwFrameFormat&>(*m_pFormat)))
+        {
             // Table Format: save table position, table formats are volatile!
             SwTable * pTable = SwIterator<SwTable,SwFormat>( *m_pFormat ).First();
             if ( pTable ) {
                 m_nNodeIndex = pTable->GetTabSortBoxes()[ 0 ]->GetSttNd()
                                ->FindTableNode()->GetIndex();
             }
-        } else if ( pDoc->GetSections().Contains( m_pFormat )) {
+        } else if (pDoc->GetSections().ContainsFormat(m_pFormat)) {
             m_nNodeIndex = m_pFormat->GetContent().GetContentIdx()->GetIndex();
         } else if ( dynamic_cast< SwTableBoxFormat* >( m_pFormat ) !=  nullptr ) {
             SwTableBox * pTableBox = SwIterator<SwTableBox,SwFormat>( *m_pFormat ).First();
@@ -200,21 +201,23 @@ bool SwUndoFormatAttr::IsFormatInDoc( SwDoc* pDoc )
 {
     // search for the Format in the Document; if it does not exist any more,
     // the attribute is not restored!
-    bool bFound = false;
+    bool isAlive(false);
     switch ( m_nFormatWhich )
     {
         case RES_TXTFMTCOLL:
         case RES_CONDTXTFMTCOLL:
-            bFound = pDoc->GetTextFormatColls()->Contains( m_pFormat );
+            isAlive = pDoc->GetTextFormatColls()->IsAlive(
+                    static_cast<const SwTextFormatColl *>(m_pFormat));
             break;
 
         case RES_GRFFMTCOLL:
-            bFound = pDoc->GetGrfFormatColls()->Contains(
-                    static_cast<const SwGrfFormatColl*>(m_pFormat) );
+            isAlive = pDoc->GetGrfFormatColls()->IsAlive(
+                    static_cast<const SwGrfFormatColl*>(m_pFormat));
             break;
 
         case RES_CHRFMT:
-            bFound = pDoc->GetCharFormats()->Contains( m_pFormat );
+            isAlive = pDoc->GetCharFormats()->IsAlive(
+                    static_cast<const SwCharFormat *>(m_pFormat));
             break;
 
         case RES_FRMFMT:
@@ -225,14 +228,14 @@ bool SwUndoFormatAttr::IsFormatInDoc( SwDoc* pDoc )
                 {
                     m_pFormat =
                         static_cast<SwTableNode*>(pNd)->GetTable().GetFrameFormat();
-                    bFound = true;
+                    isAlive = true;
                     break;
                 }
                 else if ( pNd->IsSectionNode() )
                 {
                     m_pFormat =
                         static_cast<SwSectionNode*>(pNd)->GetSection().GetFormat();
-                    bFound = true;
+                    isAlive = true;
                     break;
                 }
                 else if ( pNd->IsStartNode() && (SwTableBoxStartNode ==
@@ -246,7 +249,7 @@ bool SwUndoFormatAttr::IsFormatInDoc( SwDoc* pDoc )
                         if ( pBox )
                         {
                             m_pFormat = pBox->GetFrameFormat();
-                            bFound = true;
+                            isAlive = true;
                             break;
                         }
                     }
@@ -255,15 +258,15 @@ bool SwUndoFormatAttr::IsFormatInDoc( SwDoc* pDoc )
             SAL_FALLTHROUGH;
         case RES_DRAWFRMFMT:
         case RES_FLYFRMFMT:
-            bFound = pDoc->GetSpzFrameFormats()->Contains( m_pFormat );
-            if ( !bFound )
+            if (pDoc->GetSpzFrameFormats()->IsAlive(static_cast<const SwFrameFormat *>(m_pFormat))
+                || pDoc->GetFrameFormats()->IsAlive(static_cast<const SwFrameFormat *>(m_pFormat)))
             {
-                bFound = pDoc->GetFrameFormats()->Contains( m_pFormat );
+                isAlive = true;
             }
             break;
     }
 
-    if ( !bFound )
+    if (!isAlive)
     {
         // Format does not exist; reset
         m_pFormat = nullptr;
@@ -375,12 +378,12 @@ void SwUndoFormatAttr::SaveFlyAnchor( bool bSvDrwPt )
 
     sal_Int32 nContent = 0;
     switch( rAnchor.GetAnchorId() ) {
-    case FLY_AS_CHAR:
-    case FLY_AT_CHAR:
+    case RndStdIds::FLY_AS_CHAR:
+    case RndStdIds::FLY_AT_CHAR:
         nContent = rAnchor.GetContentAnchor()->nContent.GetIndex();
         SAL_FALLTHROUGH;
-    case FLY_AT_PARA:
-    case FLY_AT_FLY:
+    case RndStdIds::FLY_AT_PARA:
+    case RndStdIds::FLY_AT_FLY:
         m_nNodeIndex = rAnchor.GetContentAnchor()->nNode.GetIndex();
         break;
     default:
@@ -403,10 +406,10 @@ bool SwUndoFormatAttr::RestoreFlyAnchor(::sw::UndoRedoContext & rContext)
         static_cast<const SwFormatAnchor&>( m_pOldSet->Get( RES_ANCHOR, false ) );
 
     SwFormatAnchor aNewAnchor( rAnchor.GetAnchorId() );
-    if (FLY_AT_PAGE != rAnchor.GetAnchorId()) {
+    if (RndStdIds::FLY_AT_PAGE != rAnchor.GetAnchorId()) {
         SwNode* pNd = pDoc->GetNodes()[ m_nNodeIndex  ];
 
-        if (  (FLY_AT_FLY == rAnchor.GetAnchorId())
+        if (  (RndStdIds::FLY_AT_FLY == rAnchor.GetAnchorId())
               ? ( !pNd->IsStartNode() || (SwFlyStartNode !=
                                           static_cast<SwStartNode*>(pNd)->GetStartNodeType()) )
               : !pNd->IsTextNode() ) {
@@ -416,8 +419,8 @@ bool SwUndoFormatAttr::RestoreFlyAnchor(::sw::UndoRedoContext & rContext)
         }
 
         SwPosition aPos( *pNd );
-        if ((FLY_AS_CHAR == rAnchor.GetAnchorId()) ||
-            (FLY_AT_CHAR == rAnchor.GetAnchorId())) {
+        if ((RndStdIds::FLY_AS_CHAR == rAnchor.GetAnchorId()) ||
+            (RndStdIds::FLY_AT_CHAR == rAnchor.GetAnchorId())) {
             aPos.nContent.Assign( static_cast<SwTextNode*>(pNd), rAnchor.GetPageNum() );
             if ( aPos.nContent.GetIndex() > pNd->GetTextNode()->GetText().getLength()) {
                 // #i35443# - invalid position.
@@ -449,7 +452,7 @@ bool SwUndoFormatAttr::RestoreFlyAnchor(::sw::UndoRedoContext & rContext)
     const SwFormatAnchor &rOldAnch = pFrameFormat->GetAnchor();
     // #i54336#
     // Consider case, that as-character anchored object has moved its anchor position.
-    if (FLY_AS_CHAR == rOldAnch.GetAnchorId()) {
+    if (RndStdIds::FLY_AS_CHAR == rOldAnch.GetAnchorId()) {
         // With InContents it's tricky: the text attribute needs to be deleted.
         // Unfortunately, this not only destroys the Frames but also the format.
         // To prevent that, first detach the connection between attribute and
@@ -460,9 +463,10 @@ bool SwUndoFormatAttr::RestoreFlyAnchor(::sw::UndoRedoContext & rContext)
         const sal_Int32 nIdx = pPos->nContent.GetIndex();
         SwTextAttr * const pHint =
             pTextNode->GetTextAttrForCharAt( nIdx, RES_TXTATR_FLYCNT );
-        OSL_ENSURE( pHint && pHint->Which() == RES_TXTATR_FLYCNT,
+        assert(pHint && "Missing Hint.");
+        OSL_ENSURE( pHint->Which() == RES_TXTATR_FLYCNT,
                     "Missing FlyInCnt-Hint." );
-        OSL_ENSURE( pHint && pHint->GetFlyCnt().GetFrameFormat() == pFrameFormat,
+        OSL_ENSURE( pHint->GetFlyCnt().GetFrameFormat() == pFrameFormat,
                     "Wrong TextFlyCnt-Hint." );
         const_cast<SwFormatFlyCnt&>(pHint->GetFlyCnt()).SetFlyFormat();
 
@@ -483,27 +487,17 @@ bool SwUndoFormatAttr::RestoreFlyAnchor(::sw::UndoRedoContext & rContext)
         }
     }
 
-    SwDrawContact *pCont = nullptr;
-    if ( RES_DRAWFRMFMT == pFrameFormat->Which() ) {
-        pCont = static_cast<SwDrawContact*>(pFrameFormat->FindContactObj());
+    if ( RES_DRAWFRMFMT == pFrameFormat->Which() )
+    {
         // The Draw model also prepared an Undo object for its right positioning
         // which unfortunately is relative. Therefore block here a position
         // change of the Contact object by setting the anchor.
-        SdrObject* pObj = pCont->GetMaster();
-
-        if( pCont->GetAnchorFrame() && !pObj->IsInserted() ) {
-            OSL_ENSURE( pDoc->getIDocumentDrawModelAccess().GetDrawModel(),
-                        "RestoreFlyAnchor without DrawModel" );
-            pDoc->getIDocumentDrawModelAccess().GetDrawModel()->GetPage( 0 )->InsertObject( pObj );
-        }
-        pObj->SetRelativePos( aDrawSavePt );
-
+        pFrameFormat->CallSwClientNotify(sw::RestoreFlyAnchorHint(aDrawSavePt));
         // cache the old value again
-        m_pOldSet->Put(
-            SwFormatFrameSize( ATT_VAR_SIZE, aDrawOldPt.X(), aDrawOldPt.Y() ) );
+        m_pOldSet->Put(SwFormatFrameSize(ATT_VAR_SIZE, aDrawOldPt.X(), aDrawOldPt.Y()));
     }
 
-    if (FLY_AS_CHAR == aNewAnchor.GetAnchorId()) {
+    if (RndStdIds::FLY_AS_CHAR == aNewAnchor.GetAnchorId()) {
         const SwPosition* pPos = aNewAnchor.GetContentAnchor();
         SwTextNode* pTextNd = pPos->nNode.GetNode().GetTextNode();
         OSL_ENSURE( pTextNd, "no Text Node at position." );
@@ -515,8 +509,7 @@ bool SwUndoFormatAttr::RestoreFlyAnchor(::sw::UndoRedoContext & rContext)
         pFrameFormat->MakeFrames();
     else
     {
-        SdrObject* pSdrObj = pFrameFormat->FindSdrObject();
-        pCont->GetAnchoredObj(pSdrObj)->MakeObjPos();
+        pFrameFormat->CallSwClientNotify(sw::DrawFrameFormatHint(sw::DrawFrameFormatHintId::POST_RESTORE_FLY_ANCHOR));
     }
 
     rContext.SetSelections(pFrameFormat, nullptr);
@@ -527,7 +520,7 @@ bool SwUndoFormatAttr::RestoreFlyAnchor(::sw::UndoRedoContext & rContext)
 
 SwUndoFormatResetAttr::SwUndoFormatResetAttr( SwFormat& rChangedFormat,
                                         const sal_uInt16 nWhichId )
-    : SwUndo( UNDO_RESETATTR )
+    : SwUndo( SwUndoId::RESETATTR, rChangedFormat.GetDoc() )
     , m_pChangedFormat( &rChangedFormat )
     , m_nWhichId( nWhichId )
 {
@@ -556,14 +549,14 @@ void SwUndoFormatResetAttr::RedoImpl(::sw::UndoRedoContext &)
 }
 
 SwUndoResetAttr::SwUndoResetAttr( const SwPaM& rRange, sal_uInt16 nFormatId )
-    : SwUndo( UNDO_RESETATTR ), SwUndRng( rRange )
+    : SwUndo( SwUndoId::RESETATTR, rRange.GetDoc() ), SwUndRng( rRange )
     , m_pHistory( new SwHistory )
     , m_nFormatId( nFormatId )
 {
 }
 
 SwUndoResetAttr::SwUndoResetAttr( const SwPosition& rPos, sal_uInt16 nFormatId )
-    : SwUndo( UNDO_RESETATTR )
+    : SwUndo( SwUndoId::RESETATTR, rPos.GetDoc() )
     , m_pHistory( new SwHistory )
     , m_nFormatId( nFormatId )
 {
@@ -671,8 +664,8 @@ void SwUndoResetAttr::SetAttrs( const std::set<sal_uInt16> &rAttrs )
 
 SwUndoAttr::SwUndoAttr( const SwPaM& rRange, const SfxPoolItem& rAttr,
                         const SetAttrMode nFlags )
-    : SwUndo( UNDO_INSATTR ), SwUndRng( rRange )
-    , m_AttrSet( rRange.GetDoc()->GetAttrPool(), rAttr.Which(), rAttr.Which() )
+    : SwUndo( SwUndoId::INSATTR, rRange.GetDoc() ), SwUndRng( rRange )
+    , m_AttrSet( rRange.GetDoc()->GetAttrPool(), {{rAttr.Which(), rAttr.Which()}} )
     , m_pHistory( new SwHistory )
     , m_nNodeIndex( ULONG_MAX )
     , m_nInsertFlags( nFlags )
@@ -682,7 +675,7 @@ SwUndoAttr::SwUndoAttr( const SwPaM& rRange, const SfxPoolItem& rAttr,
 
 SwUndoAttr::SwUndoAttr( const SwPaM& rRange, const SfxItemSet& rSet,
                         const SetAttrMode nFlags )
-    : SwUndo( UNDO_INSATTR ), SwUndRng( rRange )
+    : SwUndo( SwUndoId::INSATTR, rRange.GetDoc() ), SwUndRng( rRange )
     , m_AttrSet( rSet )
     , m_pHistory( new SwHistory )
     , m_nNodeIndex( ULONG_MAX )
@@ -709,7 +702,7 @@ void SwUndoAttr::SaveRedlineData( const SwPaM& rPam, bool bIsContent )
         m_pRedlineSaveData.reset(nullptr);
     }
 
-    SetRedlineMode( pDoc->getIDocumentRedlineAccess().GetRedlineMode() );
+    SetRedlineFlags( pDoc->getIDocumentRedlineAccess().GetRedlineFlags() );
     if ( bIsContent ) {
         m_nNodeIndex = rPam.GetPoint()->nNode.GetIndex();
     }
@@ -721,7 +714,7 @@ void SwUndoAttr::UndoImpl(::sw::UndoRedoContext & rContext)
 
     RemoveIdx( *pDoc );
 
-    if( IDocumentRedlineAccess::IsRedlineOn( GetRedlineMode() ) ) {
+    if( IDocumentRedlineAccess::IsRedlineOn( GetRedlineFlags() ) ) {
         SwPaM aPam(pDoc->GetNodes().GetEndOfContent());
         if ( ULONG_MAX != m_nNodeIndex ) {
             aPam.DeleteMark();
@@ -772,10 +765,9 @@ void SwUndoAttr::RedoImpl(::sw::UndoRedoContext & rContext)
     SwPaM & rPam = AddUndoRedoPaM(rContext);
 
     if ( m_pRedlineData.get() &&
-         IDocumentRedlineAccess::IsRedlineOn( GetRedlineMode() ) ) {
-        RedlineMode_t eOld = rDoc.getIDocumentRedlineAccess().GetRedlineMode();
-        rDoc.getIDocumentRedlineAccess().SetRedlineMode_intern(static_cast<RedlineMode_t>(
-                    eOld & ~nsRedlineMode_t::REDLINE_IGNORE));
+         IDocumentRedlineAccess::IsRedlineOn( GetRedlineFlags() ) ) {
+        RedlineFlags eOld = rDoc.getIDocumentRedlineAccess().GetRedlineFlags();
+        rDoc.getIDocumentRedlineAccess().SetRedlineFlags_intern( eOld & ~RedlineFlags::Ignore );
         rDoc.getIDocumentContentOperations().InsertItemSet( rPam, m_AttrSet, m_nInsertFlags );
 
         if ( ULONG_MAX != m_nNodeIndex ) {
@@ -789,7 +781,7 @@ void SwUndoAttr::RedoImpl(::sw::UndoRedoContext & rContext)
             rDoc.getIDocumentRedlineAccess().AppendRedline( new SwRangeRedline( *m_pRedlineData, rPam ), true);
         }
 
-        rDoc.getIDocumentRedlineAccess().SetRedlineMode_intern( eOld );
+        rDoc.getIDocumentRedlineAccess().SetRedlineFlags_intern( eOld );
     } else {
         rDoc.getIDocumentContentOperations().InsertItemSet( rPam, m_AttrSet, m_nInsertFlags );
     }
@@ -836,8 +828,8 @@ void SwUndoAttr::RemoveIdx( SwDoc& rDoc )
     }
 }
 
-SwUndoDefaultAttr::SwUndoDefaultAttr( const SfxItemSet& rSet )
-    : SwUndo( UNDO_SETDEFTATTR )
+SwUndoDefaultAttr::SwUndoDefaultAttr( const SfxItemSet& rSet, const SwDoc* pDoc )
+    : SwUndo( SwUndoId::SETDEFTATTR, pDoc )
 {
     const SfxPoolItem* pItem;
     if( SfxItemState::SET == rSet.GetItemState( RES_PARATR_TABSTOP, false, &pItem ) ) {
@@ -883,7 +875,7 @@ void SwUndoDefaultAttr::RedoImpl(::sw::UndoRedoContext & rContext)
 
 SwUndoMoveLeftMargin::SwUndoMoveLeftMargin(
     const SwPaM& rPam, bool bFlag, bool bMod )
-    : SwUndo( bFlag ? UNDO_INC_LEFTMARGIN : UNDO_DEC_LEFTMARGIN )
+    : SwUndo( bFlag ? SwUndoId::INC_LEFTMARGIN : SwUndoId::DEC_LEFTMARGIN, rPam.GetDoc() )
     , SwUndRng( rPam )
     , m_pHistory( new SwHistory )
     , m_bModulus( bMod )
@@ -911,20 +903,20 @@ void SwUndoMoveLeftMargin::RedoImpl(::sw::UndoRedoContext & rContext)
     SwPaM & rPam = AddUndoRedoPaM(rContext);
 
     rDoc.MoveLeftMargin( rPam,
-                         GetId() == UNDO_INC_LEFTMARGIN, m_bModulus );
+                         GetId() == SwUndoId::INC_LEFTMARGIN, m_bModulus );
 }
 
 void SwUndoMoveLeftMargin::RepeatImpl(::sw::RepeatContext & rContext)
 {
     SwDoc & rDoc = rContext.GetDoc();
-    rDoc.MoveLeftMargin(rContext.GetRepeatPaM(), GetId() == UNDO_INC_LEFTMARGIN,
+    rDoc.MoveLeftMargin(rContext.GetRepeatPaM(), GetId() == SwUndoId::INC_LEFTMARGIN,
                         m_bModulus );
 }
 
 SwUndoChangeFootNote::SwUndoChangeFootNote(
     const SwPaM& rRange, const OUString& rText,
     sal_uInt16 nNum, bool bIsEndNote )
-    : SwUndo( UNDO_CHGFTN ), SwUndRng( rRange )
+    : SwUndo( SwUndoId::CHGFTN, rRange.GetDoc() ), SwUndRng( rRange )
     , m_pHistory( new SwHistory() )
     , m_Text( rText )
     , m_nNumber( nNum )
@@ -962,8 +954,8 @@ void SwUndoChangeFootNote::RepeatImpl(::sw::RepeatContext & rContext)
     rDoc.SetCurFootnote( rContext.GetRepeatPaM(), m_Text, m_nNumber, m_bEndNote );
 }
 
-SwUndoFootNoteInfo::SwUndoFootNoteInfo( const SwFootnoteInfo &rInfo )
-    : SwUndo( UNDO_FTNINFO )
+SwUndoFootNoteInfo::SwUndoFootNoteInfo( const SwFootnoteInfo &rInfo, const SwDoc* pDoc )
+    : SwUndo( SwUndoId::FTNINFO, pDoc )
     , m_pFootNoteInfo( new SwFootnoteInfo( rInfo ) )
 {
 }
@@ -988,8 +980,8 @@ void SwUndoFootNoteInfo::RedoImpl(::sw::UndoRedoContext & rContext)
     m_pFootNoteInfo.reset( pInf );
 }
 
-SwUndoEndNoteInfo::SwUndoEndNoteInfo( const SwEndNoteInfo &rInfo )
-    : SwUndo( UNDO_FTNINFO )
+SwUndoEndNoteInfo::SwUndoEndNoteInfo( const SwEndNoteInfo &rInfo, const SwDoc* pDoc )
+    : SwUndo( SwUndoId::FTNINFO, pDoc )
     , m_pEndNoteInfo( new SwEndNoteInfo( rInfo ) )
 {
 }
@@ -1015,7 +1007,7 @@ void SwUndoEndNoteInfo::RedoImpl(::sw::UndoRedoContext & rContext)
 }
 
 SwUndoDontExpandFormat::SwUndoDontExpandFormat( const SwPosition& rPos )
-    : SwUndo( UNDO_DONTEXPAND )
+    : SwUndo( SwUndoId::DONTEXPAND, rPos.GetDoc() )
     , m_nNodeIndex( rPos.nNode.GetIndex() )
     , m_nContentIndex( rPos.nContent.GetIndex() )
 {
