@@ -21,10 +21,12 @@
 
 #include <map>
 #include <algorithm>
+#include <memory>
 
 #include <com/sun/star/beans/PropertyState.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <com/sun/star/embed/XStorage.hpp>
+#include <com/sun/star/io/IOException.hpp>
 #include <com/sun/star/text/XTextSection.hpp>
 
 #include <svx/svxids.hrc>
@@ -84,6 +86,7 @@
 #include <SwNodeNum.hxx>
 #include <fmtmeta.hxx>
 #include <txtfld.hxx>
+#include <unoparagraph.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -106,7 +109,7 @@ static SwPaM* lcl_createPamCopy(const SwPaM& rPam)
 void GetSelectableFromAny(uno::Reference<uno::XInterface> const& xIfc,
         SwDoc & rTargetDoc,
         SwPaM *& o_rpPaM, std::pair<OUString, FlyCntType> & o_rFrame,
-        OUString & o_rTableName, SwUnoTableCrsr const*& o_rpTableCursor,
+        OUString & o_rTableName, SwUnoTableCursor const*& o_rpTableCursor,
         ::sw::mark::IMark const*& o_rpMark,
         std::vector<SdrObject *> & o_rSdrObjects)
 {
@@ -173,14 +176,14 @@ void GetSelectableFromAny(uno::Reference<uno::XInterface> const& xIfc,
         return;
     }
 
-    SwXTextRanges *const pRanges(
+    SwXTextRanges* const pRanges(
         ::sw::UnoTunnelGetImplementation<SwXTextRanges>(xTunnel));
     if (pRanges)
     {
-        SwUnoCrsr const* pUnoCrsr = pRanges->GetCursor();
-        if (pUnoCrsr && pUnoCrsr->GetDoc() == &rTargetDoc)
+        SwUnoCursor const* pUnoCursor = pRanges->GetCursor();
+        if (pUnoCursor && pUnoCursor->GetDoc() == &rTargetDoc)
         {
-            o_rpPaM = lcl_createPamCopy(*pUnoCrsr);
+            o_rpPaM = lcl_createPamCopy(*pUnoCursor);
         }
         return;
     }
@@ -226,7 +229,7 @@ void GetSelectableFromAny(uno::Reference<uno::XInterface> const& xIfc,
             {
                 SwPosition const aPos(*pBox->GetSttNd());
                 SwPaM aPam(aPos);
-                aPam.Move(fnMoveForward, fnGoNode);
+                aPam.Move(fnMoveForward, GoInNode);
                 o_rpPaM = lcl_createPamCopy(aPam);
             }
         }
@@ -248,12 +251,12 @@ void GetSelectableFromAny(uno::Reference<uno::XInterface> const& xIfc,
         ::sw::UnoTunnelGetImplementation<SwXCellRange>(xTunnel));
     if (pCellRange)
     {
-        SwUnoCrsr const*const pUnoCrsr(pCellRange->GetTableCrsr());
-        if (pUnoCrsr && pUnoCrsr->GetDoc() == &rTargetDoc)
+        SwUnoCursor const*const pUnoCursor(pCellRange->GetTableCursor());
+        if (pUnoCursor && pUnoCursor->GetDoc() == &rTargetDoc)
         {
             // probably can't copy it to o_rpPaM for this since it's
             // a SwTableCursor
-            o_rpTableCursor = dynamic_cast<SwUnoTableCrsr const*>(pUnoCrsr);
+            o_rpTableCursor = dynamic_cast<SwUnoTableCursor const*>(pUnoCursor);
         }
         return;
     }
@@ -268,19 +271,19 @@ void GetSelectableFromAny(uno::Reference<uno::XInterface> const& xIfc,
 }
 
 uno::Reference<text::XTextContent>
-GetNestedTextContent(SwTextNode & rTextNode, sal_Int32 const nIndex,
+GetNestedTextContent(SwTextNode const & rTextNode, sal_Int32 const nIndex,
         bool const bParent)
 {
     // these should be unambiguous because of the dummy character
-    SwTextNode::GetTextAttrMode const eMode( (bParent)
+    SwTextNode::GetTextAttrMode const eMode( bParent
         ? SwTextNode::PARENT : SwTextNode::EXPAND );
     SwTextAttr *const pMetaTextAttr =
         rTextNode.GetTextAttrAt(nIndex, RES_TXTATR_META, eMode);
     SwTextAttr *const pMetaFieldTextAttr =
         rTextNode.GetTextAttrAt(nIndex, RES_TXTATR_METAFIELD, eMode);
     // which is innermost?
-    SwTextAttr *const pTextAttr = (pMetaTextAttr)
-        ? ((pMetaFieldTextAttr)
+    SwTextAttr *const pTextAttr = pMetaTextAttr
+        ? (pMetaFieldTextAttr
             ? ((pMetaFieldTextAttr->GetStart() >
                     pMetaTextAttr->GetStart())
                 ? pMetaFieldTextAttr : pMetaTextAttr)
@@ -291,14 +294,14 @@ GetNestedTextContent(SwTextNode & rTextNode, sal_Int32 const nIndex,
     {
         ::sw::Meta *const pMeta(
             static_cast<SwFormatMeta &>(pTextAttr->GetAttr()).GetMeta());
-        OSL_ASSERT(pMeta);
+        assert(pMeta);
         xRet.set(pMeta->MakeUnoObject(), uno::UNO_QUERY);
     }
     return xRet;
 }
 
 // Read the special properties of the cursor
-bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
+bool getCursorPropertyValue(const SfxItemPropertySimpleEntry& rEntry
                                         , SwPaM& rPam
                                         , Any *pAny
                                         , PropertyState& eState
@@ -363,7 +366,7 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
         case FN_UNO_PARA_CONDITIONAL_STYLE_NAME:
         case FN_UNO_PARA_STYLE :
         {
-            SwFormatColl* pFormat = 0;
+            SwFormatColl* pFormat = nullptr;
             if(pNode)
                 pFormat = FN_UNO_PARA_CONDITIONAL_STYLE_NAME == rEntry.nWID
                             ? pNode->GetFormatColl() : &pNode->GetAnyFormatColl();
@@ -377,7 +380,7 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
                 if( pAny )
                 {
                     OUString sVal;
-                    SwStyleNameMapper::FillProgName(pFormat->GetName(), sVal, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL, true );
+                    SwStyleNameMapper::FillProgName(pFormat->GetName(), sVal, SwGetPoolIdFromName::TxtColl );
                     *pAny <<= sVal;
                 }
             }
@@ -465,7 +468,7 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
             break;
         case FN_UNO_DOCUMENT_INDEX_MARK:
         {
-            ::std::vector<SwTextAttr *> marks;
+            std::vector<SwTextAttr *> marks;
             if (rPam.GetNode().IsTextNode())
             {
                 marks = rPam.GetNode().GetTextNode()->GetTextAttrsAt(
@@ -511,10 +514,10 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
             const SwPosition *pPos = rPam.Start();
             const SwTextNode *pTextNd =
                 rPam.GetDoc()->GetNodes()[pPos->nNode.GetIndex()]->GetTextNode();
-            const SwTextAttr* pTextAttr = (pTextNd)
+            const SwTextAttr* pTextAttr = pTextNd
                 ? pTextNd->GetFieldTextAttrAt( pPos->nContent.GetIndex(), true )
-                : 0;
-            if ( pTextAttr != NULL )
+                : nullptr;
+            if ( pTextAttr != nullptr )
             {
                 if( pAny )
                 {
@@ -538,18 +541,18 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
                 if( pAny )
                 {
                     const SwTableNode* pTableNode = pSttNode->FindTableNode();
-                    SwFrameFormat* pTableFormat = (SwFrameFormat*)pTableNode->GetTable().GetFrameFormat();
+                    SwFrameFormat* pTableFormat = static_cast<SwFrameFormat*>(pTableNode->GetTable().GetFrameFormat());
                     //SwTable& rTable = static_cast<SwTableNode*>(pSttNode)->GetTable();
                     if(FN_UNO_TEXT_TABLE == rEntry.nWID)
                     {
                         uno::Reference< XTextTable >  xTable = SwXTextTables::GetObject(*pTableFormat);
-                        pAny->setValue(&xTable, cppu::UnoType<XTextTable>::get());
+                        *pAny <<= xTable;
                     }
                     else
                     {
                         SwTableBox* pBox = pSttNode->GetTableBox();
                         uno::Reference< XCell >  xCell = SwXCell::CreateXCell(pTableFormat, pBox);
-                        pAny->setValue(&xCell, cppu::UnoType<XCell>::get());
+                        *pAny <<= xCell;
                     }
                 }
             }
@@ -563,7 +566,7 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
             SwStartNodeType eType = pSttNode->GetStartNodeType();
 
             SwFrameFormat* pFormat;
-            if(eType == SwFlyStartNode && 0 != (pFormat = pSttNode->GetFlyFormat()))
+            if(eType == SwFlyStartNode && nullptr != (pFormat = pSttNode->GetFlyFormat()))
             {
                 if( pAny )
                 {
@@ -584,19 +587,31 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
                 if( pAny )
                 {
                     uno::Reference< XTextSection >  xSect = SwXTextSections::GetObject( *pSect->GetFormat() );
-                    pAny->setValue(&xSect, cppu::UnoType<XTextSection>::get());
+                    *pAny <<= xSect;
                 }
             }
             else
                 eNewState = PropertyState_DEFAULT_VALUE;
         }
         break;
+        case FN_UNO_TEXT_PARAGRAPH:
+        {
+            SwTextNode* pTextNode = rPam.GetPoint()->nNode.GetNode().GetTextNode();
+            if (pTextNode)
+            {
+                uno::Reference<text::XTextContent> xParagraph = SwXParagraph::CreateXParagraph(*pTextNode->GetDoc(), pTextNode);
+                *pAny <<= xParagraph;
+            }
+            else
+                eNewState = PropertyState_DEFAULT_VALUE;
+        }
+        break;
         case FN_UNO_ENDNOTE:
         case FN_UNO_FOOTNOTE:
         {
             SwTextAttr *const pTextAttr = rPam.GetNode().IsTextNode() ?
                 rPam.GetNode().GetTextNode()->GetTextAttrForCharAt(
-                    rPam.GetPoint()->nContent.GetIndex(), RES_TXTATR_FTN) : 0;
+                    rPam.GetPoint()->nContent.GetIndex(), RES_TXTATR_FTN) : nullptr;
             if(pTextAttr)
             {
                 const SwFormatFootnote& rFootnote = pTextAttr->GetFootnote();
@@ -619,12 +634,11 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
         break;
         case FN_UNO_REFERENCE_MARK:
         {
-            ::std::vector<SwTextAttr *> marks;
+            std::vector<SwTextAttr *> marks;
             if (rPam.GetNode().IsTextNode())
             {
-                marks = (
-                rPam.GetNode().GetTextNode()->GetTextAttrsAt(
-                    rPam.GetPoint()->nContent.GetIndex(), RES_TXTATR_REFMARK));
+                marks = rPam.GetNode().GetTextNode()->GetTextAttrsAt(
+                            rPam.GetPoint()->nContent.GetIndex(), RES_TXTATR_REFMARK);
             }
             if (marks.size())
             {
@@ -634,7 +648,7 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
                     uno::Reference<XTextContent> const xRef =
                         SwXReferenceMark::CreateXReferenceMark(*rPam.GetDoc(),
                                 const_cast<SwFormatRefMark*>(&rRef));
-                    pAny->setValue(&xRef, cppu::UnoType<XTextContent>::get());
+                    *pAny <<= xRef;
                 }
             }
             else
@@ -646,7 +660,7 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
             uno::Reference<XTextContent> const xRet(rPam.GetNode().IsTextNode()
                 ? GetNestedTextContent(*rPam.GetNode().GetTextNode(),
                     rPam.GetPoint()->nContent.GetIndex(), false)
-                : 0);
+                : nullptr);
             if (xRet.is())
             {
                 if (pAny)
@@ -664,7 +678,7 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
         {
 
             SwTextNode *const pTextNode = rPam.GetNode().GetTextNode();
-            if (&rPam.GetNode(true) == &rPam.GetNode(false)
+            if (&rPam.GetNode() == &rPam.GetNode(false)
                 && pTextNode && pTextNode->GetpSwpHints())
             {
                 sal_Int32 nPaMStart = rPam.GetPoint()->nContent.GetIndex();
@@ -675,9 +689,9 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
                 }
                 Sequence< OUString> aCharStyles;
                 SwpHints* pHints = pTextNode->GetpSwpHints();
-                for( size_t nAttr = 0; nAttr < pHints->GetStartCount(); ++nAttr )
+                for( size_t nAttr = 0; nAttr < pHints->Count(); ++nAttr )
                 {
-                    SwTextAttr* pAttr = pHints->GetStart( nAttr );
+                    SwTextAttr* pAttr = pHints->Get( nAttr );
                     if(pAttr->Which() != RES_TXTATR_CHARFMT)
                         continue;
                     const sal_Int32 nAttrStart = pAttr->GetStart();
@@ -691,7 +705,6 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
                                     nAttrEnd < nPaMEnd)
                         {
                             aCharStyles.realloc(0);
-                            eNewState = PropertyState_AMBIGUOUS_VALUE;
                             break;
                         }
                         else
@@ -705,7 +718,7 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
                             OSL_ENSURE(pAttr->GetCharFormat().GetCharFormat(), "no character format set");
                             aCharStyles.getArray()[aCharStyles.getLength() - 1] =
                                         SwStyleNameMapper::GetProgName(
-                                            pAttr->GetCharFormat().GetCharFormat()->GetName(), nsSwGetPoolIdFromName::GET_POOLID_CHRFMT);
+                                            pAttr->GetCharFormat().GetCharFormat()->GetName(), SwGetPoolIdFromName::ChrFmt);
                         }
                     }
 
@@ -729,7 +742,7 @@ bool getCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry
     return bDone;
 };
 
-sal_Int16 IsNodeNumStart(SwPaM& rPam, PropertyState& eState)
+sal_Int16 IsNodeNumStart(SwPaM const & rPam, PropertyState& eState)
 {
     const SwTextNode* pTextNd = rPam.GetNode().GetTextNode();
     // correction: check, if restart value is set at the text node and use
@@ -750,7 +763,7 @@ void setNumberingProperty(const Any& rValue, SwPaM& rPam)
     uno::Reference<XIndexReplace> xIndexReplace;
     if(rValue >>= xIndexReplace)
     {
-        SwXNumberingRules* pSwNum = 0;
+        SwXNumberingRules* pSwNum = nullptr;
 
         uno::Reference<XUnoTunnel> xNumTunnel(xIndexReplace, UNO_QUERY);
         if(xNumTunnel.is())
@@ -779,14 +792,14 @@ void setNumberingProperty(const Any& rValue, SwPaM& rPam)
                             // FIXME
                             // Is something missing/wrong here?
                             // if condition is always false due to outer check!
-                            aFormat.SetCharFormat(0);
+                            aFormat.SetCharFormat(nullptr);
                         }
                         else
                         {
 
                             // get CharStyle and set the rule
                             const size_t nChCount = pDoc->GetCharFormats()->size();
-                            SwCharFormat* pCharFormat = 0;
+                            SwCharFormat* pCharFormat = nullptr;
                             for(size_t nCharFormat = 0; nCharFormat < nChCount; ++nCharFormat)
                             {
                                 SwCharFormat& rChFormat = *((*(pDoc->GetCharFormats()))[nCharFormat]);
@@ -801,10 +814,10 @@ void setNumberingProperty(const Any& rValue, SwPaM& rPam)
                             {
                                 SfxStyleSheetBasePool* pPool = pDoc->GetDocShell()->GetStyleSheetPool();
                                 SfxStyleSheetBase* pBase;
-                                pBase = pPool->Find(pNewCharStyles[i], SFX_STYLE_FAMILY_CHAR);
+                                pBase = pPool->Find(pNewCharStyles[i], SfxStyleFamily::Char);
                             // shall it really be created?
                                 if(!pBase)
-                                    pBase = &pPool->Make(pNewCharStyles[i], SFX_STYLE_FAMILY_PAGE);
+                                    pBase = &pPool->Make(pNewCharStyles[i], SfxStyleFamily::Page);
                                 pCharFormat = static_cast<SwDocStyleSheet*>(pBase)->GetCharFormat();
                             }
                             if(pCharFormat)
@@ -815,7 +828,7 @@ void setNumberingProperty(const Any& rValue, SwPaM& rPam)
                     if(
                        !pBulletFontNames[i].isEmpty() &&
                        !SwXNumberingRules::isInvalidStyle(pBulletFontNames[i]) &&
-                       (!aFormat.GetBulletFont() || aFormat.GetBulletFont()->GetName() != pBulletFontNames[i])
+                       (!aFormat.GetBulletFont() || aFormat.GetBulletFont()->GetFamilyName() != pBulletFontNames[i])
                       )
                     {
                         const SvxFontListItem* pFontListItem =
@@ -823,9 +836,9 @@ void setNumberingProperty(const Any& rValue, SwPaM& rPam)
                                                     ->GetItem( SID_ATTR_CHAR_FONTLIST ));
                         const FontList*  pList = pFontListItem->GetFontList();
 
-                        vcl::FontInfo aInfo = pList->Get(
+                        FontMetric aFontMetric = pList->Get(
                             pBulletFontNames[i],WEIGHT_NORMAL, ITALIC_NONE);
-                        vcl::Font aFont(aInfo);
+                        vcl::Font aFont(aFontMetric);
                         aFormat.SetBulletFont(&aFont);
                     }
                     aRule.Set( i, aFormat );
@@ -834,15 +847,15 @@ void setNumberingProperty(const Any& rValue, SwPaM& rPam)
 
                 if( rPam.GetNext() != &rPam )           // Multiple selection?
                 {
-                    pDoc->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
+                    pDoc->GetIDocumentUndoRedo().StartUndo( SwUndoId::START, nullptr );
                     SwPamRanges aRangeArr( rPam );
                     SwPaM aPam( *rPam.GetPoint() );
-                    for ( SwPamRanges::size_type n = 0; n < aRangeArr.Count(); ++n )
+                    for ( size_t n = 0; n < aRangeArr.Count(); ++n )
                     {
                         // no start of a new list
                         pDoc->SetNumRule( aRangeArr.SetPam( n, aPam ), aRule, false );
                     }
-                    pDoc->GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
+                    pDoc->GetIDocumentUndoRedo().EndUndo( SwUndoId::END, nullptr );
                 }
                 else
                 {
@@ -885,31 +898,31 @@ void  getNumberingProperty(SwPaM& rPam, PropertyState& eState, Any * pAny )
     {
         uno::Reference< XIndexReplace >  xNum = new SwXNumberingRules(*pNumRule);
         if ( pAny )
-            pAny->setValue(&xNum, cppu::UnoType<XIndexReplace>::get());
+            *pAny <<= xNum;
         eState = PropertyState_DIRECT_VALUE;
     }
     else
         eState = PropertyState_DEFAULT_VALUE;
 }
 
-void GetCurPageStyle(SwPaM& rPaM, OUString &rString)
+void GetCurPageStyle(SwPaM const & rPaM, OUString &rString)
 {
     if (!rPaM.GetContentNode())
         return; // TODO: is there an easy way to get it for tables/sections?
-    SwContentFrm* pFrame = rPaM.GetContentNode()->getLayoutFrm(rPaM.GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout());
+    SwContentFrame* pFrame = rPaM.GetContentNode()->getLayoutFrame(rPaM.GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout());
     if(pFrame)
     {
-        const SwPageFrm* pPage = pFrame->FindPageFrm();
+        const SwPageFrame* pPage = pFrame->FindPageFrame();
         if(pPage)
         {
             SwStyleNameMapper::FillProgName(pPage->GetPageDesc()->GetName(),
-                rString, nsSwGetPoolIdFromName::GET_POOLID_PAGEDESC, true);
+                rString, SwGetPoolIdFromName::PageDesc);
         }
     }
 }
 
 // reset special properties of the cursor
-void resetCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry, SwPaM& rPam)
+void resetCursorPropertyValue(const SfxItemPropertySimpleEntry& rEntry, SwPaM& rPam)
 {
     SwDoc* pDoc = rPam.GetDoc();
     switch(rEntry.nWID)
@@ -924,12 +937,12 @@ void resetCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry, SwPaM& rPa
 
             if( rPam.GetNext() != &rPam )           // Multiple selection?
             {
-                pDoc->GetIDocumentUndoRedo().StartUndo( UNDO_START, NULL );
+                pDoc->GetIDocumentUndoRedo().StartUndo( SwUndoId::START, nullptr );
                 SwPamRanges aRangeArr( rPam );
                 SwPaM aPam( *rPam.GetPoint() );
-                for( SwPamRanges::size_type n = 0; n < aRangeArr.Count(); ++n )
+                for( size_t n = 0; n < aRangeArr.Count(); ++n )
                     pDoc->SetNodeNumStart( *aRangeArr.SetPam( n, aPam ).GetPoint(), 1 );
-                pDoc->GetIDocumentUndoRedo().EndUndo( UNDO_END, NULL );
+                pDoc->GetIDocumentUndoRedo().EndUndo( SwUndoId::END, nullptr );
             }
             else
                 pDoc->SetNodeNumStart( *rPam.GetPoint(), 0 );
@@ -950,13 +963,11 @@ void resetCrsrPropertyValue(const SfxItemPropertySimpleEntry& rEntry, SwPaM& rPa
     }
 }
 
-void InsertFile(SwUnoCrsr* pUnoCrsr, const OUString& rURL,
+void InsertFile(SwUnoCursor* pUnoCursor, const OUString& rURL,
     const uno::Sequence< beans::PropertyValue >& rOptions)
-    throw (lang::IllegalArgumentException, io::IOException,
-           uno::RuntimeException, std::exception)
 {
-    SfxMedium* pMed = 0;
-    SwDoc* pDoc = pUnoCrsr->GetDoc();
+    std::unique_ptr<SfxMedium> pMed;
+    SwDoc* pDoc = pUnoCursor->GetDoc();
     SwDocShell* pDocSh = pDoc->GetDocShell();
     utl::MediaDescriptor aMediaDescriptor( rOptions );
     OUString sFileName = rURL;
@@ -982,7 +993,7 @@ void InsertFile(SwUnoCrsr* pUnoCrsr, const OUString& rURL,
         return;
 
     SfxObjectFactory& rFact = pDocSh->GetFactory();
-    const SfxFilter* pFilter = rFact.GetFilterContainer()->GetFilter4FilterName( sFilterName );
+    std::shared_ptr<const SfxFilter> pFilter = rFact.GetFilterContainer()->GetFilter4FilterName( sFilterName );
     uno::Reference < embed::XStorage > xReadStorage;
     if( xInputStream.is() )
     {
@@ -991,56 +1002,48 @@ void InsertFile(SwUnoCrsr* pUnoCrsr, const OUString& rURL,
         aArgs[1] <<= embed::ElementModes::READ;
         try
         {
-            xReadStorage = uno::Reference< embed::XStorage >(
-                            ::comphelper::OStorageHelper::GetStorageFactory()->createInstanceWithArguments( aArgs ),
-                            uno::UNO_QUERY );
-        }
-        catch( const io::IOException& rEx)
-        {
-            (void)rEx;
+            xReadStorage.set( ::comphelper::OStorageHelper::GetStorageFactory()->createInstanceWithArguments( aArgs ),
+                              uno::UNO_QUERY );
         }
+        catch( const io::IOException&) {}
     }
     if ( !pFilter )
     {
         if( xInputStream.is() && !xReadStorage.is())
         {
-            pMed = new SfxMedium;
+            pMed.reset(new SfxMedium);
             pMed->setStreamToLoadFrom(xInputStream, true );
         }
         else
-            pMed = xReadStorage.is() ?
-                new SfxMedium(xReadStorage, sBaseURL, 0 ) :
-                new SfxMedium(sFileName, StreamMode::READ, 0, 0 );
+            pMed.reset(xReadStorage.is() ?
+                new SfxMedium(xReadStorage, sBaseURL, nullptr ) :
+                new SfxMedium(sFileName, StreamMode::READ, nullptr, nullptr ));
         if( !sBaseURL.isEmpty() )
             pMed->GetItemSet()->Put( SfxStringItem( SID_DOC_BASEURL, sBaseURL ) );
 
         SfxFilterMatcher aMatcher( rFact.GetFilterContainer()->GetName() );
-        ErrCode nErr = aMatcher.GuessFilter(*pMed, &pFilter, SfxFilterFlags::NONE);
+        ErrCode nErr = aMatcher.GuessFilter(*pMed, pFilter, SfxFilterFlags::NONE);
         if ( nErr || !pFilter)
-            DELETEZ(pMed);
-        else
-            pMed->SetFilter( pFilter );
+            return;
+        pMed->SetFilter( pFilter );
     }
     else
     {
-        if(!pMed)
+        if( xInputStream.is() && !xReadStorage.is())
         {
-            if( xInputStream.is() && !xReadStorage.is())
+            pMed.reset(new SfxMedium);
+            pMed->setStreamToLoadFrom(xInputStream, true );
+            pMed->SetFilter( pFilter );
+        }
+        else
+        {
+            if( xReadStorage.is() )
             {
-                pMed = new SfxMedium;
-                pMed->setStreamToLoadFrom(xInputStream, true );
+                pMed.reset(new SfxMedium(xReadStorage, sBaseURL, nullptr ));
                 pMed->SetFilter( pFilter );
             }
             else
-            {
-                if( xReadStorage.is() )
-                {
-                    pMed = new SfxMedium(xReadStorage, sBaseURL, 0 );
-                    pMed->SetFilter( pFilter );
-                }
-                else
-                    pMed = new SfxMedium(sFileName, StreamMode::READ, pFilter, 0);
-            }
+                pMed.reset(new SfxMedium(sFileName, StreamMode::READ, pFilter, nullptr));
         }
         if(!sFilterOptions.isEmpty())
             pMed->GetItemSet()->Put( SfxStringItem( SID_FILE_FILTEROPTIONS, sFilterOptions ) );
@@ -1048,51 +1051,47 @@ void InsertFile(SwUnoCrsr* pUnoCrsr, const OUString& rURL,
             pMed->GetItemSet()->Put( SfxStringItem( SID_DOC_BASEURL, sBaseURL ) );
     }
 
-    if( !pMed )
-        return;
-
     // this sourcecode is not responsible for the lifetime of the shell, SfxObjectShellLock should not be used
     SfxObjectShellRef aRef( pDocSh );
 
     pMed->Download();   // if necessary: start the download
-    if( aRef.Is() && 1 < aRef->GetRefCount() )  // Ref still valid?
+    if( aRef.is() && 1 < aRef->GetRefCount() )  // Ref still valid?
     {
         SwReader* pRdr;
         SfxItemSet* pSet =  pMed->GetItemSet();
         pSet->Put(SfxBoolItem(FN_API_CALL, true));
         if(!sPassword.isEmpty())
             pSet->Put(SfxStringItem(SID_PASSWORD, sPassword));
-        Reader *pRead = pDocSh->StartConvertFrom( *pMed, &pRdr, 0, pUnoCrsr);
+        Reader *pRead = pDocSh->StartConvertFrom( *pMed, &pRdr, nullptr, pUnoCursor);
         if( pRead )
         {
 
             UnoActionContext aContext(pDoc);
 
-            if(pUnoCrsr->HasMark())
-                pDoc->getIDocumentContentOperations().DeleteAndJoin(*pUnoCrsr);
+            if(pUnoCursor->HasMark())
+                pDoc->getIDocumentContentOperations().DeleteAndJoin(*pUnoCursor);
 
-            SwNodeIndex aSave(  pUnoCrsr->GetPoint()->nNode, -1 );
-            sal_Int32 nContent = pUnoCrsr->GetPoint()->nContent.GetIndex();
+            SwNodeIndex aSave(  pUnoCursor->GetPoint()->nNode, -1 );
+            sal_Int32 nContent = pUnoCursor->GetPoint()->nContent.GetIndex();
 
-            sal_uInt32 nErrno = pRdr->Read( *pRead );   // and paste the document
+            ErrCode nErrno = pRdr->Read( *pRead );   // and paste the document
 
             if(!nErrno)
             {
                 ++aSave;
-                pUnoCrsr->SetMark();
-                pUnoCrsr->GetMark()->nNode = aSave;
+                pUnoCursor->SetMark();
+                pUnoCursor->GetMark()->nNode = aSave;
 
                 SwContentNode* pCntNode = aSave.GetNode().GetContentNode();
                 if( !pCntNode )
                     nContent = 0;
-                pUnoCrsr->GetMark()->nContent.Assign( pCntNode, nContent );
+                pUnoCursor->GetMark()->nContent.Assign( pCntNode, nContent );
             }
 
             delete pRdr;
 
         }
     }
-    delete pMed;
 }
 
 // insert text and scan for CR characters in order to insert
@@ -1158,10 +1157,9 @@ bool DocInsertStringSplitCR(
     return bOK;
 }
 
-void makeRedline( SwPaM& rPaM,
+void makeRedline( SwPaM const & rPaM,
     const OUString& rRedlineType,
     const uno::Sequence< beans::PropertyValue >& rRedlineProperties )
-        throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
     IDocumentRedlineAccess* pRedlineAccess = &rPaM.GetDoc()->getIDocumentRedlineAccess();
 
@@ -1181,39 +1179,28 @@ void makeRedline( SwPaM& rPaM,
 
     //todo: what about REDLINE_FMTCOLL?
     comphelper::SequenceAsHashMap aPropMap( rRedlineProperties );
-    uno::Any aAuthorValue;
-    aAuthorValue = aPropMap.getUnpackedValueOrDefault("RedlineAuthor", aAuthorValue);
-    sal_uInt16 nAuthor = 0;
+    std::size_t nAuthor = 0;
     OUString sAuthor;
-    if( aAuthorValue >>= sAuthor )
+    if( aPropMap.getValue("RedlineAuthor") >>= sAuthor )
         nAuthor = pRedlineAccess->InsertRedlineAuthor(sAuthor);
 
     OUString sComment;
-    uno::Any aCommentValue;
-    aCommentValue = aPropMap.getUnpackedValueOrDefault("RedlineComment", aCommentValue);
-
     SwRedlineData aRedlineData( eType, nAuthor );
-    if( aCommentValue >>= sComment )
+    if( aPropMap.getValue("RedlineComment") >>= sComment )
         aRedlineData.SetComment( sComment );
 
     ::util::DateTime aStamp;
-    uno::Any aDateTimeValue;
-    aDateTimeValue = aPropMap.getUnpackedValueOrDefault("RedlineDateTime", aDateTimeValue);
-    if( aDateTimeValue >>= aStamp )
+    if( aPropMap.getValue("RedlineDateTime") >>= aStamp )
     {
-       aRedlineData.SetTimeStamp(
-        DateTime( Date( aStamp.Day, aStamp.Month, aStamp.Year ), tools::Time( aStamp.Hours, aStamp.Minutes, aStamp.Seconds ) ) );
+        aRedlineData.SetTimeStamp( DateTime( aStamp));
     }
 
-    SwRedlineExtraData_FormattingChanges* pRedlineExtraData = NULL;
+    SwRedlineExtraData_FormattingChanges* pRedlineExtraData = nullptr;
 
     // Read the 'Redline Revert Properties' from the parameters
     uno::Sequence< beans::PropertyValue > aRevertProperties;
-    uno::Any aRevertPropertiesValue;
-    aRevertPropertiesValue = aPropMap.getUnpackedValueOrDefault("RedlineRevertProperties", aRevertPropertiesValue);
-
     // Check if the value exists
-    if ( aRevertPropertiesValue >>= aRevertProperties )
+    if ( aPropMap.getValue("RedlineRevertProperties") >>= aRevertProperties )
     {
         int nMap = 0;
         // Make sure that paragraph format gets its own map, otherwise e.g. fill attributes are not preserved.
@@ -1221,7 +1208,7 @@ void makeRedline( SwPaM& rPaM,
             nMap = PROPERTY_MAP_PARAGRAPH;
         else
             nMap = PROPERTY_MAP_TEXTPORTION_EXTENSIONS;
-        SfxItemPropertySet const& rPropSet = (*aSwMapProvider.GetPropertySet(nMap));
+        SfxItemPropertySet const& rPropSet = *aSwMapProvider.GetPropertySet(nMap);
 
         // Check if there are any properties
         if (aRevertProperties.getLength())
@@ -1275,20 +1262,19 @@ void makeRedline( SwPaM& rPaM,
     }
 
     SwRangeRedline* pRedline = new SwRangeRedline( aRedlineData, rPaM );
-    RedlineMode_t nPrevMode = pRedlineAccess->GetRedlineMode( );
+    RedlineFlags nPrevMode = pRedlineAccess->GetRedlineFlags( );
     pRedline->SetExtraData( pRedlineExtraData );
 
-    pRedlineAccess->SetRedlineMode_intern(nsRedlineMode_t::REDLINE_ON);
-    bool bRet = pRedlineAccess->AppendRedline( pRedline, false );
-    pRedlineAccess->SetRedlineMode_intern( nPrevMode );
-    if( !bRet )
+    pRedlineAccess->SetRedlineFlags_intern(RedlineFlags::On);
+    auto const result(pRedlineAccess->AppendRedline(pRedline, false));
+    pRedlineAccess->SetRedlineFlags_intern( nPrevMode );
+    if (IDocumentRedlineAccess::AppendResult::IGNORED == result)
         throw lang::IllegalArgumentException();
 }
 
 void makeTableRowRedline( SwTableLine& rTableLine,
     const OUString& rRedlineType,
     const uno::Sequence< beans::PropertyValue >& rRedlineProperties )
-        throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
     IDocumentRedlineAccess* pRedlineAccess = &rTableLine.GetFrameFormat()->GetDoc()->getIDocumentRedlineAccess();
 
@@ -1307,37 +1293,30 @@ void makeTableRowRedline( SwTableLine& rTableLine,
     }
 
     comphelper::SequenceAsHashMap aPropMap( rRedlineProperties );
-    uno::Any aAuthorValue;
-    aAuthorValue = aPropMap.getUnpackedValueOrDefault("RedlineAuthor", aAuthorValue);
-    sal_uInt16 nAuthor = 0;
+    std::size_t nAuthor = 0;
     OUString sAuthor;
-    if( aAuthorValue >>= sAuthor )
+    if( aPropMap.getValue("RedlineAuthor") >>= sAuthor )
         nAuthor = pRedlineAccess->InsertRedlineAuthor(sAuthor);
 
     OUString sComment;
-    uno::Any aCommentValue;
-    aCommentValue = aPropMap.getUnpackedValueOrDefault("RedlineComment", aCommentValue);
-
     SwRedlineData aRedlineData( eType, nAuthor );
-    if( aCommentValue >>= sComment )
+    if( aPropMap.getValue("RedlineComment") >>= sComment )
         aRedlineData.SetComment( sComment );
 
     ::util::DateTime aStamp;
-    uno::Any aDateTimeValue;
-    aDateTimeValue = aPropMap.getUnpackedValueOrDefault("RedlineDateTime", aDateTimeValue);
-    if( aDateTimeValue >>= aStamp )
+    if( aPropMap.getValue("RedlineDateTime") >>= aStamp )
     {
        aRedlineData.SetTimeStamp(
         DateTime( Date( aStamp.Day, aStamp.Month, aStamp.Year ), tools::Time( aStamp.Hours, aStamp.Minutes, aStamp.Seconds ) ) );
     }
 
     SwTableRowRedline* pRedline = new SwTableRowRedline( aRedlineData, rTableLine );
-    RedlineMode_t nPrevMode = pRedlineAccess->GetRedlineMode( );
-    pRedline->SetExtraData( NULL );
+    RedlineFlags nPrevMode = pRedlineAccess->GetRedlineFlags( );
+    pRedline->SetExtraData( nullptr );
 
-    pRedlineAccess->SetRedlineMode_intern(nsRedlineMode_t::REDLINE_ON);
+    pRedlineAccess->SetRedlineFlags_intern(RedlineFlags::On);
     bool bRet = pRedlineAccess->AppendTableRowRedline( pRedline, false );
-    pRedlineAccess->SetRedlineMode_intern( nPrevMode );
+    pRedlineAccess->SetRedlineFlags_intern( nPrevMode );
     if( !bRet )
         throw lang::IllegalArgumentException();
 }
@@ -1345,7 +1324,6 @@ void makeTableRowRedline( SwTableLine& rTableLine,
 void makeTableCellRedline( SwTableBox& rTableBox,
     const OUString& rRedlineType,
     const uno::Sequence< beans::PropertyValue >& rRedlineProperties )
-        throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
     IDocumentRedlineAccess* pRedlineAccess = &rTableBox.GetFrameFormat()->GetDoc()->getIDocumentRedlineAccess();
 
@@ -1364,37 +1342,30 @@ void makeTableCellRedline( SwTableBox& rTableBox,
     }
 
     comphelper::SequenceAsHashMap aPropMap( rRedlineProperties );
-    uno::Any aAuthorValue;
-    aAuthorValue = aPropMap.getUnpackedValueOrDefault("RedlineAuthor", aAuthorValue);
-    sal_uInt16 nAuthor = 0;
+    std::size_t nAuthor = 0;
     OUString sAuthor;
-    if( aAuthorValue >>= sAuthor )
+    if( aPropMap.getValue("RedlineAuthor") >>= sAuthor )
         nAuthor = pRedlineAccess->InsertRedlineAuthor(sAuthor);
 
     OUString sComment;
-    uno::Any aCommentValue;
-    aCommentValue = aPropMap.getUnpackedValueOrDefault("RedlineComment", aCommentValue);
-
     SwRedlineData aRedlineData( eType, nAuthor );
-    if( aCommentValue >>= sComment )
+    if( aPropMap.getValue("RedlineComment") >>= sComment )
         aRedlineData.SetComment( sComment );
 
     ::util::DateTime aStamp;
-    uno::Any aDateTimeValue;
-    aDateTimeValue = aPropMap.getUnpackedValueOrDefault("RedlineDateTime", aDateTimeValue);
-    if( aDateTimeValue >>= aStamp )
+    if( aPropMap.getValue("RedlineDateTime") >>= aStamp )
     {
        aRedlineData.SetTimeStamp(
         DateTime( Date( aStamp.Day, aStamp.Month, aStamp.Year ), tools::Time( aStamp.Hours, aStamp.Minutes, aStamp.Seconds ) ) );
     }
 
     SwTableCellRedline* pRedline = new SwTableCellRedline( aRedlineData, rTableBox );
-    RedlineMode_t nPrevMode = pRedlineAccess->GetRedlineMode( );
-    pRedline->SetExtraData( NULL );
+    RedlineFlags nPrevMode = pRedlineAccess->GetRedlineFlags( );
+    pRedline->SetExtraData( nullptr );
 
-    pRedlineAccess->SetRedlineMode_intern(nsRedlineMode_t::REDLINE_ON);
+    pRedlineAccess->SetRedlineFlags_intern(RedlineFlags::On);
     bool bRet = pRedlineAccess->AppendTableCellRedline( pRedline, false );
-    pRedlineAccess->SetRedlineMode_intern( nPrevMode );
+    pRedlineAccess->SetRedlineFlags_intern( nPrevMode );
     if( !bRet )
         throw lang::IllegalArgumentException();
 }
@@ -1402,21 +1373,21 @@ void makeTableCellRedline( SwTableBox& rTableBox,
 void SwAnyMapHelper::SetValue( sal_uInt16 nWhichId, sal_uInt16 nMemberId, const uno::Any& rAny )
 {
     sal_uInt32 nKey = (nWhichId << 16) + nMemberId;
-    auto aIt = maMap.find( nKey );
-    if( aIt != maMap.end() )
-        *(aIt->second) = rAny;
+    auto aIt = m_Map.find( nKey );
+    if (aIt != m_Map.end())
+        aIt->second = rAny;
     else
-        maMap.insert( nKey, new uno::Any(rAny) );
+        m_Map.insert(std::make_pair(nKey, rAny));
 }
 
 bool    SwAnyMapHelper::FillValue( sal_uInt16 nWhichId, sal_uInt16 nMemberId, const uno::Any*& pAny )
 {
     bool bRet = false;
     sal_uInt32 nKey = (nWhichId << 16) + nMemberId;
-    auto aIt = maMap.find( nKey );
-    if( aIt != maMap.end() )
+    auto aIt = m_Map.find( nKey );
+    if (aIt != m_Map.end())
     {
-        pAny = aIt->second;
+        pAny = & aIt->second;
         bRet = true;
     }
     return bRet;
