@@ -17,19 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <editeng/unolingu.hxx>
 
 #include <unobaseclass.hxx>
+#include <unocrsrhelper.hxx>
 #include <unoflatpara.hxx>
 
-#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <com/sun/star/text/TextMarkupType.hpp>
+#include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <unotextmarkup.hxx>
 #include <ndtxt.hxx>
 #include <doc.hxx>
 #include <docsh.hxx>
+#include <IDocumentLayoutAccess.hxx>
+#include <IDocumentStylePoolAccess.hxx>
 #include <viewsh.hxx>
 #include <viewimp.hxx>
 #include <breakit.hxx>
@@ -43,6 +45,8 @@
 #include <IGrammarContact.hxx>
 #include <viewopt.hxx>
 #include <comphelper/servicehelper.hxx>
+#include <comphelper/propertysetinfo.hxx>
+#include <comphelper/sequence.hxx>
 
 #include <com/sun/star/lang/XUnoTunnel.hpp>
 #include <com/sun/star/text/XTextRange.hpp>
@@ -60,13 +64,9 @@ CreateFlatParagraphIterator(SwDoc & rDoc, sal_Int32 const nTextMarkupType,
 
 }
 
-/******************************************************************************
- * SwXFlatParagraph
- ******************************************************************************/
-
-SwXFlatParagraph::SwXFlatParagraph( SwTxtNode& rTxtNode, OUString aExpandText, const ModelToViewHelper& rMap ) :
-    SwXTextMarkup( rTxtNode, rMap ),
-    maExpandText( aExpandText )
+SwXFlatParagraph::SwXFlatParagraph( SwTextNode& rTextNode, const OUString& aExpandText, const ModelToViewHelper& rMap )
+    : SwXFlatParagraph_Base(& rTextNode, rMap)
+    , maExpandText(aExpandText)
 {
 }
 
@@ -74,203 +74,241 @@ SwXFlatParagraph::~SwXFlatParagraph()
 {
 }
 
-uno::Sequence< uno::Type > SwXFlatParagraph::getTypes(  ) throw(uno::RuntimeException)
+
+// XPropertySet
+uno::Reference< beans::XPropertySetInfo > SAL_CALL
+SwXFlatParagraph::getPropertySetInfo()
 {
-    uno::Sequence< uno::Type > aTypes = SwXTextMarkup::getTypes();
-    aTypes.realloc( aTypes.getLength() + 1 );
-    aTypes[aTypes.getLength()-1] = ::getCppuType((uno::Reference< text::XFlatParagraph >*)0);
-    return aTypes;
+    static comphelper::PropertyMapEntry s_Entries[] = {
+        { OUString("FieldPositions"), -1, ::cppu::UnoType<uno::Sequence<sal_Int32>>::get(), beans::PropertyAttribute::READONLY, 0 },
+        { OUString("FootnotePositions"), -1, ::cppu::UnoType<uno::Sequence<sal_Int32>>::get(), beans::PropertyAttribute::READONLY, 0 },
+        { OUString(), -1, css::uno::Type(), 0, 0 }
+    };
+    return new comphelper::PropertySetInfo(s_Entries);
 }
 
-namespace
+void SAL_CALL
+SwXFlatParagraph::setPropertyValue(const OUString&, const uno::Any&)
 {
-    class theSwXFlatParagraphImplementationId : public rtl::Static< UnoTunnelIdInit, theSwXFlatParagraphImplementationId > {};
+    throw lang::IllegalArgumentException("no values can be set",
+            static_cast< ::cppu::OWeakObject*>(this), 0);
 }
 
-uno::Sequence< sal_Int8 > SwXFlatParagraph::getImplementationId(  ) throw(uno::RuntimeException)
+uno::Any SAL_CALL
+SwXFlatParagraph::getPropertyValue(const OUString& rPropertyName)
 {
-    return theSwXFlatParagraphImplementationId::get().getSeq();
-}
+    SolarMutexGuard g;
 
-uno::Any SAL_CALL SwXFlatParagraph::queryInterface( const uno::Type& rType ) throw(uno::RuntimeException)
-{
-    if ( rType == ::getCppuType((uno::Reference< text::XFlatParagraph >*)0) )
+    if (rPropertyName == "FieldPositions")
     {
-        return uno::makeAny( uno::Reference < text::XFlatParagraph >(this) );
+        return uno::makeAny( comphelper::containerToSequence( GetConversionMap().getFieldPositions() ) );
     }
-    else
-        return SwXTextMarkup::queryInterface( rType );
+    else if (rPropertyName == "FootnotePositions")
+    {
+        return uno::makeAny( comphelper::containerToSequence( GetConversionMap().getFootnotePositions() ) );
+    }
+    return uno::Any();
 }
 
-void SAL_CALL SwXFlatParagraph::acquire() throw()
+void SAL_CALL
+SwXFlatParagraph::addPropertyChangeListener(
+        const OUString& /*rPropertyName*/,
+        const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/)
 {
-    SwXTextMarkup::acquire();
+    SAL_WARN("sw.uno",
+        "SwXFlatParagraph::addPropertyChangeListener(): not implemented");
 }
 
-void SAL_CALL SwXFlatParagraph::release() throw()
+void SAL_CALL
+SwXFlatParagraph::removePropertyChangeListener(
+        const OUString& /*rPropertyName*/,
+        const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/)
 {
-    SwXTextMarkup::release();
+    SAL_WARN("sw.uno",
+        "SwXFlatParagraph::removePropertyChangeListener(): not implemented");
 }
 
-const SwTxtNode* SwXFlatParagraph::getTxtNode() const
+void SAL_CALL
+SwXFlatParagraph::addVetoableChangeListener(
+        const OUString& /*rPropertyName*/,
+        const uno::Reference< beans::XVetoableChangeListener >& /*xListener*/)
 {
-    return mpTxtNode;
+    SAL_WARN("sw.uno",
+        "SwXFlatParagraph::addVetoableChangeListener(): not implemented");
 }
 
-css::uno::Reference< css::container::XStringKeyMap > SAL_CALL SwXFlatParagraph::getMarkupInfoContainer() throw (css::uno::RuntimeException)
+void SAL_CALL
+SwXFlatParagraph::removeVetoableChangeListener(
+        const OUString& /*rPropertyName*/,
+        const uno::Reference< beans::XVetoableChangeListener >& /*xListener*/)
+{
+    SAL_WARN("sw.uno",
+        "SwXFlatParagraph::removeVetoableChangeListener(): not implemented");
+}
+
+
+css::uno::Reference< css::container::XStringKeyMap > SAL_CALL SwXFlatParagraph::getMarkupInfoContainer()
 {
     return SwXTextMarkup::getMarkupInfoContainer();
 }
 
 void SAL_CALL SwXFlatParagraph::commitTextRangeMarkup(::sal_Int32 nType, const OUString & aIdentifier, const uno::Reference< text::XTextRange> & xRange,
-                                                      const css::uno::Reference< css::container::XStringKeyMap > & xMarkupInfoContainer) throw (uno::RuntimeException)
+                                                      const css::uno::Reference< css::container::XStringKeyMap > & xMarkupInfoContainer)
 {
     SolarMutexGuard aGuard;
     SwXTextMarkup::commitTextRangeMarkup( nType, aIdentifier, xRange,  xMarkupInfoContainer );
 }
 
-void SAL_CALL SwXFlatParagraph::commitStringMarkup(::sal_Int32 nType, const OUString & rIdentifier, ::sal_Int32 nStart, ::sal_Int32 nLength, const css::uno::Reference< css::container::XStringKeyMap > & rxMarkupInfoContainer) throw (css::uno::RuntimeException)
+void SAL_CALL SwXFlatParagraph::commitStringMarkup(::sal_Int32 nType, const OUString & rIdentifier, ::sal_Int32 nStart, ::sal_Int32 nLength, const css::uno::Reference< css::container::XStringKeyMap > & rxMarkupInfoContainer)
 {
     SolarMutexGuard aGuard;
     SwXTextMarkup::commitStringMarkup( nType, rIdentifier, nStart, nLength,  rxMarkupInfoContainer );
 }
 
 // text::XFlatParagraph:
-OUString SAL_CALL SwXFlatParagraph::getText() throw (uno::RuntimeException)
+OUString SAL_CALL SwXFlatParagraph::getText()
 {
     return maExpandText;
 }
 
 // text::XFlatParagraph:
-void SAL_CALL SwXFlatParagraph::setChecked( ::sal_Int32 nType, ::sal_Bool bVal ) throw (uno::RuntimeException)
+void SAL_CALL SwXFlatParagraph::setChecked( ::sal_Int32 nType, sal_Bool bVal )
 {
     SolarMutexGuard aGuard;
 
-    if ( mpTxtNode )
+    if (GetTextNode())
     {
         if ( text::TextMarkupType::SPELLCHECK == nType )
-            mpTxtNode->SetWrongDirty( !bVal );
+        {
+            GetTextNode()->SetWrongDirty(
+                bVal ? SwTextNode::WrongState::DONE : SwTextNode::WrongState::TODO);
+        }
         else if ( text::TextMarkupType::SMARTTAG == nType )
-            mpTxtNode->SetSmartTagDirty( !bVal );
+            GetTextNode()->SetSmartTagDirty( !bVal );
         else if( text::TextMarkupType::PROOFREADING == nType )
         {
-            mpTxtNode->SetGrammarCheckDirty( !bVal );
+            GetTextNode()->SetGrammarCheckDirty( !bVal );
             if( bVal )
-                ::finishGrammarCheck( *mpTxtNode );
+                ::finishGrammarCheck( *GetTextNode() );
         }
     }
 }
 
 // text::XFlatParagraph:
-::sal_Bool SAL_CALL SwXFlatParagraph::isChecked( ::sal_Int32 nType ) throw (uno::RuntimeException)
+sal_Bool SAL_CALL SwXFlatParagraph::isChecked( ::sal_Int32 nType )
 {
     SolarMutexGuard aGuard;
-    if ( mpTxtNode )
+    if (GetTextNode())
     {
         if ( text::TextMarkupType::SPELLCHECK == nType )
-            return mpTxtNode->IsWrongDirty();
+            return !GetTextNode()->IsWrongDirty();
         else if ( text::TextMarkupType::PROOFREADING == nType )
-            return mpTxtNode->IsGrammarCheckDirty();
+            return !GetTextNode()->IsGrammarCheckDirty();
         else if ( text::TextMarkupType::SMARTTAG == nType )
-            return mpTxtNode->IsSmartTagDirty();
+            return !GetTextNode()->IsSmartTagDirty();
     }
 
-    return sal_False;
+    return true;
 }
 
 // text::XFlatParagraph:
-::sal_Bool SAL_CALL SwXFlatParagraph::isModified() throw (uno::RuntimeException)
+sal_Bool SAL_CALL SwXFlatParagraph::isModified()
 {
     SolarMutexGuard aGuard;
-    return 0 == mpTxtNode;
+    return nullptr == GetTextNode();
 }
 
 // text::XFlatParagraph:
 lang::Locale SAL_CALL SwXFlatParagraph::getLanguageOfText(::sal_Int32 nPos, ::sal_Int32 nLen)
-    throw (uno::RuntimeException, lang::IllegalArgumentException)
 {
     SolarMutexGuard aGuard;
-    if (!mpTxtNode)
+    if (!GetTextNode())
         return LanguageTag::convertToLocale( LANGUAGE_NONE );
 
-    const lang::Locale aLocale( SW_BREAKITER()->GetLocale( mpTxtNode->GetLang( static_cast<sal_uInt16>(nPos), static_cast<sal_uInt16>(nLen) ) ) );
+    const lang::Locale aLocale( SW_BREAKITER()->GetLocale( GetTextNode()->GetLang(nPos, nLen) ) );
     return aLocale;
 }
 
 // text::XFlatParagraph:
 lang::Locale SAL_CALL SwXFlatParagraph::getPrimaryLanguageOfText(::sal_Int32 nPos, ::sal_Int32 nLen)
-    throw (uno::RuntimeException, lang::IllegalArgumentException)
 {
     SolarMutexGuard aGuard;
 
-    if (!mpTxtNode)
+    if (!GetTextNode())
         return LanguageTag::convertToLocale( LANGUAGE_NONE );
 
-    const lang::Locale aLocale( SW_BREAKITER()->GetLocale( mpTxtNode->GetLang( static_cast<sal_uInt16>(nPos), static_cast<sal_uInt16>(nLen) ) ) );
+    const lang::Locale aLocale( SW_BREAKITER()->GetLocale( GetTextNode()->GetLang(nPos, nLen) ) );
     return aLocale;
 }
 
 // text::XFlatParagraph:
-void SAL_CALL SwXFlatParagraph::changeText(::sal_Int32 nPos, ::sal_Int32 nLen, const OUString & aNewText, const css::uno::Sequence< css::beans::PropertyValue > & aAttributes) throw (css::uno::RuntimeException, css::lang::IllegalArgumentException)
+void SAL_CALL SwXFlatParagraph::changeText(::sal_Int32 nPos, ::sal_Int32 nLen, const OUString & aNewText, const css::uno::Sequence< css::beans::PropertyValue > & aAttributes)
 {
     SolarMutexGuard aGuard;
 
-    if ( !mpTxtNode )
+    if (!GetTextNode())
         return;
 
-    SwTxtNode* pOldTxtNode = mpTxtNode;
+    SwTextNode *const pOldTextNode = GetTextNode();
 
-    SwPaM aPaM( *mpTxtNode, static_cast<sal_uInt16>(nPos), *mpTxtNode, static_cast<sal_uInt16>(nPos + nLen) );
+    if (nPos < 0 || pOldTextNode->Len() < nPos || nLen < 0 || static_cast<sal_uInt32>(pOldTextNode->Len()) < static_cast<sal_uInt32>(nPos) + nLen)
+    {
+        throw lang::IllegalArgumentException();
+    }
 
-    UnoActionContext aAction( mpTxtNode->GetDoc() );
+    SwPaM aPaM( *GetTextNode(), nPos, *GetTextNode(), nPos+nLen );
+
+    UnoActionContext aAction( GetTextNode()->GetDoc() );
 
     const uno::Reference< text::XTextRange > xRange =
         SwXTextRange::CreateXTextRange(
-            *mpTxtNode->GetDoc(), *aPaM.GetPoint(), aPaM.GetMark() );
+            *GetTextNode()->GetDoc(), *aPaM.GetPoint(), aPaM.GetMark() );
     uno::Reference< beans::XPropertySet > xPropSet( xRange, uno::UNO_QUERY );
     if ( xPropSet.is() )
     {
-        for ( sal_uInt16 i = 0; i < aAttributes.getLength(); ++i )
+        for ( sal_Int32 i = 0; i < aAttributes.getLength(); ++i )
             xPropSet->setPropertyValue( aAttributes[i].Name, aAttributes[i].Value );
     }
 
-    mpTxtNode = pOldTxtNode; // setPropertyValue() modifies this. We restore the old state.
+    IDocumentContentOperations& rIDCO = pOldTextNode->getIDocumentContentOperations();
+    rIDCO.ReplaceRange( aPaM, aNewText, false );
 
-    IDocumentContentOperations* pIDCO = mpTxtNode->getIDocumentContentOperations();
-    pIDCO->ReplaceRange( aPaM, aNewText, false );
-
-    mpTxtNode = 0;
+    ClearTextNode(); // TODO: is this really needed?
 }
 
 // text::XFlatParagraph:
-void SAL_CALL SwXFlatParagraph::changeAttributes(::sal_Int32 nPos, ::sal_Int32 nLen, const css::uno::Sequence< css::beans::PropertyValue > & aAttributes) throw (css::uno::RuntimeException, css::lang::IllegalArgumentException)
+void SAL_CALL SwXFlatParagraph::changeAttributes(::sal_Int32 nPos, ::sal_Int32 nLen, const css::uno::Sequence< css::beans::PropertyValue > & aAttributes)
 {
     SolarMutexGuard aGuard;
 
-    if ( !mpTxtNode )
+    if (!GetTextNode())
         return;
 
-    SwPaM aPaM( *mpTxtNode, static_cast<sal_uInt16>(nPos), *mpTxtNode, static_cast<sal_uInt16>(nPos + nLen) );
+    if (nPos < 0 || GetTextNode()->Len() < nPos || nLen < 0 || static_cast<sal_uInt32>(GetTextNode()->Len()) < static_cast<sal_uInt32>(nPos) + nLen)
+    {
+        throw lang::IllegalArgumentException();
+    }
 
-    UnoActionContext aAction( mpTxtNode->GetDoc() );
+    SwPaM aPaM( *GetTextNode(), nPos, *GetTextNode(), nPos+nLen );
+
+    UnoActionContext aAction( GetTextNode()->GetDoc() );
 
     const uno::Reference< text::XTextRange > xRange =
         SwXTextRange::CreateXTextRange(
-            *mpTxtNode->GetDoc(), *aPaM.GetPoint(), aPaM.GetMark() );
+            *GetTextNode()->GetDoc(), *aPaM.GetPoint(), aPaM.GetMark() );
     uno::Reference< beans::XPropertySet > xPropSet( xRange, uno::UNO_QUERY );
     if ( xPropSet.is() )
     {
-        for ( sal_uInt16 i = 0; i < aAttributes.getLength(); ++i )
+        for ( sal_Int32 i = 0; i < aAttributes.getLength(); ++i )
             xPropSet->setPropertyValue( aAttributes[i].Name, aAttributes[i].Value );
     }
 
-    mpTxtNode = 0;
+    ClearTextNode(); // TODO: is this really needed?
 }
 
 // text::XFlatParagraph:
-css::uno::Sequence< ::sal_Int32 > SAL_CALL SwXFlatParagraph::getLanguagePortions() throw (css::uno::RuntimeException)
+css::uno::Sequence< ::sal_Int32 > SAL_CALL SwXFlatParagraph::getLanguagePortions()
 {
-    SolarMutexGuard aGuard;
     return css::uno::Sequence< ::sal_Int32>();
 }
 
@@ -288,36 +326,30 @@ SwXFlatParagraph::getUnoTunnelId()
 sal_Int64 SAL_CALL
 SwXFlatParagraph::getSomething(
         const uno::Sequence< sal_Int8 >& rId)
-    throw (uno::RuntimeException)
 {
     return sw::UnoTunnelImpl(rId, this);
 }
 
-
-/******************************************************************************
- * SwXFlatParagraphIterator
- ******************************************************************************/
-
-SwXFlatParagraphIterator::SwXFlatParagraphIterator( SwDoc& rDoc, sal_Int32 nType, sal_Bool bAutomatic )
+SwXFlatParagraphIterator::SwXFlatParagraphIterator( SwDoc& rDoc, sal_Int32 nType, bool bAutomatic )
     : mpDoc( &rDoc ),
       mnType( nType ),
       mbAutomatic( bAutomatic ),
       mnCurrentNode( 0 ),
-      mnStartNode( 0 ),
-      mnEndNode( rDoc.GetNodes().Count() ),
-      mbWrapped( sal_False )
+      mnEndNode( rDoc.GetNodes().Count() )
 {
     //mnStartNode = mnCurrentNode = get node from current cursor TODO!
 
     // register as listener and get notified when document is closed
-    mpDoc->GetPageDescFromPool( RES_POOLPAGE_STANDARD )->Add(this);
+    mpDoc->getIDocumentStylePoolAccess().GetPageDescFromPool( RES_POOLPAGE_STANDARD )->Add(this);
 }
 
 SwXFlatParagraphIterator::~SwXFlatParagraphIterator()
 {
+    SolarMutexGuard aGuard;
+    if(GetRegisteredIn())
+        GetRegisteredIn()->Remove(this);
 }
 
-
 void SwXFlatParagraphIterator::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
 {
     ClientModify( this, pOld, pNew );
@@ -325,19 +357,16 @@ void SwXFlatParagraphIterator::Modify( const SfxPoolItem* pOld, const SfxPoolIte
     if(!GetRegisteredIn())
     {
         SolarMutexGuard aGuard;
-        mpDoc = 0;
+        mpDoc = nullptr;
     }
 }
 
-
 uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getFirstPara()
-    throw( uno::RuntimeException )
 {
     return getNextPara();   // TODO
 }
 
 uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getNextPara()
-    throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
 
@@ -345,17 +374,16 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getNextPara()
     if (!mpDoc)
         return xRet;
 
-    SwTxtNode* pRet = 0;
+    SwTextNode* pRet = nullptr;
     if ( mbAutomatic )
     {
-        SwViewShell* pViewShell = 0;
-        mpDoc->GetEditShell( &pViewShell );
+        SwViewShell* pViewShell = mpDoc->getIDocumentLayoutAccess().GetCurrentViewShell();
 
-        SwPageFrm* pCurrentPage = pViewShell ? pViewShell->Imp()->GetFirstVisPage() : 0;
-        SwPageFrm* pStartPage = pCurrentPage;
-        SwPageFrm* pStopPage = 0;
+        SwPageFrame* pCurrentPage = pViewShell ? pViewShell->Imp()->GetFirstVisPage(pViewShell->GetOut()) : nullptr;
+        SwPageFrame* pStartPage = pCurrentPage;
+        SwPageFrame* pStopPage = nullptr;
 
-        while ( pCurrentPage != pStopPage )
+        while ( pCurrentPage && pCurrentPage != pStopPage )
         {
             if (mnType != text::TextMarkupType::SPELLCHECK || pCurrentPage->IsInvalidSpelling() )
             {
@@ -365,23 +393,23 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getNextPara()
                     return xRet;
 
                 // search for invalid content:
-                SwCntntFrm* pCnt = pCurrentPage->ContainsCntnt();
+                SwContentFrame* pCnt = pCurrentPage->ContainsContent();
 
                 while( pCnt && pCurrentPage->IsAnLower( pCnt ) )
                 {
-                    SwTxtNode* pTxtNode = dynamic_cast<SwTxtNode*>( pCnt->GetNode()->GetTxtNode() );
+                    SwTextNode* pTextNode = pCnt->GetNode()->GetTextNode();
 
-                    if ( pTxtNode &&
+                    if ( pTextNode &&
                         ((mnType == text::TextMarkupType::SPELLCHECK &&
-                                pTxtNode->IsWrongDirty()) ||
+                                pTextNode->IsWrongDirty()) ||
                          (mnType == text::TextMarkupType::PROOFREADING &&
-                                pTxtNode->IsGrammarCheckDirty())) )
+                                pTextNode->IsGrammarCheckDirty())) )
                     {
-                        pRet = pTxtNode;
+                        pRet = pTextNode;
                         break;
                     }
 
-                    pCnt = pCnt->GetNextCntntFrm();
+                    pCnt = pCnt->GetNextContentFrame();
                 }
             }
 
@@ -393,12 +421,12 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getNextPara()
             pCurrentPage->ValidateSpelling();
 
             // proceed with next page, wrap at end of document if required:
-            pCurrentPage = static_cast<SwPageFrm*>(pCurrentPage->GetNext());
+            pCurrentPage = static_cast<SwPageFrame*>(pCurrentPage->GetNext());
 
             if ( !pCurrentPage && !pStopPage )
             {
                 pStopPage = pStartPage;
-                pCurrentPage = static_cast<SwPageFrm*>(pViewShell->GetLayout()->Lower());
+                pCurrentPage = static_cast<SwPageFrame*>(pViewShell->GetLayout()->Lower());
             }
         }
     }
@@ -413,14 +441,14 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getNextPara()
 
             ++mnCurrentNode;
 
-            pRet = dynamic_cast<SwTxtNode*>(pNd);
+            pRet = dynamic_cast<SwTextNode*>(pNd);
             if ( pRet )
                 break;
 
-            if ( mnCurrentNode == mnEndNode && !mbWrapped )
+            if ( mnCurrentNode == mnEndNode )
             {
                 mnCurrentNode = 0;
-                mnEndNode = mnStartNode;
+                mnEndNode = 0;
             }
         }
     }
@@ -429,7 +457,7 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getNextPara()
     {
         // Expand the string:
         const ModelToViewHelper aConversionMap(*pRet);
-        OUString aExpandText = aConversionMap.getViewText();
+        const OUString& aExpandText = aConversionMap.getViewText();
 
         xRet = new SwXFlatParagraph( *pRet, aExpandText, aConversionMap );
         // keep hard references...
@@ -440,13 +468,11 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getNextPara()
 }
 
 uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getLastPara()
-    throw( uno::RuntimeException )
 {
     return getNextPara();
 }
 
 uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getParaAfter(const uno::Reference< text::XFlatParagraph > & xPara)
-    throw ( uno::RuntimeException, lang::IllegalArgumentException )
 {
     SolarMutexGuard aGuard;
 
@@ -455,35 +481,35 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getParaAfter(co
         return xRet;
 
     const uno::Reference<lang::XUnoTunnel> xFPTunnel(xPara, uno::UNO_QUERY);
-    OSL_ASSERT(xFPTunnel.is());
+    SAL_WARN_IF(!xFPTunnel.is(), "sw.core", "invalid argument");
     SwXFlatParagraph* const pFlatParagraph(sw::UnoTunnelGetImplementation<SwXFlatParagraph>(xFPTunnel));
 
     if ( !pFlatParagraph )
         return xRet;
 
-    const SwTxtNode* pCurrentNode = pFlatParagraph->getTxtNode();
+    SwTextNode const*const pCurrentNode = pFlatParagraph->GetTextNode();
 
     if ( !pCurrentNode )
         return xRet;
 
-    SwTxtNode* pNextTxtNode = 0;
+    SwTextNode* pNextTextNode = nullptr;
     const SwNodes& rNodes = pCurrentNode->GetDoc()->GetNodes();
 
     for( sal_uLong nCurrentNode = pCurrentNode->GetIndex() + 1; nCurrentNode < rNodes.Count(); ++nCurrentNode )
     {
         SwNode* pNd = rNodes[ nCurrentNode ];
-        pNextTxtNode = dynamic_cast<SwTxtNode*>(pNd);
-        if ( pNextTxtNode )
+        pNextTextNode = dynamic_cast<SwTextNode*>(pNd);
+        if ( pNextTextNode )
             break;
     }
 
-    if ( pNextTxtNode )
+    if ( pNextTextNode )
     {
         // Expand the string:
-        const ModelToViewHelper aConversionMap(*pNextTxtNode);
-        OUString aExpandText = aConversionMap.getViewText();
+        const ModelToViewHelper aConversionMap(*pNextTextNode);
+        const OUString& aExpandText = aConversionMap.getViewText();
 
-        xRet = new SwXFlatParagraph( *pNextTxtNode, aExpandText, aConversionMap );
+        xRet = new SwXFlatParagraph( *pNextTextNode, aExpandText, aConversionMap );
         // keep hard references...
         m_aFlatParaList.insert( xRet );
     }
@@ -492,7 +518,6 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getParaAfter(co
 }
 
 uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getParaBefore(const uno::Reference< text::XFlatParagraph > & xPara )
-    throw ( uno::RuntimeException, lang::IllegalArgumentException )
 {
     SolarMutexGuard aGuard;
 
@@ -501,35 +526,36 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getParaBefore(c
         return xRet;
 
     const uno::Reference<lang::XUnoTunnel> xFPTunnel(xPara, uno::UNO_QUERY);
-    OSL_ASSERT(xFPTunnel.is());
+
+    SAL_WARN_IF(!xFPTunnel.is(), "sw.core", "invalid argument");
     SwXFlatParagraph* const pFlatParagraph(sw::UnoTunnelGetImplementation<SwXFlatParagraph>(xFPTunnel));
 
     if ( !pFlatParagraph )
         return xRet;
 
-    const SwTxtNode* pCurrentNode = pFlatParagraph->getTxtNode();
+    SwTextNode const*const pCurrentNode = pFlatParagraph->GetTextNode();
 
     if ( !pCurrentNode )
         return xRet;
 
-    SwTxtNode* pPrevTxtNode = 0;
+    SwTextNode* pPrevTextNode = nullptr;
     const SwNodes& rNodes = pCurrentNode->GetDoc()->GetNodes();
 
     for( sal_uLong nCurrentNode = pCurrentNode->GetIndex() - 1; nCurrentNode > 0; --nCurrentNode )
     {
         SwNode* pNd = rNodes[ nCurrentNode ];
-        pPrevTxtNode = dynamic_cast<SwTxtNode*>(pNd);
-        if ( pPrevTxtNode )
+        pPrevTextNode = dynamic_cast<SwTextNode*>(pNd);
+        if ( pPrevTextNode )
             break;
     }
 
-    if ( pPrevTxtNode )
+    if ( pPrevTextNode )
     {
         // Expand the string:
-        const ModelToViewHelper aConversionMap(*pPrevTxtNode);
-        OUString aExpandText = aConversionMap.getViewText();
+        const ModelToViewHelper aConversionMap(*pPrevTextNode);
+        const OUString& aExpandText = aConversionMap.getViewText();
 
-        xRet = new SwXFlatParagraph( *pPrevTxtNode, aExpandText, aConversionMap );
+        xRet = new SwXFlatParagraph( *pPrevTextNode, aExpandText, aConversionMap );
         // keep hard references...
         m_aFlatParaList.insert( xRet );
     }
