@@ -22,7 +22,7 @@
 #include <utility>
 
 #include <osl/mutex.hxx>
-#include <cppuhelper/interfacecontainer.h>
+#include <comphelper/interfacecontainer2.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <vcl/svapp.hxx>
 #include <comphelper/sequence.hxx>
@@ -49,39 +49,38 @@ class SwXFootnote::Impl
     : public SwClient
 {
 private:
-    ::osl::Mutex m_Mutex; // just for OInterfaceContainerHelper
+    ::osl::Mutex m_Mutex; // just for OInterfaceContainerHelper2
 
 public:
 
     SwXFootnote &               m_rThis;
     uno::WeakReference<uno::XInterface> m_wThis;
     const bool                  m_bIsEndnote;
-    ::cppu::OInterfaceContainerHelper m_EventListeners;
-    bool                        m_bIsDescriptor;
-    const SwFmtFtn *            m_pFmtFtn;
+    ::comphelper::OInterfaceContainerHelper2  m_EventListeners;
+    bool                                m_bIsDescriptor;
+    const SwFormatFootnote *            m_pFormatFootnote;
     OUString             m_sLabel;
 
     Impl(   SwXFootnote & rThis,
-            SwFmtFtn *const pFootnote,
+            SwFormatFootnote *const pFootnote,
             const bool bIsEndnote)
         : SwClient(pFootnote)
         , m_rThis(rThis)
         , m_bIsEndnote(bIsEndnote)
         , m_EventListeners(m_Mutex)
-        , m_bIsDescriptor(0 == pFootnote)
-        , m_pFmtFtn(pFootnote)
+        , m_bIsDescriptor(nullptr == pFootnote)
+        , m_pFormatFootnote(pFootnote)
     {
     }
 
-    const SwFmtFtn* GetFootnoteFormat() const {
-        return m_rThis.GetDoc() ? m_pFmtFtn : 0;
+    const SwFormatFootnote* GetFootnoteFormat() const {
+        return m_rThis.GetDoc() ? m_pFormatFootnote : nullptr;
     }
 
-    SwFmtFtn const& GetFootnoteFormatOrThrow() {
-        SwFmtFtn const*const pFootnote( GetFootnoteFormat() );
+    SwFormatFootnote const& GetFootnoteFormatOrThrow() {
+        SwFormatFootnote const*const pFootnote( GetFootnoteFormat() );
         if (!pFootnote) {
-            throw uno::RuntimeException(OUString(
-                        "SwXFootnote: disposed or invalid"), 0);
+            throw uno::RuntimeException("SwXFootnote: disposed or invalid", nullptr);
         }
         return *pFootnote;
     }
@@ -89,7 +88,7 @@ public:
     void    Invalidate();
 protected:
     // SwClient
-    virtual void Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew) SAL_OVERRIDE;
+    virtual void Modify( const SfxPoolItem *pOld, const SfxPoolItem *pNew) override;
 
 };
 
@@ -97,10 +96,10 @@ void SwXFootnote::Impl::Invalidate()
 {
     if (GetRegisteredIn())
     {
-        const_cast<SwModify*>(GetRegisteredIn())->Remove(this);
+        GetRegisteredIn()->Remove(this);
     }
-    m_pFmtFtn = 0;
-    m_rThis.SetDoc(0);
+    m_pFormatFootnote = nullptr;
+    m_rThis.SetDoc(nullptr);
     uno::Reference<uno::XInterface> const xThis(m_wThis);
     if (!xThis.is())
     {   // fdo#72695: if UNO object is already dead, don't revive it with event
@@ -121,14 +120,14 @@ void SwXFootnote::Impl::Modify(const SfxPoolItem *pOld, const SfxPoolItem *pNew)
 }
 
 SwXFootnote::SwXFootnote(const bool bEndnote)
-    : SwXText(0, CURSOR_FOOTNOTE)
-    , m_pImpl( new SwXFootnote::Impl(*this, 0, bEndnote) )
+    : SwXText(nullptr, CursorType::Footnote)
+    , m_pImpl( new SwXFootnote::Impl(*this, nullptr, bEndnote) )
 {
 }
 
-SwXFootnote::SwXFootnote(SwDoc & rDoc, SwFmtFtn & rFmt)
-    : SwXText(& rDoc, CURSOR_FOOTNOTE)
-    , m_pImpl( new SwXFootnote::Impl(*this, &rFmt, rFmt.IsEndNote()) )
+SwXFootnote::SwXFootnote(SwDoc & rDoc, SwFormatFootnote & rFormat)
+    : SwXText(& rDoc, CursorType::Footnote)
+    , m_pImpl( new SwXFootnote::Impl(*this, &rFormat, rFormat.IsEndNote()) )
 {
 }
 
@@ -137,24 +136,24 @@ SwXFootnote::~SwXFootnote()
 }
 
 uno::Reference<text::XFootnote>
-SwXFootnote::CreateXFootnote(SwDoc & rDoc, SwFmtFtn *const pFootnoteFmt,
+SwXFootnote::CreateXFootnote(SwDoc & rDoc, SwFormatFootnote *const pFootnoteFormat,
         bool const isEndnote)
 {
     // i#105557: do not iterate over the registered clients: race condition
     uno::Reference<text::XFootnote> xNote;
-    if (pFootnoteFmt)
+    if (pFootnoteFormat)
     {
-        xNote = pFootnoteFmt->GetXFootnote();
+        xNote = pFootnoteFormat->GetXFootnote();
     }
     if (!xNote.is())
     {
-        SwXFootnote *const pNote((pFootnoteFmt)
-                ? new SwXFootnote(rDoc, *pFootnoteFmt)
+        SwXFootnote *const pNote(pFootnoteFormat
+                ? new SwXFootnote(rDoc, *pFootnoteFormat)
                 : new SwXFootnote(isEndnote));
         xNote.set(pNote);
-        if (pFootnoteFmt)
+        if (pFootnoteFormat)
         {
-            pFootnoteFmt->SetXFootnote(xNote);
+            pFootnoteFormat->SetXFootnote(xNote);
         }
         // need a permanent Reference to initialize m_wThis
         pNote->m_pImpl->m_wThis = xNote;
@@ -174,14 +173,13 @@ const uno::Sequence< sal_Int8 > & SwXFootnote::getUnoTunnelId()
 
 sal_Int64 SAL_CALL
 SwXFootnote::getSomething(const uno::Sequence< sal_Int8 >& rId)
-throw (uno::RuntimeException, std::exception)
 {
     const sal_Int64 nRet( ::sw::UnoTunnelImpl<SwXFootnote>(rId, this) );
-    return (nRet) ? nRet : SwXText::getSomething(rId);
+    return nRet ? nRet : SwXText::getSomething(rId);
 }
 
 OUString SAL_CALL
-SwXFootnote::getImplementationName() throw (uno::RuntimeException, std::exception)
+SwXFootnote::getImplementationName()
 {
     return OUString("SwXFootnote");
 }
@@ -194,18 +192,17 @@ static char const*const g_ServicesFootnote[] =
     "com.sun.star.text.Endnote", // NB: only supported for endnotes!
 };
 
-static const size_t g_nServicesEndnote( sizeof (g_ServicesFootnote) / sizeof (g_ServicesFootnote[0]) );
+static const size_t g_nServicesEndnote( SAL_N_ELEMENTS(g_ServicesFootnote) );
 
 static const size_t g_nServicesFootnote( g_nServicesEndnote - 1 ); // NB: omit!
 
 sal_Bool SAL_CALL SwXFootnote::supportsService(const OUString& rServiceName)
-throw (uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 uno::Sequence< OUString > SAL_CALL
-SwXFootnote::getSupportedServiceNames() throw (uno::RuntimeException, std::exception)
+SwXFootnote::getSupportedServiceNames()
 {
     SolarMutexGuard g;
     return ::sw::GetSupportedServiceNamesImpl(
@@ -214,7 +211,7 @@ SwXFootnote::getSupportedServiceNames() throw (uno::RuntimeException, std::excep
 }
 
 uno::Sequence< uno::Type > SAL_CALL
-SwXFootnote::getTypes() throw (uno::RuntimeException, std::exception)
+SwXFootnote::getTypes()
 {
     const uno::Sequence< uno::Type > aTypes = SwXFootnote_Base::getTypes();
     const uno::Sequence< uno::Type > aTextTypes = SwXText::getTypes();
@@ -222,30 +219,29 @@ SwXFootnote::getTypes() throw (uno::RuntimeException, std::exception)
 }
 
 uno::Sequence< sal_Int8 > SAL_CALL
-SwXFootnote::getImplementationId() throw (uno::RuntimeException, std::exception)
+SwXFootnote::getImplementationId()
 {
     return css::uno::Sequence<sal_Int8>();
 }
 
 uno::Any SAL_CALL
 SwXFootnote::queryInterface(const uno::Type& rType)
-throw (uno::RuntimeException, std::exception)
 {
     const uno::Any ret = SwXFootnote_Base::queryInterface(rType);
-    return (ret.getValueType() == ::getCppuVoidType())
+    return (ret.getValueType() == cppu::UnoType<void>::get())
         ?   SwXText::queryInterface(rType)
         :   ret;
 }
 
-OUString SAL_CALL SwXFootnote::getLabel() throw (uno::RuntimeException, std::exception)
+OUString SAL_CALL SwXFootnote::getLabel()
 {
     SolarMutexGuard aGuard;
 
     OUString sRet;
-    SwFmtFtn const*const pFmt = m_pImpl->GetFootnoteFormat();
-    if(pFmt)
+    SwFormatFootnote const*const pFormat = m_pImpl->GetFootnoteFormat();
+    if(pFormat)
     {
-        sRet = pFmt->GetNumStr();
+        sRet = pFormat->GetNumStr();
     }
     else if (m_pImpl->m_bIsDescriptor)
     {
@@ -259,23 +255,28 @@ OUString SAL_CALL SwXFootnote::getLabel() throw (uno::RuntimeException, std::exc
 }
 
 void SAL_CALL
-SwXFootnote::setLabel(const OUString& aLabel) throw (uno::RuntimeException, std::exception)
+SwXFootnote::setLabel(const OUString& aLabel)
 {
     SolarMutexGuard aGuard;
-
-    SwFmtFtn const*const pFmt = m_pImpl->GetFootnoteFormat();
-    if(pFmt)
+    OUString newLabel(aLabel);
+    //new line must not occur as footnote label
+    if(newLabel.indexOf('\n') >=0 )
     {
-        const SwTxtFtn* pTxtFtn = pFmt->GetTxtFtn();
-        OSL_ENSURE(pTxtFtn, "kein TextNode?");
-        SwTxtNode& rTxtNode = (SwTxtNode&)pTxtFtn->GetTxtNode();
+       newLabel = newLabel.replace('\n', ' ');
+    }
+    SwFormatFootnote const*const pFormat = m_pImpl->GetFootnoteFormat();
+    if(pFormat)
+    {
+        const SwTextFootnote* pTextFootnote = pFormat->GetTextFootnote();
+        OSL_ENSURE(pTextFootnote, "No TextNode?");
+        SwTextNode& rTextNode = const_cast<SwTextNode&>(pTextFootnote->GetTextNode());
 
-        SwPaM aPam(rTxtNode, pTxtFtn->GetStart());
-        GetDoc()->SetCurFtn(aPam, aLabel, pFmt->GetNumber(), pFmt->IsEndNote());
+        SwPaM aPam(rTextNode, pTextFootnote->GetStart());
+        GetDoc()->SetCurFootnote(aPam, newLabel, pFormat->GetNumber(), pFormat->IsEndNote());
     }
     else if (m_pImpl->m_bIsDescriptor)
     {
-        m_pImpl->m_sLabel = aLabel;
+        m_pImpl->m_sLabel = newLabel;
     }
     else
     {
@@ -285,7 +286,6 @@ SwXFootnote::setLabel(const OUString& aLabel) throw (uno::RuntimeException, std:
 
 void SAL_CALL
 SwXFootnote::attach(const uno::Reference< text::XTextRange > & xTextRange)
-throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -300,7 +300,7 @@ throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception)
     OTextCursorHelper *const pCursor =
         ::sw::UnoTunnelGetImplementation<OTextCursorHelper>(xRangeTunnel);
     SwDoc *const pNewDoc =
-        (pRange) ? pRange->GetDoc() : ((pCursor) ? pCursor->GetDoc() : 0);
+        pRange ? &pRange->GetDoc() : (pCursor ? pCursor->GetDoc() : nullptr);
     if (!pNewDoc)
     {
         throw lang::IllegalArgumentException();
@@ -313,7 +313,7 @@ throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception)
     UnoActionContext aCont(pNewDoc);
     pNewDoc->getIDocumentContentOperations().DeleteAndJoin(aPam);
     aPam.DeleteMark();
-    SwFmtFtn aFootNote(m_pImpl->m_bIsEndnote);
+    SwFormatFootnote aFootNote(m_pImpl->m_bIsEndnote);
     if (!m_pImpl->m_sLabel.isEmpty())
     {
         aFootNote.SetNumStr(m_pImpl->m_sLabel);
@@ -322,29 +322,29 @@ throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception)
     SwXTextCursor const*const pTextCursor(
             dynamic_cast<SwXTextCursor*>(pCursor));
     const bool bForceExpandHints( pTextCursor && pTextCursor->IsAtEndOfMeta() );
-    const SetAttrMode nInsertFlags = (bForceExpandHints)
-        ? nsSetAttrMode::SETATTR_FORCEHINTEXPAND
-        : nsSetAttrMode::SETATTR_DEFAULT;
+    const SetAttrMode nInsertFlags = bForceExpandHints
+        ? SetAttrMode::FORCEHINTEXPAND
+        : SetAttrMode::DEFAULT;
 
     pNewDoc->getIDocumentContentOperations().InsertPoolItem(aPam, aFootNote, nInsertFlags);
 
-    SwTxtFtn *const pTxtAttr = static_cast<SwTxtFtn*>(
-        aPam.GetNode().GetTxtNode()->GetTxtAttrForCharAt(
+    SwTextFootnote *const pTextAttr = static_cast<SwTextFootnote*>(
+        aPam.GetNode().GetTextNode()->GetTextAttrForCharAt(
                 aPam.GetPoint()->nContent.GetIndex()-1, RES_TXTATR_FTN ));
 
-    if (pTxtAttr)
+    if (pTextAttr)
     {
-        const SwFmtFtn& rFtn = pTxtAttr->GetFtn();
-        m_pImpl->m_pFmtFtn = &rFtn;
-        const_cast<SwFmtFtn*>(m_pImpl->m_pFmtFtn)->Add(m_pImpl.get());
+        const SwFormatFootnote& rFootnote = pTextAttr->GetFootnote();
+        m_pImpl->m_pFormatFootnote = &rFootnote;
+        const_cast<SwFormatFootnote*>(m_pImpl->m_pFormatFootnote)->Add(m_pImpl.get());
         // force creation of sequence id - is used for references
         if (pNewDoc->IsInReading())
         {
-            pTxtAttr->SetSeqNo(pNewDoc->GetFtnIdxs().size());
+            pTextAttr->SetSeqNo(pNewDoc->GetFootnoteIdxs().size());
         }
         else
         {
-            pTxtAttr->SetSeqRefNo();
+            pTextAttr->SetSeqRefNo();
         }
     }
     m_pImpl->m_bIsDescriptor = false;
@@ -352,40 +352,38 @@ throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception)
 }
 
 uno::Reference< text::XTextRange > SAL_CALL
-SwXFootnote::getAnchor() throw (uno::RuntimeException, std::exception)
+SwXFootnote::getAnchor()
 {
     SolarMutexGuard aGuard;
 
-    SwFmtFtn const& rFmt( m_pImpl->GetFootnoteFormatOrThrow() );
+    SwFormatFootnote const& rFormat( m_pImpl->GetFootnoteFormatOrThrow() );
 
-    SwTxtFtn const*const pTxtFtn = rFmt.GetTxtFtn();
-    SwPaM aPam( pTxtFtn->GetTxtNode(), pTxtFtn->GetStart() );
-    SwPosition aMark( *aPam.Start() );
+    SwTextFootnote const*const pTextFootnote = rFormat.GetTextFootnote();
+    SwPaM aPam( pTextFootnote->GetTextNode(), pTextFootnote->GetStart() );
     aPam.SetMark();
-    aPam.GetMark()->nContent++;
+    ++aPam.GetMark()->nContent;
     const uno::Reference< text::XTextRange > xRet =
         SwXTextRange::CreateXTextRange(*GetDoc(), *aPam.Start(), aPam.End());
     return xRet;
 }
 
-void SAL_CALL SwXFootnote::dispose() throw (uno::RuntimeException, std::exception)
+void SAL_CALL SwXFootnote::dispose()
 {
     SolarMutexGuard aGuard;
 
-    SwFmtFtn const& rFmt( m_pImpl->GetFootnoteFormatOrThrow() );
+    SwFormatFootnote const& rFormat( m_pImpl->GetFootnoteFormatOrThrow() );
 
-    SwTxtFtn const*const pTxtFtn = rFmt.GetTxtFtn();
-    OSL_ENSURE(pTxtFtn, "no TextNode?");
-    SwTxtNode& rTxtNode = const_cast<SwTxtNode&>(pTxtFtn->GetTxtNode());
-    const sal_Int32 nPos = pTxtFtn->GetStart();
-    SwPaM aPam(rTxtNode, nPos, rTxtNode, nPos+1);
+    SwTextFootnote const*const pTextFootnote = rFormat.GetTextFootnote();
+    OSL_ENSURE(pTextFootnote, "no TextNode?");
+    SwTextNode& rTextNode = const_cast<SwTextNode&>(pTextFootnote->GetTextNode());
+    const sal_Int32 nPos = pTextFootnote->GetStart();
+    SwPaM aPam(rTextNode, nPos, rTextNode, nPos+1);
     GetDoc()->getIDocumentContentOperations().DeleteAndJoin( aPam );
 }
 
 void SAL_CALL
 SwXFootnote::addEventListener(
     const uno::Reference< lang::XEventListener > & xListener)
-throw (uno::RuntimeException, std::exception)
 {
     // no need to lock here as m_pImpl is const and container threadsafe
     m_pImpl->m_EventListeners.addInterface(xListener);
@@ -394,7 +392,6 @@ throw (uno::RuntimeException, std::exception)
 void SAL_CALL
 SwXFootnote::removeEventListener(
     const uno::Reference< lang::XEventListener > & xListener)
-throw (uno::RuntimeException, std::exception)
 {
     // no need to lock here as m_pImpl is const and container threadsafe
     m_pImpl->m_EventListeners.removeInterface(xListener);
@@ -402,37 +399,37 @@ throw (uno::RuntimeException, std::exception)
 
 const SwStartNode *SwXFootnote::GetStartNode() const
 {
-    SwFmtFtn const*const   pFmt = m_pImpl->GetFootnoteFormat();
-    if(pFmt)
+    SwFormatFootnote const*const   pFormat = m_pImpl->GetFootnoteFormat();
+    if(pFormat)
     {
-        const SwTxtFtn* pTxtFtn = pFmt->GetTxtFtn();
-        if( pTxtFtn )
+        const SwTextFootnote* pTextFootnote = pFormat->GetTextFootnote();
+        if( pTextFootnote )
         {
-            return pTxtFtn->GetStartNode()->GetNode().GetStartNode();
+            return pTextFootnote->GetStartNode()->GetNode().GetStartNode();
         }
     }
-    return 0;
+    return nullptr;
 }
 
 uno::Reference< text::XTextCursor >
-SwXFootnote::CreateCursor() throw (uno::RuntimeException)
+SwXFootnote::CreateCursor()
 {
     return createTextCursor();
 }
 
 uno::Reference< text::XTextCursor > SAL_CALL
-SwXFootnote::createTextCursor() throw (uno::RuntimeException, std::exception)
+SwXFootnote::createTextCursor()
 {
     SolarMutexGuard aGuard;
 
-    SwFmtFtn const& rFmt( m_pImpl->GetFootnoteFormatOrThrow() );
+    SwFormatFootnote const& rFormat( m_pImpl->GetFootnoteFormatOrThrow() );
 
-    SwTxtFtn const*const pTxtFtn = rFmt.GetTxtFtn();
-    SwPosition aPos( *pTxtFtn->GetStartNode() );
+    SwTextFootnote const*const pTextFootnote = rFormat.GetTextFootnote();
+    SwPosition aPos( *pTextFootnote->GetStartNode() );
     SwXTextCursor *const pXCursor =
-        new SwXTextCursor(*GetDoc(), this, CURSOR_FOOTNOTE, aPos);
-    SwUnoCrsr *const pUnoCrsr = pXCursor->GetCursor();
-    pUnoCrsr->Move(fnMoveForward, fnGoNode);
+        new SwXTextCursor(*GetDoc(), this, CursorType::Footnote, aPos);
+    auto& rUnoCursor(pXCursor->GetCursor());
+    rUnoCursor.Move(fnMoveForward, GoInNode);
     const uno::Reference< text::XTextCursor > xRet =
         static_cast<text::XWordCursor*>(pXCursor);
     return xRet;
@@ -441,11 +438,10 @@ SwXFootnote::createTextCursor() throw (uno::RuntimeException, std::exception)
 uno::Reference< text::XTextCursor > SAL_CALL
 SwXFootnote::createTextCursorByRange(
     const uno::Reference< text::XTextRange > & xTextPosition)
-throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
-    SwFmtFtn const& rFmt( m_pImpl->GetFootnoteFormatOrThrow() );
+    SwFormatFootnote const& rFormat( m_pImpl->GetFootnoteFormatOrThrow() );
 
     SwUnoInternalPaM aPam(*GetDoc());
     if (!::sw::XTextRangeToSwPaM(aPam, xTextPosition))
@@ -453,52 +449,48 @@ throw (uno::RuntimeException, std::exception)
         throw uno::RuntimeException();
     }
 
-    SwTxtFtn const*const pTxtFtn = rFmt.GetTxtFtn();
-    SwNode const*const pFtnStartNode = &pTxtFtn->GetStartNode()->GetNode();
+    SwTextFootnote const*const pTextFootnote = rFormat.GetTextFootnote();
+    SwNode const*const pFootnoteStartNode = &pTextFootnote->GetStartNode()->GetNode();
 
     const SwNode* pStart = aPam.GetNode().FindFootnoteStartNode();
-    if (pStart != pFtnStartNode)
+    if (pStart != pFootnoteStartNode)
     {
         throw uno::RuntimeException();
     }
 
     const uno::Reference< text::XTextCursor > xRet =
         static_cast<text::XWordCursor*>(
-                new SwXTextCursor(*GetDoc(), this, CURSOR_FOOTNOTE,
+                new SwXTextCursor(*GetDoc(), this, CursorType::Footnote,
                     *aPam.GetPoint(), aPam.GetMark()));
     return xRet;
 }
 
 uno::Reference< container::XEnumeration > SAL_CALL
-SwXFootnote::createEnumeration() throw (uno::RuntimeException, std::exception)
+SwXFootnote::createEnumeration()
 {
     SolarMutexGuard aGuard;
 
-    SwFmtFtn const& rFmt( m_pImpl->GetFootnoteFormatOrThrow() );
+    SwFormatFootnote const& rFormat( m_pImpl->GetFootnoteFormatOrThrow() );
 
-    SwTxtFtn const*const pTxtFtn = rFmt.GetTxtFtn();
-    SwPosition aPos( *pTxtFtn->GetStartNode() );
-    ::std::unique_ptr<SwUnoCrsr> pUnoCursor(
-        GetDoc()->CreateUnoCrsr(aPos, false));
-    pUnoCursor->Move(fnMoveForward, fnGoNode);
-    const uno::Reference< container::XEnumeration >  xRet =
-        new SwXParagraphEnumeration(this, std::move(pUnoCursor), CURSOR_FOOTNOTE);
-    return xRet;
+    SwTextFootnote const*const pTextFootnote = rFormat.GetTextFootnote();
+    SwPosition aPos( *pTextFootnote->GetStartNode() );
+    auto pUnoCursor(GetDoc()->CreateUnoCursor(aPos));
+    pUnoCursor->Move(fnMoveForward, GoInNode);
+    return SwXParagraphEnumeration::Create(this, pUnoCursor, CursorType::Footnote);
 }
 
-uno::Type SAL_CALL SwXFootnote::getElementType() throw (uno::RuntimeException, std::exception)
+uno::Type SAL_CALL SwXFootnote::getElementType()
 {
     return cppu::UnoType<text::XTextRange>::get();
 }
 
-sal_Bool SAL_CALL SwXFootnote::hasElements() throw (uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL SwXFootnote::hasElements()
 {
-    return sal_True;
+    return true;
 }
 
 uno::Reference< beans::XPropertySetInfo > SAL_CALL
 SwXFootnote::getPropertySetInfo()
-throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
     static uno::Reference< beans::XPropertySetInfo > xRet =
@@ -509,9 +501,6 @@ throw (uno::RuntimeException, std::exception)
 
 void SAL_CALL
 SwXFootnote::setPropertyValue(const OUString&, const uno::Any&)
-throw (beans::UnknownPropertyException, beans::PropertyVetoException,
-        lang::IllegalArgumentException, lang::WrappedTargetException,
-        uno::RuntimeException, std::exception)
 {
     //no values to be set
     throw lang::IllegalArgumentException();
@@ -519,8 +508,6 @@ throw (beans::UnknownPropertyException, beans::PropertyVetoException,
 
 uno::Any SAL_CALL
 SwXFootnote::getPropertyValue(const OUString& rPropertyName)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-        uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -538,12 +525,12 @@ throw (beans::UnknownPropertyException, lang::WrappedTargetException,
         }
         else if (rPropertyName == UNO_NAME_REFERENCE_ID)
         {
-            SwFmtFtn const*const pFmt = m_pImpl->GetFootnoteFormat();
-            if (pFmt)
+            SwFormatFootnote const*const pFormat = m_pImpl->GetFootnoteFormat();
+            if (pFormat)
             {
-                SwTxtFtn const*const pTxtFtn = pFmt->GetTxtFtn();
-                OSL_ENSURE(pTxtFtn, "no TextNode?");
-                aRet <<= static_cast<sal_Int16>(pTxtFtn->GetSeqRefNo());
+                SwTextFootnote const*const pTextFootnote = pFormat->GetTextFootnote();
+                OSL_ENSURE(pTextFootnote, "no TextNode?");
+                aRet <<= static_cast<sal_Int16>(pTextFootnote->GetSeqRefNo());
             }
         }
         else
@@ -560,8 +547,6 @@ void SAL_CALL
 SwXFootnote::addPropertyChangeListener(
         const OUString& /*rPropertyName*/,
         const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-    uno::RuntimeException, std::exception)
 {
     OSL_FAIL("SwXFootnote::addPropertyChangeListener(): not implemented");
 }
@@ -570,8 +555,6 @@ void SAL_CALL
 SwXFootnote::removePropertyChangeListener(
         const OUString& /*rPropertyName*/,
         const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-    uno::RuntimeException, std::exception)
 {
     OSL_FAIL("SwXFootnote::removePropertyChangeListener(): not implemented");
 }
@@ -580,8 +563,6 @@ void SAL_CALL
 SwXFootnote::addVetoableChangeListener(
         const OUString& /*rPropertyName*/,
         const uno::Reference< beans::XVetoableChangeListener >& /*xListener*/)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-    uno::RuntimeException, std::exception)
 {
     OSL_FAIL("SwXFootnote::addVetoableChangeListener(): not implemented");
 }
@@ -590,8 +571,6 @@ void SAL_CALL
 SwXFootnote::removeVetoableChangeListener(
         const OUString& /*rPropertyName*/,
         const uno::Reference< beans::XVetoableChangeListener >& /*xListener*/)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-        uno::RuntimeException, std::exception)
 {
     OSL_FAIL("SwXFootnote::removeVetoableChangeListener(): not implemented");
 }
