@@ -20,7 +20,8 @@
 #include <unoport.hxx>
 
 #include <cmdid.h>
-#include <osl/mutex.hxx>
+#include <o3tl/make_unique.hxx>
+#include <cppuhelper/exc_hlp.hxx>
 #include <cppuhelper/interfacecontainer.h>
 #include <vcl/svapp.hxx>
 #include <svl/itemprop.hxx>
@@ -43,103 +44,79 @@
 #include <com/sun/star/beans/SetPropertyTolerantFailed.hpp>
 #include <com/sun/star/beans/GetPropertyTolerantResult.hpp>
 #include <com/sun/star/beans/TolerantPropertySetResultType.hpp>
+#include <com/sun/star/lang/WrappedTargetRuntimeException.hpp>
 #include <comphelper/servicehelper.hxx>
 #include <cppuhelper/supportsservice.hxx>
-
+#include <comphelper/sequence.hxx>
 
 using namespace ::com::sun::star;
 
-/******************************************************************
- * SwXTextPortion
- ******************************************************************/
-
-class SwXTextPortion::Impl
+void SwXTextPortion::init(const SwUnoCursor* pPortionCursor)
 {
-private:
-    ::osl::Mutex m_Mutex; // just for OInterfaceContainerHelper
-
-public:
-    ::cppu::OInterfaceContainerHelper m_EventListeners;
-
-    Impl() : m_EventListeners(m_Mutex) { }
-};
-
-void SwXTextPortion::init(const SwUnoCrsr* pPortionCursor)
-{
-    SwUnoCrsr* pUnoCursor =
-        pPortionCursor->GetDoc()->CreateUnoCrsr(*pPortionCursor->GetPoint());
+    m_pUnoCursor = pPortionCursor->GetDoc()->CreateUnoCursor(*pPortionCursor->GetPoint());
     if (pPortionCursor->HasMark())
     {
-        pUnoCursor->SetMark();
-        *pUnoCursor->GetMark() = *pPortionCursor->GetMark();
+        m_pUnoCursor->SetMark();
+        *m_pUnoCursor->GetMark() = *pPortionCursor->GetMark();
     }
-    pUnoCursor->Add(this);
 }
 
-SwXTextPortion::SwXTextPortion(const SwUnoCrsr* pPortionCrsr,
+SwXTextPortion::SwXTextPortion(
+    const SwUnoCursor* pPortionCursor,
         uno::Reference< text::XText > const& rParent,
         SwTextPortionType eType)
-    : m_pImpl(new Impl)
-    , m_pPropSet(aSwMapProvider.GetPropertySet(
+    : m_pPropSet(aSwMapProvider.GetPropertySet(
         (PORTION_REDLINE_START == eType ||
          PORTION_REDLINE_END   == eType)
             ?  PROPERTY_MAP_REDLINE_PORTION
             :  PROPERTY_MAP_TEXTPORTION_EXTENSIONS))
     , m_xParentText(rParent)
-    , m_pRubyText(0)
-    , m_pRubyStyle(0)
-    , m_pRubyAdjust(0)
-    , m_pRubyIsAbove(0)
-    , m_FrameDepend(this, 0)
-    , m_pFrameFmt(0)
+    , m_FrameDepend(this, nullptr)
+    , m_pFrameFormat(nullptr)
     , m_ePortionType(eType)
     , m_bIsCollapsed(false)
 {
-    init( pPortionCrsr);
+    init( pPortionCursor);
 }
 
-SwXTextPortion::SwXTextPortion(const SwUnoCrsr* pPortionCrsr,
-        uno::Reference< text::XText > const& rParent,
-        SwFrmFmt& rFmt )
-    : m_pImpl(new Impl)
-    , m_pPropSet(aSwMapProvider.GetPropertySet(
+SwXTextPortion::SwXTextPortion(
+    const SwUnoCursor* pPortionCursor,
+    uno::Reference< text::XText > const& rParent,
+    SwFrameFormat& rFormat )
+    : m_pPropSet(aSwMapProvider.GetPropertySet(
                     PROPERTY_MAP_TEXTPORTION_EXTENSIONS))
     , m_xParentText(rParent)
-    , m_pRubyText(0)
-    , m_pRubyStyle(0)
-    , m_pRubyAdjust(0)
-    , m_pRubyIsAbove(0)
-    , m_FrameDepend(this, &rFmt)
-    , m_pFrameFmt(&rFmt)
+    , m_FrameDepend(this, &rFormat)
+    , m_pFrameFormat(&rFormat)
     , m_ePortionType(PORTION_FRAME)
     , m_bIsCollapsed(false)
 {
-    init( pPortionCrsr);
+    init( pPortionCursor);
 }
 
-SwXTextPortion::SwXTextPortion(const SwUnoCrsr* pPortionCrsr,
-                    SwTxtRuby const& rAttr,
-                    uno::Reference< text::XText > const& xParent,
-                    sal_Bool bIsEnd )
-    : m_pImpl(new Impl)
-    , m_pPropSet(aSwMapProvider.GetPropertySet(
+SwXTextPortion::SwXTextPortion(
+    const SwUnoCursor* pPortionCursor,
+    SwTextRuby const& rAttr,
+    uno::Reference< text::XText > const& xParent,
+    bool bIsEnd )
+    : m_pPropSet(aSwMapProvider.GetPropertySet(
                     PROPERTY_MAP_TEXTPORTION_EXTENSIONS))
     , m_xParentText(xParent)
-    , m_pRubyText   ( bIsEnd ? 0 : new uno::Any )
-    , m_pRubyStyle  ( bIsEnd ? 0 : new uno::Any )
-    , m_pRubyAdjust ( bIsEnd ? 0 : new uno::Any )
-    , m_pRubyIsAbove( bIsEnd ? 0 : new uno::Any )
-    , m_FrameDepend(this, 0)
-    , m_pFrameFmt(0)
+    , m_pRubyText   ( bIsEnd ? nullptr : new uno::Any )
+    , m_pRubyStyle  ( bIsEnd ? nullptr : new uno::Any )
+    , m_pRubyAdjust ( bIsEnd ? nullptr : new uno::Any )
+    , m_pRubyIsAbove( bIsEnd ? nullptr : new uno::Any )
+    , m_FrameDepend(this, nullptr)
+    , m_pFrameFormat(nullptr)
     , m_ePortionType( bIsEnd ? PORTION_RUBY_END : PORTION_RUBY_START )
     , m_bIsCollapsed(false)
 {
-    init( pPortionCrsr);
+    init( pPortionCursor);
 
     if (!bIsEnd)
     {
         const SfxPoolItem& rItem = rAttr.GetAttr();
-        rItem.QueryValue(*m_pRubyText, MID_RUBY_TEXT);
+        rItem.QueryValue(*m_pRubyText);
         rItem.QueryValue(*m_pRubyStyle, MID_RUBY_CHARSTYLE);
         rItem.QueryValue(*m_pRubyAdjust, MID_RUBY_ADJUST);
         rItem.QueryValue(*m_pRubyIsAbove, MID_RUBY_ABOVE);
@@ -149,83 +126,74 @@ SwXTextPortion::SwXTextPortion(const SwUnoCrsr* pPortionCrsr,
 SwXTextPortion::~SwXTextPortion()
 {
     SolarMutexGuard aGuard;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    delete pUnoCrsr;
+    m_pUnoCursor.reset(nullptr);
+    if(m_FrameDepend.GetRegisteredIn())
+    {
+        auto pFrameDepend(const_cast<SwDepend*>(&m_FrameDepend));
+        pFrameDepend->GetRegisteredIn()->Remove(pFrameDepend);
+    }
 }
 
 uno::Reference< text::XText >  SwXTextPortion::getText()
-throw( uno::RuntimeException )
 {
     return m_xParentText;
 }
 
 uno::Reference< text::XTextRange >  SwXTextPortion::getStart()
-throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
     uno::Reference< text::XTextRange >  xRet;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
-    SwPaM aPam(*pUnoCrsr->Start());
+    SwPaM aPam(*rUnoCursor.Start());
     uno::Reference< text::XText > xParent = getText();
     xRet = new SwXTextRange(aPam, xParent);
     return xRet;
 }
 
 uno::Reference< text::XTextRange >  SwXTextPortion::getEnd()
-throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
     uno::Reference< text::XTextRange >  xRet;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
-    SwPaM aPam(*pUnoCrsr->End());
+    SwPaM aPam(*rUnoCursor.End());
     uno::Reference< text::XText > xParent = getText();
     xRet = new SwXTextRange(aPam, xParent);
     return xRet;
 }
 
 OUString SwXTextPortion::getString()
-throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
-    OUString aTxt;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    OUString aText;
+    SwUnoCursor& rUnoCursor = GetCursor();
 
     // TextPortions are always within a paragraph
-    SwTxtNode* pTxtNd = pUnoCrsr->GetNode()->GetTxtNode();
-    if ( pTxtNd )
+    SwTextNode* pTextNd = rUnoCursor.GetNode().GetTextNode();
+    if ( pTextNd )
     {
-        const sal_Int32 nStt = pUnoCrsr->Start()->nContent.GetIndex();
-        aTxt = pTxtNd->GetExpandTxt( nStt,
-                pUnoCrsr->End()->nContent.GetIndex() - nStt );
+        const sal_Int32 nStt = rUnoCursor.Start()->nContent.GetIndex();
+        aText = pTextNd->GetExpandText( nStt,
+                rUnoCursor.End()->nContent.GetIndex() - nStt );
     }
-    return aTxt;
+    return aText;
 }
 
-void SwXTextPortion::setString(const OUString& aString) throw( uno::RuntimeException )
+void SwXTextPortion::setString(const OUString& aString)
 {
     SolarMutexGuard aGuard;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
-    SwUnoCursorHelper::SetString(*pUnoCrsr, aString);
+    SwUnoCursorHelper::SetString(rUnoCursor, aString);
 }
 
 uno::Reference< beans::XPropertySetInfo >  SwXTextPortion::getPropertySetInfo()
-throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
     //! PropertySetInfo for text portion extensions
     static uno::Reference< beans::XPropertySetInfo >
-            xTxtPorExtRef = aSwMapProvider.GetPropertySet(
+            xTextPorExtRef = aSwMapProvider.GetPropertySet(
                     PROPERTY_MAP_TEXTPORTION_EXTENSIONS)->getPropertySetInfo();
     //! PropertySetInfo for redline portions
     static uno::Reference< beans::XPropertySetInfo >
@@ -233,33 +201,29 @@ throw( uno::RuntimeException )
                     PROPERTY_MAP_REDLINE_PORTION)->getPropertySetInfo();
 
     return (PORTION_REDLINE_START == m_ePortionType ||
-            PORTION_REDLINE_END   == m_ePortionType) ? xRedlPorRef : xTxtPorExtRef;
+            PORTION_REDLINE_END   == m_ePortionType) ? xRedlPorRef : xTextPorExtRef;
 }
 
 void SwXTextPortion::setPropertyValue(const OUString& rPropertyName,
     const uno::Any& aValue)
-    throw( beans::UnknownPropertyException,
-        beans::PropertyVetoException, lang::IllegalArgumentException, lang::WrappedTargetException, uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
-    SwUnoCursorHelper::SetPropertyValue(*pUnoCrsr, *m_pPropSet,
+    SwUnoCursorHelper::SetPropertyValue(rUnoCursor, *m_pPropSet,
             rPropertyName, aValue);
 }
 
 void SwXTextPortion::GetPropertyValue(
         uno::Any &rVal,
         const SfxItemPropertySimpleEntry& rEntry,
-        SwUnoCrsr *pUnoCrsr,
-        SfxItemSet *&pSet )
+        SwUnoCursor *pUnoCursor,
+        std::unique_ptr<SfxItemSet> &pSet )
 {
-    OSL_ENSURE( pUnoCrsr, "UNO cursor missing" );
-    if (!pUnoCrsr)
+    OSL_ENSURE( pUnoCursor, "UNO cursor missing" );
+    if (!pUnoCursor)
         return;
-    if(pUnoCrsr)
+    if(pUnoCursor)
     {
         switch(rEntry.nWID)
         {
@@ -273,22 +237,28 @@ void SwXTextPortion::GetPropertyValue(
                 case PORTION_FRAME:         pRet = "Frame";break;
                 case PORTION_FOOTNOTE:      pRet = "Footnote";break;
                 case PORTION_REFMARK_START:
-                case PORTION_REFMARK_END:   pRet = SW_PROP_NAME_STR(UNO_NAME_REFERENCE_MARK);break;
+                case PORTION_REFMARK_END:   pRet = UNO_NAME_REFERENCE_MARK;break;
                 case PORTION_TOXMARK_START:
-                case PORTION_TOXMARK_END:   pRet = SW_PROP_NAME_STR(UNO_NAME_DOCUMENT_INDEX_MARK);break;
+                case PORTION_TOXMARK_END:   pRet = UNO_NAME_DOCUMENT_INDEX_MARK;break;
                 case PORTION_BOOKMARK_START :
-                case PORTION_BOOKMARK_END : pRet = SW_PROP_NAME_STR(UNO_NAME_BOOKMARK);break;
+                case PORTION_BOOKMARK_END : pRet = UNO_NAME_BOOKMARK;break;
                 case PORTION_REDLINE_START:
                 case PORTION_REDLINE_END:   pRet = "Redline";break;
                 case PORTION_RUBY_START:
                 case PORTION_RUBY_END:      pRet = "Ruby";break;
                 case PORTION_SOFT_PAGEBREAK:pRet = "SoftPageBreak";break;
-                case PORTION_META:          pRet = SW_PROP_NAME_STR(UNO_NAME_META); break;
+                case PORTION_META:          pRet = UNO_NAME_META; break;
                 case PORTION_FIELD_START:pRet = "TextFieldStart";break;
                 case PORTION_FIELD_END:pRet = "TextFieldEnd";break;
                 case PORTION_FIELD_START_END:pRet = "TextFieldStartEnd";break;
+                case PORTION_ANNOTATION:
+                    pRet = "Annotation";
+                    break;
+                case PORTION_ANNOTATION_END:
+                    pRet = "AnnotationEnd";
+                    break;
                 default:
-                    pRet = 0;
+                    pRet = nullptr;
                 }
 
                 OUString sRet;
@@ -333,7 +303,7 @@ void SwXTextPortion::GetPropertyValue(
                     case PORTION_RUBY_END:
                     case PORTION_FIELD_START:
                     case PORTION_FIELD_END:
-                        rVal.setValue(&m_bIsCollapsed, ::getBooleanCppuType());
+                        rVal <<= m_bIsCollapsed;
                     break;
                     default:
                     break;
@@ -342,7 +312,7 @@ void SwXTextPortion::GetPropertyValue(
             break;
             case FN_UNO_IS_START:
             {
-                sal_Bool bStart = sal_True, bPut = sal_True;
+                bool bStart = true, bPut = true;
                 switch (m_ePortionType)
                 {
                     case PORTION_REFMARK_START:
@@ -359,18 +329,18 @@ void SwXTextPortion::GetPropertyValue(
                     case PORTION_REDLINE_END:
                     case PORTION_RUBY_END:
                     case PORTION_FIELD_END:
-                        bStart = sal_False;
+                        bStart = false;
                     break;
                     default:
-                        bPut = sal_False;
+                        bPut = false;
                 }
                 if(bPut)
-                    rVal.setValue(&bStart, ::getBooleanCppuType());
+                    rVal <<= bStart;
             }
             break;
             case RES_TXTATR_CJK_RUBY:
             {
-                const uno::Any* pToSet = 0;
+                const uno::Any* pToSet = nullptr;
                 switch(rEntry.nMemberId)
                 {
                     case MID_RUBY_TEXT :    pToSet = m_pRubyText.get();   break;
@@ -384,18 +354,19 @@ void SwXTextPortion::GetPropertyValue(
             break;
             default:
                 beans::PropertyState eTemp;
-                bool bDone = SwUnoCursorHelper::getCrsrPropertyValue(
-                                    rEntry, *pUnoCrsr, &(rVal), eTemp );
+                bool bDone = SwUnoCursorHelper::getCursorPropertyValue(
+                                    rEntry, *pUnoCursor, &rVal, eTemp );
                 if(!bDone)
                 {
                     if(!pSet)
                     {
-                        pSet = new SfxItemSet(pUnoCrsr->GetDoc()->GetAttrPool(),
-                            RES_CHRATR_BEGIN, RES_FRMATR_END - 1,
-                            RES_UNKNOWNATR_CONTAINER, RES_UNKNOWNATR_CONTAINER,
-                            RES_TXTATR_UNKNOWN_CONTAINER, RES_TXTATR_UNKNOWN_CONTAINER,
-                            0L);
-                        SwUnoCursorHelper::GetCrsrAttr(*pUnoCrsr, *pSet);
+                        pSet = o3tl::make_unique<SfxItemSet>(
+                            pUnoCursor->GetDoc()->GetAttrPool(),
+                            svl::Items<
+                                RES_CHRATR_BEGIN, RES_FRMATR_END - 1,
+                                RES_UNKNOWNATR_CONTAINER,
+                                    RES_UNKNOWNATR_CONTAINER>{});
+                        SwUnoCursorHelper::GetCursorAttr(*pUnoCursor, *pSet);
                     }
                     m_pPropSet->getPropertyValue(rEntry, *pSet, rVal);
                 }
@@ -405,55 +376,42 @@ void SwXTextPortion::GetPropertyValue(
 
 uno::Sequence< uno::Any > SAL_CALL SwXTextPortion::GetPropertyValues_Impl(
         const uno::Sequence< OUString >& rPropertyNames )
-    throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     sal_Int32 nLength = rPropertyNames.getLength();
     const OUString *pPropertyNames = rPropertyNames.getConstArray();
     uno::Sequence< uno::Any > aValues(rPropertyNames.getLength());
     uno::Any *pValues = aValues.getArray();
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
     {
-        SfxItemSet *pSet = 0;
-        // get startting pount fo the look-up, either the provided one or else
+        std::unique_ptr<SfxItemSet> pSet;
+        // get starting point for the look-up, either the provided one or else
         // from the beginning of the map
         const SfxItemPropertyMap& rMap = m_pPropSet->getPropertyMap();
         for(sal_Int32 nProp = 0; nProp < nLength; nProp++)
         {
             const SfxItemPropertySimpleEntry* pEntry = rMap.getByName(pPropertyNames[nProp]);
-            if(pEntry)
-            {
-                GetPropertyValue( pValues[nProp], *pEntry, pUnoCrsr, pSet );
-            }
-            else
-                throw beans::UnknownPropertyException(OUString( "Unknown property: " ) + pPropertyNames[nProp], static_cast < cppu::OWeakObject * > ( this ) );
+            if(!pEntry)
+                throw beans::UnknownPropertyException( "Unknown property: " + pPropertyNames[nProp], static_cast < cppu::OWeakObject * > ( this ) );
+            GetPropertyValue( pValues[nProp], *pEntry, &rUnoCursor, pSet );
         }
-        delete pSet;
     }
     return aValues;
 }
 
 uno::Any SwXTextPortion::getPropertyValue(
     const OUString& rPropertyName)
-        throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
-    uno::Sequence< OUString > aPropertyNames(1);
-    aPropertyNames.getArray()[0] = rPropertyName;
+    uno::Sequence< OUString > aPropertyNames { rPropertyName };
     return GetPropertyValues_Impl(aPropertyNames).getConstArray()[0];
 }
 
 void SAL_CALL SwXTextPortion::SetPropertyValues_Impl(
     const uno::Sequence< OUString >& rPropertyNames,
     const uno::Sequence< uno::Any >& rValues )
-    throw( beans::UnknownPropertyException, beans::PropertyVetoException, lang::IllegalArgumentException,
-            lang::WrappedTargetException, uno::RuntimeException)
 {
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
     {
         const OUString* pPropertyNames = rPropertyNames.getConstArray();
@@ -464,22 +422,20 @@ void SAL_CALL SwXTextPortion::SetPropertyValues_Impl(
         {
             const SfxItemPropertySimpleEntry* pEntry = rMap.getByName(pPropertyNames[nProp]);
             if (!pEntry)
-                throw beans::UnknownPropertyException(OUString( "Unknown property: " ) + pPropertyNames[nProp], static_cast < cppu::OWeakObject * > ( this ) );
+                throw beans::UnknownPropertyException( "Unknown property: " + pPropertyNames[nProp], static_cast < cppu::OWeakObject * > ( this ) );
             if ( pEntry->nFlags & beans::PropertyAttribute::READONLY)
                 throw beans::PropertyVetoException ("Property is read-only: " + pPropertyNames[nProp], static_cast < cppu::OWeakObject * > ( this ) );
 
             aValues[nProp].Name = pPropertyNames[nProp];
             aValues[nProp].Value = pValues[nProp];
         }
-        SwUnoCursorHelper::SetPropertyValues( *pUnoCrsr, *m_pPropSet, aValues );
+        SwUnoCursorHelper::SetPropertyValues( rUnoCursor, *m_pPropSet, aValues );
     }
 }
 
 void SwXTextPortion::setPropertyValues(
     const uno::Sequence< OUString >& rPropertyNames,
     const uno::Sequence< uno::Any >& rValues )
-        throw(beans::PropertyVetoException, lang::IllegalArgumentException,
-            lang::WrappedTargetException, uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
 
@@ -500,7 +456,6 @@ void SwXTextPortion::setPropertyValues(
 
 uno::Sequence< uno::Any > SwXTextPortion::getPropertyValues(
     const uno::Sequence< OUString >& rPropertyNames )
-        throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     uno::Sequence< uno::Any > aValues;
@@ -526,15 +481,12 @@ uno::Sequence< uno::Any > SwXTextPortion::getPropertyValues(
 uno::Sequence< beans::SetPropertyTolerantFailed > SAL_CALL SwXTextPortion::setPropertyValuesTolerant(
         const uno::Sequence< OUString >& rPropertyNames,
         const uno::Sequence< uno::Any >& rValues )
-    throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
 
     if (rPropertyNames.getLength() != rValues.getLength())
         throw lang::IllegalArgumentException();
-    SwUnoCrsr* pUnoCrsr = this->GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
     sal_Int32 nProps = rPropertyNames.getLength();
     const OUString *pProp = rPropertyNames.getConstArray();
@@ -566,7 +518,7 @@ uno::Sequence< beans::SetPropertyTolerantFailed > SAL_CALL SwXTextPortion::setPr
                 else
                 {
                     SwUnoCursorHelper::SetPropertyValue(
-                                *pUnoCrsr, *m_pPropSet, pProp[i], pValue[i] );
+                                rUnoCursor, *m_pPropSet, pProp[i], pValue[i] );
                 }
             }
         }
@@ -596,12 +548,11 @@ uno::Sequence< beans::SetPropertyTolerantFailed > SAL_CALL SwXTextPortion::setPr
 
 uno::Sequence< beans::GetPropertyTolerantResult > SAL_CALL SwXTextPortion::getPropertyValuesTolerant(
         const uno::Sequence< OUString >& rPropertyNames )
-    throw (uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
 
     uno::Sequence< beans::GetDirectPropertyTolerantResult > aTmpRes(
-            GetPropertyValuesTolerant_Impl( rPropertyNames, sal_False ) );
+            GetPropertyValuesTolerant_Impl( rPropertyNames, false ) );
     const beans::GetDirectPropertyTolerantResult *pTmpRes = aTmpRes.getConstArray();
 
     // copy temporary result to final result type
@@ -615,154 +566,151 @@ uno::Sequence< beans::GetPropertyTolerantResult > SAL_CALL SwXTextPortion::getPr
 
 uno::Sequence< beans::GetDirectPropertyTolerantResult > SAL_CALL SwXTextPortion::getDirectPropertyValuesTolerant(
         const uno::Sequence< OUString >& rPropertyNames )
-    throw (uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
-    return GetPropertyValuesTolerant_Impl( rPropertyNames, sal_True );
+    return GetPropertyValuesTolerant_Impl( rPropertyNames, true );
 }
 
 uno::Sequence< beans::GetDirectPropertyTolerantResult > SAL_CALL SwXTextPortion::GetPropertyValuesTolerant_Impl(
         const uno::Sequence< OUString >& rPropertyNames,
-        sal_Bool bDirectValuesOnly )
-    throw (uno::RuntimeException)
+        bool bDirectValuesOnly )
 {
     SolarMutexGuard aGuard;
 
-    SwUnoCrsr* pUnoCrsr = this->GetCursor();
-    if(!pUnoCrsr)
-        throw uno::RuntimeException();
-
-    sal_Int32 nProps = rPropertyNames.getLength();
-    const OUString *pProp = rPropertyNames.getConstArray();
-
-    SfxItemSet *pSet = 0;
-
-    const SfxItemPropertyMap& rPropMap = m_pPropSet->getPropertyMap();
-
-    uno::Sequence< beans::PropertyState > aPropertyStates =
-        SwUnoCursorHelper::GetPropertyStates(
-            *pUnoCrsr, *m_pPropSet,
-            rPropertyNames,
-            SW_PROPERTY_STATE_CALLER_SWX_TEXT_PORTION_TOLERANT );
-    const beans::PropertyState* pPropertyStates = aPropertyStates.getConstArray();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
     std::vector< beans::GetDirectPropertyTolerantResult > aResultVector;
-    for (sal_Int32 i = 0;  i < nProps;  ++i)
+
+    try
     {
-        beans::GetDirectPropertyTolerantResult aResult;
-        try
+        sal_Int32 nProps = rPropertyNames.getLength();
+        const OUString *pProp = rPropertyNames.getConstArray();
+
+        std::unique_ptr<SfxItemSet> pSet;
+
+        const SfxItemPropertyMap& rPropMap = m_pPropSet->getPropertyMap();
+
+
+        uno::Sequence< beans::PropertyState > aPropertyStates =
+            SwUnoCursorHelper::GetPropertyStates(
+                rUnoCursor, *m_pPropSet,
+                rPropertyNames,
+                SW_PROPERTY_STATE_CALLER_SWX_TEXT_PORTION_TOLERANT );
+        const beans::PropertyState* pPropertyStates = aPropertyStates.getConstArray();
+
+        for (sal_Int32 i = 0;  i < nProps;  ++i)
         {
-            aResult.Name = pProp[i];
-            if(pPropertyStates[i] == beans::PropertyState_MAKE_FIXED_SIZE)     // property unknown?
+            beans::GetDirectPropertyTolerantResult aResult;
+            try
             {
-                if( bDirectValuesOnly )
-                    continue;
+                aResult.Name = pProp[i];
+                if(pPropertyStates[i] == beans::PropertyState::PropertyState_MAKE_FIXED_SIZE)     // property unknown?
+                {
+                    if( bDirectValuesOnly )
+                        continue;
+                    else
+                        aResult.Result = beans::TolerantPropertySetResultType::UNKNOWN_PROPERTY;
+                }
                 else
-                    aResult.Result = beans::TolerantPropertySetResultType::UNKNOWN_PROPERTY;
+                {
+                    const SfxItemPropertySimpleEntry* pEntry = rPropMap.getByName( pProp[i] );
+                    if (!pEntry)
+                        throw beans::UnknownPropertyException( "Unknown property: " + pProp[i], static_cast < cppu::OWeakObject * > ( this ) );
+                    aResult.State  = pPropertyStates[i];
+
+                    aResult.Result = beans::TolerantPropertySetResultType::UNKNOWN_FAILURE;
+                    //#i104499# ruby portion attributes need special handling:
+                    if( pEntry->nWID == RES_TXTATR_CJK_RUBY &&
+                        m_ePortionType == PORTION_RUBY_START )
+                    {
+                            aResult.State = beans::PropertyState_DIRECT_VALUE;
+                    }
+                    if (!bDirectValuesOnly  ||  beans::PropertyState_DIRECT_VALUE == aResult.State)
+                    {
+                        // get property value
+                        // (compare to SwXTextPortion::getPropertyValue(s))
+                        GetPropertyValue( aResult.Value, *pEntry, &rUnoCursor, pSet );
+                        aResult.Result = beans::TolerantPropertySetResultType::SUCCESS;
+                        aResultVector.push_back( aResult );
+                    }
+                }
             }
-            else
+            catch (const beans::UnknownPropertyException &)
             {
-                  const SfxItemPropertySimpleEntry* pEntry = rPropMap.getByName( pProp[i] );
-                aResult.State  = pPropertyStates[i];
-
-                aResult.Result = beans::TolerantPropertySetResultType::UNKNOWN_FAILURE;
-                //#i104499# ruby portion attributes need special handling:
-                if( pEntry->nWID == RES_TXTATR_CJK_RUBY &&
-                    m_ePortionType == PORTION_RUBY_START )
-                {
-                        aResult.State = beans::PropertyState_DIRECT_VALUE;
-                }
-                if (!bDirectValuesOnly  ||  beans::PropertyState_DIRECT_VALUE == aResult.State)
-                {
-                    // get property value
-                    // (compare to SwXTextPortion::getPropertyValue(s))
-                    GetPropertyValue( aResult.Value, *pEntry, pUnoCrsr, pSet );
-                    aResult.Result = beans::TolerantPropertySetResultType::SUCCESS;
-                    aResultVector.push_back( aResult );
-                }
+                // should not occur because property was searched for before
+                OSL_FAIL( "unexpected exception caught" );
+                aResult.Result = beans::TolerantPropertySetResultType::UNKNOWN_PROPERTY;
+            }
+            catch (const lang::IllegalArgumentException &)
+            {
+                aResult.Result = beans::TolerantPropertySetResultType::ILLEGAL_ARGUMENT;
+            }
+            catch (const beans::PropertyVetoException &)
+            {
+                aResult.Result = beans::TolerantPropertySetResultType::PROPERTY_VETO;
+            }
+            catch (const lang::WrappedTargetException &)
+            {
+                aResult.Result = beans::TolerantPropertySetResultType::WRAPPED_TARGET;
             }
         }
-        catch (beans::UnknownPropertyException &)
-        {
-            // should not occur because property was searched for before
-            OSL_FAIL( "unexpected exception caught" );
-            aResult.Result = beans::TolerantPropertySetResultType::UNKNOWN_PROPERTY;
-        }
-        catch (lang::IllegalArgumentException &)
-        {
-            aResult.Result = beans::TolerantPropertySetResultType::ILLEGAL_ARGUMENT;
-        }
-        catch (beans::PropertyVetoException &)
-        {
-            aResult.Result = beans::TolerantPropertySetResultType::PROPERTY_VETO;
-        }
-        catch (lang::WrappedTargetException &)
-        {
-            aResult.Result = beans::TolerantPropertySetResultType::WRAPPED_TARGET;
-        }
     }
-    delete pSet;
-
-    uno::Sequence< beans::GetDirectPropertyTolerantResult > aResult( aResultVector.size() );
-    std::vector< beans::GetDirectPropertyTolerantResult >::const_iterator aIt = aResultVector.begin();
-    beans::GetDirectPropertyTolerantResult *pResult = aResult.getArray();
-    for( sal_Int32 nResult = 0; nResult < aResult.getLength(); ++nResult )
+    catch (const uno::RuntimeException&)
     {
-        pResult[nResult] = *aIt;
-        ++aIt;
+        throw;
+    }
+    catch (const uno::Exception& e)
+    {
+        css::uno::Any a(cppu::getCaughtException());
+        throw css::lang::WrappedTargetRuntimeException(
+            "wrapped Exception " + e.Message,
+            css::uno::Reference<css::uno::XInterface>(), a);
     }
 
-    return aResult;
+    return comphelper::containerToSequence(aResultVector);
 }
 
 void SwXTextPortion::addPropertiesChangeListener(
     const uno::Sequence< OUString >& /*aPropertyNames*/,
     const uno::Reference< beans::XPropertiesChangeListener >& /*xListener*/ )
-        throw(uno::RuntimeException)
 {}
 
 void SwXTextPortion::removePropertiesChangeListener(
     const uno::Reference< beans::XPropertiesChangeListener >& /*xListener*/ )
-        throw(uno::RuntimeException)
 {}
 
 void SwXTextPortion::firePropertiesChangeEvent(
     const uno::Sequence< OUString >& /*aPropertyNames*/,
     const uno::Reference< beans::XPropertiesChangeListener >& /*xListener*/ )
-        throw(uno::RuntimeException)
 {}
 
 void SwXTextPortion::addPropertyChangeListener(
     const OUString& /*PropertyName*/,
     const uno::Reference< beans::XPropertyChangeListener > & /*xListener*/)
-        throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     OSL_FAIL("not implemented");
 }
 
-void SwXTextPortion::removePropertyChangeListener(const OUString& /*rPropertyName*/, const uno::Reference< beans::XPropertyChangeListener > & /*aListener*/) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextPortion::removePropertyChangeListener(const OUString& /*rPropertyName*/, const uno::Reference< beans::XPropertyChangeListener > & /*aListener*/)
 {
     OSL_FAIL("not implemented");
 }
 
-void SwXTextPortion::addVetoableChangeListener(const OUString& /*rPropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextPortion::addVetoableChangeListener(const OUString& /*rPropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/)
 {
     OSL_FAIL("not implemented");
 }
 
-void SwXTextPortion::removeVetoableChangeListener(const OUString& /*rPropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/) throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
+void SwXTextPortion::removeVetoableChangeListener(const OUString& /*rPropertyName*/, const uno::Reference< beans::XVetoableChangeListener > & /*aListener*/)
 {
     OSL_FAIL("not implemented");
 }
 
 beans::PropertyState SwXTextPortion::getPropertyState(const OUString& rPropertyName)
-            throw( beans::UnknownPropertyException, uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
     beans::PropertyState eRet = beans::PropertyState_DEFAULT_VALUE;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
     if (GetTextPortionType() == PORTION_RUBY_START &&
         rPropertyName.startsWith("Ruby"))
@@ -771,7 +719,7 @@ beans::PropertyState SwXTextPortion::getPropertyState(const OUString& rPropertyN
     }
     else
     {
-        eRet = SwUnoCursorHelper::GetPropertyState(*pUnoCrsr, *m_pPropSet,
+        eRet = SwUnoCursorHelper::GetPropertyState(rUnoCursor, *m_pPropSet,
                 rPropertyName);
     }
     return eRet;
@@ -779,15 +727,12 @@ beans::PropertyState SwXTextPortion::getPropertyState(const OUString& rPropertyN
 
 uno::Sequence< beans::PropertyState > SwXTextPortion::getPropertyStates(
         const uno::Sequence< OUString >& rPropertyNames)
-        throw( beans::UnknownPropertyException, uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if(!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
     uno::Sequence< beans::PropertyState > aRet =
-        SwUnoCursorHelper::GetPropertyStates(*pUnoCrsr, *m_pPropSet,
+        SwUnoCursorHelper::GetPropertyStates(rUnoCursor, *m_pPropSet,
                 rPropertyNames, SW_PROPERTY_STATE_CALLER_SWX_TEXT_PORTION);
 
     if(GetTextPortionType() == PORTION_RUBY_START)
@@ -804,94 +749,31 @@ uno::Sequence< beans::PropertyState > SwXTextPortion::getPropertyStates(
 }
 
 void SwXTextPortion::setPropertyToDefault(const OUString& rPropertyName)
-                throw( beans::UnknownPropertyException, uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
     SwUnoCursorHelper::SetPropertyToDefault(
-            *pUnoCrsr, *m_pPropSet, rPropertyName);
+            rUnoCursor, *m_pPropSet, rPropertyName);
 }
 
 uno::Any SwXTextPortion::getPropertyDefault(const OUString& rPropertyName)
-        throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
     uno::Any aRet;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
+    SwUnoCursor& rUnoCursor = GetCursor();
 
-    aRet = SwUnoCursorHelper::GetPropertyDefault(*pUnoCrsr, *m_pPropSet,
+    aRet = SwUnoCursorHelper::GetPropertyDefault(rUnoCursor, *m_pPropSet,
                 rPropertyName);
     return aRet;
 }
 
-void SwXTextPortion::attach(const uno::Reference< text::XTextRange > & /*xTextRange*/)
-    throw( lang::IllegalArgumentException, uno::RuntimeException )
-{
-    SolarMutexGuard aGuard;
-    // SwXTextPortion cannot be created at the factory therefore
-    // they cannot be attached
-    throw uno::RuntimeException();
-}
-
-uno::Reference< text::XTextRange >  SwXTextPortion::getAnchor()
-throw( uno::RuntimeException )
-{
-    SolarMutexGuard aGuard;
-    uno::Reference< text::XTextRange >  aRet;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
-
-    aRet = new SwXTextRange(*pUnoCrsr, m_xParentText);
-    return aRet;
-}
-
-void SwXTextPortion::dispose()
-throw( uno::RuntimeException )
-{
-    SolarMutexGuard aGuard;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
-
-    setString(aEmptyOUStr);
-    pUnoCrsr->Remove(this);
-}
-
-void SAL_CALL SwXTextPortion::addEventListener(
-        const uno::Reference<lang::XEventListener> & xListener)
-throw (uno::RuntimeException)
-{
-    // no need to lock here as m_pImpl is const and container threadsafe
-    m_pImpl->m_EventListeners.addInterface(xListener);
-}
-
-void SAL_CALL SwXTextPortion::removeEventListener(
-        const uno::Reference<lang::XEventListener> & xListener)
-throw (uno::RuntimeException)
-{
-    // no need to lock here as m_pImpl is const and container threadsafe
-    m_pImpl->m_EventListeners.removeInterface(xListener);
-}
-
 uno::Reference< container::XEnumeration >  SwXTextPortion::createContentEnumeration(const OUString& /*aServiceName*/)
-        throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if(!pUnoCrsr)
-        throw uno::RuntimeException();
-
-    uno::Reference< container::XEnumeration >  xRet =
-        new SwXParaFrameEnumeration(*pUnoCrsr, PARAFRAME_PORTION_CHAR,
-                m_pFrameFmt);
-    return xRet;
+    SwUnoCursor& rUnoCursor = GetCursor();
 
+    return SwXParaFrameEnumeration::Create(rUnoCursor, PARAFRAME_PORTION_CHAR, m_pFrameFormat);
 }
 
 namespace
@@ -905,7 +787,6 @@ const uno::Sequence< sal_Int8 > & SwXTextPortion::getUnoTunnelId()
 }
 
 sal_Int64 SwXTextPortion::getSomething( const uno::Sequence< sal_Int8 >& rId )
-    throw(uno::RuntimeException)
 {
     if( rId.getLength() == 16
         && 0 == memcmp( getUnoTunnelId().getConstArray(),
@@ -917,34 +798,24 @@ sal_Int64 SwXTextPortion::getSomething( const uno::Sequence< sal_Int8 >& rId )
 }
 
 uno::Sequence< OUString > SwXTextPortion::getAvailableServiceNames()
-throw( uno::RuntimeException )
 {
     SolarMutexGuard aGuard;
-    uno::Sequence< OUString > aRet(1);
-    OUString* pArray = aRet.getArray();
-    pArray[0] = "com.sun.star.text.TextContent";
+    uno::Sequence<OUString> aRet { "com.sun.star.text.TextContent" };
     return aRet;
 }
 
 OUString SwXTextPortion::getImplementationName()
-throw( uno::RuntimeException )
 {
     return OUString("SwXTextPortion");
 }
 
-sal_Bool SwXTextPortion::supportsService(const OUString& rServiceName) throw( uno::RuntimeException )
+sal_Bool SwXTextPortion::supportsService(const OUString& rServiceName)
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 uno::Sequence< OUString > SwXTextPortion::getSupportedServiceNames()
-throw( uno::RuntimeException )
 {
-    SolarMutexGuard aGuard;
-    SwUnoCrsr* pUnoCrsr = GetCursor();
-    if (!pUnoCrsr)
-        throw uno::RuntimeException();
-
     uno::Sequence< OUString > aRet(7);
     OUString* pArray = aRet.getArray();
     pArray[0] = "com.sun.star.text.TextPortion";
@@ -962,7 +833,7 @@ void SwXTextPortion::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew)
     ClientModify(this, pOld, pNew);
     if (!m_FrameDepend.GetRegisteredIn())
     {
-        m_pFrameFmt = 0;
+        m_pFrameFormat = nullptr;
     }
 }
 
