@@ -49,6 +49,7 @@
 #include <undobj.hxx>
 #include <swundo.hxx>
 #include <swtable.hxx>
+#include <tblafmt.hxx>
 #include <tblsel.hxx>
 #include <pagedesc.hxx>
 #include <poolfmt.hxx>
@@ -61,7 +62,7 @@
 
 using namespace ::com::sun::star;
 
-sal_uLong SwReader::Read( const Reader& rOptions )
+ErrCode SwReader::Read( const Reader& rOptions )
 {
     // copy variables
     Reader* po = const_cast<Reader*>(&rOptions);
@@ -82,16 +83,16 @@ sal_uLong SwReader::Read( const Reader& rOptions )
         return ERR_SWG_FILE_FORMAT_ERROR;
     }
 
-    sal_uLong nError = 0L;
+    ErrCode nError = ERRCODE_NONE;
 
     GetDoc();
 
     // while reading, do not call OLE-Modified
-    Link<bool,void> aOLELink( pDoc->GetOle2Link() );
-    pDoc->SetOle2Link( Link<bool,void>() );
+    Link<bool,void> aOLELink( mxDoc->GetOle2Link() );
+    mxDoc->SetOle2Link( Link<bool,void>() );
 
-    pDoc->SetInReading( true );
-    pDoc->SetInXMLImport( dynamic_cast< XMLReader* >(po) !=  nullptr );
+    mxDoc->SetInReading( true );
+    mxDoc->SetInXMLImport( dynamic_cast< XMLReader* >(po) !=  nullptr );
 
     SwPaM *pPam;
     if( pCursor )
@@ -99,13 +100,13 @@ sal_uLong SwReader::Read( const Reader& rOptions )
     else
     {
         // if the Reader was not called by a Shell, create a PaM ourselves
-        SwNodeIndex nNode( pDoc->GetNodes().GetEndOfContent(), -1 );
+        SwNodeIndex nNode( mxDoc->GetNodes().GetEndOfContent(), -1 );
         pPam = new SwPaM( nNode );
         // For Web documents the default template was set already by InitNew,
         // unless the filter is not HTML,
         // or a SetTemplateName was called in ConvertFrom.
-        if( !pDoc->getIDocumentSettingAccess().get(DocumentSettingId::HTML_MODE) || ReadHTML != po || !po->pTemplate  )
-            po->SetTemplate( *pDoc );
+        if( !mxDoc->getIDocumentSettingAccess().get(DocumentSettingId::HTML_MODE) || ReadHTML != po || !po->mxTemplate.is()  )
+            po->SetTemplate( *mxDoc );
     }
 
     // Pams are connected like rings; stop when we return to the 1st element
@@ -113,31 +114,32 @@ sal_uLong SwReader::Read( const Reader& rOptions )
     SwUndoInsDoc* pUndo = nullptr;
 
     bool bReadPageDescs = false;
-    bool const bDocUndo = pDoc->GetIDocumentUndoRedo().DoesUndo();
+    bool const bDocUndo = mxDoc->GetIDocumentUndoRedo().DoesUndo();
     bool bSaveUndo = bDocUndo && pCursor;
     if( bSaveUndo )
     {
         // the reading of the page template cannot be undone!
-        if( ( bReadPageDescs = po->aOpt.IsPageDescs() ) )
+        bReadPageDescs = po->aOpt.IsPageDescs();
+        if( bReadPageDescs )
         {
             bSaveUndo = false;
-            pDoc->GetIDocumentUndoRedo().DelAllUndoObj();
+            mxDoc->GetIDocumentUndoRedo().DelAllUndoObj();
         }
         else
         {
-            pDoc->GetIDocumentUndoRedo().ClearRedo();
-            pDoc->GetIDocumentUndoRedo().StartUndo( UNDO_INSDOKUMENT, nullptr );
+            mxDoc->GetIDocumentUndoRedo().ClearRedo();
+            mxDoc->GetIDocumentUndoRedo().StartUndo( SwUndoId::INSDOKUMENT, nullptr );
         }
     }
-    pDoc->GetIDocumentUndoRedo().DoUndo(false);
+    mxDoc->GetIDocumentUndoRedo().DoUndo(false);
 
-    SwNodeIndex aSplitIdx( pDoc->GetNodes() );
+    SwNodeIndex aSplitIdx( mxDoc->GetNodes() );
 
-    RedlineMode_t eOld = pDoc->getIDocumentRedlineAccess().GetRedlineMode();
-    RedlineMode_t ePostReadRedlineMode( nsRedlineMode_t::REDLINE_IGNORE );
+    RedlineFlags eOld = mxDoc->getIDocumentRedlineAccess().GetRedlineFlags();
+    RedlineFlags ePostReadRedlineFlags( RedlineFlags::Ignore );
 
     // Array of FlyFormats
-    SwFrameFormats aFlyFrameArr;
+    SwFrameFormatsV aFlyFrameArr;
     // only read templates? then ignore multi selection!
     bool bFormatsOnly = po->aOpt.IsFormatsOnly();
 
@@ -146,7 +148,7 @@ sal_uLong SwReader::Read( const Reader& rOptions )
         if( bSaveUndo )
             pUndo = new SwUndoInsDoc( *pPam );
 
-        pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( nsRedlineMode_t::REDLINE_IGNORE );
+        mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( RedlineFlags::Ignore );
 
         SwPaM* pUndoPam = nullptr;
         if( bDocUndo || pCursor )
@@ -159,8 +161,8 @@ sal_uLong SwReader::Read( const Reader& rOptions )
         // store for now all Fly's
         if( pCursor )
         {
-            std::copy(pDoc->GetSpzFrameFormats()->begin(),
-                pDoc->GetSpzFrameFormats()->end(), std::back_inserter(aFlyFrameArr));
+            std::copy(mxDoc->GetSpzFrameFormats()->begin(),
+                mxDoc->GetSpzFrameFormats()->end(), std::back_inserter(aFlyFrameArr));
         }
 
         const sal_Int32 nSttContent = pPam->GetPoint()->nContent.GetIndex();
@@ -170,21 +172,21 @@ sal_uLong SwReader::Read( const Reader& rOptions )
         sal_Int32 nEndContent = pCNd ? pCNd->Len() - nSttContent : 0;
         SwNodeIndex aEndPos( pPam->GetPoint()->nNode, 1 );
 
-        pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( eOld );
+        mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( eOld );
 
-        nError = po->Read( *pDoc, GetBaseURL(), *pPam, aFileName );
+        nError = po->Read( *mxDoc, sBaseURL, *pPam, aFileName );
 
         // an ODF document may contain redline mode in settings.xml; save it!
-        ePostReadRedlineMode = pDoc->getIDocumentRedlineAccess().GetRedlineMode();
+        ePostReadRedlineFlags = mxDoc->getIDocumentRedlineAccess().GetRedlineFlags();
 
-        pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( nsRedlineMode_t::REDLINE_IGNORE );
+        mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( RedlineFlags::Ignore );
 
-        if( !IsError( nError ))     // set the End position already
+        if( ! nError.IsError() )     // set the End position already
         {
             --aEndPos;
             pCNd = aEndPos.GetNode().GetContentNode();
             if( !pCNd && nullptr == ( pCNd = SwNodes::GoPrevious( &aEndPos ) ))
-                pCNd = pDoc->GetNodes().GoNext( &aEndPos );
+                pCNd = mxDoc->GetNodes().GoNext( &aEndPos );
 
             pPam->GetPoint()->nNode = aEndPos;
             const sal_Int32 nLen = pCNd->Len();
@@ -200,7 +202,7 @@ sal_uLong SwReader::Read( const Reader& rOptions )
                 SwTableBox* pBox = pTableBoxStart->GetTableBox();
                 if ( pBox )
                 {
-                    pDoc->ChkBoxNumFormat( *pBox, true );
+                    mxDoc->ChkBoxNumFormat( *pBox, true );
                 }
             }
         }
@@ -220,17 +222,18 @@ sal_uLong SwReader::Read( const Reader& rOptions )
                                    rNd.FindFooterStartNode();
 
             // search all new Fly's, and store them as individual Undo Objects
-            for( SwFrameFormats::size_type n = 0; n < pDoc->GetSpzFrameFormats()->size(); ++n )
+            for( SwFrameFormats::size_type n = 0; n < mxDoc->GetSpzFrameFormats()->size(); ++n )
             {
-                SwFrameFormat* pFrameFormat = (*pDoc->GetSpzFrameFormats())[ n ];
+                SwFrameFormat* pFrameFormat = (*mxDoc->GetSpzFrameFormats())[ n ];
                 const SwFormatAnchor& rAnchor = pFrameFormat->GetAnchor();
-                if( !aFlyFrameArr.Contains( pFrameFormat) )
+                // ok, here IsAlive is a misnomer...
+                if (!aFlyFrameArr.IsAlive(pFrameFormat))
                 {
                     SwPosition const*const pFrameAnchor(
                             rAnchor.GetContentAnchor());
-                    if  (   (FLY_AT_PAGE == rAnchor.GetAnchorId())
+                    if  (   (RndStdIds::FLY_AT_PAGE == rAnchor.GetAnchorId())
                         ||  (   pFrameAnchor
-                            &&  (   (   (FLY_AT_PARA == rAnchor.GetAnchorId())
+                            &&  (   (   (RndStdIds::FLY_AT_PARA == rAnchor.GetAnchorId())
                                     &&  (   (pUndoPam->GetPoint()->nNode ==
                                              pFrameAnchor->nNode)
                                         ||  (pUndoPam->GetMark()->nNode ==
@@ -238,37 +241,36 @@ sal_uLong SwReader::Read( const Reader& rOptions )
                                         )
                                     )
                                 // #i97570# also check frames anchored AT char
-                                ||  (   (FLY_AT_CHAR == rAnchor.GetAnchorId())
+                                ||  (   (RndStdIds::FLY_AT_CHAR == rAnchor.GetAnchorId())
                                     &&  !IsDestroyFrameAnchoredAtChar(
                                               *pFrameAnchor,
                                               *pUndoPam->GetPoint(),
-                                              *pUndoPam->GetMark(),
-                                              pDoc)
+                                              *pUndoPam->GetMark())
                                     )
                                 )
                             )
                         )
                     {
                         if( bChkHeaderFooter &&
-                            (FLY_AT_PARA == rAnchor.GetAnchorId()) &&
+                            (RndStdIds::FLY_AT_PARA == rAnchor.GetAnchorId()) &&
                             RES_DRAWFRMFMT == pFrameFormat->Which() )
                         {
                             // DrawObjects are not allowed in Headers/Footers!
                             pFrameFormat->DelFrames();
-                            pDoc->DelFrameFormat( pFrameFormat );
+                            mxDoc->DelFrameFormat( pFrameFormat );
                             --n;
                         }
                         else
                         {
                             if( bSaveUndo )
                             {
-                                pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( eOld );
+                                mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( eOld );
                                 // UGLY: temp. enable undo
-                                pDoc->GetIDocumentUndoRedo().DoUndo(true);
-                                pDoc->GetIDocumentUndoRedo().AppendUndo(
+                                mxDoc->GetIDocumentUndoRedo().DoUndo(true);
+                                mxDoc->GetIDocumentUndoRedo().AppendUndo(
                                     new SwUndoInsLayFormat( pFrameFormat,0,0 ) );
-                                pDoc->GetIDocumentUndoRedo().DoUndo(false);
-                                pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( nsRedlineMode_t::REDLINE_IGNORE );
+                                mxDoc->GetIDocumentUndoRedo().DoUndo(false);
+                                mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( RedlineFlags::Ignore );
                             }
                             if( pFrameFormat->HasWriterListeners() )
                             {
@@ -276,7 +278,7 @@ sal_uLong SwReader::Read( const Reader& rOptions )
                                 pFrameFormat->DelFrames();
                             }
 
-                            if (FLY_AT_PAGE == rAnchor.GetAnchorId())
+                            if (RndStdIds::FLY_AT_PAGE == rAnchor.GetAnchorId())
                             {
                                 if( !rAnchor.GetContentAnchor() )
                                 {
@@ -284,7 +286,7 @@ sal_uLong SwReader::Read( const Reader& rOptions )
                                 }
                                 else if( pCursor )
                                 {
-                                    pDoc->SetContainsAtPageObjWithContentAnchor( true );
+                                    mxDoc->SetContainsAtPageObjWithContentAnchor( true );
                                 }
                             }
                             else
@@ -296,22 +298,22 @@ sal_uLong SwReader::Read( const Reader& rOptions )
             if( !aFlyFrameArr.empty() )
                 aFlyFrameArr.clear();
 
-            pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( eOld );
-            if( pDoc->getIDocumentRedlineAccess().IsRedlineOn() )
-                pDoc->getIDocumentRedlineAccess().AppendRedline( new SwRangeRedline( nsRedlineType_t::REDLINE_INSERT, *pUndoPam ), true);
+            mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( eOld );
+            if( mxDoc->getIDocumentRedlineAccess().IsRedlineOn() )
+                mxDoc->getIDocumentRedlineAccess().AppendRedline( new SwRangeRedline( nsRedlineType_t::REDLINE_INSERT, *pUndoPam ), true);
             else
-                pDoc->getIDocumentRedlineAccess().SplitRedline( *pUndoPam );
-            pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( nsRedlineMode_t::REDLINE_IGNORE );
+                mxDoc->getIDocumentRedlineAccess().SplitRedline( *pUndoPam );
+            mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( RedlineFlags::Ignore );
         }
         if( bSaveUndo )
         {
-            pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( eOld );
+            mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( eOld );
             pUndo->SetInsertRange( *pUndoPam, false );
             // UGLY: temp. enable undo
-            pDoc->GetIDocumentUndoRedo().DoUndo(true);
-            pDoc->GetIDocumentUndoRedo().AppendUndo( pUndo );
-            pDoc->GetIDocumentUndoRedo().DoUndo(false);
-            pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( nsRedlineMode_t::REDLINE_IGNORE );
+            mxDoc->GetIDocumentUndoRedo().DoUndo(true);
+            mxDoc->GetIDocumentUndoRedo().AppendUndo( pUndo );
+            mxDoc->GetIDocumentUndoRedo().DoUndo(false);
+            mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( RedlineFlags::Ignore );
         }
 
         delete pUndoPam;
@@ -326,7 +328,7 @@ sal_uLong SwReader::Read( const Reader& rOptions )
 
         /*
          * !!! The Status of the Stream has to be reset directly. !!!
-         *     When Seeking, the current Status-, EOF- und bad-Bit is set;
+         *     When Seeking, the current Status-, EOF- and bad-Bit is set;
          *     nobody knows why
          */
         if( pStrm )
@@ -336,23 +338,25 @@ sal_uLong SwReader::Read( const Reader& rOptions )
         }
     }
 
-    pDoc->SetInReading( false );
-    pDoc->SetInXMLImport( false );
+    mxDoc->SetInReading( false );
+    mxDoc->SetInXMLImport( false );
 
-    pDoc->InvalidateNumRules();
-    pDoc->UpdateNumRule();
-    pDoc->ChkCondColls();
-    pDoc->SetAllUniqueFlyNames();
-    pDoc->getIDocumentState().SetLoaded();
+    mxDoc->InvalidateNumRules();
+    mxDoc->UpdateNumRule();
+    mxDoc->ChkCondColls();
+    mxDoc->SetAllUniqueFlyNames();
+    mxDoc->getIDocumentState().SetLoaded();
+    // Clear unassigned cell styles, because they aren't needed anymore.
+    mxDoc->GetCellStyles().clear();
 
-    pDoc->GetIDocumentUndoRedo().DoUndo(bDocUndo);
+    mxDoc->GetIDocumentUndoRedo().DoUndo(bDocUndo);
     if (!bReadPageDescs)
     {
         if( bSaveUndo )
         {
-            pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( eOld );
-            pDoc->GetIDocumentUndoRedo().EndUndo( UNDO_INSDOKUMENT, nullptr );
-            pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( nsRedlineMode_t::REDLINE_IGNORE );
+            mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( eOld );
+            mxDoc->GetIDocumentUndoRedo().EndUndo( SwUndoId::INSDOKUMENT, nullptr );
+            mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( RedlineFlags::Ignore );
         }
     }
 
@@ -364,27 +368,26 @@ sal_uLong SwReader::Read( const Reader& rOptions )
         // #i42634# Moved common code of SwReader::Read() and
         // SwDocShell::UpdateLinks() to new SwDoc::UpdateLinks():
     // ATM still with Update
-        pDoc->getIDocumentLinksAdministration().UpdateLinks( true );
+        mxDoc->getIDocumentLinksAdministration().UpdateLinks();
 
         // not insert: set the redline mode read from settings.xml
-        eOld = static_cast<RedlineMode_t>(
-                ePostReadRedlineMode & ~nsRedlineMode_t::REDLINE_IGNORE);
+        eOld = ePostReadRedlineFlags & ~RedlineFlags::Ignore;
 
-        pDoc->getIDocumentFieldsAccess().SetFieldsDirty(false, nullptr, 0);
+        mxDoc->getIDocumentFieldsAccess().SetFieldsDirty(false, nullptr, 0);
     }
 
-    pDoc->getIDocumentRedlineAccess().SetRedlineMode_intern( eOld );
-    pDoc->SetOle2Link( aOLELink );
+    mxDoc->getIDocumentRedlineAccess().SetRedlineFlags_intern( eOld );
+    mxDoc->SetOle2Link( aOLELink );
 
-    if( pCursor )                 // das Doc ist jetzt modifiziert
-        pDoc->getIDocumentState().SetModified();
+    if( pCursor )                 // the document is now modified
+        mxDoc->getIDocumentState().SetModified();
     // #i38810# - If links have been updated, the document
     // have to be modified. During update of links the OLE link at the document
     // isn't set. Thus, the document's modified state has to be set again after
-    // the OLE link is restored - see above <pDoc->SetOle2Link( aOLELink )>.
-    if ( pDoc->getIDocumentLinksAdministration().LinksUpdated() )
+    // the OLE link is restored - see above <mxDoc->SetOle2Link( aOLELink )>.
+    if ( mxDoc->getIDocumentLinksAdministration().LinksUpdated() )
     {
-        pDoc->getIDocumentState().SetModified();
+        mxDoc->getIDocumentState().SetModified();
     }
 
     po->SetReadUTF8( false );
@@ -426,8 +429,7 @@ SwReader::SwReader( const uno::Reference < embed::XStorage > &rStg, const OUStri
 }
 
 Reader::Reader()
-    : pTemplate(nullptr),
-    aDStamp( Date::EMPTY ),
+  : aDStamp( Date::EMPTY ),
     aTStamp( tools::Time::EMPTY ),
     aChkDateTime( DateTime::EMPTY ),
     pStrm(nullptr), pMedium(nullptr), bInsertMode(false),
@@ -438,7 +440,6 @@ Reader::Reader()
 
 Reader::~Reader()
 {
-    delete pTemplate;
 }
 
 OUString Reader::GetTemplateName() const
@@ -460,20 +461,20 @@ SwDoc* Reader::GetTemplateDoc()
     else
     {
         INetURLObject aTDir( aTemplateNm );
-        const OUString aFileName = aTDir.GetMainURL( INetURLObject::NO_DECODE );
+        const OUString aFileName = aTDir.GetMainURL( INetURLObject::DecodeMechanism::NONE );
         OSL_ENSURE( !aTDir.HasError(), "No absolute path for template name!" );
         DateTime aCurrDateTime( DateTime::SYSTEM );
         bool bLoad = false;
 
         // if the template is already loaded, check once-a-minute if it has changed
-        if( !pTemplate || aCurrDateTime >= aChkDateTime )
+        if( !mxTemplate.is() || aCurrDateTime >= aChkDateTime )
         {
             Date aTstDate( Date::EMPTY );
             tools::Time aTstTime( tools::Time::EMPTY );
             if( FStatHelper::GetModifiedDateTimeOfFile(
-                            aTDir.GetMainURL( INetURLObject::NO_DECODE ),
+                            aTDir.GetMainURL( INetURLObject::DecodeMechanism::NONE ),
                             &aTstDate, &aTstTime ) &&
-                ( !pTemplate || aDStamp != aTstDate || aTStamp != aTstTime ))
+                ( !mxTemplate.is() || aDStamp != aTstDate || aTStamp != aTstTime ))
             {
                 bLoad = true;
                 aDStamp = aTstDate;
@@ -482,49 +483,46 @@ SwDoc* Reader::GetTemplateDoc()
 
             // only one minute later check if it has changed
             aChkDateTime = aCurrDateTime;
-            aChkDateTime += tools::Time( 0L, 1L );
+            aChkDateTime += tools::Time( 0, 1 );
         }
 
-        if( bLoad )
+        if (bLoad)
         {
             ClearTemplate();
-            OSL_ENSURE( !pTemplate, "Who holds the template doc?" );
+            OSL_ENSURE( !mxTemplate.is(), "Who holds the template doc?" );
 
-                // If the writer module is not installed,
-                // we cannot create a SwDocShell. We could create a
-                // SwWebDocShell however, because this exists always
-                // for the help.
-                SvtModuleOptions aModuleOptions;
-                if( aModuleOptions.IsWriter() )
+            // If the writer module is not installed,
+            // we cannot create a SwDocShell. We could create a
+            // SwWebDocShell however, because this exists always
+            // for the help.
+            SvtModuleOptions aModuleOptions;
+            if (aModuleOptions.IsWriter())
+            {
+                SwDocShell *pDocSh = new SwDocShell(SfxObjectCreateMode::INTERNAL);
+                SfxObjectShellLock xDocSh = pDocSh;
+                if (pDocSh->DoInitNew())
                 {
-                    SwDocShell *pDocSh =
-                        new SwDocShell ( SfxObjectCreateMode::INTERNAL );
-                    SfxObjectShellLock xDocSh = pDocSh;
-                    if( pDocSh->DoInitNew() )
-                    {
-                        pTemplate = pDocSh->GetDoc();
-                        pTemplate->SetOle2Link( Link<bool,void>() );
-                        // always FALSE
-                        pTemplate->GetIDocumentUndoRedo().DoUndo( false );
-                        pTemplate->getIDocumentSettingAccess().set(DocumentSettingId::BROWSE_MODE, bTmplBrowseMode );
-                        pTemplate->RemoveAllFormatLanguageDependencies();
+                    mxTemplate = pDocSh->GetDoc();
+                    mxTemplate->SetOle2Link( Link<bool,void>() );
+                    // always FALSE
+                    mxTemplate->GetIDocumentUndoRedo().DoUndo( false );
+                    mxTemplate->getIDocumentSettingAccess().set(DocumentSettingId::BROWSE_MODE, bTmplBrowseMode );
+                    mxTemplate->RemoveAllFormatLanguageDependencies();
 
-                        ReadXML->SetOrganizerMode( true );
-                        SfxMedium aMedium( aFileName, StreamMode::NONE );
-                        SwReader aRdr( aMedium, OUString(), pTemplate );
-                        aRdr.Read( *ReadXML );
-                        ReadXML->SetOrganizerMode( false );
-
-                        pTemplate->acquire();
-                    }
+                    ReadXML->SetOrganizerMode( true );
+                    SfxMedium aMedium( aFileName, StreamMode::NONE );
+                    SwReader aRdr( aMedium, OUString(), mxTemplate.get() );
+                    aRdr.Read( *ReadXML );
+                    ReadXML->SetOrganizerMode( false );
                 }
+            }
         }
 
-        OSL_ENSURE( !pTemplate || FStatHelper::IsDocument( aFileName ) || aTemplateNm=="$$Dummy$$",
+        OSL_ENSURE( !mxTemplate.is() || FStatHelper::IsDocument( aFileName ) || aTemplateNm=="$$Dummy$$",
                 "TemplatePtr but no template exist!" );
     }
 
-    return pTemplate;
+    return mxTemplate.get();
 }
 
 bool Reader::SetTemplate( SwDoc& rDoc )
@@ -532,11 +530,11 @@ bool Reader::SetTemplate( SwDoc& rDoc )
     bool bRet = false;
 
     GetTemplateDoc();
-    if( pTemplate )
+    if( mxTemplate.is() )
     {
         rDoc.RemoveAllFormatLanguageDependencies();
-        rDoc.ReplaceStyles( *pTemplate );
-        rDoc.getIDocumentFieldsAccess().SetFixFields(false, nullptr);
+        rDoc.ReplaceStyles( *mxTemplate );
+        rDoc.getIDocumentFieldsAccess().SetFixFields(nullptr);
         bRet = true;
     }
 
@@ -545,12 +543,7 @@ bool Reader::SetTemplate( SwDoc& rDoc )
 
 void Reader::ClearTemplate()
 {
-    if( pTemplate )
-    {
-        if( 0 == pTemplate->release() )
-            delete pTemplate;
-        pTemplate = nullptr;
-    }
+    mxTemplate.clear();
 }
 
 void Reader::SetTemplateName( const OUString& rDir )
@@ -565,11 +558,10 @@ void Reader::SetTemplateName( const OUString& rDir )
 void Reader::MakeHTMLDummyTemplateDoc()
 {
     ClearTemplate();
-    pTemplate = new SwDoc;
-    pTemplate->acquire();
-    pTemplate->getIDocumentSettingAccess().set(DocumentSettingId::BROWSE_MODE, bTmplBrowseMode );
-    pTemplate->getIDocumentDeviceAccess().getPrinter( true );
-    pTemplate->RemoveAllFormatLanguageDependencies();
+    mxTemplate = new SwDoc;
+    mxTemplate->getIDocumentSettingAccess().set(DocumentSettingId::BROWSE_MODE, bTmplBrowseMode );
+    mxTemplate->getIDocumentDeviceAccess().getPrinter( true );
+    mxTemplate->RemoveAllFormatLanguageDependencies();
     aChkDateTime = Date( 1, 1, 2300 );  // year 2300 should be sufficient
     aTemplateNm = "$$Dummy$$";
 }
@@ -628,9 +620,9 @@ void Reader::ResetFrameFormats( SwDoc& rDoc )
     sal_uInt16 const s_ids[3] = {
         RES_POOLFRM_FRAME, RES_POOLFRM_GRAPHIC, RES_POOLFRM_OLE
     };
-    for (size_t i = 0; i < SAL_N_ELEMENTS(s_ids); ++i)
+    for (sal_uInt16 i : s_ids)
     {
-        SwFrameFormat *const pFrameFormat = rDoc.getIDocumentStylePoolAccess().GetFrameFormatFromPool( s_ids[i] );
+        SwFrameFormat *const pFrameFormat = rDoc.getIDocumentStylePoolAccess().GetFrameFormatFromPool( i );
 
         pFrameFormat->ResetFormatAttr( RES_LR_SPACE );
         pFrameFormat->ResetFormatAttr( RES_UL_SPACE );
@@ -734,7 +726,7 @@ SwWriter::SwWriter(SfxMedium& rMedium, SwDoc &rDocument)
 {
 }
 
-sal_uLong SwWriter::Write( WriterRef& rxWriter, const OUString* pRealFileName )
+ErrCode SwWriter::Write( WriterRef const & rxWriter, const OUString* pRealFileName )
 {
     // #i73788#
     SwPauseThreadStarting aPauseThreadStarting;
@@ -742,13 +734,12 @@ sal_uLong SwWriter::Write( WriterRef& rxWriter, const OUString* pRealFileName )
     bool bHasMark = false;
     SwPaM * pPam;
 
-    SwDoc *pDoc = nullptr;
+    rtl::Reference<SwDoc> xDoc;
 
     if ( pShell && !bWriteAll && pShell->IsTableMode() )
     {
         bWriteAll = true;
-        pDoc = new SwDoc;
-        pDoc->acquire();
+        xDoc = new SwDoc;
 
         // Copy parts of a table:
         // Create a table with the width of the original and copy the selected cells.
@@ -758,11 +749,11 @@ sal_uLong SwWriter::Write( WriterRef& rxWriter, const OUString* pRealFileName )
         SwSelBoxes aBoxes;
         GetTableSel( *pShell, aBoxes );
         const SwTableNode* pTableNd = static_cast<const SwTableNode*>(aBoxes[0]->GetSttNd()->StartOfSectionNode());
-        SwNodeIndex aIdx( pDoc->GetNodes().GetEndOfExtras(), 2 );
+        SwNodeIndex aIdx( xDoc->GetNodes().GetEndOfExtras(), 2 );
         SwContentNode *pNd = aIdx.GetNode().GetContentNode();
         OSL_ENSURE( pNd, "Node not found" );
         SwPosition aPos( aIdx, SwIndex( pNd ) );
-        pTableNd->GetTable().MakeCopy( pDoc, aPos, aBoxes );
+        pTableNd->GetTable().MakeCopy( xDoc.get(), aPos, aBoxes );
     }
 
     if( !bWriteAll && ( pShell || pOutPam ))
@@ -796,9 +787,9 @@ sal_uLong SwWriter::Write( WriterRef& rxWriter, const OUString* pRealFileName )
             else
             {
                 pPam = new SwPaM( *pPam, pPam );
-                pPam->Move( fnMoveBackward, fnGoDoc );
+                pPam->Move( fnMoveBackward, GoInDoc );
                 pPam->SetMark();
-                pPam->Move( fnMoveForward, fnGoDoc );
+                pPam->Move( fnMoveForward, GoInDoc );
             }
         }
         // pPam is still the current Cursor !!
@@ -806,29 +797,29 @@ sal_uLong SwWriter::Write( WriterRef& rxWriter, const OUString* pRealFileName )
     else
     {
         // no Shell or write-everything -> create a Pam
-        SwDoc* pOutDoc = pDoc ? pDoc : &rDoc;
+        SwDoc* pOutDoc = xDoc.is() ? xDoc.get() : &rDoc;
         pPam = new SwPaM( pOutDoc->GetNodes().GetEndOfContent() );
         if( pOutDoc->IsClipBoard() )
         {
-            pPam->Move( fnMoveBackward, fnGoDoc );
+            pPam->Move( fnMoveBackward, GoInDoc );
             pPam->SetMark();
-            pPam->Move( fnMoveForward, fnGoDoc );
+            pPam->Move( fnMoveForward, GoInDoc );
         }
         else
         {
             pPam->SetMark();
-            pPam->Move( fnMoveBackward, fnGoDoc );
+            pPam->Move( fnMoveBackward, GoInDoc );
         }
     }
 
     rxWriter->bWriteAll = bWriteAll;
-    SwDoc* pOutDoc = pDoc ? pDoc : &rDoc;
+    SwDoc* pOutDoc = xDoc.is() ? xDoc.get() : &rDoc;
 
     // If the default PageDesc has still the initial value,
     // (e.g. if no printer was set) then set it to DIN A4.
     // #i37248# - Modifications are only allowed at a new document.
-    // <pOutDoc> contains a new document, if <pDoc> is set - see above.
-    if ( pDoc && !pOutDoc->getIDocumentDeviceAccess().getPrinter( false ) )
+    // <pOutDoc> contains a new document, if <xDoc> is set - see above.
+    if ( xDoc.is() && !pOutDoc->getIDocumentDeviceAccess().getPrinter( false ) )
     {
         const SwPageDesc& rPgDsc = pOutDoc->GetPageDesc( 0 );
         //const SwPageDesc& rPgDsc = *pOutDoc->GetPageDescFromPool( RES_POOLPAGE_STANDARD );
@@ -858,13 +849,10 @@ sal_uLong SwWriter::Write( WriterRef& rxWriter, const OUString* pRealFileName )
 
     const bool bOrigPurgeOle = pOutDoc->getIDocumentSettingAccess().get(DocumentSettingId::PURGE_OLE);
     pOutDoc->getIDocumentSettingAccess().set(DocumentSettingId::PURGE_OLE, false);
-    const RedlineMode_t nOrigRedlineMode = pOutDoc->getIDocumentRedlineAccess().GetRedlineMode();
 
-    sal_uLong nError = 0;
+    ErrCode nError = ERRCODE_NONE;
     if( pMedium )
         nError = rxWriter->Write( *pPam, *pMedium, pRealFileName );
-    else if( pStg )
-        nError = rxWriter->Write( *pPam, *pStg, pRealFileName );
     else if( pStrm )
         nError = rxWriter->Write( *pPam, *pStrm, pRealFileName );
     else if( xStg.is() )
@@ -884,18 +872,16 @@ sal_uLong SwWriter::Write( WriterRef& rxWriter, const OUString* pRealFileName )
         if(!bHasMark)
         {
             if( pShell )
-                pShell->Pop( false );
+                pShell->Pop(SwCursorShell::PopMode::DeleteCurrent);
             else
                 delete pPam;
         }
-        pOutDoc->getIDocumentRedlineAccess().SetRedlineMode(nOrigRedlineMode);
     }
     else
     {
         delete pPam;            // delete the created Pam
-        pOutDoc->getIDocumentRedlineAccess().SetRedlineMode(nOrigRedlineMode);
         // Everything was written successfully? Tell the document!
-        if ( !IsError( nError ) && !pDoc )
+        if ( !nError.IsError() && !xDoc.is() )
         {
             rDoc.getIDocumentState().ResetModified();
             // #i38810# - reset also flag, that indicates updated links
@@ -903,10 +889,9 @@ sal_uLong SwWriter::Write( WriterRef& rxWriter, const OUString* pRealFileName )
         }
     }
 
-    if ( pDoc )
+    if ( xDoc.is() )
     {
-        if ( !pDoc->release() )
-            delete pDoc;
+        xDoc.clear();
         bWriteAll = false;
     }
 
