@@ -22,6 +22,7 @@
 #include <hintids.hxx>
 #include <rtl/ustring.hxx>
 #include <rtl/ustrbuf.hxx>
+#include <utility>
 #include <xmloff/xmluconv.hxx>
 #include "xmlexpit.hxx"
 #include <xmloff/nmspmap.hxx>
@@ -32,13 +33,13 @@
 #include <tools/fldunit.hxx>
 #include <swmodule.hxx>
 #include <doc.hxx>
-#include "fmtornt.hxx"
+#include <fmtornt.hxx>
 #include <unomid.h>
-#include "frmfmt.hxx"
-#include "fmtfsize.hxx"
-#include "swrect.hxx"
+#include <frmfmt.hxx>
+#include <fmtfsize.hxx>
+#include <swrect.hxx>
 #include "xmlexp.hxx"
-#include <editeng/memberids.hrc>
+#include <editeng/memberids.h>
 #include <comphelper/processfactory.hxx>
 
 using namespace ::com::sun::star;
@@ -85,7 +86,7 @@ public:
 SwXMLTableItemMapper_Impl::SwXMLTableItemMapper_Impl(
         SvXMLItemMapEntriesRef rMapEntries,
         SwXMLExport& rExp ) :
-    SvXMLExportItemMapper( rMapEntries ),
+    SvXMLExportItemMapper( std::move(rMapEntries) ),
     aBrushItemExport( rExp ),
     nAbsWidth( USHRT_MAX )
 {
