@@ -20,7 +20,6 @@
 #include <swmodule.hxx>
 #include <swtypes.hxx>
 #include <mailconfigpage.hxx>
-#include <sfx2/imgmgr.hxx>
 #include <svtools/svmedit.hxx>
 #include <svtools/svtabbx.hxx>
 #include <svtools/headbar.hxx>
@@ -34,8 +33,9 @@
 #include <com/sun/star/mail/MailServiceProvider.hpp>
 #include <vcl/msgbox.hxx>
 #include <globals.hrc>
-#include <config.hrc>
-#include <helpid.h>
+#include <dbui.hrc>
+#include <bitmaps.hlst>
+#include <helpids.h>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::lang;
@@ -226,6 +226,8 @@ IMPL_LINK_NOARG(SwMailConfigPage, TestHdl, Button*, void)
 
 SwTestAccountSettingsDialog::SwTestAccountSettingsDialog(SwMailConfigPage* pParent)
     : SfxModalDialog(pParent, "TestMailSettings", "modules/swriter/ui/testmailsettings.ui")
+    , m_aCompletedImg(BitmapEx(RID_BMP_FORMULA_APPLY))
+    , m_aFailedImg(BitmapEx(RID_BMP_FORMULA_CANCEL))
     , m_pParent(pParent)
     , m_bStop(false)
 {
@@ -244,10 +246,6 @@ SwTestAccountSettingsDialog::SwTestAccountSettingsDialog(SwMailConfigPage* pPare
     m_sCompleted = m_pResult1->GetText();
     m_sFailed = m_pResult2->GetText();
 
-    SfxImageManager* pManager = SfxImageManager::GetImageManager(*SW_MOD());
-    m_aFailedImg = pManager->GetImage(FN_FORMULA_CANCEL);
-    m_aCompletedImg = pManager->GetImage(FN_FORMULA_APPLY);
-
     m_pStopPB->SetClickHdl(LINK(this, SwTestAccountSettingsDialog, StopHdl));
 
     Application::PostUserEvent( LINK( this, SwTestAccountSettingsDialog, TestHdl ), this, true );
@@ -325,7 +323,7 @@ void SwTestAccountSettingsDialog::Test()
                     new SwConnectionContext(
                         m_pParent->m_pConfigItem->GetInServerName(),
                         m_pParent->m_pConfigItem->GetInServerPort(),
-                        OUString("Insecure"));
+                        "Insecure");
             xInMailService->connect(xConnectionContext, xAuthenticator);
         }
         if(m_bStop)
