@@ -20,50 +20,51 @@
 #include <memory>
 #include <vcl/waitobj.hxx>
 #include <rtl/ustring.hxx>
+#include <sfx2/sfxsids.hrc>
 #include <svtools/treelistentry.hxx>
 #include <com/sun/star/uno/Sequence.h>
 #include <swtypes.hxx>
 #include <wrtsh.hxx>
 #include <initui.hxx>
-#include "labimp.hxx"
-#include <labfmt.hxx>
-#include <labprt.hxx>
+#include <labimp.hxx>
+#include "labfmt.hxx"
+#include "labprt.hxx"
 #include <unotools.hxx>
 #include <dbmgr.hxx>
-#include "uitool.hxx"
+#include <uitool.hxx>
 #include <cmdid.h>
-#include <helpid.h>
+#include <helpids.h>
 #include <globals.hrc>
-#include <../../uibase/envelp/label.hrc>
+#include <strings.hrc>
 #include <envimg.hxx>
 
 void SwLabRec::SetFromItem( const SwLabItem& rItem )
 {
-    lHDist  = rItem.m_lHDist;
-    lVDist  = rItem.m_lVDist;
-    lWidth  = rItem.m_lWidth;
-    lHeight = rItem.m_lHeight;
-    lLeft   = rItem.m_lLeft;
-    lUpper  = rItem.m_lUpper;
-    nCols   = rItem.m_nCols;
-    nRows   = rItem.m_nRows;
-    lPWidth  = rItem.m_lPWidth;
-    lPHeight = rItem.m_lPHeight;
-    bCont   = rItem.m_bCont;
+    m_nHDist  = rItem.m_lHDist;
+    m_nVDist  = rItem.m_lVDist;
+    m_nWidth  = rItem.m_lWidth;
+    m_nHeight = rItem.m_lHeight;
+    m_nLeft   = rItem.m_lLeft;
+    m_nUpper  = rItem.m_lUpper;
+    m_nCols   = rItem.m_nCols;
+    m_nRows   = rItem.m_nRows;
+    m_nPWidth  = rItem.m_lPWidth;
+    m_nPHeight = rItem.m_lPHeight;
+    m_bCont   = rItem.m_bCont;
 }
 
 void SwLabRec::FillItem( SwLabItem& rItem ) const
 {
-    rItem.m_lHDist  = lHDist;
-    rItem.m_lVDist  = lVDist;
-    rItem.m_lWidth  = lWidth;
-    rItem.m_lHeight = lHeight;
-    rItem.m_lLeft   = lLeft;
-    rItem.m_lUpper  = lUpper;
-    rItem.m_nCols   = nCols;
-    rItem.m_lPWidth  = lPWidth;
-    rItem.m_lPHeight = lPHeight;
-    rItem.m_nRows   = nRows;
+    rItem.m_lHDist  = m_nHDist;
+    rItem.m_lVDist  = m_nVDist;
+    rItem.m_lWidth  = m_nWidth;
+    rItem.m_lHeight = m_nHeight;
+    rItem.m_lLeft   = m_nLeft;
+    rItem.m_lUpper  = m_nUpper;
+    rItem.m_nCols   = m_nCols;
+    rItem.m_lPWidth  = m_nPWidth;
+    rItem.m_lPHeight = m_nPHeight;
+    rItem.m_nRows   = m_nRows;
 }
 
 void SwLabDlg::ReplaceGroup_( const OUString &rMake )
@@ -99,16 +100,13 @@ SwLabDlg::SwLabDlg(vcl::Window* pParent, const SfxItemSet& rSet,
     , aTypeIds(50, 10)
     , m_pRecs(new SwLabRecs)
     , m_bLabel(bLabel)
-    , m_nFormatId(0)
     , m_nOptionsId(0)
     , m_nLabelId(0)
     , m_nCardsId(0)
-    , m_nBusinessId(0)
-    , m_nPrivateId(0)
 {
     WaitObject aWait( pParent );
 
-    m_nFormatId = AddTabPage("format", SwLabFormatPage::Create, nullptr);
+    AddTabPage("format", SwLabFormatPage::Create, nullptr);
     m_nOptionsId = AddTabPage("options", SwLabPrtPage::Create, nullptr);
     m_nCardsId = AddTabPage("cards", SwVisitingCardPage::Create, nullptr);
     m_sBusinessCardDlg = GetPageText(m_nCardsId);
@@ -126,22 +124,22 @@ SwLabDlg::SwLabDlg(vcl::Window* pParent, const SfxItemSet& rSet,
         RemoveTabPage("labels");
         RemoveTabPage("cards");
         m_nLabelId = AddTabPage("medium", SwLabPage::Create, nullptr);
-        m_nBusinessId = AddTabPage("business", SwBusinessDataPage::Create, nullptr );
-        m_nPrivateId = AddTabPage("private", SwPrivateDataPage::Create, nullptr);
+        AddTabPage("business", SwBusinessDataPage::Create, nullptr );
+        AddTabPage("private", SwPrivateDataPage::Create, nullptr);
         SetText(m_sBusinessCardDlg);
     }
     // Read user label from writer.cfg
     SwLabItem aItem(static_cast<const SwLabItem&>(rSet.Get( FN_LABEL )));
     std::unique_ptr<SwLabRec> pRec(new SwLabRec);
-    pRec->aMake = pRec->aType = SwResId( STR_CUSTOM );
+    pRec->m_aMake = pRec->m_aType = SwResId(STR_CUSTOM_LABEL);
     pRec->SetFromItem( aItem );
 
     bool bDouble = false;
 
     for (std::unique_ptr<SwLabRec> & i : *m_pRecs)
     {
-        if (pRec->aMake == i->aMake &&
-            pRec->aType == i->aType)
+        if (pRec->m_aMake == i->m_aMake &&
+            pRec->m_aType == i->m_aType)
         {
             bDouble = true;
             break;
@@ -204,14 +202,14 @@ SwLabRec* SwLabDlg::GetRecord(const OUString &rRecName, bool bCont)
 {
     SwLabRec* pRec = nullptr;
     bool bFound = false;
-    const OUString sCustom(SwResId(STR_CUSTOM));
+    const OUString sCustom(SwResId(STR_CUSTOM_LABEL));
 
     const size_t nCount = Recs().size();
     for (size_t i = 0; i < nCount; ++i)
     {
         pRec = Recs()[i].get();
-        if (pRec->aType != sCustom &&
-            rRecName == pRec->aType && bCont == pRec->bCont)
+        if (pRec->m_aType != sCustom &&
+            rRecName == pRec->m_aType && bCont == pRec->m_bCont)
         {
             bFound = true;
             break;
@@ -267,7 +265,11 @@ SwLabPage::SwLabPage(vcl::Window* pParent, const SfxItemSet& rSet)
     m_pAddrBox->SetClickHdl (LINK(this, SwLabPage, AddrHdl         ));
     m_pDatabaseLB->SetSelectHdl(LINK(this, SwLabPage, DatabaseHdl     ));
     m_pTableLB->SetSelectHdl(LINK(this, SwLabPage, DatabaseHdl     ));
+    m_pDBFieldLB->SetSelectHdl(LINK(this, SwLabPage, DatabaseHdl     ));
     m_pInsertBT->SetClickHdl (LINK(this, SwLabPage, FieldHdl        ));
+    // Disable insert button first,
+    // it'll be enabled if m_pDatabaseLB, m_pTableLB and m_pInsertBT are filled
+    m_pInsertBT->Disable();
     m_pContButton->SetClickHdl (LINK(this, SwLabPage, PageHdl         ));
     m_pSheetButton->SetClickHdl (LINK(this, SwLabPage, PageHdl         ));
     m_pMakeBox->SetSelectHdl(LINK(this, SwLabPage, MakeHdl         ));
@@ -337,22 +339,29 @@ IMPL_LINK_NOARG(SwLabPage, AddrHdl, Button*, void)
 
 IMPL_LINK( SwLabPage, DatabaseHdl, ListBox&, rListBox, void )
 {
-    sActDBName = m_pDatabaseLB->GetSelectEntry();
+    sActDBName = m_pDatabaseLB->GetSelectedEntry();
 
     WaitObject aObj( GetParentSwLabDlg() );
 
     if (&rListBox == m_pDatabaseLB)
         GetDBManager()->GetTableNames(m_pTableLB, sActDBName);
 
-    GetDBManager()->GetColumnNames(m_pDBFieldLB, sActDBName, m_pTableLB->GetSelectEntry());
+    if (&rListBox == m_pDatabaseLB || &rListBox == m_pTableLB)
+        GetDBManager()->GetColumnNames(m_pDBFieldLB, sActDBName, m_pTableLB->GetSelectedEntry());
+
+    if (!m_pDatabaseLB->GetSelectedEntry().isEmpty() && !m_pTableLB->GetSelectedEntry().isEmpty()
+            && !m_pDBFieldLB->GetSelectedEntry().isEmpty())
+        m_pInsertBT->Enable(true);
+    else
+        m_pInsertBT->Enable(false);
 }
 
 IMPL_LINK_NOARG(SwLabPage, FieldHdl, Button*, void)
 {
-    OUString aStr("<" + m_pDatabaseLB->GetSelectEntry() + "." +
-                  m_pTableLB->GetSelectEntry() + "." +
-                  (m_pTableLB->GetSelectEntryData() == nullptr ? OUString("0") : OUString("1")) + "." +
-                  m_pDBFieldLB->GetSelectEntry() + ">");
+    OUString aStr("<" + m_pDatabaseLB->GetSelectedEntry() + "." +
+                  m_pTableLB->GetSelectedEntry() + "." +
+                  (m_pTableLB->GetSelectedEntryData() == nullptr ? OUString("0") : OUString("1")) + "." +
+                  m_pDBFieldLB->GetSelectedEntry() + ">");
     m_pWritingEdit->ReplaceSelected(aStr);
     Selection aSel = m_pWritingEdit->GetSelection();
     m_pWritingEdit->GrabFocus();
@@ -372,7 +381,7 @@ IMPL_LINK_NOARG(SwLabPage, MakeHdl, ListBox&, void)
     m_pHiddenSortTypeBox->Clear();
     GetParentSwLabDlg()->TypeIds().clear();
 
-    const OUString aMake = m_pMakeBox->GetSelectEntry();
+    const OUString aMake = m_pMakeBox->GetSelectedEntry();
     GetParentSwLabDlg()->ReplaceGroup( aMake );
     aItem.m_aLstMake = aMake;
 
@@ -380,18 +389,18 @@ IMPL_LINK_NOARG(SwLabPage, MakeHdl, ListBox&, void)
     const size_t nCount   = GetParentSwLabDlg()->Recs().size();
     size_t nLstType = 0;
 
-    const OUString sCustom(SwResId(STR_CUSTOM));
+    const OUString sCustom(SwResId(STR_CUSTOM_LABEL));
     //insert the entries into the sorted list box
     for ( size_t i = 0; i < nCount; ++i )
     {
-        const OUString aType(GetParentSwLabDlg()->Recs()[i]->aType);
+        const OUString aType(GetParentSwLabDlg()->Recs()[i]->m_aType);
         bool bInsert = false;
-        if (GetParentSwLabDlg()->Recs()[i]->aType == sCustom)
+        if (GetParentSwLabDlg()->Recs()[i]->m_aType == sCustom)
         {
             bInsert = true;
             m_pTypeBox->InsertEntry(aType );
         }
-        else if (GetParentSwLabDlg()->Recs()[i]->bCont == bCont)
+        else if (GetParentSwLabDlg()->Recs()[i]->m_bCont == bCont)
         {
             if ( m_pHiddenSortTypeBox->GetEntryPos(aType) == LISTBOX_ENTRY_NOTFOUND )
             {
@@ -420,7 +429,7 @@ IMPL_LINK_NOARG(SwLabPage, MakeHdl, ListBox&, void)
 IMPL_LINK_NOARG(SwLabPage, TypeHdl, ListBox&, void)
 {
     DisplayFormat();
-    aItem.m_aType = m_pTypeBox->GetSelectEntry();
+    aItem.m_aType = m_pTypeBox->GetSelectedEntry();
 }
 
 void SwLabPage::DisplayFormat()
@@ -433,24 +442,24 @@ void SwLabPage::DisplayFormat()
     aField->SetMax         (LONG_MAX);
 
     SwLabRec* pRec = GetSelectedEntryPos();
-    aItem.m_aLstType = pRec->aType;
-    SETFLDVAL(*aField.get(), pRec->lWidth);
+    aItem.m_aLstType = pRec->m_aType;
+    SETFLDVAL(*aField.get(), pRec->m_nWidth);
     aField->Reformat();
     const OUString aWString = aField->GetText();
 
-    SETFLDVAL(*aField.get(), pRec->lHeight);
+    SETFLDVAL(*aField.get(), pRec->m_nHeight);
     aField->Reformat();
 
-    OUString aText = pRec->aType + ": " + aWString +
+    OUString aText = pRec->m_aType + ": " + aWString +
            " x " + aField->GetText() +
-           " (" + OUString::number( pRec->nCols ) +
-           " x " + OUString::number( pRec->nRows ) + ")";
+           " (" + OUString::number( pRec->m_nCols ) +
+           " x " + OUString::number( pRec->m_nRows ) + ")";
     m_pFormatInfo->SetText(aText);
 }
 
 SwLabRec* SwLabPage::GetSelectedEntryPos()
 {
-    OUString sSelEntry(m_pTypeBox->GetSelectEntry());
+    OUString sSelEntry(m_pTypeBox->GetSelectedEntry());
 
     return GetParentSwLabDlg()->GetRecord(sSelEntry, m_pContButton->IsChecked());
 }
@@ -500,15 +509,15 @@ void SwLabPage::FillItem(SwLabItem& rItem)
     rItem.m_bAddr    = m_pAddrBox->IsChecked();
     rItem.m_aWriting = m_pWritingEdit->GetText();
     rItem.m_bCont    = m_pContButton->IsChecked();
-    rItem.m_aMake    = m_pMakeBox->GetSelectEntry();
-    rItem.m_aType    = m_pTypeBox->GetSelectEntry();
+    rItem.m_aMake    = m_pMakeBox->GetSelectedEntry();
+    rItem.m_aType    = m_pTypeBox->GetSelectedEntry();
     rItem.m_sDBName  = sActDBName;
 
     SwLabRec* pRec = GetSelectedEntryPos();
     pRec->FillItem( rItem );
 
-    rItem.m_aLstMake = m_pMakeBox->GetSelectEntry();
-    rItem.m_aLstType = m_pTypeBox->GetSelectEntry();
+    rItem.m_aLstMake = m_pMakeBox->GetSelectedEntry();
+    rItem.m_aLstType = m_pTypeBox->GetSelectedEntry();
 }
 
 bool SwLabPage::FillItemSet(SfxItemSet* rSet)
@@ -531,7 +540,7 @@ void SwLabPage::Reset(const SfxItemSet* rSet)
 
     for(std::vector<OUString>::const_iterator i = GetParentSwLabDlg()->Makes().begin(); i != GetParentSwLabDlg()->Makes().end(); ++i)
     {
-        if(m_pMakeBox->GetEntryPos(OUString(*i)) == LISTBOX_ENTRY_NOTFOUND)
+        if(m_pMakeBox->GetEntryPos(*i) == LISTBOX_ENTRY_NOTFOUND)
             m_pMakeBox->InsertEntry(*i);
     }
 
@@ -642,7 +651,7 @@ DeactivateRC SwVisitingCardPage::DeactivatePage(SfxItemSet* _pSet)
 
 bool SwVisitingCardPage::FillItemSet(SfxItemSet* rSet)
 {
-    const OUString* pGroup = static_cast<const OUString*>(m_pAutoTextGroupLB->GetSelectEntryData());
+    const OUString* pGroup = static_cast<const OUString*>(m_pAutoTextGroupLB->GetSelectedEntryData());
     OSL_ENSURE(pGroup, "no group selected?");
 
     if (pGroup)
@@ -711,7 +720,7 @@ void SwVisitingCardPage::Reset(const SfxItemSet* rSet)
     }
     if(bFound)
     {
-        if(m_pAutoTextGroupLB->GetSelectEntryPos() != i)
+        if(m_pAutoTextGroupLB->GetSelectedEntryPos() != i)
         {
             m_pAutoTextGroupLB->SelectEntryPos(i);
             AutoTextSelectHdl(*m_pAutoTextGroupLB);
