@@ -23,14 +23,14 @@
 #include <docsh.hxx>
 #include <swtypes.hxx>
 #include <globals.hrc>
+#include <strings.hrc>
 #include <fldbas.hxx>
 #include <docufld.hxx>
 #include <view.hxx>
 #include <wrtsh.hxx>
 #include <swmodule.hxx>
-#include <fldfunc.hxx>
+#include "fldfunc.hxx"
 #include <flddropdown.hxx>
-#include <fldui.hrc>
 
 #define USER_DATA_VERSION_1 "1"
 #define USER_DATA_VERSION USER_DATA_VERSION_1
@@ -210,13 +210,22 @@ void SwFieldFuncPage::Reset(const SfxItemSet* )
     }
 }
 
+static const char* FMT_MARK_ARY[] =
+{
+    FMT_MARK_TEXT,
+    FMT_MARK_TABLE,
+    FMT_MARK_FRAME,
+    FMT_MARK_GRAFIC,
+    FMT_MARK_OLE
+};
+
 IMPL_LINK_NOARG(SwFieldFuncPage, TypeHdl, ListBox&, void)
 {
     // save old ListBoxPos
     const sal_Int32 nOld = GetTypeSel();
 
     // current ListBoxPos
-    SetTypeSel(m_pTypeLB->GetSelectEntryPos());
+    SetTypeSel(m_pTypeLB->GetSelectedEntryPos());
 
     if(GetTypeSel() == LISTBOX_ENTRY_NOTFOUND)
     {
@@ -224,183 +233,184 @@ IMPL_LINK_NOARG(SwFieldFuncPage, TypeHdl, ListBox&, void)
         m_pTypeLB->SelectEntryPos(0);
     }
 
-    if (nOld != GetTypeSel())
+    if (nOld == GetTypeSel())
+        return;
+
+    const sal_uInt16 nTypeId = (sal_uInt16)reinterpret_cast<sal_uLong>(m_pTypeLB->GetEntryData(GetTypeSel()));
+
+    // fill Selection-Listbox
+    UpdateSubType();
+
+    // fill Format-Listbox
+    m_pFormatLB->Clear();
+
+    const sal_uInt16 nSize = GetFieldMgr().GetFormatCount(nTypeId, IsFieldDlgHtmlMode());
+
+    for (sal_uInt16 i = 0; i < nSize; i++)
     {
-        const sal_uInt16 nTypeId = (sal_uInt16)reinterpret_cast<sal_uLong>(m_pTypeLB->GetEntryData(GetTypeSel()));
+        sal_Int32 nPos = m_pFormatLB->InsertEntry(GetFieldMgr().GetFormatStr(nTypeId, i));
+        m_pFormatLB->SetEntryData( nPos, reinterpret_cast<void*>(GetFieldMgr().GetFormatId( nTypeId, i )) );
+    }
 
-        // fill Selection-Listbox
-        UpdateSubType();
+    if (nSize)
+    {
+        if (IsFieldEdit() && nTypeId == TYP_JUMPEDITFLD)
+            m_pFormatLB->SelectEntry(SwResId(FMT_MARK_ARY[GetCurField()->GetFormat()]));
 
-        // fill Format-Listbox
-        m_pFormatLB->Clear();
+        if (!m_pFormatLB->GetSelectedEntryCount())
+            m_pFormatLB->SelectEntryPos(0);
+    }
 
-        const sal_uInt16 nSize = GetFieldMgr().GetFormatCount(nTypeId, IsFieldDlgHtmlMode());
+    bool bValue = false, bName = false, bMacro = false, bInsert = true;
+    bool bFormat = nSize != 0;
 
-        for (sal_uInt16 i = 0; i < nSize; i++)
+    // two controls for conditional text
+    bool bDropDown = TYP_DROPDOWN == nTypeId;
+    bool bCondTextField = TYP_CONDTXTFLD == nTypeId;
+
+    m_pCond1FT->Show(!bDropDown && bCondTextField);
+    m_pCond1ED->Show(!bDropDown && bCondTextField);
+    m_pCond2FT->Show(!bDropDown && bCondTextField);
+    m_pCond2ED->Show(!bDropDown && bCondTextField);
+    m_pValueGroup->Show(!bDropDown && !bCondTextField);
+    m_pMacroBT->Show(!bDropDown);
+    m_pNameED->Show(!bDropDown);
+    m_pNameFT->Show(!bDropDown);
+
+    m_pListGroup->Show(bDropDown);
+
+    m_pNameED->SetDropEnable(false);
+
+    if (IsFieldEdit())
+    {
+        if(bDropDown)
         {
-            sal_Int32 nPos = m_pFormatLB->InsertEntry(GetFieldMgr().GetFormatStr(nTypeId, i));
-            m_pFormatLB->SetEntryData( nPos, reinterpret_cast<void*>(GetFieldMgr().GetFormatId( nTypeId, i )) );
-        }
-
-        if (nSize)
-        {
-            if (IsFieldEdit() && nTypeId == TYP_JUMPEDITFLD)
-                m_pFormatLB->SelectEntry(SwResId(FMT_MARK_BEGIN + GetCurField()->GetFormat()));
-
-            if (!m_pFormatLB->GetSelectEntryCount())
-                m_pFormatLB->SelectEntryPos(0);
-        }
-
-        bool bValue = false, bName = false, bMacro = false, bInsert = true;
-        bool bFormat = nSize != 0;
-
-        // two controls for conditional text
-        bool bDropDown = TYP_DROPDOWN == nTypeId;
-        bool bCondTextField = TYP_CONDTXTFLD == nTypeId;
-
-        m_pCond1FT->Show(!bDropDown && bCondTextField);
-        m_pCond1ED->Show(!bDropDown && bCondTextField);
-        m_pCond2FT->Show(!bDropDown && bCondTextField);
-        m_pCond2ED->Show(!bDropDown && bCondTextField);
-        m_pValueGroup->Show(!bDropDown && !bCondTextField);
-        m_pMacroBT->Show(!bDropDown);
-        m_pNameED->Show(!bDropDown);
-        m_pNameFT->Show(!bDropDown);
-
-        m_pListGroup->Show(bDropDown);
-
-        m_pNameED->SetDropEnable(false);
-
-        if (IsFieldEdit())
-        {
-            if(bDropDown)
-            {
-                const SwDropDownField* pDrop = static_cast<const SwDropDownField*>(GetCurField());
-                uno::Sequence<OUString> aItems = pDrop->GetItemSequence();
-                const OUString* pArray = aItems.getConstArray();
-                m_pListItemsLB->Clear();
-                for(sal_Int32 i = 0; i < aItems.getLength(); i++)
-                    m_pListItemsLB->InsertEntry(pArray[i]);
-                m_pListItemsLB->SelectEntry(pDrop->GetSelectedItem());
-                m_pListNameED->SetText(pDrop->GetPar2());
-                m_pListNameED->SaveValue();
-                bDropDownLBChanged = false;
-            }
-            else
-            {
-                m_pNameED->SetText(GetCurField()->GetPar1());
-                m_pValueED->SetText(GetCurField()->GetPar2());
-            }
+            const SwDropDownField* pDrop = static_cast<const SwDropDownField*>(GetCurField());
+            uno::Sequence<OUString> aItems = pDrop->GetItemSequence();
+            const OUString* pArray = aItems.getConstArray();
+            m_pListItemsLB->Clear();
+            for(sal_Int32 i = 0; i < aItems.getLength(); i++)
+                m_pListItemsLB->InsertEntry(pArray[i]);
+            m_pListItemsLB->SelectEntry(pDrop->GetSelectedItem());
+            m_pListNameED->SetText(pDrop->GetPar2());
+            m_pListNameED->SaveValue();
+            bDropDownLBChanged = false;
         }
         else
         {
-            m_pNameED->SetText(OUString());
-            m_pValueED->SetText(OUString());
+            m_pNameED->SetText(GetCurField()->GetPar1());
+            m_pValueED->SetText(GetCurField()->GetPar2());
         }
-        if(bDropDown)
-            ListEnableHdl(*m_pListItemED);
+    }
+    else
+    {
+        m_pNameED->SetText(OUString());
+        m_pValueED->SetText(OUString());
+    }
+    if(bDropDown)
+        ListEnableHdl(*m_pListItemED);
 
-        if (m_pNameFT->GetText() != m_sOldNameFT)
-            m_pNameFT->SetText(m_sOldNameFT);
-        if (m_pValueFT->GetText() != m_sOldValueFT)
-            m_pValueFT->SetText(m_sOldValueFT);
+    if (m_pNameFT->GetText() != m_sOldNameFT)
+        m_pNameFT->SetText(m_sOldNameFT);
+    if (m_pValueFT->GetText() != m_sOldValueFT)
+        m_pValueFT->SetText(m_sOldValueFT);
 
-        switch (nTypeId)
+    switch (nTypeId)
+    {
+        case TYP_MACROFLD:
+            bMacro = true;
+            if (!GetFieldMgr().GetMacroPath().isEmpty())
+                bValue = true;
+            else
+                bInsert = false;
+
+            m_pNameFT->SetText(SwResId(STR_MACNAME));
+            m_pValueFT->SetText(SwResId(STR_PROMPT));
+            m_pNameED->SetText(GetFieldMgr().GetMacroName());
+            m_pNameED->SetAccessibleName(m_pNameFT->GetText());
+            m_pValueED->SetAccessibleName(m_pValueFT->GetText());
+            break;
+
+        case TYP_HIDDENPARAFLD:
+            m_pNameFT->SetText(SwResId(STR_COND));
+            m_pNameED->SetDropEnable(true);
+            bName = true;
+            m_pNameED->SetAccessibleName(m_pNameFT->GetText());
+            m_pValueED->SetAccessibleName(m_pValueFT->GetText());
+            break;
+
+        case TYP_HIDDENTXTFLD:
         {
-            case TYP_MACROFLD:
-                bMacro = true;
-                if (!GetFieldMgr().GetMacroPath().isEmpty())
-                    bValue = true;
-                else
-                    bInsert = false;
+            m_pNameFT->SetText(SwResId(STR_COND));
+            m_pNameED->SetDropEnable(true);
+            m_pValueFT->SetText(SwResId(STR_INSTEXT));
+            SwWrtShell* pSh = GetActiveWrtShell();
+            if (!IsFieldEdit() && pSh )
+                m_pValueED->SetText(pSh->GetSelText());
+            bName = bValue = true;
+            m_pNameED->SetAccessibleName(m_pNameFT->GetText());
+            m_pValueED->SetAccessibleName(m_pValueFT->GetText());
+        }
+        break;
 
-                m_pNameFT->SetText(SwResId(STR_MACNAME));
-                m_pValueFT->SetText(SwResId(STR_PROMPT));
-                m_pNameED->SetText(GetFieldMgr().GetMacroName());
-                m_pNameED->SetAccessibleName(m_pNameFT->GetText());
-                m_pValueED->SetAccessibleName(m_pValueFT->GetText());
-                break;
+        case TYP_CONDTXTFLD:
+            m_pNameFT->SetText(SwResId(STR_COND));
+            m_pNameED->SetDropEnable(true);
+            if (IsFieldEdit())
+            {
+                m_pCond1ED->SetText(GetCurField()->GetPar2().getToken(0, '|'));
+                m_pCond2ED->SetText(GetCurField()->GetPar2().getToken(1, '|'));
+            }
 
-            case TYP_HIDDENPARAFLD:
-                m_pNameFT->SetText(SwResId(STR_COND));
+            bName = bValue = true;
+            m_pNameED->SetAccessibleName(m_pNameFT->GetText());
+            m_pValueED->SetAccessibleName(m_pValueFT->GetText());
+            break;
+
+        case TYP_JUMPEDITFLD:
+            m_pNameFT->SetText(SwResId(STR_JUMPEDITFLD));
+            m_pValueFT->SetText(SwResId(STR_PROMPT));
+            bName = bValue = true;
+            m_pNameED->SetAccessibleName(m_pNameFT->GetText());
+            m_pValueED->SetAccessibleName(m_pValueFT->GetText());
+            break;
+
+        case TYP_INPUTFLD:
+            m_pValueFT->SetText(SwResId(STR_PROMPT));
+            bValue = true;
+            m_pNameED->SetAccessibleName(m_pNameFT->GetText());
+            m_pValueED->SetAccessibleName(m_pValueFT->GetText());
+            break;
+
+        case TYP_COMBINED_CHARS:
+            {
+                m_pNameFT->SetText(SwResId(STR_COMBCHRS_FT));
                 m_pNameED->SetDropEnable(true);
                 bName = true;
-                m_pNameED->SetAccessibleName(m_pNameFT->GetText());
-                m_pValueED->SetAccessibleName(m_pValueFT->GetText());
-                break;
 
-            case TYP_HIDDENTXTFLD:
-            {
-                m_pNameFT->SetText(SwResId(STR_COND));
-                m_pNameED->SetDropEnable(true);
-                m_pValueFT->SetText(SwResId(STR_INSTEXT));
-                SwWrtShell* pSh = GetActiveWrtShell();
-                if (!IsFieldEdit() && pSh )
-                    m_pValueED->SetText(pSh->GetSelText());
-                bName = bValue = true;
+                const sal_Int32 nLen = m_pNameED->GetText().getLength();
+                if( !nLen || nLen > MAX_COMBINED_CHARACTERS )
+                    bInsert = false;
                 m_pNameED->SetAccessibleName(m_pNameFT->GetText());
                 m_pValueED->SetAccessibleName(m_pValueFT->GetText());
             }
             break;
-
-            case TYP_CONDTXTFLD:
-                m_pNameFT->SetText(SwResId(STR_COND));
-                m_pNameED->SetDropEnable(true);
-                if (IsFieldEdit())
-                {
-                    m_pCond1ED->SetText(GetCurField()->GetPar2().getToken(0, '|'));
-                    m_pCond2ED->SetText(GetCurField()->GetPar2().getToken(1, '|'));
-                }
-
-                bName = bValue = true;
-                m_pNameED->SetAccessibleName(m_pNameFT->GetText());
-                m_pValueED->SetAccessibleName(m_pValueFT->GetText());
-                break;
-
-            case TYP_JUMPEDITFLD:
-                m_pNameFT->SetText(SwResId(STR_JUMPEDITFLD));
-                m_pValueFT->SetText(SwResId(STR_PROMPT));
-                bName = bValue = true;
-                m_pNameED->SetAccessibleName(m_pNameFT->GetText());
-                m_pValueED->SetAccessibleName(m_pValueFT->GetText());
-                break;
-
-            case TYP_INPUTFLD:
-                m_pValueFT->SetText(SwResId(STR_PROMPT));
-                bValue = true;
-                m_pNameED->SetAccessibleName(m_pNameFT->GetText());
-                m_pValueED->SetAccessibleName(m_pValueFT->GetText());
-                break;
-
-            case TYP_COMBINED_CHARS:
-                {
-                    m_pNameFT->SetText(SwResId(STR_COMBCHRS_FT));
-                    m_pNameED->SetDropEnable(true);
-                    bName = true;
-
-                    const sal_Int32 nLen = m_pNameED->GetText().getLength();
-                    if( !nLen || nLen > MAX_COMBINED_CHARACTERS )
-                        bInsert = false;
-                    m_pNameED->SetAccessibleName(m_pNameFT->GetText());
-                    m_pValueED->SetAccessibleName(m_pValueFT->GetText());
-                }
-                break;
-            case TYP_DROPDOWN :
+        case TYP_DROPDOWN :
+        break;
+        default:
             break;
-            default:
-                break;
-        }
-
-        m_pSelectionLB->Hide();
-
-        m_pFormat->Enable(bFormat);
-        m_pNameFT->Enable(bName);
-        m_pNameED->Enable(bName);
-        m_pValueGroup->Enable(bValue);
-        m_pMacroBT->Enable(bMacro);
-
-        EnableInsert( bInsert );
     }
+
+    m_pSelectionLB->Hide();
+
+    m_pFormat->Enable(bFormat);
+    m_pNameFT->Enable(bName);
+    m_pNameED->Enable(bName);
+    m_pValueGroup->Enable(bValue);
+    m_pMacroBT->Enable(bMacro);
+
+    EnableInsert( bInsert );
+
 }
 
 IMPL_LINK_NOARG(SwFieldFuncPage, SelectHdl, ListBox&, void)
@@ -408,7 +418,7 @@ IMPL_LINK_NOARG(SwFieldFuncPage, SelectHdl, ListBox&, void)
     const sal_uInt16 nTypeId = (sal_uInt16)reinterpret_cast<sal_uLong>(m_pTypeLB->GetEntryData(GetTypeSel()));
 
     if( TYP_MACROFLD == nTypeId )
-        m_pNameED->SetText( m_pSelectionLB->GetSelectEntry() );
+        m_pNameED->SetText( m_pSelectionLB->GetSelectedEntry() );
 }
 
 IMPL_LINK_NOARG(SwFieldFuncPage, InsertMacroHdl, ListBox&, void)
@@ -425,7 +435,7 @@ IMPL_LINK( SwFieldFuncPage, ListModifyReturnActionHdl, ReturnActionEdit&, rContr
 {
     ListModifyHdl(&rControl);
 }
-void SwFieldFuncPage::ListModifyHdl(Control* pControl)
+void SwFieldFuncPage::ListModifyHdl(Control const * pControl)
 {
     m_pListItemsLB->SetUpdateMode(false);
     if(pControl == m_pListAddPB ||
@@ -435,9 +445,9 @@ void SwFieldFuncPage::ListModifyHdl(Control* pControl)
         m_pListItemsLB->InsertEntry(sEntry);
         m_pListItemsLB->SelectEntry(sEntry);
     }
-    else if(m_pListItemsLB->GetSelectEntryCount())
+    else if(m_pListItemsLB->GetSelectedEntryCount())
     {
-        sal_Int32 nSelPos = m_pListItemsLB->GetSelectEntryPos();
+        sal_Int32 nSelPos = m_pListItemsLB->GetSelectedEntryPos();
         if(pControl == m_pListRemovePB)
         {
             m_pListItemsLB->RemoveEntry(nSelPos);
@@ -447,7 +457,7 @@ void SwFieldFuncPage::ListModifyHdl(Control* pControl)
         {
             if(nSelPos)
             {
-                const OUString sEntry = m_pListItemsLB->GetSelectEntry();
+                const OUString sEntry = m_pListItemsLB->GetSelectedEntry();
                 m_pListItemsLB->RemoveEntry(nSelPos);
                 nSelPos--;
                 m_pListItemsLB->InsertEntry(sEntry, nSelPos);
@@ -458,7 +468,7 @@ void SwFieldFuncPage::ListModifyHdl(Control* pControl)
         {
             if(nSelPos < m_pListItemsLB->GetEntryCount() - 1)
             {
-                const OUString sEntry = m_pListItemsLB->GetSelectEntry();
+                const OUString sEntry = m_pListItemsLB->GetSelectedEntry();
                 m_pListItemsLB->RemoveEntry(nSelPos);
                 nSelPos++;
                 m_pListItemsLB->InsertEntry(sEntry, nSelPos);
@@ -480,11 +490,11 @@ IMPL_LINK_NOARG(SwFieldFuncPage, ListEnableHdl, Edit&, void)
     //enable "Add" button when text is in the Edit that's not already member of the box
     m_pListAddPB->Enable(!m_pListItemED->GetText().isEmpty() &&
                 LISTBOX_ENTRY_NOTFOUND == m_pListItemsLB->GetEntryPos(m_pListItemED->GetText()));
-    bool bEnableButtons = m_pListItemsLB->GetSelectEntryCount() > 0;
+    bool bEnableButtons = m_pListItemsLB->GetSelectedEntryCount() > 0;
     m_pListRemovePB->Enable(bEnableButtons);
-    m_pListUpPB->Enable(bEnableButtons && (m_pListItemsLB->GetSelectEntryPos() > 0));
+    m_pListUpPB->Enable(bEnableButtons && (m_pListItemsLB->GetSelectedEntryPos() > 0));
     m_pListDownPB->Enable(bEnableButtons &&
-                (m_pListItemsLB->GetSelectEntryPos() < (m_pListItemsLB->GetEntryCount() - 1)));
+                (m_pListItemsLB->GetSelectedEntryPos() < (m_pListItemsLB->GetEntryCount() - 1)));
 }
 
 // renew types in SelectionBox
@@ -543,7 +553,7 @@ bool SwFieldFuncPage::FillItemSet(SfxItemSet* )
 
     sal_uInt16 nSubType = 0;
 
-    const sal_Int32 nEntryPos = m_pFormatLB->GetSelectEntryPos();
+    const sal_Int32 nEntryPos = m_pFormatLB->GetSelectedEntryPos();
     const sal_uLong nFormat = (nEntryPos == LISTBOX_ENTRY_NOTFOUND)
         ? 0 : reinterpret_cast<sal_uLong>(m_pFormatLB->GetEntryData(nEntryPos));
 
@@ -613,7 +623,7 @@ sal_uInt16 SwFieldFuncPage::GetGroup()
 
 void    SwFieldFuncPage::FillUserData()
 {
-    const sal_Int32 nEntryPos = m_pTypeLB->GetSelectEntryPos();
+    const sal_Int32 nEntryPos = m_pTypeLB->GetSelectedEntryPos();
     const sal_uInt16 nTypeSel = ( LISTBOX_ENTRY_NOTFOUND == nEntryPos )
         ? USHRT_MAX
         : sal::static_int_cast< sal_uInt16 >
