@@ -16,6 +16,10 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
+
+#include <sal/config.h>
+
+#include "service.hxx"
 #include "vbadocument.hxx"
 #include "vbarange.hxx"
 #include "vbarangehelper.hxx"
@@ -33,7 +37,7 @@
 #include <ooo/vba/word/WdProtectionType.hpp>
 
 #include <vbahelper/helperdecl.hxx>
-#include <wordvbahelper.hxx>
+#include "wordvbahelper.hxx"
 #include <docsh.hxx>
 #include "vbatemplate.hxx"
 #include "vbaparagraph.hxx"
@@ -47,14 +51,14 @@
 #include <vbahelper/vbahelper.hxx>
 #include "vbarevisions.hxx"
 #include "vbaframes.hxx"
-#include "vbaformfields.hxx"
+#include <basic/sberrors.hxx>
 #include <osl/file.hxx>
 #include <tools/urlobj.hxx>
 
 using namespace ::ooo::vba;
 using namespace ::com::sun::star;
 
-SwVbaDocument::SwVbaDocument( const uno::Reference< XHelperInterface >& xParent, const uno::Reference< uno::XComponentContext >& xContext, uno::Reference< frame::XModel > xModel ): SwVbaDocument_BASE( xParent, xContext, xModel )
+SwVbaDocument::SwVbaDocument( const uno::Reference< XHelperInterface >& xParent, const uno::Reference< uno::XComponentContext >& xContext, uno::Reference< frame::XModel > const & xModel ): SwVbaDocument_BASE( xParent, xContext, xModel )
 {
     Initialize();
 }
@@ -73,15 +77,15 @@ void SwVbaDocument::Initialize()
 }
 
 uno::Reference< word::XRange > SAL_CALL
-SwVbaDocument::getContent() throw ( uno::RuntimeException )
+SwVbaDocument::getContent()
 {
     uno::Reference< text::XTextRange > xStart = mxTextDocument->getText()->getStart();
     uno::Reference< text::XTextRange > xEnd;
-    return uno::Reference< word::XRange >( new SwVbaRange( this, mxContext, mxTextDocument, xStart, xEnd, sal_True ) );
+    return uno::Reference< word::XRange >( new SwVbaRange( this, mxContext, mxTextDocument, xStart, xEnd ) );
 }
 
 uno::Reference< word::XRange > SAL_CALL
-SwVbaDocument::Range( const uno::Any& rStart, const uno::Any& rEnd ) throw ( uno::RuntimeException )
+SwVbaDocument::Range( const uno::Any& rStart, const uno::Any& rEnd )
 {
     if( !rStart.hasValue() && !rEnd.hasValue() )
         return getContent();
@@ -118,14 +122,14 @@ SwVbaDocument::Range( const uno::Any& rStart, const uno::Any& rEnd ) throw ( uno
         }
         catch(const uno::Exception&)
         {
-            DebugHelper::exception(SbERR_METHOD_FAILED, OUString());
+            DebugHelper::basicexception(ERRCODE_BASIC_METHOD_FAILED, OUString());
         }
     }
     return uno::Reference< word::XRange >( new SwVbaRange( this, mxContext, mxTextDocument, xStart, xEnd ) );
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::BuiltInDocumentProperties( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::BuiltInDocumentProperties( const uno::Any& index )
 {
     uno::Reference< XCollection > xCol( new SwVbaBuiltinDocumentProperties( mxParent, mxContext, getModel() ) );
     if ( index.hasValue() )
@@ -134,7 +138,7 @@ SwVbaDocument::BuiltInDocumentProperties( const uno::Any& index ) throw (uno::Ru
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::CustomDocumentProperties( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::CustomDocumentProperties( const uno::Any& index )
 {
     uno::Reference< XCollection > xCol( new SwVbaCustomDocumentProperties( mxParent, mxContext, getModel() ) );
     if ( index.hasValue() )
@@ -143,7 +147,7 @@ SwVbaDocument::CustomDocumentProperties( const uno::Any& index ) throw (uno::Run
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Bookmarks( const uno::Any& rIndex ) throw ( uno::RuntimeException )
+SwVbaDocument::Bookmarks( const uno::Any& rIndex )
 {
     uno::Reference< text::XBookmarksSupplier > xBookmarksSupplier( getModel(),uno::UNO_QUERY_THROW );
     uno::Reference<container::XIndexAccess > xBookmarks( xBookmarksSupplier->getBookmarks(), uno::UNO_QUERY_THROW );
@@ -155,10 +159,10 @@ SwVbaDocument::Bookmarks( const uno::Any& rIndex ) throw ( uno::RuntimeException
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Variables( const uno::Any& rIndex ) throw ( uno::RuntimeException )
+SwVbaDocument::Variables( const uno::Any& rIndex )
 {
-    uno::Reference< document::XDocumentPropertiesSupplier > xDocumentPropertiesSupplier( getModel(),uno::UNO_QUERY_THROW );
-    uno::Reference< document::XDocumentProperties > xDocumentProperties =  xDocumentPropertiesSupplier->getDocumentProperties();
+    uno::Reference< css::document::XDocumentPropertiesSupplier > xDocumentPropertiesSupplier( getModel(),uno::UNO_QUERY_THROW );
+    uno::Reference< css::document::XDocumentProperties > xDocumentProperties =  xDocumentPropertiesSupplier->getDocumentProperties();
     uno::Reference< beans::XPropertyAccess > xUserDefined( xDocumentProperties->getUserDefinedProperties(), uno::UNO_QUERY_THROW );
 
     uno::Reference< XCollection > xVariables( new SwVbaVariables( this, mxContext, xUserDefined ) );
@@ -169,7 +173,7 @@ SwVbaDocument::Variables( const uno::Any& rIndex ) throw ( uno::RuntimeException
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Paragraphs( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::Paragraphs( const uno::Any& index )
 {
     uno::Reference< XCollection > xCol( new SwVbaParagraphs( mxParent, mxContext, mxTextDocument ) );
     if ( index.hasValue() )
@@ -178,7 +182,7 @@ SwVbaDocument::Paragraphs( const uno::Any& index ) throw (uno::RuntimeException)
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Styles( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::Styles( const uno::Any& index )
 {
     uno::Reference< XCollection > xCol( new SwVbaStyles( mxParent, mxContext, getModel() ) );
     if ( index.hasValue() )
@@ -187,7 +191,7 @@ SwVbaDocument::Styles( const uno::Any& index ) throw (uno::RuntimeException)
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Fields( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::Fields( const uno::Any& index )
 {
     uno::Reference< XCollection > xCol( new SwVbaFields( mxParent, mxContext, getModel() ) );
     if ( index.hasValue() )
@@ -196,7 +200,7 @@ SwVbaDocument::Fields( const uno::Any& index ) throw (uno::RuntimeException)
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Shapes( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::Shapes( const uno::Any& index )
 {
     uno::Reference< drawing::XDrawPageSupplier > xDrawPageSupplier( getModel(), uno::UNO_QUERY_THROW );
     uno::Reference< container::XIndexAccess > xIndexAccess( xDrawPageSupplier->getDrawPage(), uno::UNO_QUERY_THROW );
@@ -209,7 +213,7 @@ SwVbaDocument::Shapes( const uno::Any& index ) throw (uno::RuntimeException)
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Sections( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::Sections( const uno::Any& index )
 {
     uno::Reference< XCollection > xCol( new SwVbaSections( mxParent, mxContext, getModel() ) );
     if ( index.hasValue() )
@@ -218,7 +222,7 @@ SwVbaDocument::Sections( const uno::Any& index ) throw (uno::RuntimeException)
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::TablesOfContents( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::TablesOfContents( const uno::Any& index )
 {
     uno::Reference< XCollection > xCol( new SwVbaTablesOfContents( this, mxContext, mxTextDocument ) );
     if ( index.hasValue() )
@@ -227,14 +231,14 @@ SwVbaDocument::TablesOfContents( const uno::Any& index ) throw (uno::RuntimeExce
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::FormFields( const uno::Any& /*index*/ ) throw (uno::RuntimeException)
+SwVbaDocument::FormFields( const uno::Any& /*index*/ )
 {
     uno::Reference< XCollection > xCol;
     return uno::makeAny( xCol );
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::PageSetup( ) throw (uno::RuntimeException)
+SwVbaDocument::PageSetup( )
 {
     uno::Reference< beans::XPropertySet > xPageProps( word::getCurrentPageStyle( mxModel ), uno::UNO_QUERY_THROW );
     return uno::makeAny( uno::Reference< word::XPageSetup >( new SwVbaPageSetup( this, mxContext, mxModel, xPageProps ) ) );
@@ -247,20 +251,20 @@ SwVbaDocument::getServiceImplName()
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::getAttachedTemplate() throw (uno::RuntimeException)
+SwVbaDocument::getAttachedTemplate()
 {
     uno::Reference< word::XTemplate > xTemplate;
-    uno::Reference<document::XDocumentPropertiesSupplier> const xDocPropSupp(
+    uno::Reference<css::document::XDocumentPropertiesSupplier> const xDocPropSupp(
             getModel(), uno::UNO_QUERY_THROW);
-    uno::Reference< document::XDocumentProperties > xDocProps( xDocPropSupp->getDocumentProperties(), uno::UNO_QUERY_THROW );
+    uno::Reference< css::document::XDocumentProperties > xDocProps( xDocPropSupp->getDocumentProperties(), uno::UNO_QUERY_THROW );
     OUString sTemplateUrl = xDocProps->getTemplateURL();
 
-    xTemplate = new SwVbaTemplate( this, mxContext, getModel(), sTemplateUrl );
+    xTemplate = new SwVbaTemplate( this, mxContext, sTemplateUrl );
     return uno::makeAny( xTemplate );
 }
 
 void SAL_CALL
-SwVbaDocument::setAttachedTemplate( const css::uno::Any& _attachedtemplate ) throw (uno::RuntimeException)
+SwVbaDocument::setAttachedTemplate( const css::uno::Any& _attachedtemplate )
 {
     OUString sTemplate;
     if( !( _attachedtemplate >>= sTemplate ) )
@@ -270,21 +274,20 @@ SwVbaDocument::setAttachedTemplate( const css::uno::Any& _attachedtemplate ) thr
     OUString aURL;
     INetURLObject aObj;
     aObj.SetURL( sTemplate );
-    bool bIsURL = aObj.GetProtocol() != INET_PROT_NOT_VALID;
+    bool bIsURL = aObj.GetProtocol() != INetProtocol::NotValid;
     if ( bIsURL )
         aURL = sTemplate;
     else
         osl::FileBase::getFileURLFromSystemPath( sTemplate, aURL );
 
-    uno::Reference< word::XTemplate > xTemplate;
-    uno::Reference<document::XDocumentPropertiesSupplier> const xDocPropSupp(
+    uno::Reference<css::document::XDocumentPropertiesSupplier> const xDocPropSupp(
             getModel(), uno::UNO_QUERY_THROW );
-    uno::Reference< document::XDocumentProperties > xDocProps( xDocPropSupp->getDocumentProperties(), uno::UNO_QUERY_THROW );
+    uno::Reference< css::document::XDocumentProperties > xDocProps( xDocPropSupp->getDocumentProperties(), uno::UNO_QUERY_THROW );
     xDocProps->setTemplateURL( aURL );
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Tables( const css::uno::Any& aIndex ) throw (uno::RuntimeException)
+SwVbaDocument::Tables( const css::uno::Any& aIndex )
 {
     uno::Reference< frame::XModel > xModel( mxTextDocument, uno::UNO_QUERY_THROW );
     uno::Reference< XCollection > xColl( new SwVbaTables( mxParent, mxContext, xModel ) );
@@ -294,61 +297,61 @@ SwVbaDocument::Tables( const css::uno::Any& aIndex ) throw (uno::RuntimeExceptio
     return uno::makeAny( xColl );
 }
 
-void SAL_CALL SwVbaDocument::Activate() throw (uno::RuntimeException)
+void SAL_CALL SwVbaDocument::Activate()
 {
     VbaDocumentBase::Activate();
 }
 
-::sal_Int32 SAL_CALL SwVbaDocument::getProtectionType() throw (css::uno::RuntimeException)
+::sal_Int32 SAL_CALL SwVbaDocument::getProtectionType()
 {
     //TODO
     return word::WdProtectionType::wdNoProtection;
 }
 
-void SAL_CALL SwVbaDocument::setProtectionType( ::sal_Int32 /*_protectiontype*/ ) throw (css::uno::RuntimeException)
+void SAL_CALL SwVbaDocument::setProtectionType( ::sal_Int32 /*_protectiontype*/ )
 {
     //TODO
 }
 
-::sal_Bool SAL_CALL SwVbaDocument::getUpdateStylesOnOpen() throw (css::uno::RuntimeException)
+sal_Bool SAL_CALL SwVbaDocument::getUpdateStylesOnOpen()
 {
     //TODO
-    return sal_False;
+    return false;
 }
 
-void SAL_CALL SwVbaDocument::setUpdateStylesOnOpen( ::sal_Bool /*_updatestylesonopen*/ ) throw (uno::RuntimeException)
+void SAL_CALL SwVbaDocument::setUpdateStylesOnOpen( sal_Bool /*_updatestylesonopen*/ )
 {
     //TODO
 }
 
-::sal_Bool SAL_CALL SwVbaDocument::getAutoHyphenation() throw (uno::RuntimeException)
+sal_Bool SAL_CALL SwVbaDocument::getAutoHyphenation()
 {
     // check this property only in default paragraph style
-    sal_Bool IsAutoHyphenation = sal_False;
+    bool IsAutoHyphenation = false;
     uno::Reference< beans::XPropertySet > xParaProps( word::getDefaultParagraphStyle( getModel() ), uno::UNO_QUERY_THROW );
     xParaProps->getPropertyValue("ParaIsHyphenation") >>= IsAutoHyphenation;
     return IsAutoHyphenation;
 }
 
-void SAL_CALL SwVbaDocument::setAutoHyphenation( ::sal_Bool _autohyphenation ) throw (uno::RuntimeException)
+void SAL_CALL SwVbaDocument::setAutoHyphenation( sal_Bool _autohyphenation )
 {
     //TODO
     uno::Reference< beans::XPropertySet > xParaProps( word::getDefaultParagraphStyle( getModel() ), uno::UNO_QUERY_THROW );
     xParaProps->setPropertyValue("ParaIsHyphenation", uno::makeAny( _autohyphenation ) );
 }
 
-::sal_Int32 SAL_CALL SwVbaDocument::getHyphenationZone() throw (uno::RuntimeException)
+::sal_Int32 SAL_CALL SwVbaDocument::getHyphenationZone()
 {
     //TODO
     return 0;
 }
 
-void SAL_CALL SwVbaDocument::setHyphenationZone( ::sal_Int32 /*_hyphenationzone*/ ) throw (uno::RuntimeException)
+void SAL_CALL SwVbaDocument::setHyphenationZone( ::sal_Int32 /*_hyphenationzone*/ )
 {
     //TODO
 }
 
-::sal_Int32 SAL_CALL SwVbaDocument::getConsecutiveHyphensLimit() throw (uno::RuntimeException)
+::sal_Int32 SAL_CALL SwVbaDocument::getConsecutiveHyphensLimit()
 {
     //TODO
     sal_Int16 nHyphensLimit = 0;
@@ -357,40 +360,40 @@ void SAL_CALL SwVbaDocument::setHyphenationZone( ::sal_Int32 /*_hyphenationzone*
     return nHyphensLimit;
 }
 
-void SAL_CALL SwVbaDocument::setConsecutiveHyphensLimit( ::sal_Int32 _consecutivehyphenslimit ) throw (uno::RuntimeException)
+void SAL_CALL SwVbaDocument::setConsecutiveHyphensLimit( ::sal_Int32 _consecutivehyphenslimit )
 {
     sal_Int16 nHyphensLimit = static_cast< sal_Int16 >( _consecutivehyphenslimit );
     uno::Reference< beans::XPropertySet > xParaProps( word::getDefaultParagraphStyle( getModel() ), uno::UNO_QUERY_THROW );
     xParaProps->setPropertyValue("ParaHyphenationMaxHyphens", uno::makeAny( nHyphensLimit ) );
 }
 
-void SAL_CALL SwVbaDocument::Protect( ::sal_Int32 /*Type*/, const uno::Any& /*NOReset*/, const uno::Any& /*Password*/, const uno::Any& /*UseIRM*/, const uno::Any& /*EnforceStyleLock*/ ) throw (uno::RuntimeException)
+void SAL_CALL SwVbaDocument::Protect( ::sal_Int32 /*Type*/, const uno::Any& /*NOReset*/, const uno::Any& /*Password*/, const uno::Any& /*UseIRM*/, const uno::Any& /*EnforceStyleLock*/ )
 {
     // Seems not support in Writer
     // VbaDocumentBase::Protect( Password );
 }
 
-void SAL_CALL SwVbaDocument::PrintOut( const uno::Any& /*Background*/, const uno::Any& /*Append*/, const uno::Any& /*Range*/, const uno::Any& /*OutputFileName*/, const uno::Any& /*From*/, const uno::Any& /*To*/, const uno::Any& /*Item*/, const uno::Any& /*Copies*/, const uno::Any& /*Pages*/, const uno::Any& /*PageType*/, const uno::Any& /*PrintToFile*/, const uno::Any& /*Collate*/, const uno::Any& /*FileName*/, const uno::Any& /*ActivePrinterMacGX*/, const uno::Any& /*ManualDuplexPrint*/, const uno::Any& /*PrintZoomColumn*/, const uno::Any& /*PrintZoomRow*/, const uno::Any& /*PrintZoomPaperWidth*/, const uno::Any& /*PrintZoomPaperHeight*/ ) throw (uno::RuntimeException)
+void SAL_CALL SwVbaDocument::PrintOut( const uno::Any& /*Background*/, const uno::Any& /*Append*/, const uno::Any& /*Range*/, const uno::Any& /*OutputFileName*/, const uno::Any& /*From*/, const uno::Any& /*To*/, const uno::Any& /*Item*/, const uno::Any& /*Copies*/, const uno::Any& /*Pages*/, const uno::Any& /*PageType*/, const uno::Any& /*PrintToFile*/, const uno::Any& /*Collate*/, const uno::Any& /*FileName*/, const uno::Any& /*ActivePrinterMacGX*/, const uno::Any& /*ManualDuplexPrint*/, const uno::Any& /*PrintZoomColumn*/, const uno::Any& /*PrintZoomRow*/, const uno::Any& /*PrintZoomPaperWidth*/, const uno::Any& /*PrintZoomPaperHeight*/ )
 {
     //TODO
 }
 
-void SAL_CALL SwVbaDocument::PrintPreview(  ) throw (uno::RuntimeException)
+void SAL_CALL SwVbaDocument::PrintPreview(  )
 {
     OUString url = ".uno:PrintPreview";
     dispatchRequests( mxModel,url );
 }
 
-void SAL_CALL SwVbaDocument::ClosePrintPreview(  ) throw (uno::RuntimeException)
+void SAL_CALL SwVbaDocument::ClosePrintPreview(  )
 {
     OUString url = ".uno:ClosePreview";
     dispatchRequests( mxModel,url );
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Revisions( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::Revisions( const uno::Any& index )
 {
-    uno::Reference< document::XRedlinesSupplier > xRedlinesSupp( mxTextDocument, uno::UNO_QUERY_THROW );
+    uno::Reference< css::document::XRedlinesSupplier > xRedlinesSupp( mxTextDocument, uno::UNO_QUERY_THROW );
     uno::Reference< container::XIndexAccess > xRedlines( xRedlinesSupp->getRedlines(), uno::UNO_QUERY_THROW );
     uno::Reference< XCollection > xCol( new SwVbaRevisions( this, mxContext, getModel(), xRedlines ) );
     if ( index.hasValue() )
@@ -399,7 +402,7 @@ SwVbaDocument::Revisions( const uno::Any& index ) throw (uno::RuntimeException)
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::Frames( const uno::Any& index ) throw (uno::RuntimeException)
+SwVbaDocument::Frames( const uno::Any& index )
 {
     uno::Reference< text::XTextFramesSupplier > xTextFramesSupp( mxTextDocument, uno::UNO_QUERY_THROW );
     uno::Reference< container::XIndexAccess > xFrames( xTextFramesSupp->getTextFrames(), uno::UNO_QUERY_THROW );
@@ -424,7 +427,7 @@ SwVbaDocument::getControlShape( const OUString& sName )
         if( xControlShape.is() )
         {
              uno::Reference< container::XNamed > xNamed( xControlShape->getControl(), uno::UNO_QUERY_THROW );
-            if( sName.equals( xNamed->getName() ))
+            if( sName == xNamed->getName() )
             {
                 return aUnoObj;
             }
@@ -434,27 +437,25 @@ SwVbaDocument::getControlShape( const OUString& sName )
 }
 
 uno::Reference< beans::XIntrospectionAccess > SAL_CALL
-SwVbaDocument::getIntrospection(  ) throw (uno::RuntimeException)
+SwVbaDocument::getIntrospection(  )
 {
     return uno::Reference< beans::XIntrospectionAccess >();
 }
 
 uno::Any SAL_CALL
-SwVbaDocument::invoke( const OUString& aFunctionName, const uno::Sequence< uno::Any >& /*aParams*/, uno::Sequence< ::sal_Int16 >& /*aOutParamIndex*/, uno::Sequence< uno::Any >& /*aOutParam*/ ) throw (lang::IllegalArgumentException, script::CannotConvertException, reflection::InvocationTargetException, uno::RuntimeException)
+SwVbaDocument::invoke( const OUString& aFunctionName, const uno::Sequence< uno::Any >& /*aParams*/, uno::Sequence< ::sal_Int16 >& /*aOutParamIndex*/, uno::Sequence< uno::Any >& /*aOutParam*/ )
 {
-    OSL_TRACE("** SwVbaDocument::invoke( %s ), will barf",
-        OUStringToOString( aFunctionName, RTL_TEXTENCODING_UTF8 ).getStr() );
-
+    SAL_INFO("sw", "** will barf " << aFunctionName );
     throw uno::RuntimeException(); // unsupported operation
 }
 
 void SAL_CALL
-SwVbaDocument::setValue( const OUString& /*aPropertyName*/, const uno::Any& /*aValue*/ ) throw (beans::UnknownPropertyException, script::CannotConvertException, reflection::InvocationTargetException, uno::RuntimeException)
+SwVbaDocument::setValue( const OUString& /*aPropertyName*/, const uno::Any& /*aValue*/ )
 {
     throw uno::RuntimeException(); // unsupported operation
 }
 uno::Any SAL_CALL
-SwVbaDocument::getValue( const OUString& aPropertyName ) throw (beans::UnknownPropertyException, uno::RuntimeException)
+SwVbaDocument::getValue( const OUString& aPropertyName )
 {
     uno::Reference< drawing::XControlShape > xControlShape( getControlShape( aPropertyName ), uno::UNO_QUERY_THROW );
 
@@ -464,19 +465,19 @@ SwVbaDocument::getValue( const OUString& aPropertyName ) throw (beans::UnknownPr
     return uno::makeAny( xControl );
 }
 
-::sal_Bool SAL_CALL
-SwVbaDocument::hasMethod( const OUString& /*aName*/ ) throw (uno::RuntimeException)
+sal_Bool SAL_CALL
+SwVbaDocument::hasMethod( const OUString& /*aName*/ )
 {
-    return sal_False;
+    return false;
 }
 
-::sal_Bool SAL_CALL
-SwVbaDocument::hasProperty( const OUString& aName ) throw (uno::RuntimeException)
+sal_Bool SAL_CALL
+SwVbaDocument::hasProperty( const OUString& aName )
 {
     uno::Reference< container::XNameAccess > xFormControls( getFormControls() );
     if ( xFormControls.is() )
         return xFormControls->hasByName( aName );
-    return sal_False;
+    return false;
 }
 
 uno::Reference< container::XNameAccess >
@@ -514,8 +515,8 @@ SwVbaDocument::getServiceNames()
 namespace document
 {
 namespace sdecl = comphelper::service_decl;
-sdecl::vba_service_class_<SwVbaDocument, sdecl::with_args<true> > serviceImpl;
-extern sdecl::ServiceDecl const serviceDecl(
+sdecl::vba_service_class_<SwVbaDocument, sdecl::with_args<true> > const serviceImpl;
+sdecl::ServiceDecl const serviceDecl(
     serviceImpl,
     "SwVbaDocument",
     "ooo.vba.word.Document" );
