@@ -28,24 +28,26 @@
 #include <comphelper/string.hxx>
 #include <ooo/vba/word/WdFieldType.hpp>
 #include <swtypes.hxx>
+#include <basic/sberrors.hxx>
+#include <cppuhelper/implbase.hxx>
 
 using namespace ::ooo::vba;
 using namespace ::com::sun::star;
 
-SwVbaField::SwVbaField(  const uno::Reference< ooo::vba::XHelperInterface >& rParent, const uno::Reference< uno::XComponentContext >& rContext, const css::uno::Reference< css::text::XTextDocument >& rDocument, const  uno::Reference< css::text::XTextField >& xTextField) throw ( uno::RuntimeException ) : SwVbaField_BASE( rParent, rContext ), mxTextDocument( rDocument )
+SwVbaField::SwVbaField(  const uno::Reference< ooo::vba::XHelperInterface >& rParent, const uno::Reference< uno::XComponentContext >& rContext, const  uno::Reference< css::text::XTextField >& xTextField) : SwVbaField_BASE( rParent, rContext )
 {
     mxTextField.set( xTextField, uno::UNO_QUERY_THROW );
 }
 
-sal_Bool SAL_CALL SwVbaField::Update() throw (uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL SwVbaField::Update()
 {
     uno::Reference< util::XUpdatable > xUpdatable( mxTextField, uno::UNO_QUERY );
     if( xUpdatable.is() )
     {
         xUpdatable->update();
-        return sal_True;
+        return true;
     }
-    return sal_False;
+    return false;
 }
 
 // XHelperInterface
@@ -76,15 +78,14 @@ private:
     sal_Int32 nLen, nFnd, nNext, nSavPtr;
     OUString aFieldName;
 public:
-    SwVbaReadFieldParams( const OUString& rData );
-    ~SwVbaReadFieldParams();
+    explicit SwVbaReadFieldParams( const OUString& rData );
 
     long SkipToNextToken();
 
-    sal_Int32 FindNextStringPiece( sal_Int32 _nStart = -1 );
+    sal_Int32 FindNextStringPiece( sal_Int32 _nStart );
 
     OUString GetResult() const;
-    OUString GetFieldName()const { return aFieldName; }
+    const OUString& GetFieldName()const { return aFieldName; }
 };
 
 SwVbaReadFieldParams::SwVbaReadFieldParams( const OUString& _rData )
@@ -110,10 +111,6 @@ SwVbaReadFieldParams::SwVbaReadFieldParams( const OUString& _rData )
     aFieldName = aData.copy( 0, nFnd );
 }
 
-SwVbaReadFieldParams::~SwVbaReadFieldParams()
-{
-}
-
 OUString SwVbaReadFieldParams::GetResult() const
 {
     return    (-1 == nFnd)
@@ -161,7 +158,7 @@ long SwVbaReadFieldParams::SkipToNextToken()
 
 // Output ppNext (if ppNext != 0) beginning of the search for the next parameter or 0
 
-// Return value: 0 if String-End reached, otherwise begin of the paramater or the string
+// Return value: 0 if String-End reached, otherwise begin of the parameter or the string
 
 sal_Int32 SwVbaReadFieldParams::FindNextStringPiece(const sal_Int32 nStart)
 {
@@ -222,14 +219,11 @@ static uno::Any lcl_createField( const uno::Reference< XHelperInterface >& xPare
 {
     uno::Reference< text::XTextField > xTextField( aSource, uno::UNO_QUERY_THROW );
     uno::Reference< text::XTextDocument > xTextDocument( xModel, uno::UNO_QUERY_THROW );
-    uno::Reference< word::XField > xField( new SwVbaField( xParent, xContext, xTextDocument, xTextField ) );
+    uno::Reference< word::XField > xField( new SwVbaField( xParent, xContext, xTextField ) );
     return uno::makeAny( xField );
 }
 
-typedef ::cppu::WeakImplHelper1< css::container::XEnumeration > FieldEnumeration_BASE;
-typedef ::cppu::WeakImplHelper2< container::XIndexAccess, container::XEnumerationAccess > FieldCollectionHelper_BASE;
-
-class FieldEnumeration : public FieldEnumeration_BASE
+class FieldEnumeration : public ::cppu::WeakImplHelper< css::container::XEnumeration >
 {
     uno::Reference< XHelperInterface > mxParent;
     uno::Reference< uno::XComponentContext > mxContext;
@@ -239,11 +233,11 @@ public:
     FieldEnumeration(  const uno::Reference< XHelperInterface >& xParent, const uno::Reference< uno::XComponentContext > & xContext, const uno::Reference< frame::XModel >& xModel, const uno::Reference< container::XEnumeration >& xEnumeration ) : mxParent( xParent ), mxContext( xContext ), mxModel( xModel ), mxEnumeration( xEnumeration )
     {
     }
-    virtual sal_Bool SAL_CALL hasMoreElements(  ) throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+    virtual sal_Bool SAL_CALL hasMoreElements(  ) override
     {
         return mxEnumeration->hasMoreElements();
     }
-    virtual uno::Any SAL_CALL nextElement(  ) throw (container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) SAL_OVERRIDE
+    virtual uno::Any SAL_CALL nextElement(  ) override
     {
         if ( !hasMoreElements() )
             throw container::NoSuchElementException();
@@ -251,23 +245,25 @@ public:
     }
 };
 
-class FieldCollectionHelper : public FieldCollectionHelper_BASE
+class FieldCollectionHelper : public ::cppu::WeakImplHelper< container::XIndexAccess,
+                                                             container::XEnumerationAccess >
 {
     uno::Reference< XHelperInterface > mxParent;
     uno::Reference< uno::XComponentContext > mxContext;
     uno::Reference< frame::XModel > mxModel;
     uno::Reference< container::XEnumerationAccess > mxEnumerationAccess;
 public:
-    FieldCollectionHelper( const uno::Reference< XHelperInterface >& xParent, const uno::Reference< uno::XComponentContext >& xContext, const uno::Reference< frame::XModel >& xModel ) throw (css::uno::RuntimeException) : mxParent( xParent ), mxContext( xContext ), mxModel( xModel )
+    /// @throws css::uno::RuntimeException
+    FieldCollectionHelper( const uno::Reference< XHelperInterface >& xParent, const uno::Reference< uno::XComponentContext >& xContext, const uno::Reference< frame::XModel >& xModel ) : mxParent( xParent ), mxContext( xContext ), mxModel( xModel )
     {
         uno::Reference< text::XTextFieldsSupplier > xSupp( xModel, uno::UNO_QUERY_THROW );
         mxEnumerationAccess.set( xSupp->getTextFields(), uno::UNO_QUERY_THROW );
     }
     // XElementAccess
-    virtual uno::Type SAL_CALL getElementType(  ) throw (uno::RuntimeException, std::exception) SAL_OVERRIDE { return  mxEnumerationAccess->getElementType(); }
-    virtual sal_Bool SAL_CALL hasElements(  ) throw (uno::RuntimeException, std::exception) SAL_OVERRIDE { return mxEnumerationAccess->hasElements(); }
+    virtual uno::Type SAL_CALL getElementType(  ) override { return  mxEnumerationAccess->getElementType(); }
+    virtual sal_Bool SAL_CALL hasElements(  ) override { return mxEnumerationAccess->hasElements(); }
     // XIndexAccess
-    virtual ::sal_Int32 SAL_CALL getCount(  ) throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+    virtual ::sal_Int32 SAL_CALL getCount(  ) override
     {
         uno::Reference< container::XEnumeration > xEnumeration =  mxEnumerationAccess->createEnumeration();
         sal_Int32 nCount = 0;
@@ -278,7 +274,7 @@ public:
         }
         return nCount;
     }
-    virtual uno::Any SAL_CALL getByIndex( ::sal_Int32 Index ) throw (lang::IndexOutOfBoundsException, lang::WrappedTargetException, uno::RuntimeException, std::exception ) SAL_OVERRIDE
+    virtual uno::Any SAL_CALL getByIndex( ::sal_Int32 Index ) override
     {
         if( Index < 0 || Index >= getCount() )
             throw lang::IndexOutOfBoundsException();
@@ -296,7 +292,7 @@ public:
         throw lang::IndexOutOfBoundsException();
     }
     // XEnumerationAccess
-    virtual uno::Reference< container::XEnumeration > SAL_CALL createEnumeration(  ) throw (uno::RuntimeException, std::exception) SAL_OVERRIDE
+    virtual uno::Reference< container::XEnumeration > SAL_CALL createEnumeration(  ) override
     {
         uno::Reference< container::XEnumeration > xEnumeration =  mxEnumerationAccess->createEnumeration();
         return uno::Reference< container::XEnumeration >( new FieldEnumeration( mxParent, mxContext, mxModel, xEnumeration ) );
@@ -309,7 +305,7 @@ SwVbaFields::SwVbaFields( const uno::Reference< XHelperInterface >& xParent, con
 }
 
 uno::Reference< word::XField > SAL_CALL
-SwVbaFields::Add( const css::uno::Reference< ::ooo::vba::word::XRange >& Range, const css::uno::Any& Type, const css::uno::Any& Text, const css::uno::Any& /*PreserveFormatting*/ ) throw (css::script::BasicErrorException, css::uno::RuntimeException, std::exception)
+SwVbaFields::Add( const css::uno::Reference< ::ooo::vba::word::XRange >& Range, const css::uno::Any& Type, const css::uno::Any& Text, const css::uno::Any& /*PreserveFormatting*/ )
 {
     sal_Int32 nType = word::WdFieldType::wdFieldEmpty;
     Type >>= nType;
@@ -321,7 +317,7 @@ SwVbaFields::Add( const css::uno::Reference< ::ooo::vba::word::XRange >& Range,
     {
         SwVbaReadFieldParams aReadParam(sText);
         sFieldName = aReadParam.GetFieldName();
-        OSL_TRACE("SwVbaFields::Add, the field name is %s ",OUStringToOString( sFieldName, RTL_TEXTENCODING_UTF8 ).getStr() );
+        SAL_INFO("sw", "the field name is " << sFieldName );
     }
 
     uno::Reference< text::XTextContent > xTextField;
@@ -342,11 +338,10 @@ SwVbaFields::Add( const css::uno::Reference< ::ooo::vba::word::XRange >& Range,
     uno::Reference< text::XTextRange > xTextRange = rVbaRange.getXTextRange();
     uno::Reference< text::XText > xText = xTextRange->getText();
     xText->insertTextContent( xTextRange, xTextField, true );
-    return uno::Reference< word::XField >( new SwVbaField( mxParent, mxContext, uno::Reference< text::XTextDocument >( mxModel, uno::UNO_QUERY_THROW ), uno::Reference< text::XTextField >( xTextField, uno::UNO_QUERY_THROW ) ) );
+    return uno::Reference< word::XField >( new SwVbaField( mxParent, mxContext, uno::Reference< text::XTextField >( xTextField, uno::UNO_QUERY_THROW ) ) );
 }
 
 uno::Reference< text::XTextField > SwVbaFields::Create_Field_FileName( const OUString& _text )
-    throw (uno::RuntimeException, script::BasicErrorException)
 {
     uno::Reference< text::XTextField > xTextField( mxMSF->createInstance("com.sun.star.text.TextField.FileName"), uno::UNO_QUERY_THROW );
     sal_Int16 nFileFormat = text::FilenameDisplayFormat::NAME_AND_EXT;
@@ -366,7 +361,7 @@ uno::Reference< text::XTextField > SwVbaFields::Create_Field_FileName( const OUS
                     aReadParam.SkipToNextToken();
                     break;
                 default:
-                    DebugHelper::basicexception(SbERR_BAD_ARGUMENT, OUString());
+                    DebugHelper::basicexception(ERRCODE_BASIC_BAD_ARGUMENT, OUString());
                     break;
             }
         }
@@ -387,35 +382,35 @@ struct DocPropertyTable
 static const DocPropertyTable aDocPropertyTables[] =
 {
     { "Author", "com.sun.star.text.textfield.docinfo.CreateAuthor" },
-    { "Bytes", NULL },
-    { "Category", NULL },
-    { "Characters",NULL },
-    { "CharactersWithSpaces", NULL },
+    { "Bytes", nullptr },
+    { "Category", nullptr },
+    { "Characters",nullptr },
+    { "CharactersWithSpaces", nullptr },
     { "Comments", "com.sun.star.text.textfield.docinfo.Description" },
-    { "Company", NULL },
+    { "Company", nullptr },
     { "CreateTime", "com.sun.star.text.textfield.docinfo.CreateDateTime" },
-    { "HyperlinkBase", NULL },
+    { "HyperlinkBase", nullptr },
     { "Keywords", "com.sun.star.text.textfield.docinfo.Keywords" },
     { "LastPrinted", "com.sun.star.text.textfield.docinfo.PrintDateTime" },
     { "LastSavedBy", "com.sun.star.text.textfield.docinfo.ChangeAuthor" },
     { "LastSavedTime", "com.sun.star.text.textfield.docinfo.ChangeDateTime" },
-    { "Lines", NULL },
-    { "Manager", NULL },
-    { "NameofApplication", NULL },
-    { "ODMADocID", NULL },
+    { "Lines", nullptr },
+    { "Manager", nullptr },
+    { "NameofApplication", nullptr },
+    { "ODMADocID", nullptr },
     { "Pages", "com.sun.star.text.textfield.PageCount" },
     { "Paragraphs", "com.sun.star.text.textfield.ParagraphCount" },
     { "RevisionNumber", "com.sun.star.text.textfield.docinfo.Revision" },
-    { "Security", NULL },
+    { "Security", nullptr },
     { "Subject", "com.sun.star.text.textfield.docinfo.Subject" },
     { "Template", "com.sun.star.text.textfield.TemplateName" },
     { "Title", "com.sun.star.text.textfield.docinfo.Title" },
     { "TotalEditingTime", "com.sun.star.text.textfield.docinfo.EditTime" },
     { "Words", "com.sun.star.text.textfield.WordCount" },
-    { NULL, NULL }
+    { nullptr, nullptr }
 };
 
-uno::Reference< text::XTextField > SwVbaFields::Create_Field_DocProperty( const OUString& _text ) throw (uno::RuntimeException)
+uno::Reference< text::XTextField > SwVbaFields::Create_Field_DocProperty( const OUString& _text )
 {
     OUString aDocProperty;
     SwVbaReadFieldParams aReadParam( _text );
@@ -434,8 +429,8 @@ uno::Reference< text::XTextField > SwVbaFields::Create_Field_DocProperty( const
                 break;
         }
     }
-    aDocProperty = comphelper::string::remove(aDocProperty, '"');
-    OSL_TRACE("SwVbaFields::Create_Field_DocProperty, the document property name is %s ",OUStringToOString( aDocProperty, RTL_TEXTENCODING_UTF8 ).getStr() );
+    aDocProperty = aDocProperty.replaceAll("\"", "");
+    SAL_INFO("sw", "SwVbaFields::Create_Field_DocProperty, the document property name is " << aDocProperty );
     if( aDocProperty.isEmpty() )
     {
         throw uno::RuntimeException();
@@ -444,11 +439,11 @@ uno::Reference< text::XTextField > SwVbaFields::Create_Field_DocProperty( const
     bool bCustom = true;
     OUString sFieldService;
     // find the build in document properties
-    for( const DocPropertyTable* pTable = aDocPropertyTables; pTable->sDocPropertyName != NULL; pTable++ )
+    for( const DocPropertyTable* pTable = aDocPropertyTables; pTable->sDocPropertyName != nullptr; pTable++ )
     {
         if( aDocProperty.equalsIgnoreAsciiCaseAscii( pTable->sDocPropertyName ) )
         {
-            if( pTable->sFieldService != NULL )
+            if( pTable->sFieldService != nullptr )
                 sFieldService = OUString::createFromAscii(pTable->sFieldService);
             bCustom = false;
             break;
@@ -469,15 +464,14 @@ uno::Reference< text::XTextField > SwVbaFields::Create_Field_DocProperty( const
     if( bCustom )
     {
         uno::Reference< beans::XPropertySet > xProps( xTextField, uno::UNO_QUERY_THROW );
-        OUString sDocPropertyName( aDocProperty );
-        xProps->setPropertyValue("Name", uno::makeAny( sDocPropertyName ) );
+        xProps->setPropertyValue("Name", uno::makeAny( aDocProperty ) );
     }
 
     return xTextField;
 }
 
 uno::Reference< container::XEnumeration > SAL_CALL
-SwVbaFields::createEnumeration() throw (uno::RuntimeException)
+SwVbaFields::createEnumeration()
 {
     uno::Reference< container::XEnumerationAccess > xEnumerationAccess( m_xIndexAccess, uno::UNO_QUERY_THROW );
     return xEnumerationAccess->createEnumeration();
@@ -490,7 +484,7 @@ SwVbaFields::createCollectionObject( const uno::Any& aSource )
     return lcl_createField( mxParent, mxContext, mxModel, aSource );
 }
 
-sal_Int32 SAL_CALL SwVbaFields::Update() throw (uno::RuntimeException, std::exception)
+sal_Int32 SAL_CALL SwVbaFields::Update()
 {
     sal_Int32 nUpdate = 1;
     try
@@ -516,7 +510,7 @@ SwVbaFields::getServiceImplName()
 
 // XEnumerationAccess
 uno::Type SAL_CALL
-SwVbaFields::getElementType() throw (uno::RuntimeException)
+SwVbaFields::getElementType()
 {
     return  cppu::UnoType<word::XField>::get();
 }
