@@ -346,7 +346,7 @@ style::LineSpacing SwVbaParagraphFormat::getOOoLineSpacing( float _lineSpace, sa
             aLineSpacing.Mode = style::LineSpacingMode::PROP;
             aLineSpacing.Height = PERCENT150;
         }
-        else if( _lineSpace == ( sal_Int16 )( ( CHARACTER_INDENT_FACTOR ) * 2 ) )
+        else if( _lineSpace == ( sal_Int16 )( CHARACTER_INDENT_FACTOR * 2 ) )
         {
             aLineSpacing.Mode = style::LineSpacingMode::PROP;
             aLineSpacing.Height = PERCENT200;
@@ -410,7 +410,7 @@ style::LineSpacing SwVbaParagraphFormat::getOOoLineSpacingFromRule( sal_Int32 _l
     return aLineSpacing;
 }
 
-float SwVbaParagraphFormat::getMSWordLineSpacing( style::LineSpacing& rLineSpacing )
+float SwVbaParagraphFormat::getMSWordLineSpacing( style::LineSpacing const & rLineSpacing )
 {
     float wdLineSpacing = 0;
     if( rLineSpacing.Mode != style::LineSpacingMode::PROP )
@@ -424,7 +424,7 @@ float SwVbaParagraphFormat::getMSWordLineSpacing( style::LineSpacing& rLineSpaci
     return wdLineSpacing;
 }
 
-sal_Int32 SwVbaParagraphFormat::getMSWordLineSpacingRule( style::LineSpacing& rLineSpacing )
+sal_Int32 SwVbaParagraphFormat::getMSWordLineSpacingRule( style::LineSpacing const & rLineSpacing )
 {
     sal_Int32 wdLineSpacing = word::WdLineSpacing::wdLineSpaceSingle;
     switch( rLineSpacing.Mode )
