@@ -17,10 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "wrtsh.hxx"
+#include <wrtsh.hxx>
 
-#include "dbui.hrc"
-#include "dbui.hxx"
+#include <dbui.hrc>
+#include <dbui.hxx>
 
 PrintMonitor::PrintMonitor(vcl::Window *pParent, bool modal, PrintMonitorType eType )
     : CancelableDialog(pParent, modal, "PrintMonitorDialog",
@@ -108,7 +108,7 @@ void CreateMonitor::SetCurrentPosition( sal_Int32 nCurrent )
 CancelableDialog::CancelableDialog( vcl::Window *pParent, bool modal,
         const OUString& rID, const OUString& rUIXMLDescription )
     : Dialog( pParent , rID, rUIXMLDescription,
-              modal ? WINDOW_MODALDIALOG : WINDOW_MODELESSDIALOG )
+              modal ? WindowType::MODALDIALOG : WindowType::MODELESSDIALOG )
     , mbModal( modal )
 {
     get(m_pCancelButton, "cancel");
