@@ -54,31 +54,30 @@
 #include <usrpref.hxx>
 #include <edtwin.hxx>
 #include <swwait.hxx>
-#include <shells.hrc>
-#include <popup.hrc>
+#include <strings.hrc>
 
 #include <sfx2/objface.hxx>
-#include <sfx2/sidebar/EnumContext.hxx>
+#include <vcl/EnumContext.hxx>
 #include <svx/svdomedia.hxx>
 #include <svx/sdr/contact/viewcontactofsdrmediaobj.hxx>
 #include <avmedia/mediaitem.hxx>
 
 #define SwMediaShell
 #include <sfx2/msg.hxx>
-#include "swslots.hxx"
-#include "swabstdlg.hxx"
+#include <swslots.hxx>
+#include <swabstdlg.hxx>
 #include <memory>
 
 SFX_IMPL_INTERFACE(SwMediaShell, SwBaseShell)
 
 void SwMediaShell::InitInterface_Impl()
 {
-    GetStaticInterface()->RegisterPopupMenu(SW_RES(MN_MEDIA_POPUPMENU));
+    GetStaticInterface()->RegisterPopupMenu("media");
 
-    GetStaticInterface()->RegisterObjectBar(SFX_OBJECTBAR_OBJECT, RID_MEDIA_TOOLBOX);
+    GetStaticInterface()->RegisterObjectBar(SFX_OBJECTBAR_OBJECT, SfxVisibilityFlags::Invisible, ToolbarId::Media_Toolbox);
 }
 
-void SwMediaShell::ExecMedia(SfxRequest &rReq)
+void SwMediaShell::ExecMedia(SfxRequest const &rReq)
 {
     SwWrtShell* pSh = &GetShell();
     SdrView*    pSdrView = pSh->GetDrawView();
@@ -107,7 +106,7 @@ void SwMediaShell::ExecMedia(SfxRequest &rReq)
             }
             break;
 
-            case( SID_AVMEDIA_TOOLBOX ):
+            case SID_AVMEDIA_TOOLBOX:
             {
                 if( pSh->IsObjSelected() )
                 {
@@ -191,8 +190,7 @@ SwMediaShell::SwMediaShell(SwView &_rView) :
 
 {
     SetName("Media Playback");
-    SetHelpId(SW_MEDIASHELL);
-    SfxShell::SetContextName(sfx2::sidebar::EnumContext::GetContextName(sfx2::sidebar::EnumContext::Context_Media));
+    SfxShell::SetContextName(vcl::EnumContext::GetContextName(vcl::EnumContext::Context::Media));
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
