@@ -38,7 +38,7 @@
 #include <editeng/scripttypeitem.hxx>
 #include <editeng/frmdiritem.hxx>
 #include <editeng/cmapitem.hxx>
-#include "paratr.hxx"
+#include <paratr.hxx>
 
 #include <fmtinfmt.hxx>
 #include <docsh.hxx>
@@ -53,11 +53,10 @@
 
 #include <cmdid.h>
 #include <globals.h>
-#include <shells.hrc>
+#include <strings.hrc>
 #include <SwStyleNameMapper.hxx>
-#include "swabstdlg.hxx"
-#include "outline.hxx"
-#include "chrdlg.hrc"
+#include <swabstdlg.hxx>
+#include <outline.hxx>
 #include <memory>
 
 const sal_uInt32 nFontInc = 40;      // 2pt
@@ -78,7 +77,7 @@ void SwTextShell::ExecCharAttr(SfxRequest &rReq)
                                 Get( nWhich )).GetValue() ? STATE_ON : STATE_OFF;
     }
 
-    SfxItemSet aSet( GetPool(), RES_CHRATR_BEGIN, RES_CHRATR_END-1 );
+    SfxItemSet aSet( GetPool(), svl::Items<RES_CHRATR_BEGIN, RES_CHRATR_END-1>{} );
     if (STATE_TOGGLE == eState)
         rSh.GetCurAttr( aSet );
 
@@ -92,8 +91,7 @@ void SwTextShell::ExecCharAttr(SfxRequest &rReq)
             {
             case STATE_TOGGLE:
             {
-                short nTmpEsc = static_cast<const SvxEscapementItem&>(
-                            aSet.Get( RES_CHRATR_ESCAPEMENT )).GetEsc();
+                short nTmpEsc = aSet.Get( RES_CHRATR_ESCAPEMENT ).GetEsc();
                 eEscape = nWhich == FN_SET_SUPER_SCRIPT ?
                                 SvxEscapement::Superscript:
                                 SvxEscapement::Subscript;
@@ -138,7 +136,7 @@ void SwTextShell::ExecCharAttr(SfxRequest &rReq)
             {
             case STATE_TOGGLE:
             {
-                SvxCaseMap eTmpCaseMap = static_cast<const SvxCaseMapItem&>(aSet.Get(RES_CHRATR_CASEMAP)).GetCaseMap();
+                SvxCaseMap eTmpCaseMap = aSet.Get(RES_CHRATR_CASEMAP).GetCaseMap();
                 if (eTmpCaseMap == SvxCaseMap::SmallCaps)
                     eCaseMap = SvxCaseMap::NotMapped;
             }
@@ -163,8 +161,8 @@ void SwTextShell::ExecCharAttr(SfxRequest &rReq)
             break;
         case FN_UNDERLINE_DOUBLE:
         {
-            FontLineStyle eUnderline = static_cast<const SvxUnderlineItem&>(
-                            aSet.Get(RES_CHRATR_UNDERLINE)).GetLineStyle();
+            FontLineStyle eUnderline =
+                            aSet.Get(RES_CHRATR_UNDERLINE).GetLineStyle();
             switch( eState )
             {
                 case STATE_TOGGLE:
@@ -259,7 +257,7 @@ void SwTextShell::ExecCharAttrArgs(SfxRequest &rReq)
             {
                 // must create new one, otherwise document is without pam
                 SwPaM* pPaM = rWrtSh.GetCursor();
-                vItems.push_back( std::make_pair( pSize, o3tl::make_unique<SwPaM>( *(pPaM->GetMark()), *(pPaM->GetPoint())) ) );
+                vItems.emplace_back( pSize, o3tl::make_unique<SwPaM>( *(pPaM->GetMark()), *(pPaM->GetPoint())) );
             }
             else
                 vItems = rWrtSh.GetItemWithPaM( RES_CHRATR_FONTSIZE );
@@ -312,9 +310,8 @@ void SwTextShell::ExecParaAttr(SfxRequest &rReq)
 
     // Get both attributes immediately isn't more expensive!!
     SfxItemSet aSet( GetPool(),
-        RES_PARATR_LINESPACING, RES_PARATR_ADJUST,
-        RES_FRAMEDIR, RES_FRAMEDIR,
-        0 );
+        svl::Items<RES_PARATR_LINESPACING, RES_PARATR_ADJUST,
+        RES_FRAMEDIR, RES_FRAMEDIR>{} );
 
     sal_uInt16 nSlot = rReq.GetSlot();
     switch (nSlot)
@@ -375,7 +372,7 @@ SET_LINESPACE:
         case SID_ATTR_PARA_RIGHT_TO_LEFT :
         {
             SfxItemSet aAdjustSet( GetPool(),
-                    RES_PARATR_ADJUST, RES_PARATR_ADJUST );
+                    svl::Items<RES_PARATR_ADJUST, RES_PARATR_ADJUST>{} );
             GetShell().GetCurAttr(aAdjustSet);
             bool bChgAdjust = false;
             SfxItemState eAdjustState = aAdjustSet.GetItemState(RES_PARATR_ADJUST, false);
@@ -460,7 +457,7 @@ void SwTextShell::ExecParaAttrArgs(SfxRequest &rReq)
             if( pItem )
             {
                 OUString sCharStyleName = static_cast<const SfxStringItem*>(pItem)->GetValue();
-                SfxItemSet aSet(GetPool(), RES_PARATR_DROP, RES_PARATR_DROP, 0L);
+                SfxItemSet aSet(GetPool(), svl::Items<RES_PARATR_DROP, RES_PARATR_DROP>{});
                 rSh.GetCurAttr(aSet);
                 SwFormatDrop aDropItem(static_cast<const SwFormatDrop&>(aSet.Get(RES_PARATR_DROP)));
                 SwCharFormat* pFormat = nullptr;
@@ -480,15 +477,13 @@ void SwTextShell::ExecParaAttrArgs(SfxRequest &rReq)
             }
             else
             {
-                SfxItemSet aSet(GetPool(), RES_PARATR_DROP, RES_PARATR_DROP,
-                                           HINT_END, HINT_END, 0);
+                SfxItemSet aSet(GetPool(), svl::Items<RES_PARATR_DROP, RES_PARATR_DROP,
+                                           HINT_END, HINT_END>{});
                 rSh.GetCurAttr(aSet);
                 SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-                OSL_ENSURE(pFact, "SwAbstractDialogFactory fail!");
-
-                ScopedVclPtr<SfxAbstractDialog> pDlg(pFact->CreateSfxDialog( GetView().GetWindow(), aSet,
-                    rSh.GetView().GetViewFrame()->GetFrame().GetFrameInterface(), DLG_SWDROPCAPS));
-                OSL_ENSURE(pDlg, "Dialog creation failed!");
+                assert(pFact && "SwAbstractDialogFactory fail!");
+                ScopedVclPtr<SfxAbstractDialog> pDlg(pFact->CreateSwDropCapsDialog(GetView().GetWindow(), aSet));
+                assert(pDlg && "Dialog creation failed!");
                 if (pDlg->Execute() == RET_OK)
                 {
                     rSh.StartAction();
@@ -518,8 +513,8 @@ void SwTextShell::ExecParaAttrArgs(SfxRequest &rReq)
             if(pItem)
             {
                 SfxItemSet aCoreSet( GetPool(),
-                    RES_PAGEDESC,   RES_PAGEDESC,
-                    SID_ATTR_PARA_MODEL, SID_ATTR_PARA_MODEL, 0);
+                    svl::Items<RES_PAGEDESC,   RES_PAGEDESC,
+                    SID_ATTR_PARA_MODEL, SID_ATTR_PARA_MODEL>{});
                 aCoreSet.Put(*pItem);
                 SfxToSwPageDescAttr( rSh, aCoreSet);
                 rSh.SetAttrSet(aCoreSet);
@@ -701,8 +696,8 @@ void SwTextShell::GetAttrState(SfxItemSet &rSet)
                 eState = aCoreSet.GetItemState(RES_CHRATR_UNDERLINE);
                 if( eState >= SfxItemState::DEFAULT )
                 {
-                    FontLineStyle eUnderline = static_cast<const SvxUnderlineItem&>(
-                            aCoreSet.Get(RES_CHRATR_UNDERLINE)).GetLineStyle();
+                    FontLineStyle eUnderline =
+                            aCoreSet.Get(RES_CHRATR_UNDERLINE).GetLineStyle();
                     rSet.Put(SfxBoolItem(nSlot, eUnderline == LINESTYLE_DOUBLE));
                 }
                 else
@@ -787,9 +782,8 @@ void SwTextShell::GetAttrState(SfxItemSet &rSet)
             case SID_ATTR_PARA_MODEL:
             {
                 SfxItemSet aTemp(GetPool(),
-                        RES_PAGEDESC,RES_PAGEDESC,
-                        SID_ATTR_PARA_MODEL,SID_ATTR_PARA_MODEL,
-                        0L);
+                        svl::Items<RES_PAGEDESC,RES_PAGEDESC,
+                        SID_ATTR_PARA_MODEL,SID_ATTR_PARA_MODEL>{});
                 aTemp.Put(aCoreSet);
                 ::SwToSfxPageDescAttr(aTemp);
                 rSet.Put(aTemp.Get(SID_ATTR_PARA_MODEL));
@@ -798,7 +792,7 @@ void SwTextShell::GetAttrState(SfxItemSet &rSet)
             break;
             case RES_TXTATR_INETFMT:
             {
-                SfxItemSet aSet(GetPool(), RES_TXTATR_INETFMT, RES_TXTATR_INETFMT);
+                SfxItemSet aSet(GetPool(), svl::Items<RES_TXTATR_INETFMT, RES_TXTATR_INETFMT>{});
                 rSh.GetCurAttr(aSet);
                 const SfxPoolItem& rItem = aSet.Get(RES_TXTATR_INETFMT);
                 rSet.Put(rItem);
