@@ -62,12 +62,12 @@
 #include <prtopt.hxx>
 #include <docstat.hxx>
 #include <usrpref.hxx>
-#include <viewfunc.hxx>
+#include "viewfunc.hxx"
 
-#include <helpid.h>
+#include <helpids.h>
 #include <cmdid.h>
 #include <globals.hrc>
-#include <view.hrc>
+#include <strings.hrc>
 
 #define SwPagePreview
 #include <sfx2/msg.hxx>
@@ -76,7 +76,6 @@
 
 #include <svx/svxdlg.hxx>
 #include <svx/dialogs.hrc>
-#include <osl/mutex.hxx>
 
 #include <memory>
 
@@ -95,7 +94,7 @@ void SwPagePreview::InitInterface_Impl()
     GetStaticInterface()->RegisterPopupMenu("preview");
     GetStaticInterface()->RegisterObjectBar(SFX_OBJECTBAR_OBJECT,
                                             SfxVisibilityFlags::Standard|SfxVisibilityFlags::Client|SfxVisibilityFlags::FullScreen|SfxVisibilityFlags::ReadonlyDoc,
-                                            RID_PVIEW_TOOLBOX);
+                                            ToolbarId::PView_Toolbox);
 }
 
 
@@ -761,7 +760,7 @@ void  SwPagePreview::Execute( SfxRequest &rReq )
             ScopedVclPtr<AbstractSvxZoomDialog> pDlg;
             if(!pArgs)
             {
-                SfxItemSet aCoreSet(GetPool(), SID_ATTR_ZOOM, SID_ATTR_ZOOM);
+                SfxItemSet aCoreSet(GetPool(), svl::Items<SID_ATTR_ZOOM, SID_ATTR_ZOOM>{});
                 const SwViewOption* pVOpt = GetViewShell()->GetViewOptions();
                 SvxZoomItem aZoom( pVOpt->GetZoomType(), pVOpt->GetZoom() );
                 aZoom.SetValueSet(
@@ -816,9 +815,8 @@ void  SwPagePreview::Execute( SfxRequest &rReq )
         case SID_ZOOM_IN:
         case SID_ZOOM_OUT:
         {
-            SvxZoomType eType = SvxZoomType::PERCENT;
             const SwViewOption* pVOpt = GetViewShell()->GetViewOptions();
-            SetZoom(eType,
+            SetZoom(SvxZoomType::PERCENT,
                     lcl_GetNextZoomStep(pVOpt->GetZoom(), SID_ZOOM_IN == rReq.GetSlot()));
         }
         break;
@@ -908,7 +906,7 @@ void  SwPagePreview::Execute( SfxRequest &rReq )
 MOVEPAGE:
             {
                 bool bRet = ChgPage( eMvMode );
-                // return value fuer Basic
+                // return value for Basic
                 if(bRetVal)
                     rReq.SetReturnValue(SfxBoolItem(rReq.GetSlot(), !bRet));
 
@@ -973,7 +971,6 @@ MOVEPAGE:
 void  SwPagePreview::GetState( SfxItemSet& rSet )
 {
     SfxWhichIter aIter(rSet);
-    sal_uInt8 nRow = 1;
     sal_uInt16 nWhich = aIter.FirstWhich();
     OSL_ENSURE(nWhich, "empty set");
     SwPagePreviewLayout* pPagePreviewLay = GetViewShell()->PagePreviewLayout();
@@ -1069,7 +1066,7 @@ void  SwPagePreview::GetState( SfxItemSet& rSet )
         break;
 
         case FN_SHOW_TWO_PAGES:
-            if( 2 == m_pViewWin->GetCol() && nRow == m_pViewWin->GetRow() )
+            if( 2 == m_pViewWin->GetCol() && 1 == m_pViewWin->GetRow() )
                 rSet.DisableItem( nWhich );
             break;
 
@@ -1077,7 +1074,7 @@ void  SwPagePreview::GetState( SfxItemSet& rSet )
             // has the same status like the normal printing
             {
                 const SfxPoolItem* pItem;
-                SfxItemSet aSet( *rSet.GetPool(), SID_PRINTDOC, SID_PRINTDOC );
+                SfxItemSet aSet( *rSet.GetPool(), svl::Items<SID_PRINTDOC, SID_PRINTDOC>{} );
                 GetSlotState( SID_PRINTDOC, SfxViewShell::GetInterface(), &aSet );
                 if( SfxItemState::DISABLED == aSet.GetItemState( SID_PRINTDOC,
                         false, &pItem ))
@@ -1857,7 +1854,7 @@ uno::Reference< css::accessibility::XAccessible >
     return GetAccessible( false );
 }
 
-void SwPagePreview::ApplyAccessiblityOptions(SvtAccessibilityOptions& rAccessibilityOptions)
+void SwPagePreview::ApplyAccessiblityOptions(SvtAccessibilityOptions const & rAccessibilityOptions)
 {
     GetViewShell()->ApplyAccessiblityOptions(rAccessibilityOptions);
 }
