@@ -19,7 +19,7 @@
 
 #include <string>
 
-#include "hintids.hxx"
+#include <hintids.hxx>
 #include <vcl/svapp.hxx>
 #include <sfx2/dispatch.hxx>
 #include <svx/ruler.hxx>
@@ -45,9 +45,8 @@
 #include <wview.hxx>
 
 #include <cmdid.h>
-#include <view.hrc>
-#include <ribbar.hrc>
-#include <helpid.h>
+#include <strings.hrc>
+#include <helpids.h>
 #include <globals.hrc>
 
 #include <IDocumentSettingAccess.hxx>
@@ -57,18 +56,17 @@ sal_uInt16  SwView::m_nMoveType = NID_PGE;
 sal_Int32 SwView::m_nActMark = 0;
 
 using namespace ::com::sun::star::uno;
-using namespace ::com::sun::star::frame;
 
 void SwView::SetZoom( SvxZoomType eZoomType, short nFactor, bool bViewOnly )
 {
     bool const bCursorIsVisible(m_pWrtShell->IsCursorVisible());
-    _SetZoom( GetEditWin().GetOutputSizePixel(), eZoomType, nFactor, bViewOnly );
+    SetZoom_( GetEditWin().GetOutputSizePixel(), eZoomType, nFactor, bViewOnly );
     // fdo#40465 force the cursor to stay in view whilst zooming
     if (bCursorIsVisible)
         m_pWrtShell->ShowCursor();
 }
 
-void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
+void SwView::SetZoom_( const Size &rEditSize, SvxZoomType eZoomType,
                         short nFactor, bool bViewOnly )
 {
     bool bUnLockView = !m_pWrtShell->IsViewLocked();
@@ -92,8 +90,8 @@ void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
     {
         const bool bAutomaticViewLayout = 0 == pOpt->GetViewLayoutColumns();
 
-        const SwRect aPageRect( m_pWrtShell->GetAnyCurRect( RECT_PAGE_CALC ) );
-        const SwRect aRootRect( m_pWrtShell->GetAnyCurRect( RECT_PAGES_AREA ) );
+        const SwRect aPageRect( m_pWrtShell->GetAnyCurRect( CurRectType::PageCalc ) );
+        const SwRect aRootRect( m_pWrtShell->GetAnyCurRect( CurRectType::PagesArea ) );
         Size aPageSize( aPageRect.SSize() );
         Size aRootSize( aRootRect.SSize() );
 
@@ -102,20 +100,20 @@ void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
         if (pPostItMgr->HasNotes() && pPostItMgr->ShowNotes())
             aPageSize.Width() += pPostItMgr->GetSidebarWidth() + pPostItMgr->GetSidebarBorderWidth();
 
-        const MapMode aTmpMap( MAP_TWIP );
+        const MapMode aTmpMap( MapUnit::MapTwip );
         const Size aWindowSize( GetEditWin().PixelToLogic( rEditSize, aTmpMap ) );
 
-        if( nsUseOnPage::PD_MIRROR == rDesc.GetUseOn() )    // mirrored pages
+        if( UseOnPage::Mirror == rDesc.GetUseOn() )    // mirrored pages
         {
             const SvxLRSpaceItem &rLeftLRSpace = rDesc.GetLeft().GetLRSpace();
-            aPageSize.Width() += std::abs( long(rLeftLRSpace.GetLeft()) - long(rLRSpace.GetLeft()) );
+            aPageSize.Width() += std::abs( rLeftLRSpace.GetLeft() - rLRSpace.GetLeft() );
         }
 
         if( SvxZoomType::OPTIMAL == eZoomType )
         {
             if (!pPostItMgr->HasNotes() || !pPostItMgr->ShowNotes())
                 aPageSize.Width() -= ( rLRSpace.GetLeft() + rLRSpace.GetRight() + nLeftOfst * 2 );
-            lLeftMargin = long(rLRSpace.GetLeft()) + DOCUMENTBORDER + nLeftOfst;
+            lLeftMargin = rLRSpace.GetLeft() + DOCUMENTBORDER + nLeftOfst;
             nFac = aWindowSize.Width() * 100 / aPageSize.Width();
         }
         else if(SvxZoomType::WHOLEPAGE == eZoomType || SvxZoomType::PAGEWIDTH == eZoomType )
@@ -166,7 +164,7 @@ void SwView::_SetZoom( const Size &rEditSize, SvxZoomType eZoomType,
             Point aPos;
 
             if ( eZoomType == SvxZoomType::WHOLEPAGE )
-                aPos.Y() = m_pWrtShell->GetAnyCurRect(RECT_PAGE).Top() - DOCUMENTBORDER;
+                aPos.Y() = m_pWrtShell->GetAnyCurRect(CurRectType::Page).Top() - DOCUMENTBORDER;
             else
             {
                 // Make sure that the cursor is in the visible range, so that
@@ -258,29 +256,30 @@ void SwView::SetViewLayout( sal_uInt16 nColumns, bool bBookMode, bool bViewOnly
 
 // Scrollbar - Handler
 
-IMPL_LINK_TYPED( SwView, WindowChildEventListener, VclWindowEvent&, rEvent, void )
+IMPL_LINK( SwView, WindowChildEventListener, VclWindowEvent&, rEvent, void )
 {
     OSL_ENSURE( rEvent.GetWindow(), "Window???" );
     vcl::Window* pChildWin = static_cast< vcl::Window* >( rEvent.GetData() );
 
     switch ( rEvent.GetId() )
     {
-        case VCLEVENT_WINDOW_HIDE:
+        case VclEventId::WindowHide:
             if( pChildWin == m_pHScrollbar )
                 ShowHScrollbar( false );
             else if( pChildWin == m_pVScrollbar )
                 ShowVScrollbar( false );
             break;
-        case VCLEVENT_WINDOW_SHOW:
+        case VclEventId::WindowShow:
             if( pChildWin == m_pHScrollbar )
                 ShowHScrollbar( true );
             else if( pChildWin == m_pVScrollbar )
                 ShowVScrollbar( true );
             break;
+        default: break;
     }
 }
 
-int SwView::_CreateScrollbar( bool bHori )
+void SwView::CreateScrollbar( bool bHori )
 {
     vcl::Window *pMDI = &GetViewFrame()->GetWindow();
     VclPtr<SwScrollbar>& ppScrollbar = bHori ? m_pHScrollbar : m_pVScrollbar;
@@ -302,11 +301,9 @@ int SwView::_CreateScrollbar( bool bHori )
 
     if (!m_bShowAtResize)
         ppScrollbar->ExtendedShow();
-
-    return 1;
 }
 
-IMPL_LINK_TYPED( SwView, MoveNavigationHdl, void*, p, void )
+IMPL_LINK( SwView, MoveNavigationHdl, void*, p, void )
 {
     bool* pbNext = static_cast<bool*>(p);
     if ( !pbNext )
@@ -321,9 +318,9 @@ IMPL_LINK_TYPED( SwView, MoveNavigationHdl, void*, p, void )
         case NID_TBL :
             rSh.EnterStdMode();
             if(bNext)
-                rSh.MoveTable(fnTableNext, fnTableStart);
+                rSh.MoveTable(GotoNextTable, fnTableStart);
             else
-                rSh.MoveTable(fnTablePrev, fnTableStart);
+                rSh.MoveTable(GotoPrevTable, fnTableStart);
         break;
         case NID_FRM :
         case NID_GRF:
@@ -354,9 +351,9 @@ IMPL_LINK_TYPED( SwView, MoveNavigationHdl, void*, p, void )
         case NID_REG :
             rSh.EnterStdMode();
             if(bNext)
-                rSh.MoveRegion(fnRegionNext, fnRegionStart);
+                rSh.MoveRegion(GotoNextRegion, fnRegionStart);
             else
-                rSh.MoveRegion(fnRegionPrev, fnRegionStart);
+                rSh.MoveRegion(GotoPrevRegion, fnRegionStart);
 
         break;
         case NID_BKM :
@@ -386,7 +383,7 @@ IMPL_LINK_TYPED( SwView, MoveNavigationHdl, void*, p, void )
 
             // collect navigator reminders
             IDocumentMarkAccess* const pMarkAccess = rSh.getIDocumentMarkAccess();
-            ::std::vector< const ::sw::mark::IMark* > vNavMarks;
+            std::vector< const ::sw::mark::IMark* > vNavMarks;
             for( IDocumentMarkAccess::const_iterator_t ppMark = pMarkAccess->getAllMarksBegin();
                 ppMark != pMarkAccess->getAllMarksEnd();
                 ++ppMark)
@@ -418,10 +415,10 @@ IMPL_LINK_TYPED( SwView, MoveNavigationHdl, void*, p, void )
         case NID_POSTIT:
             {
                 rSh.EnterStdMode();
-                sw::sidebarwindows::SwSidebarWin* pPostIt = GetPostItMgr()->GetActiveSidebarWin();
+                sw::annotation::SwAnnotationWin* pPostIt = GetPostItMgr()->GetActiveSidebarWin();
                 if (pPostIt)
                     GetPostItMgr()->SetActiveSidebarWin(nullptr);
-                SwFieldType* pFieldType = rSh.GetFieldType(0, RES_POSTITFLD);
+                SwFieldType* pFieldType = rSh.GetFieldType(0, SwFieldIds::Postit);
                 if ( rSh.MoveFieldType( pFieldType, bNext ) )
                     GetViewFrame()->GetDispatcher()->Execute(FN_POSTIT);
                 else
@@ -520,16 +517,16 @@ int SwView::KillVRuler()
     return 1;
 }
 
-IMPL_LINK_TYPED( SwView, ExecRulerClick, Ruler *, pRuler, void )
+IMPL_LINK( SwView, ExecRulerClick, Ruler *, pRuler, void )
 {
     OUString sDefPage;
     switch( pRuler->GetClickType() )
     {
-        case RULER_TYPE_DONTKNOW:
-        case RULER_TYPE_OUTSIDE:
-        case RULER_TYPE_INDENT:
-        case RULER_TYPE_MARGIN1:
-        case RULER_TYPE_MARGIN2:
+        case RulerType::DontKnow:
+        case RulerType::Outside:
+        case RulerType::Indent:
+        case RulerType::Margin1:
+        case RulerType::Margin2:
             sDefPage = "indents";
         break;
         default:
@@ -538,9 +535,9 @@ IMPL_LINK_TYPED( SwView, ExecRulerClick, Ruler *, pRuler, void )
     }
 
     SfxStringItem aDefPage(SID_PARA_DLG, sDefPage);
-    GetViewFrame()->GetDispatcher()->Execute( SID_PARA_DLG,
+    GetViewFrame()->GetDispatcher()->ExecuteList(SID_PARA_DLG,
                                 SfxCallMode::SYNCHRON|SfxCallMode::RECORD,
-                                &aDefPage, 0L );
+                                { &aDefPage });
 }
 
 sal_uInt16 SwView::GetMoveType()
