@@ -65,11 +65,11 @@
 #include <paratr.hxx>
 #include <fmtcol.hxx>
 #include <poolfmt.hxx>
-#include "usrpref.hxx"
+#include <usrpref.hxx>
 
 #include <cmdid.h>
 #include <globals.hrc>
-#include <utlui.hrc>
+#include <strings.hrc>
 #include <doc.hxx>
 #include <docary.hxx>
 #include <charfmt.hxx>
@@ -107,12 +107,12 @@ void PrepareBoxInfo(SfxItemSet& rSet, const SwWrtShell& rSh)
         aBoxInfo = *static_cast<const SvxBoxInfoItem*>(pBoxInfo);
 
         // Table variant: If more than one table cells are selected
-    rSh.GetCrsr();                  //So that GetCrsrCnt() returns the right thing
-    aBoxInfo.SetTable          (rSh.IsTableMode() && rSh.GetCrsrCnt() > 1);
+    rSh.GetCursor();                  //So that GetCursorCnt() returns the right thing
+    aBoxInfo.SetTable          (rSh.IsTableMode() && rSh.GetCursorCnt() > 1);
         // Always show the distance field
     aBoxInfo.SetDist           (true);
         // Set minimal size in tables and paragraphs
-    aBoxInfo.SetMinDist        (rSh.IsTableMode() || rSh.GetSelectionType() & (nsSelectionType::SEL_TXT | nsSelectionType::SEL_TBL));
+    aBoxInfo.SetMinDist        (rSh.IsTableMode() || rSh.GetSelectionType() & (SelectionType::Text | SelectionType::Table));
         // Set always the default distance
     aBoxInfo.SetDefDist        (MIN_BORDER_DIST);
         // Single lines can have only in tables DontCare-Status
@@ -178,11 +178,11 @@ void ConvertAttrGenToChar(SfxItemSet& rSet, const SfxItemSet& rOrigSet, const sa
             if( SfxItemState::SET == rOrigSet.GetItemState( RES_CHRATR_GRABBAG, false, &pTmpItem ) )
             {
                 SfxGrabBagItem aGrabBag(*static_cast<const SfxGrabBagItem*>(pTmpItem));
-                std::map<OUString, com::sun::star::uno::Any>& rMap = aGrabBag.GetGrabBag();
+                std::map<OUString, css::uno::Any>& rMap = aGrabBag.GetGrabBag();
                 auto aIterator = rMap.find("CharShadingMarker");
                 if( aIterator != rMap.end() )
                 {
-                    aIterator->second = uno::makeAny(false);
+                    aIterator->second <<= false;
                 }
                 rSet.Put( aGrabBag );
             }
@@ -224,40 +224,40 @@ void FillHdFt(SwFrameFormat* pFormat, const  SfxItemSet& rSet)
     const SfxBoolItem& rDynamic = static_cast<const SfxBoolItem&>(rSet.Get(SID_ATTR_PAGE_DYNAMIC));
 
     // Convert size
-    SwFormatFrmSize aFrmSize(rDynamic.GetValue() ? ATT_MIN_SIZE : ATT_FIX_SIZE,
+    SwFormatFrameSize aFrameSize(rDynamic.GetValue() ? ATT_MIN_SIZE : ATT_FIX_SIZE,
                             rSize.GetSize().Width(),
                             rSize.GetSize().Height());
-    aSet.Put(aFrmSize);
+    aSet.Put(aFrameSize);
     pFormat->SetFormatAttr(aSet);
 }
 
 /// Convert from UseOnPage to SvxPageUsage.
-UseOnPage lcl_convertUseToSvx(UseOnPage nUse)
+SvxPageUsage lcl_convertUseToSvx(UseOnPage nUse)
 {
-    UseOnPage nRet = nsUseOnPage::PD_NONE;
-    if ((nUse & nsUseOnPage::PD_LEFT) == nsUseOnPage::PD_LEFT)
-        nRet |= SVX_PAGE_LEFT;
-    if ((nUse & nsUseOnPage::PD_RIGHT) == nsUseOnPage::PD_RIGHT)
-        nRet |= SVX_PAGE_RIGHT;
-    if ((nUse & nsUseOnPage::PD_ALL) == nsUseOnPage::PD_ALL)
-        nRet |= SVX_PAGE_ALL;
-    if ((nUse & nsUseOnPage::PD_MIRROR) == nsUseOnPage::PD_MIRROR)
-        nRet |= SVX_PAGE_MIRROR;
+    SvxPageUsage nRet = SvxPageUsage::NONE;
+    if (nUse & UseOnPage::Left)
+        nRet = SvxPageUsage::Left;
+    if (nUse & UseOnPage::Right)
+        nRet = SvxPageUsage::Right;
+    if ((nUse & UseOnPage::All) == UseOnPage::All)
+        nRet = SvxPageUsage::All;
+    if ((nUse & UseOnPage::Mirror) == UseOnPage::Mirror)
+        nRet = SvxPageUsage::Mirror;
     return nRet;
 }
 
 /// Convert from SvxPageUsage to UseOnPage.
-UseOnPage lcl_convertUseFromSvx(UseOnPage nUse)
+UseOnPage lcl_convertUseFromSvx(SvxPageUsage nUse)
 {
-    UseOnPage nRet = nsUseOnPage::PD_NONE;
-    if ((nUse & SVX_PAGE_LEFT) == SVX_PAGE_LEFT)
-        nRet |= nsUseOnPage::PD_LEFT;
-    if ((nUse & SVX_PAGE_RIGHT) == SVX_PAGE_RIGHT)
-        nRet |= nsUseOnPage::PD_RIGHT;
-    if ((nUse & SVX_PAGE_ALL) == SVX_PAGE_ALL)
-        nRet |= nsUseOnPage::PD_ALL;
-    if ((nUse & SVX_PAGE_MIRROR) == SVX_PAGE_MIRROR)
-        nRet |= nsUseOnPage::PD_MIRROR;
+    UseOnPage nRet = UseOnPage::NONE;
+    if (nUse == SvxPageUsage::Left)
+        nRet = UseOnPage::Left;
+    else if (nUse == SvxPageUsage::Right)
+        nRet = UseOnPage::Right;
+    else if (nUse == SvxPageUsage::All)
+        nRet = UseOnPage::All;
+    else if (nUse == SvxPageUsage::Mirror)
+        nRet = UseOnPage::Mirror;
     return nRet;
 }
 
@@ -276,19 +276,19 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
     {
         const SvxPageItem& rPageItem = static_cast<const SvxPageItem&>(rSet.Get(SID_ATTR_PAGE));
 
-        const sal_uInt16 nUse = rPageItem.GetPageUsage();
-        if(nUse)
-            rPageDesc.SetUseOn( lcl_convertUseFromSvx((UseOnPage) nUse) );
+        const SvxPageUsage nUse = rPageItem.GetPageUsage();
+        if(nUse != SvxPageUsage::NONE)
+            rPageDesc.SetUseOn( lcl_convertUseFromSvx(nUse) );
         rPageDesc.SetLandscape(rPageItem.IsLandscape());
         SvxNumberType aNumType;
-        aNumType.SetNumberingType( static_cast< sal_Int16 >(rPageItem.GetNumType()) );
+        aNumType.SetNumberingType( rPageItem.GetNumType() );
         rPageDesc.SetNumType(aNumType);
     }
     // Size
     if(rSet.GetItemState(SID_ATTR_PAGE_SIZE) == SfxItemState::SET)
     {
         const SvxSizeItem& rSizeItem = static_cast<const SvxSizeItem&>(rSet.Get(SID_ATTR_PAGE_SIZE));
-        SwFormatFrmSize aSize(ATT_FIX_SIZE);
+        SwFormatFrameSize aSize(ATT_FIX_SIZE);
         aSize.SetSize(rSizeItem.GetSize());
         rMaster.SetFormatAttr(aSize);
     }
@@ -309,7 +309,7 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
             // Pick out everything and adapt the header format
             SwFormatHeader aHeaderFormat(rMaster.GetHeader());
             SwFrameFormat *pHeaderFormat = aHeaderFormat.GetHeaderFormat();
-            OSL_ENSURE(pHeaderFormat != 0, "no header format");
+            OSL_ENSURE(pHeaderFormat != nullptr, "no header format");
 
             ::FillHdFt(pHeaderFormat, rHeaderSet);
 
@@ -349,7 +349,7 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
             // Pick out everything and adapt the footer format
             SwFormatFooter aFooterFormat(rMaster.GetFooter());
             SwFrameFormat *pFooterFormat = aFooterFormat.GetFooterFormat();
-            OSL_ENSURE(pFooterFormat != 0, "no footer format");
+            OSL_ENSURE(pFooterFormat != nullptr, "no footer format");
 
             ::FillHdFt(pFooterFormat, rFooterSet);
 
@@ -359,7 +359,6 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
             {
                 rPageDesc.ChgFirstShare(static_cast<const SfxBoolItem&>(
                             rFooterSet.Get(SID_ATTR_PAGE_SHARED_FIRST)).GetValue());
-                nFirstShare = rPageDesc.IsFirstShared() ? 1 : 0;
             }
         }
         else
@@ -388,7 +387,7 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
     {
         bool bSet = static_cast<const SfxBoolItem*>(pItem)->GetValue();
         if(!bSet)
-            rPageDesc.SetRegisterFormatColl(0);
+            rPageDesc.SetRegisterFormatColl(nullptr);
         else if(SfxItemState::SET == rSet.GetItemState(
                                 SID_SWREGISTER_COLLECTION, false, &pItem))
         {
@@ -398,7 +397,7 @@ void ItemSetToPageDesc( const SfxItemSet& rSet, SwPageDesc& rPageDesc )
             if( !pColl )
             {
                 const sal_uInt16 nId = SwStyleNameMapper::GetPoolIdFromUIName(
-                    rColl, nsSwGetPoolIdFromName::GET_POOLID_TXTCOLL );
+                    rColl, SwGetPoolIdFromName::TxtColl );
                 if( USHRT_MAX != nId )
                     pColl = rDoc.getIDocumentStylePoolAccess().GetTextCollFromPool( nId );
                 else
@@ -421,11 +420,11 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
     aPageItem.SetDescName(rPageDesc.GetName());
     aPageItem.SetPageUsage(lcl_convertUseToSvx(rPageDesc.GetUseOn()));
     aPageItem.SetLandscape(rPageDesc.GetLandscape());
-    aPageItem.SetNumType((SvxNumType)rPageDesc.GetNumType().GetNumberingType());
+    aPageItem.SetNumType(rPageDesc.GetNumType().GetNumberingType());
     rSet.Put(aPageItem);
 
     // Size
-    SvxSizeItem aSizeItem(SID_ATTR_PAGE_SIZE, rMaster.GetFrmSize().GetSize());
+    SvxSizeItem aSizeItem(SID_ATTR_PAGE_SIZE, rMaster.GetFrameSize().GetSize());
     rSet.Put(aSizeItem);
 
     // Maximum size
@@ -462,30 +461,29 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
     {
         const SwFormatHeader &rHeaderFormat = rMaster.GetHeader();
         const SwFrameFormat *pHeaderFormat = rHeaderFormat.GetHeaderFormat();
-        OSL_ENSURE(pHeaderFormat != 0, "no header format");
+        OSL_ENSURE(pHeaderFormat != nullptr, "no header format");
 
         // HeaderInfo, margins, background, border
         SfxItemSet aHeaderSet(*rSet.GetPool(),
-            RES_FRMATR_BEGIN,RES_FRMATR_END - 1,            // [82
+            svl::Items<RES_FRMATR_BEGIN,RES_FRMATR_END - 1,            // [82
 
-            //UUUU FillAttribute support
+            // FillAttribute support
             XATTR_FILL_FIRST, XATTR_FILL_LAST,              // [1014
 
             SID_ATTR_BORDER_INNER,SID_ATTR_BORDER_INNER,    // [10023
             SID_ATTR_PAGE_SIZE,SID_ATTR_PAGE_SIZE,          // [10051
             SID_ATTR_PAGE_ON,SID_ATTR_PAGE_SHARED,          // [10060
-            SID_ATTR_PAGE_SHARED_FIRST,SID_ATTR_PAGE_SHARED_FIRST,
-            0, 0);
+            SID_ATTR_PAGE_SHARED_FIRST,SID_ATTR_PAGE_SHARED_FIRST>{});
 
-        //UUUU set correct parent to get the XFILL_NONE FillStyle as needed
+        // set correct parent to get the XFILL_NONE FillStyle as needed
         aHeaderSet.SetParent(&rMaster.GetDoc()->GetDfltFrameFormat()->GetAttrSet());
 
         // Dynamic or fixed height
         SfxBoolItem aOn(SID_ATTR_PAGE_ON, true);
         aHeaderSet.Put(aOn);
 
-        const SwFormatFrmSize &rFrmSize = pHeaderFormat->GetFrmSize();
-        const SwFrmSize eSizeType = rFrmSize.GetHeightSizeType();
+        const SwFormatFrameSize &rFrameSize = pHeaderFormat->GetFrameSize();
+        const SwFrameSize eSizeType = rFrameSize.GetHeightSizeType();
         SfxBoolItem aDynamic(SID_ATTR_PAGE_DYNAMIC, eSizeType != ATT_FIX_SIZE);
         aHeaderSet.Put(aDynamic);
 
@@ -496,7 +494,7 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
         aHeaderSet.Put(aFirstShared);
 
         // Size
-        SvxSizeItem aSize(SID_ATTR_PAGE_SIZE, Size(rFrmSize.GetSize()));
+        SvxSizeItem aSize(SID_ATTR_PAGE_SIZE, Size(rFrameSize.GetSize()));
         aHeaderSet.Put(aSize);
 
         // Shifting frame attributes
@@ -513,30 +511,29 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
     {
         const SwFormatFooter &rFooterFormat = rMaster.GetFooter();
         const SwFrameFormat *pFooterFormat = rFooterFormat.GetFooterFormat();
-        OSL_ENSURE(pFooterFormat != 0, "no footer format");
+        OSL_ENSURE(pFooterFormat != nullptr, "no footer format");
 
         // FooterInfo, margins, background, border
         SfxItemSet aFooterSet(*rSet.GetPool(),
-            RES_FRMATR_BEGIN,RES_FRMATR_END - 1,            // [82
+            svl::Items<RES_FRMATR_BEGIN,RES_FRMATR_END - 1,            // [82
 
-            //UUUU FillAttribute support
+            // FillAttribute support
             XATTR_FILL_FIRST, XATTR_FILL_LAST,              // [1014
 
             SID_ATTR_BORDER_INNER,SID_ATTR_BORDER_INNER,    // [10023
             SID_ATTR_PAGE_SIZE,SID_ATTR_PAGE_SIZE,          // [10051
             SID_ATTR_PAGE_ON,SID_ATTR_PAGE_SHARED,          // [10060
-            SID_ATTR_PAGE_SHARED_FIRST,SID_ATTR_PAGE_SHARED_FIRST,
-            0, 0);
+            SID_ATTR_PAGE_SHARED_FIRST,SID_ATTR_PAGE_SHARED_FIRST>{});
 
-        //UUUU set correct parent to get the XFILL_NONE FillStyle as needed
+        // set correct parent to get the XFILL_NONE FillStyle as needed
         aFooterSet.SetParent(&rMaster.GetDoc()->GetDfltFrameFormat()->GetAttrSet());
 
         // Dynamic or fixed height
         SfxBoolItem aOn(SID_ATTR_PAGE_ON, true);
         aFooterSet.Put(aOn);
 
-        const SwFormatFrmSize &rFrmSize = pFooterFormat->GetFrmSize();
-        const SwFrmSize eSizeType = rFrmSize.GetHeightSizeType();
+        const SwFormatFrameSize &rFrameSize = pFooterFormat->GetFrameSize();
+        const SwFrameSize eSizeType = rFrameSize.GetHeightSizeType();
         SfxBoolItem aDynamic(SID_ATTR_PAGE_DYNAMIC, eSizeType != ATT_FIX_SIZE);
         aFooterSet.Put(aDynamic);
 
@@ -547,7 +544,7 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
         aFooterSet.Put(aFirstShared);
 
         // Size
-        SvxSizeItem aSize(SID_ATTR_PAGE_SIZE, Size(rFrmSize.GetSize()));
+        SvxSizeItem aSize(SID_ATTR_PAGE_SIZE, Size(rFrameSize.GetSize()));
         aFooterSet.Put(aSize);
 
         // Shifting Frame attributes
@@ -560,13 +557,13 @@ void PageDescToItemSet( const SwPageDesc& rPageDesc, SfxItemSet& rSet)
     }
 
     // Integrate footnotes
-    SwPageFootnoteInfo& rInfo = (SwPageFootnoteInfo&)rPageDesc.GetFootnoteInfo();
-    SwPageFootnoteInfoItem aFootnoteItem(FN_PARAM_FTN_INFO, rInfo);
+    SwPageFootnoteInfo& rInfo = const_cast<SwPageFootnoteInfo&>(rPageDesc.GetFootnoteInfo());
+    SwPageFootnoteInfoItem aFootnoteItem(rInfo);
     rSet.Put(aFootnoteItem);
 
     // Register compliant
     const SwTextFormatColl* pCol = rPageDesc.GetRegisterFormatColl();
-    SwRegisterItem aReg(pCol != 0);
+    SwRegisterItem aReg(pCol != nullptr);
     aReg.SetWhich(SID_SWREGISTER_MODE);
     rSet.Put(aReg);
     if(pCol)
@@ -581,7 +578,7 @@ void MakeDefTabs(SwTwips nDefDist, SvxTabStopItem& rTabs)
     if( rTabs.Count() )
         return;
     {
-        SvxTabStop aSwTabStop( nDefDist, SVX_TAB_ADJUST_DEFAULT );
+        SvxTabStop aSwTabStop( nDefDist, SvxTabAdjust::Default );
         rTabs.Insert( aSwTabStop );
     }
 }
@@ -601,10 +598,25 @@ void SfxToSwPageDescAttr( const SwWrtShell& rShell, SfxItemSet& rSet )
 
     bool bChanged = false;
     // Page number
-    if(SfxItemState::SET == rSet.GetItemState(SID_ATTR_PARA_PAGENUM, false, &pItem))
+    switch (rSet.GetItemState(SID_ATTR_PARA_PAGENUM, false, &pItem))
     {
-        aPgDesc.SetNumOffset(static_cast<const SfxUInt16Item*>(pItem)->GetValue());
-        bChanged = true;
+        case SfxItemState::SET:
+        {
+            aPgDesc.SetNumOffset(static_cast<const SfxUInt16Item*>(pItem)->GetValue());
+            bChanged = true;
+            break;
+        }
+        case SfxItemState::DISABLED:
+        {
+            bChanged = true; // default initialised aPgDesc clears the number
+            break;
+        }
+        case SfxItemState::UNKNOWN:
+        case SfxItemState::DEFAULT:
+            break;
+        default:
+            assert(false); // unexpected
+            break;
     }
     if( SfxItemState::SET == rSet.GetItemState( SID_ATTR_PARA_MODEL, false, &pItem ))
     {
@@ -613,7 +625,7 @@ void SfxToSwPageDescAttr( const SwWrtShell& rShell, SfxItemSet& rSet )
         {
             // Delete only, if PageDesc will be enabled!
             rSet.ClearItem( RES_BREAK );
-            SwPageDesc* pDesc = ((SwWrtShell&)rShell).FindPageDescByName(
+            SwPageDesc* pDesc = const_cast<SwWrtShell&>(rShell).FindPageDescByName(
                                                     rDescName, true );
             if( pDesc )
                 aPgDesc.RegisterToPageDesc( *pDesc );
@@ -623,7 +635,7 @@ void SfxToSwPageDescAttr( const SwWrtShell& rShell, SfxItemSet& rSet )
     }
     else
     {
-        SfxItemSet aCoreSet(rShell.GetView().GetPool(), RES_PAGEDESC, RES_PAGEDESC );
+        SfxItemSet aCoreSet(rShell.GetView().GetPool(), svl::Items<RES_PAGEDESC, RES_PAGEDESC>{} );
         rShell.GetCurAttr( aCoreSet );
         if(SfxItemState::SET == aCoreSet.GetItemState( RES_PAGEDESC, true, &pItem ) )
         {
@@ -641,7 +653,7 @@ void SfxToSwPageDescAttr( const SwWrtShell& rShell, SfxItemSet& rSet )
 // Inquire if in the set is a Sfx-PageDesc combination present and return it.
 void SwToSfxPageDescAttr( SfxItemSet& rCoreSet )
 {
-    const SfxPoolItem* pItem = 0;
+    const SfxPoolItem* pItem = nullptr;
     OUString aName;
     ::boost::optional<sal_uInt16> oNumOffset;
     bool bPut = true;
@@ -707,7 +719,7 @@ void FillCharStyleListBox(ListBox& rToFill, SwDocShell* pDocSh, bool bSorted, bo
 {
     const sal_Int32 nOffset = rToFill.GetEntryCount() > 0 ? 1 : 0;
     SfxStyleSheetBasePool* pPool = pDocSh->GetStyleSheetPool();
-    pPool->SetSearchMask(SFX_STYLE_FAMILY_CHAR, SFXSTYLEBIT_ALL);
+    pPool->SetSearchMask(SfxStyleFamily::Char);
     SwDoc* pDoc = pDocSh->GetDoc();
     const SfxStyleSheetBase* pBase = pPool->First();
     OUString sStandard;
@@ -719,7 +731,7 @@ void FillCharStyleListBox(ListBox& rToFill, SwDocShell* pDocSh, bool bSorted, bo
             const sal_Int32 nPos = bSorted
                 ? InsertStringSorted(pBase->GetName(), rToFill, nOffset )
                 : rToFill.InsertEntry(pBase->GetName());
-            sal_IntPtr nPoolId = SwStyleNameMapper::GetPoolIdFromUIName( pBase->GetName(), nsSwGetPoolIdFromName::GET_POOLID_CHRFMT );
+            sal_IntPtr nPoolId = SwStyleNameMapper::GetPoolIdFromUIName( pBase->GetName(), SwGetPoolIdFromName::ChrFmt );
             rToFill.SetEntryData( nPos, reinterpret_cast<void*>(nPoolId));
         }
         pBase = pPool->Next();
@@ -737,13 +749,12 @@ void FillCharStyleListBox(ListBox& rToFill, SwDocShell* pDocSh, bool bSorted, bo
             const sal_Int32 nPos = bSorted
                 ? InsertStringSorted(rName, rToFill, nOffset )
                 : rToFill.InsertEntry(rName);
-            sal_IntPtr nPoolId = USHRT_MAX;
-            rToFill.SetEntryData( nPos, reinterpret_cast<void*>(nPoolId));
+            rToFill.SetEntryData( nPos, reinterpret_cast<void*>(USHRT_MAX));
         }
     }
 };
 
-SwTwips GetTableWidth( SwFrameFormat* pFormat, SwTabCols& rCols, sal_uInt16 *pPercent,
+SwTwips GetTableWidth( SwFrameFormat const * pFormat, SwTabCols const & rCols, sal_uInt16 *pPercent,
             SwWrtShell* pSh )
 {
     // To get the width is slightly more complicated.
@@ -756,19 +767,19 @@ SwTwips GetTableWidth( SwFrameFormat* pFormat, SwTabCols& rCols, sal_uInt16 *pPe
         case text::HoriOrientation::LEFT:
         case text::HoriOrientation::RIGHT:
         case text::HoriOrientation::CENTER:
-            nWidth = pFormat->GetFrmSize().GetWidth();
+            nWidth = pFormat->GetFrameSize().GetWidth();
         break;
         default:
         {
             if(pSh)
             {
-                if ( 0 == pSh->GetFlyFrameFormat() )
+                if ( nullptr == pSh->GetFlyFrameFormat() )
                 {
-                    nWidth = pSh->GetAnyCurRect(RECT_PAGE_PRT).Width();
+                    nWidth = pSh->GetAnyCurRect(CurRectType::PagePrt).Width();
                 }
                 else
                 {
-                    nWidth = pSh->GetAnyCurRect(RECT_FLY_PRT_EMBEDDED).Width();
+                    nWidth = pSh->GetAnyCurRect(CurRectType::FlyEmbeddedPrt).Width();
                 }
             }
             else
@@ -780,7 +791,7 @@ SwTwips GetTableWidth( SwFrameFormat* pFormat, SwTabCols& rCols, sal_uInt16 *pPe
         }
     }
     if (pPercent)
-        *pPercent = pFormat->GetFrmSize().GetWidthPercent();
+        *pPercent = pFormat->GetFrameSize().GetWidthPercent();
     return nWidth;
 }
 
@@ -788,7 +799,7 @@ OUString GetAppLangDateTimeString( const DateTime& rDT )
 {
     const SvtSysLocale aSysLocale;
     const LocaleDataWrapper& rAppLclData = aSysLocale.GetLocaleData();
-    OUString sRet = rAppLclData.getDate( rDT ) + " " + rAppLclData.getTime( rDT, false, false );
+    OUString sRet = rAppLclData.getDate( rDT ) + " " + rAppLclData.getTime( rDT );
     return sRet;
 }
 
@@ -804,7 +815,7 @@ void SetApplyCharUnit(bool bApplyChar, bool bWeb)
     SW_MOD()->ApplyUserCharUnit(bApplyChar, bWeb);
 }
 
-bool ExecuteMenuCommand( PopupMenu& rMenu, SfxViewFrame& rViewFrame, sal_uInt16 nId )
+bool ExecuteMenuCommand( PopupMenu const & rMenu, SfxViewFrame const & rViewFrame, sal_uInt16 nId )
 {
     bool bRet = false;
     const sal_uInt16 nItemCount = rMenu.GetItemCount();
