@@ -33,6 +33,9 @@
 #include <osl/time.h>
 
 #ifdef SAL_W32
+#if !defined WIN32_LEAN_AND_MEAN
+# define WIN32_LEAN_AND_MEAN
+#endif
 #include <windows.h>
 #else
 #include <sys/times.h>
@@ -371,24 +374,14 @@ static void createInstance( Reference< T > & rxOut,
 
     if (! x.is())
     {
-        OUStringBuffer buf( 64 );
-        buf.append( "cannot get service instance \"" );
-        buf.append( rServiceName );
-        buf.append( "\"!" );
-        throw RuntimeException( buf.makeStringAndClear() );
+        throw RuntimeException( "cannot get service instance \"" + rServiceName );
     }
 
     rxOut = Reference< T >::query( x );
     if (! rxOut.is())
     {
-        OUStringBuffer buf( 64 );
-        buf.append( "service instance \"" );
-        buf.append( rServiceName );
-        buf.append( "\" does not support demanded interface \"" );
-        const Type & rType = cppu::UnoType<T>::get();
-        buf.append( rType.getTypeName() );
-        buf.append( "\"!" );
-        throw RuntimeException( buf.makeStringAndClear() );
+        throw RuntimeException( "service instance \"" + rServiceName +
+                  "\" does not support demanded interface \"" + cppu::UnoType<T>::get().getTypeName() );
     }
 }
 
@@ -422,8 +415,6 @@ public:
 };
 
 
-
-
 TestImpl::TestImpl( const Reference< XMultiServiceFactory > & xSMgr )
     : _xSMgr( xSMgr )
 {
@@ -492,11 +483,7 @@ Reference< XInterface > TestImpl::resolveObject( const OUString & rUnoUrl )
 
     if (! xResolvedObject.is())
     {
-        OUStringBuffer buf( 32 );
-        buf.append( "cannot resolve object \"" );
-        buf.append( rUnoUrl );
-        buf.append( "\"!" );
-        throw RuntimeException( buf.makeStringAndClear() );
+        throw RuntimeException( "cannot resolve object \"" + rUnoUrl + "\"!" );
     }
 
     return xResolvedObject;
@@ -556,9 +543,7 @@ static void benchmark(
     TimingSheet & rSheet, const Reference< XInterface > & xInstance, sal_Int64 nLoop )
     throw (Exception)
 {
-    Reference< XPerformanceTest > xBench( xInstance, UNO_QUERY );
-    if (! xBench.is())
-        throw RuntimeException("illegal test object!" );
+    Reference< XPerformanceTest > xBench( xInstance, UNO_QUERY_THROW );
 
     sal_Int64 i;
     sal_uInt32 tStart, tEnd;
@@ -788,7 +773,7 @@ static void benchmark(
     while (i--)
         xBench->setString( aDummyString );
     tEnd = getSystemTicks();
-    rSheet.insert( "6c: setString() call (emtpy)", nLoop, tEnd - tStart );
+    rSheet.insert( "6c: setString() call (empty)", nLoop, tEnd - tStart );
     i = nLoop;
     tStart = getSystemTicks();
     while (i--)
@@ -991,11 +976,7 @@ sal_Int32 TestImpl::run( const Sequence< OUString > & rArgs )
                 stream = ::fopen( aFileName.getStr(), "w" );
                 if (! stream)
                 {
-                    OUStringBuffer buf( 32 );
-                    buf.append( "cannot open file for writing: \"" );
-                    buf.append( aLogStr );
-                    buf.append( "\"!" );
-                    throw RuntimeException( buf.makeStringAndClear() );
+                    throw RuntimeException( "cannot open file for writing: \"" + aLogStr + "\"!" );
                 }
             }
         }
@@ -1026,7 +1007,6 @@ sal_Int32 TestImpl::run( const Sequence< OUString > & rArgs )
         TimingSheet aDirect;
 
 
-
         if (aArg.indexOf( 'd' ) >= 0)
         {
             // in process direct test
@@ -1037,7 +1017,6 @@ sal_Int32 TestImpl::run( const Sequence< OUString > & rArgs )
         }
 
 
-
         if (aArg.indexOf( 'm' ) >= 0)
         {
             // in process uno dispatch
@@ -1068,7 +1047,6 @@ sal_Int32 TestImpl::run( const Sequence< OUString > & rArgs )
         }
 
 
-
         if (aArg.indexOf( 's' ) >= 0)
         {
             // start server process
@@ -1136,7 +1114,6 @@ sal_Int32 TestImpl::run( const Sequence< OUString > & rArgs )
         }
 
 
-
         if (aArg.indexOf( 'r' ) >= 0)
         {
             // remote
@@ -1155,7 +1132,6 @@ sal_Int32 TestImpl::run( const Sequence< OUString > & rArgs )
         }
 
 
-
         if (aArg.indexOf( 'j' ) >= 0)
         {
             // java
@@ -1168,9 +1144,6 @@ sal_Int32 TestImpl::run( const Sequence< OUString > & rArgs )
         // dump out tables
 
         out( "\nTimes( ratio to direct in process )", stream );
-#if OSL_DEBUG_LEVEL > 1
-        out ("; compiled with OSL_DEBUG_LEVEL > 1", stream );
-#endif
         out( ":", stream );
 
         sal_Int32 nPos = 60;
@@ -1256,11 +1229,6 @@ sal_Int32 TestImpl::run( const Sequence< OUString > & rArgs )
 }
 
 
-
-
-
-
-
 extern "C"
 {
 
