@@ -22,6 +22,7 @@
 #include <toolkit/helper/property.hxx>
 
 #include <com/sun/star/lang/DisposedException.hpp>
+#include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
 #include <com/sun/star/awt/VisualEffect.hpp>
 #include <com/sun/star/awt/ImageScaleMode.hpp>
 #include <com/sun/star/awt/XAnimation.hpp>
@@ -36,7 +37,7 @@
 
 #include <cppuhelper/implbase2.hxx>
 
-#include "helper/unopropertyarrayhelper.hxx"
+#include <helper/unopropertyarrayhelper.hxx>
 
 using namespace css::awt;
 using namespace css::container;
@@ -57,26 +58,26 @@ public:
     OUString GetComponentServiceName() override;
 
     // XAnimation
-    virtual void SAL_CALL startAnimation(  ) throw (css::uno::RuntimeException, std::exception) override;
-    virtual void SAL_CALL stopAnimation(  ) throw (css::uno::RuntimeException, std::exception) override;
-    virtual sal_Bool SAL_CALL isAnimationRunning(  ) throw (css::uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL startAnimation(  ) override;
+    virtual void SAL_CALL stopAnimation(  ) override;
+    virtual sal_Bool SAL_CALL isAnimationRunning(  ) override;
 
     // XServiceInfo
-    OUString SAL_CALL getImplementationName(  ) throw(css::uno::RuntimeException, std::exception) override;
-    css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() throw(css::uno::RuntimeException, std::exception) override;
+    OUString SAL_CALL getImplementationName(  ) override;
+    css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() override;
 
     // XControl
-    sal_Bool SAL_CALL setModel( const css::uno::Reference< css::awt::XControlModel >& i_rModel ) throw ( css::uno::RuntimeException, std::exception ) override;
-    void SAL_CALL createPeer( const css::uno::Reference< css::awt::XToolkit >& i_toolkit, const css::uno::Reference< css::awt::XWindowPeer >& i_parentPeer ) throw(css::uno::RuntimeException, std::exception) override;
+    sal_Bool SAL_CALL setModel( const css::uno::Reference< css::awt::XControlModel >& i_rModel ) override;
+    void SAL_CALL createPeer( const css::uno::Reference< css::awt::XToolkit >& i_toolkit, const css::uno::Reference< css::awt::XWindowPeer >& i_parentPeer ) override;
 
 
     // XContainerListener
-    virtual void SAL_CALL elementInserted( const css::container::ContainerEvent& Event ) throw (css::uno::RuntimeException, std::exception) override;
-    virtual void SAL_CALL elementRemoved( const css::container::ContainerEvent& Event ) throw (css::uno::RuntimeException, std::exception) override;
-    virtual void SAL_CALL elementReplaced( const css::container::ContainerEvent& Event ) throw (css::uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL elementInserted( const css::container::ContainerEvent& Event ) override;
+    virtual void SAL_CALL elementRemoved( const css::container::ContainerEvent& Event ) override;
+    virtual void SAL_CALL elementReplaced( const css::container::ContainerEvent& Event ) override;
 
     // XEventListener
-    virtual void SAL_CALL disposing( const css::lang::EventObject& i_event ) throw (css::uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL disposing( const css::lang::EventObject& i_event ) override;
 };
 
     AnimatedImagesControl::AnimatedImagesControl()
@@ -91,7 +92,7 @@ public:
     }
 
 
-    void SAL_CALL AnimatedImagesControl::startAnimation(  ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControl::startAnimation(  )
     {
         Reference< XAnimation > xAnimation( getPeer(), UNO_QUERY );
         if ( xAnimation.is() )
@@ -99,7 +100,7 @@ public:
     }
 
 
-    void SAL_CALL AnimatedImagesControl::stopAnimation(  ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControl::stopAnimation(  )
     {
         Reference< XAnimation > xAnimation( getPeer(), UNO_QUERY );
         if ( xAnimation.is() )
@@ -107,22 +108,22 @@ public:
     }
 
 
-    sal_Bool SAL_CALL AnimatedImagesControl::isAnimationRunning(  ) throw (RuntimeException, std::exception)
+    sal_Bool SAL_CALL AnimatedImagesControl::isAnimationRunning(  )
     {
         Reference< XAnimation > xAnimation( getPeer(), UNO_QUERY );
         if ( xAnimation.is() )
             return xAnimation->isAnimationRunning();
-        return sal_False;
+        return false;
     }
 
 
-    OUString SAL_CALL AnimatedImagesControl::getImplementationName(  ) throw(RuntimeException, std::exception)
+    OUString SAL_CALL AnimatedImagesControl::getImplementationName(  )
     {
         return OUString( "org.openoffice.comp.toolkit.AnimatedImagesControl" );
     }
 
 
-    Sequence< OUString > SAL_CALL AnimatedImagesControl::getSupportedServiceNames() throw(RuntimeException, std::exception)
+    Sequence< OUString > SAL_CALL AnimatedImagesControl::getSupportedServiceNames()
     {
         Sequence< OUString > aServices( AnimatedImagesControl_Base::getSupportedServiceNames() );
         aServices.realloc( aServices.getLength() + 1 );
@@ -146,13 +147,13 @@ public:
     }
 
 
-    sal_Bool SAL_CALL AnimatedImagesControl::setModel( const Reference< XControlModel >& i_rModel ) throw ( RuntimeException, std::exception )
+    sal_Bool SAL_CALL AnimatedImagesControl::setModel( const Reference< XControlModel >& i_rModel )
     {
         const Reference< XAnimatedImages > xOldContainer( getModel(), UNO_QUERY );
         const Reference< XAnimatedImages > xNewContainer( i_rModel, UNO_QUERY );
 
         if ( !AnimatedImagesControl_Base::setModel( i_rModel ) )
-            return sal_False;
+            return false;
 
         if ( xOldContainer.is() )
             xOldContainer->removeContainerListener( this );
@@ -162,11 +163,11 @@ public:
 
         lcl_updatePeer( getPeer(), getModel() );
 
-        return sal_True;
+        return true;
     }
 
 
-    void SAL_CALL AnimatedImagesControl::createPeer( const Reference< XToolkit >& i_toolkit, const Reference< XWindowPeer >& i_parentPeer ) throw(RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControl::createPeer( const Reference< XToolkit >& i_toolkit, const Reference< XWindowPeer >& i_parentPeer )
     {
         AnimatedImagesControl_Base::createPeer( i_toolkit, i_parentPeer );
 
@@ -174,7 +175,7 @@ public:
     }
 
 
-    void SAL_CALL AnimatedImagesControl::elementInserted( const ContainerEvent& i_event ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControl::elementInserted( const ContainerEvent& i_event )
     {
         const Reference< XContainerListener > xPeerListener( getPeer(), UNO_QUERY );
         if ( xPeerListener.is() )
@@ -182,7 +183,7 @@ public:
     }
 
 
-    void SAL_CALL AnimatedImagesControl::elementRemoved( const ContainerEvent& i_event ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControl::elementRemoved( const ContainerEvent& i_event )
     {
         const Reference< XContainerListener > xPeerListener( getPeer(), UNO_QUERY );
         if ( xPeerListener.is() )
@@ -190,7 +191,7 @@ public:
     }
 
 
-    void SAL_CALL AnimatedImagesControl::elementReplaced( const ContainerEvent& i_event ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControl::elementReplaced( const ContainerEvent& i_event )
     {
         const Reference< XContainerListener > xPeerListener( getPeer(), UNO_QUERY );
         if ( xPeerListener.is() )
@@ -198,7 +199,7 @@ public:
     }
 
 
-    void SAL_CALL AnimatedImagesControl::disposing( const EventObject& i_event ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControl::disposing( const EventObject& i_event )
     {
         UnoControlBase::disposing( i_event );
     }
@@ -221,7 +222,7 @@ namespace toolkit {
                 throw IndexOutOfBoundsException( OUString(), i_context );
         }
 
-        void lcl_notify( ::osl::ClearableMutexGuard& i_guard, ::cppu::OBroadcastHelper& i_broadcaseHelper,
+        void lcl_notify( ::osl::ClearableMutexGuard& i_guard, ::cppu::OBroadcastHelper const & i_broadcaseHelper,
             void ( SAL_CALL XContainerListener::*i_notificationMethod )( const ContainerEvent& ),
             const sal_Int32 i_accessor, const Sequence< OUString >& i_imageURLs, const Reference< XInterface >& i_context )
         {
@@ -275,26 +276,26 @@ namespace toolkit {
     }
 
 
-    Reference< css::beans::XPropertySetInfo > SAL_CALL AnimatedImagesControlModel::getPropertySetInfo(  ) throw(RuntimeException, std::exception)
+    Reference< css::beans::XPropertySetInfo > SAL_CALL AnimatedImagesControlModel::getPropertySetInfo(  )
     {
         static Reference< css::beans::XPropertySetInfo > xInfo( createPropertySetInfo( getInfoHelper() ) );
         return xInfo;
     }
 
 
-    OUString SAL_CALL AnimatedImagesControlModel::getServiceName() throw(RuntimeException, std::exception)
+    OUString SAL_CALL AnimatedImagesControlModel::getServiceName()
     {
         return OUString("com.sun.star.awt.AnimatedImagesControlModel");
     }
 
 
-    OUString SAL_CALL AnimatedImagesControlModel::getImplementationName(  ) throw(RuntimeException, std::exception)
+    OUString SAL_CALL AnimatedImagesControlModel::getImplementationName(  )
     {
         return OUString("org.openoffice.comp.toolkit.AnimatedImagesControlModel");
     }
 
 
-    Sequence< OUString > SAL_CALL AnimatedImagesControlModel::getSupportedServiceNames() throw(RuntimeException, std::exception)
+    Sequence< OUString > SAL_CALL AnimatedImagesControlModel::getSupportedServiceNames()
     {
         Sequence< OUString > aServiceNames(2);
         aServiceNames[0] = "com.sun.star.awt.AnimatedImagesControlModel";
@@ -303,7 +304,7 @@ namespace toolkit {
     }
 
 
-    void SAL_CALL AnimatedImagesControlModel::setFastPropertyValue_NoBroadcast( sal_Int32 i_handle, const Any& i_value ) throw (Exception, std::exception)
+    void SAL_CALL AnimatedImagesControlModel::setFastPropertyValue_NoBroadcast( sal_Int32 i_handle, const Any& i_value )
     {
         switch ( i_handle )
         {
@@ -361,7 +362,7 @@ namespace toolkit {
     }
 
 
-    ::sal_Int32 SAL_CALL AnimatedImagesControlModel::getStepTime() throw (RuntimeException, std::exception)
+    ::sal_Int32 SAL_CALL AnimatedImagesControlModel::getStepTime()
     {
         sal_Int32 nStepTime( 100 );
         OSL_VERIFY( getPropertyValue( GetPropertyName( BASEPROPERTY_STEP_TIME ) ) >>= nStepTime );
@@ -369,13 +370,13 @@ namespace toolkit {
     }
 
 
-    void SAL_CALL AnimatedImagesControlModel::setStepTime( ::sal_Int32 i_stepTime ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControlModel::setStepTime( ::sal_Int32 i_stepTime )
     {
         setPropertyValue( GetPropertyName( BASEPROPERTY_STEP_TIME ), makeAny( i_stepTime ) );
     }
 
 
-    sal_Bool SAL_CALL AnimatedImagesControlModel::getAutoRepeat() throw (RuntimeException, std::exception)
+    sal_Bool SAL_CALL AnimatedImagesControlModel::getAutoRepeat()
     {
         bool bAutoRepeat( true );
         OSL_VERIFY( getPropertyValue( GetPropertyName( BASEPROPERTY_AUTO_REPEAT ) ) >>= bAutoRepeat );
@@ -383,13 +384,13 @@ namespace toolkit {
     }
 
 
-    void SAL_CALL AnimatedImagesControlModel::setAutoRepeat( sal_Bool i_autoRepeat ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControlModel::setAutoRepeat( sal_Bool i_autoRepeat )
     {
         setPropertyValue( GetPropertyName( BASEPROPERTY_AUTO_REPEAT ), makeAny( i_autoRepeat ) );
     }
 
 
-    ::sal_Int16 SAL_CALL AnimatedImagesControlModel::getScaleMode() throw (RuntimeException, std::exception)
+    ::sal_Int16 SAL_CALL AnimatedImagesControlModel::getScaleMode()
     {
         sal_Int16 nImageScaleMode( ImageScaleMode::ANISOTROPIC );
         OSL_VERIFY( getPropertyValue( GetPropertyName( BASEPROPERTY_IMAGE_SCALE_MODE ) ) >>= nImageScaleMode );
@@ -397,13 +398,13 @@ namespace toolkit {
     }
 
 
-    void SAL_CALL AnimatedImagesControlModel::setScaleMode( ::sal_Int16 i_scaleMode ) throw (IllegalArgumentException, RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControlModel::setScaleMode( ::sal_Int16 i_scaleMode )
     {
         setPropertyValue( GetPropertyName( BASEPROPERTY_IMAGE_SCALE_MODE ), makeAny( i_scaleMode ) );
     }
 
 
-    ::sal_Int32 SAL_CALL AnimatedImagesControlModel::getImageSetCount(  ) throw (RuntimeException, std::exception)
+    ::sal_Int32 SAL_CALL AnimatedImagesControlModel::getImageSetCount(  )
     {
         ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
         if ( GetBroadcastHelper().bDisposed || GetBroadcastHelper().bInDispose )
@@ -413,7 +414,7 @@ namespace toolkit {
     }
 
 
-    Sequence< OUString > SAL_CALL AnimatedImagesControlModel::getImageSet( ::sal_Int32 i_index ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+    Sequence< OUString > SAL_CALL AnimatedImagesControlModel::getImageSet( ::sal_Int32 i_index )
     {
         ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
         if ( GetBroadcastHelper().bDisposed || GetBroadcastHelper().bInDispose )
@@ -425,7 +426,7 @@ namespace toolkit {
     }
 
 
-    void SAL_CALL AnimatedImagesControlModel::insertImageSet( ::sal_Int32 i_index, const Sequence< OUString >& i_imageURLs ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControlModel::insertImageSet( ::sal_Int32 i_index, const Sequence< OUString >& i_imageURLs )
     {
         ::osl::ClearableMutexGuard aGuard( GetMutex() );
         // sanity checks
@@ -442,7 +443,7 @@ namespace toolkit {
     }
 
 
-    void SAL_CALL AnimatedImagesControlModel::replaceImageSet( ::sal_Int32 i_index, const Sequence< OUString >& i_imageURLs ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControlModel::replaceImageSet( ::sal_Int32 i_index, const Sequence< OUString >& i_imageURLs )
     {
         ::osl::ClearableMutexGuard aGuard( GetMutex() );
         // sanity checks
@@ -459,7 +460,7 @@ namespace toolkit {
     }
 
 
-    void SAL_CALL AnimatedImagesControlModel::removeImageSet( ::sal_Int32 i_index ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControlModel::removeImageSet( ::sal_Int32 i_index )
     {
         ::osl::ClearableMutexGuard aGuard( GetMutex() );
         // sanity checks
@@ -478,13 +479,13 @@ namespace toolkit {
     }
 
 
-    void SAL_CALL AnimatedImagesControlModel::addContainerListener( const Reference< XContainerListener >& i_listener ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControlModel::addContainerListener( const Reference< XContainerListener >& i_listener )
     {
         BrdcstHelper.addListener( cppu::UnoType<XContainerListener>::get(), i_listener );
     }
 
 
-    void SAL_CALL AnimatedImagesControlModel::removeContainerListener( const Reference< XContainerListener >& i_listener ) throw (RuntimeException, std::exception)
+    void SAL_CALL AnimatedImagesControlModel::removeContainerListener( const Reference< XContainerListener >& i_listener )
     {
         BrdcstHelper.removeListener( cppu::UnoType<XContainerListener>::get(), i_listener );
     }
