@@ -7,10 +7,11 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
+#include <memory>
 #include <string>
 
 #include <sal/types.h>
-#include "cppunit/TestFixture.h"
+#include <cppunit/TestFixture.h>
 #include <cppunit/extensions/HelperMacros.h>
 #include <tools/stream.hxx>
 #include <tools/urlobj.hxx>
@@ -43,39 +44,24 @@ namespace tools_urlobj
     {
 
       public:
-        // initialise your test code values here.
-        void setUp(  ) override
-        {
-        }
-
-        void tearDown(  ) override
-        {
-        }
-
         // insert your test code here.
         // this is only demonstration code
         void urlobjTest_001(  )
         {
             INetURLObject aUrl( OUString( "file://10.10.1.1/sampledir/sample.file" ) );
 #ifdef LINUX
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE )
-                            == "smb://10.10.1.1/sampledir/sample.file" );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::Smb );
+            CPPUNIT_ASSERT_EQUAL(OUString("smb://10.10.1.1/sampledir/sample.file"),
+                                 aUrl.GetMainURL(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(INetProtocol::Smb, aUrl.GetProtocol());
 #endif
-#ifdef WIN
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE ).
-                            equalsAscii
-                            ( "file://10.10.1.1/sampledir/sample.file" ) );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::File );
-#endif
-            CPPUNIT_ASSERT( aUrl.GetHost( INetURLObject::NO_DECODE )
-                            == "10.10.1.1" );
-            CPPUNIT_ASSERT( aUrl.GetURLPath( INetURLObject::NO_DECODE )
-                            == "/sampledir/sample.file" );
-            CPPUNIT_ASSERT( aUrl.getName(  )
-                            == "sample.file" );
-            CPPUNIT_ASSERT( aUrl.getBase(  ) == "sample" );
-            CPPUNIT_ASSERT( aUrl.getExtension(  ) == "file" );
+            CPPUNIT_ASSERT_EQUAL(OUString("10.10.1.1"),
+                                 aUrl.GetHost(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("/sampledir/sample.file"),
+                                 aUrl.GetURLPath(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("sample.file"),
+                                 aUrl.getName());
+            CPPUNIT_ASSERT_EQUAL(OUString("sample"), aUrl.getBase());
+            CPPUNIT_ASSERT_EQUAL(OUString("file"), aUrl.getExtension());
         }
 
         void urlobjTest_002(  )
@@ -83,24 +69,19 @@ namespace tools_urlobj
             INetURLObject aUrl;
             aUrl.
                 setFSysPath( "\\\\137.65.170.24\\c$\\Img0001.jpg",
-                             INetURLObject::FSYS_DETECT );
+                             FSysStyle::Detect );
 #ifdef LINUX
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE )
-                            == "smb://137.65.170.24/c$/Img0001.jpg" );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::Smb );
+            CPPUNIT_ASSERT_EQUAL(OUString("smb://137.65.170.24/c$/Img0001.jpg"),
+                                 aUrl.GetMainURL(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(INetProtocol::Smb, aUrl.GetProtocol());
 #endif
-#ifdef WIN
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE ).
-                            equalsAscii( "file://137.65.170.24/c$/Img0001.jpg" ) );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::File );
-#endif
-            CPPUNIT_ASSERT( aUrl.GetHost( INetURLObject::NO_DECODE )
-                            == "137.65.170.24" );
-            CPPUNIT_ASSERT( aUrl.GetURLPath( INetURLObject::NO_DECODE )
-                            == "/c$/Img0001.jpg" );
-            CPPUNIT_ASSERT( aUrl.getName(  ) == "Img0001.jpg" );
-            CPPUNIT_ASSERT( aUrl.getBase(  ) == "Img0001" );
-            CPPUNIT_ASSERT( aUrl.getExtension(  ) == "jpg" );
+            CPPUNIT_ASSERT_EQUAL(OUString("137.65.170.24"),
+                                 aUrl.GetHost(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("/c$/Img0001.jpg"),
+                                 aUrl.GetURLPath(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("Img0001.jpg"), aUrl.getName());
+            CPPUNIT_ASSERT_EQUAL(OUString("Img0001"), aUrl.getBase());
+            CPPUNIT_ASSERT_EQUAL(OUString("jpg"), aUrl.getExtension());
         }
 
 
@@ -109,67 +90,52 @@ namespace tools_urlobj
             INetURLObject aUrl;
             aUrl.
                 setFSysPath( "\\\\hive-winxp-x86\\pmladek\\test2.odt",
-                             INetURLObject::FSYS_DETECT );
+                             FSysStyle::Detect );
 #ifdef LINUX
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE )
-                            == "smb://hive-winxp-x86/pmladek/test2.odt" );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::Smb );
+            CPPUNIT_ASSERT_EQUAL(OUString("smb://hive-winxp-x86/pmladek/test2.odt"),
+                                 aUrl.GetMainURL(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(INetProtocol::Smb, aUrl.GetProtocol());
 #endif
-#ifdef WIN
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE ).
-                            equalsAscii( "file://hive-winxp-x86/pmladek/test2.odt" ) );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::File );
-#endif
-            CPPUNIT_ASSERT( aUrl.GetHost( INetURLObject::NO_DECODE )
-                            == "hive-winxp-x86" );
-            CPPUNIT_ASSERT( aUrl.GetURLPath( INetURLObject::NO_DECODE )
-                            == "/pmladek/test2.odt" );
+            CPPUNIT_ASSERT_EQUAL(OUString("hive-winxp-x86"),
+                                 aUrl.GetHost(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("/pmladek/test2.odt"),
+                                 aUrl.GetURLPath(INetURLObject::DecodeMechanism::NONE));
         }
 
         void urlobjTest_004(  )
         {
             INetURLObject aUrl( OUString( "smb://10.10.1.1/sampledir/sample.file" ) );
 #ifdef LINUX
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE )
-                            == "smb://10.10.1.1/sampledir/sample.file" );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::Smb );
+            CPPUNIT_ASSERT_EQUAL(OUString("smb://10.10.1.1/sampledir/sample.file"),
+                                 aUrl.GetMainURL(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL( INetProtocol::Smb, aUrl.GetProtocol(  ) );
 #endif
-#ifdef WIN
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE ).
-                            equalsAscii( "file://10.10.1.1/sampledir/sample.file" ) );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::File );
-#endif
-            CPPUNIT_ASSERT( aUrl.GetHost( INetURLObject::NO_DECODE )
-                            == "10.10.1.1" );
-            CPPUNIT_ASSERT( aUrl.GetURLPath( INetURLObject::NO_DECODE )
-                            == "/sampledir/sample.file" );
-            CPPUNIT_ASSERT( aUrl.getName(  ) == "sample.file" );
-            CPPUNIT_ASSERT( aUrl.getBase(  ) == "sample" );
-            CPPUNIT_ASSERT( aUrl.getExtension(  ) == "file" );
+            CPPUNIT_ASSERT_EQUAL(OUString("10.10.1.1"),
+                                 aUrl.GetHost(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("/sampledir/sample.file"),
+                                 aUrl.GetURLPath(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("sample.file"), aUrl.getName());
+            CPPUNIT_ASSERT_EQUAL(OUString("sample"), aUrl.getBase());
+            CPPUNIT_ASSERT_EQUAL(OUString("file"), aUrl.getExtension());
         }
 
         void urlobjTest_005(  )
         {
             INetURLObject aUrl;
             aUrl.setFSysPath( "//137.65.170.24/c$/Img0001.jpg",
-                              INetURLObject::FSYS_DETECT );
+                              FSysStyle::Detect );
 #ifdef LINUX
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE )
-                            == "smb://137.65.170.24/c$/Img0001.jpg" );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::Smb );
+            CPPUNIT_ASSERT_EQUAL(OUString("smb://137.65.170.24/c$/Img0001.jpg"),
+                                 aUrl.GetMainURL(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(INetProtocol::Smb, aUrl.GetProtocol());
 #endif
-#ifdef WIN
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE ).
-                            equalsAscii( "file://137.65.170.24/c$/Img0001.jpg" ) );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::File );
-#endif
-            CPPUNIT_ASSERT( aUrl.GetHost( INetURLObject::NO_DECODE )
-                            == "137.65.170.24" );
-            CPPUNIT_ASSERT( aUrl.GetURLPath( INetURLObject::NO_DECODE )
-                            == "/c$/Img0001.jpg" );
-            CPPUNIT_ASSERT( aUrl.getName(  ) == "Img0001.jpg" );
-            CPPUNIT_ASSERT( aUrl.getBase(  ) == "Img0001" );
-            CPPUNIT_ASSERT( aUrl.getExtension(  ) == "jpg" );
+            CPPUNIT_ASSERT_EQUAL(OUString("137.65.170.24"),
+                                 aUrl.GetHost(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("/c$/Img0001.jpg"),
+                                 aUrl.GetURLPath(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("Img0001.jpg"), aUrl.getName(  ));
+            CPPUNIT_ASSERT_EQUAL(OUString("Img0001"), aUrl.getBase(  ));
+            CPPUNIT_ASSERT_EQUAL(OUString("jpg"), aUrl.getExtension(  ));
         }
 
 
@@ -177,21 +143,16 @@ namespace tools_urlobj
         {
             INetURLObject aUrl;
             aUrl.setFSysPath( "//hive-winxp-x86/pmladek/test2.odt",
-                              INetURLObject::FSYS_DETECT );
+                              FSysStyle::Detect );
 #ifdef LINUX
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE )
-                            == "smb://hive-winxp-x86/pmladek/test2.odt" );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::Smb );
+            CPPUNIT_ASSERT_EQUAL(OUString("smb://hive-winxp-x86/pmladek/test2.odt"),
+                                 aUrl.GetMainURL(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(INetProtocol::Smb, aUrl.GetProtocol());
 #endif
-#ifdef WIN
-            CPPUNIT_ASSERT( aUrl.GetMainURL( INetURLObject::NO_DECODE ).
-                            equalsAscii( "file://hive-winxp-x86/pmladek/test2.odt" ) );
-            CPPUNIT_ASSERT( aUrl.GetProtocol(  ) == INetProtocol::File );
-#endif
-            CPPUNIT_ASSERT( aUrl.GetHost( INetURLObject::NO_DECODE )
-                            == "hive-winxp-x86" );
-            CPPUNIT_ASSERT( aUrl.GetURLPath( INetURLObject::NO_DECODE )
-                            == "/pmladek/test2.odt" );
+            CPPUNIT_ASSERT_EQUAL(OUString("hive-winxp-x86"),
+                                 aUrl.GetHost(INetURLObject::DecodeMechanism::NONE));
+            CPPUNIT_ASSERT_EQUAL(OUString("/pmladek/test2.odt"),
+                                 aUrl.GetURLPath( INetURLObject::DecodeMechanism::NONE));
         }
 
         void urlobjCmisTest(  )
@@ -200,10 +161,10 @@ namespace tools_urlobj
             {
                 INetURLObject aUrl( OUString( "vnd.libreoffice.cmis://username@http:%2F%2Ffoo.bar.com:8080%2Fmy%2Fcmis%2Fatom%23repo-id-encoded/path/to/content" ) );
                 CPPUNIT_ASSERT_EQUAL( std::string( "http://foo.bar.com:8080/my/cmis/atom#repo-id-encoded" ),
-                        OUSTR_TO_STDSTR( aUrl.GetHost( INetURLObject::DECODE_WITH_CHARSET ) ) );
+                        OUSTR_TO_STDSTR( aUrl.GetHost( INetURLObject::DecodeMechanism::WithCharset ) ) );
                 CPPUNIT_ASSERT_EQUAL( std::string( "username" ), OUSTR_TO_STDSTR( aUrl.GetUser( ) ) );
                 CPPUNIT_ASSERT_EQUAL( std::string( "/path/to/content" ),
-                        OUSTR_TO_STDSTR( aUrl.GetURLPath( INetURLObject::NO_DECODE ) ) );
+                        OUSTR_TO_STDSTR( aUrl.GetURLPath( INetURLObject::DecodeMechanism::NONE ) ) );
                 CPPUNIT_ASSERT_EQUAL_MESSAGE( "Wrong protocol found", INetProtocol::Cmis, aUrl.GetProtocol(  ) );
             }
 
@@ -212,10 +173,10 @@ namespace tools_urlobj
                 INetURLObject aUrl( OUString(
                                 "vnd.libreoffice.cmis://http:%2F%2Ffoo.bar.com:8080%2Fmy%2Fcmis%2Fatom%23repo-id-encoded/path/to/content" ) );
                 CPPUNIT_ASSERT_EQUAL( std::string( "http://foo.bar.com:8080/my/cmis/atom#repo-id-encoded" ),
-                        OUSTR_TO_STDSTR( aUrl.GetHost( INetURLObject::DECODE_WITH_CHARSET ) ) );
+                        OUSTR_TO_STDSTR( aUrl.GetHost( INetURLObject::DecodeMechanism::WithCharset ) ) );
                 CPPUNIT_ASSERT( !aUrl.HasUserData() );
                 CPPUNIT_ASSERT_EQUAL( std::string( "/path/to/content" ),
-                        OUSTR_TO_STDSTR( aUrl.GetURLPath( INetURLObject::NO_DECODE ) ) );
+                        OUSTR_TO_STDSTR( aUrl.GetURLPath( INetURLObject::DecodeMechanism::NONE ) ) );
                 CPPUNIT_ASSERT_EQUAL_MESSAGE( "Wrong protocol found", INetProtocol::Cmis, aUrl.GetProtocol(  ) );
             }
         }
@@ -249,7 +210,7 @@ namespace tools_urlobj
             url = INetURLObject("data:");
             //TODO: CPPUNIT_ASSERT(url.HasError());
             strm = url.getData();
-            CPPUNIT_ASSERT(strm == nullptr);
+            CPPUNIT_ASSERT(!strm);
 
             url = INetURLObject("data:,");
             CPPUNIT_ASSERT(!url.HasError());
@@ -273,7 +234,7 @@ namespace tools_urlobj
             url = INetURLObject("data:base64,");
             //TODO: CPPUNIT_ASSERT(url.HasError());
             strm = url.getData();
-            CPPUNIT_ASSERT(strm == nullptr);
+            CPPUNIT_ASSERT(!strm);
 
             url = INetURLObject("data:;base64,");
             CPPUNIT_ASSERT(!url.HasError());
@@ -304,12 +265,12 @@ namespace tools_urlobj
             url = INetURLObject("data:;base64,YWJjCg=");
             CPPUNIT_ASSERT(!url.HasError());
             strm = url.getData();
-            CPPUNIT_ASSERT(strm == nullptr);
+            CPPUNIT_ASSERT(!strm);
 
             url = INetURLObject("data:;base64,YWJ$Cg==");
             CPPUNIT_ASSERT(!url.HasError());
             strm = url.getData();
-            CPPUNIT_ASSERT(strm == nullptr);
+            CPPUNIT_ASSERT(!strm);
 
             url = INetURLObject("data:text/plain;param=%22;base64,%22,YQ==");
             CPPUNIT_ASSERT(!url.HasError());
@@ -326,7 +287,7 @@ namespace tools_urlobj
             url = INetURLObject("http://example.com");
             CPPUNIT_ASSERT(!url.HasError());
             strm = url.getData();
-            CPPUNIT_ASSERT(strm == nullptr);
+            CPPUNIT_ASSERT(!strm);
         }
 
         void urlobjTest_isSchemeEqualTo() {
@@ -367,6 +328,16 @@ namespace tools_urlobj
                 !INetURLObject("vnd.sun.star.pkg://example.org").isAnyKnownWebDAVScheme());
         }
 
+        void testSetExtension() {
+            INetURLObject obj("file:///foo/bar.baz/");
+            bool ok = obj.setExtension(
+                "other", INetURLObject::LAST_SEGMENT, false);
+            CPPUNIT_ASSERT(ok);
+            CPPUNIT_ASSERT_EQUAL(
+                OUString("file:///foo/bar.baz/.other"),
+                obj.GetMainURL(INetURLObject::DecodeMechanism::NONE));
+        }
+
         // Change the following lines only, if you add, remove or rename
         // member functions of the current class,
         // because these macros are need by auto register mechanism.
@@ -383,6 +354,7 @@ namespace tools_urlobj
         CPPUNIT_TEST( urlobjTest_data );
         CPPUNIT_TEST( urlobjTest_isSchemeEqualTo );
         CPPUNIT_TEST( urlobjTest_isAnyKnownWebDAVScheme );
+        CPPUNIT_TEST( testSetExtension );
         CPPUNIT_TEST_SUITE_END(  );
     };                          // class createPool
 
@@ -391,6 +363,4 @@ namespace tools_urlobj
 }                               // namespace rtl_random
 
 
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
