@@ -20,10 +20,10 @@
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/lang/XSingleServiceFactory.hpp>
 #include <com/sun/star/registry/XRegistryKey.hpp>
-#include <cachedcontentresultset.hxx>
-#include <cachedcontentresultsetstub.hxx>
-#include <cacheddynamicresultset.hxx>
-#include <cacheddynamicresultsetstub.hxx>
+#include "cachedcontentresultset.hxx"
+#include "cachedcontentresultsetstub.hxx"
+#include "cacheddynamicresultset.hxx"
+#include "cacheddynamicresultsetstub.hxx"
 
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
