@@ -23,13 +23,12 @@
 #include <sal/macros.h>
 #include <osl/time.h>
 
-#include <osl/diagnose.h>
-#include <osl/doublecheckedlocking.h>
-
+#include <com/sun/star/beans/IllegalTypeException.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/beans/PropertySetInfoChange.hpp>
 #include <com/sun/star/beans/PropertySetInfoChangeEvent.hpp>
+#include <com/sun/star/io/IOException.hpp>
 #include <com/sun/star/io/XActiveDataSink.hpp>
 #include <com/sun/star/io/XOutputStream.hpp>
 #include <com/sun/star/lang/IllegalAccessException.hpp>
@@ -85,11 +84,10 @@ Content::Content(
     const uno::Reference< uno::XComponentContext >& rxContext,
     ContentProvider* pProvider,
     const uno::Reference< ucb::XContentIdentifier >& Identifier)
-        throw ( ucb::ContentCreationException )
     : ContentImplHelper( rxContext, pProvider, Identifier ),
       m_pProvider( pProvider ), mpFile (nullptr), mpInfo( nullptr ), mbTransient(false)
 {
-    SAL_INFO("ucb.ucp.gio", "New Content ('" << m_xIdentifier->getContentIdentifier() << "')\n");
+    SAL_INFO("ucb.ucp.gio", "New Content ('" << m_xIdentifier->getContentIdentifier() << "')");
 }
 
 Content::Content(
@@ -97,11 +95,10 @@ Content::Content(
     ContentProvider* pProvider,
     const uno::Reference< ucb::XContentIdentifier >& Identifier,
     bool bIsFolder)
-        throw ( ucb::ContentCreationException )
     : ContentImplHelper( rxContext, pProvider, Identifier ),
       m_pProvider( pProvider ), mpFile (nullptr), mpInfo( nullptr ), mbTransient(true)
 {
-    SAL_INFO("ucb.ucp.gio", "Create Content ('" << m_xIdentifier->getContentIdentifier() << "')\n");
+    SAL_INFO("ucb.ucp.gio", "Create Content ('" << m_xIdentifier->getContentIdentifier() << "')");
     mpInfo = g_file_info_new();
     g_file_info_set_file_type(mpInfo, bIsFolder ? G_FILE_TYPE_DIRECTORY : G_FILE_TYPE_REGULAR);
 }
@@ -126,14 +123,13 @@ OUString Content::getParentURL()
 }
 
 void SAL_CALL Content::abort( sal_Int32 /*CommandId*/ )
-       throw( uno::RuntimeException, std::exception )
 {
     //TODO
     //stick a map from each CommandId to a new GCancellable and propagate
     //it throughout the g_file_* calls
 }
 
-OUString SAL_CALL Content::getContentType() throw( uno::RuntimeException, std::exception )
+OUString SAL_CALL Content::getContentType()
 {
     return isFolder(uno::Reference< ucb::XCommandEnvironment >())
         ? OUString( GIO_FOLDER_TYPE )
@@ -143,7 +139,7 @@ OUString SAL_CALL Content::getContentType() throw( uno::RuntimeException, std::e
 #define EXCEPT(aExcept) \
 do { \
     if (bThrow) throw aExcept;\
-    aRet = uno::makeAny( aExcept );\
+    aRet <<= aExcept;\
 } while(false)
 
 uno::Any convertToException(GError *pError, const uno::Reference< uno::XInterface >& rContext, bool bThrow)
@@ -155,7 +151,6 @@ uno::Any convertToException(GError *pError, const uno::Reference< uno::XInterfac
     g_error_free(pError);
 
     OUString sName;
-    OUString sHost;
 
     uno::Sequence< uno::Any > aArgs( 1 );
     aArgs[ 0 ] <<= sName;
@@ -263,7 +258,7 @@ uno::Any convertToException(GError *pError, const uno::Reference< uno::XInterfac
             break;
         case G_IO_ERROR_HOST_NOT_FOUND:
             { ucb::InteractiveNetworkResolveNameException aExcept(sMessage, rContext,
-                task::InteractionClassification_ERROR, sHost);
+                task::InteractionClassification_ERROR, OUString());
               EXCEPT(aExcept);}
             break;
         default:
@@ -281,7 +276,6 @@ uno::Any convertToException(GError *pError, const uno::Reference< uno::XInterfac
 }
 
 void convertToIOException(GError *pError, const uno::Reference< uno::XInterface >& rContext)
-    throw( io::IOException, uno::RuntimeException, std::exception )
 {
     try
     {
@@ -315,7 +309,7 @@ uno::Any Content::mapGIOError( GError *pError )
 uno::Any Content::getBadArgExcept()
 {
     return uno::makeAny( lang::IllegalArgumentException(
-        OUString("Wrong argument type!"),
+        "Wrong argument type!",
         static_cast< cppu::OWeakObject * >( this ), -1) );
 }
 
@@ -592,7 +586,7 @@ void Content::queryChildren( ContentRefList& rChildren )
             if ( ( nPos == -1 ) || ( nPos == ( aChildURL.getLength() - 1 ) ) )
             {
                 // No further slashes / only a final slash. It's a child!
-                rChildren.push_back( ::gio::Content::ContentRef (static_cast< ::gio::Content * >(xChild.get() ) ) );
+                rChildren.emplace_back(static_cast< ::gio::Content * >(xChild.get() ) );
             }
         }
         ++it;
@@ -673,7 +667,7 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
 
     beans::PropertyChangeEvent aEvent;
     aEvent.Source = static_cast< cppu::OWeakObject * >( this );
-    aEvent.Further = sal_False;
+    aEvent.Further = false;
     aEvent.PropertyHandle = -1;
 
     sal_Int32 nChanged = 0, nTitlePos = -1;
@@ -685,9 +679,7 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
     for ( sal_Int32 n = 0; n < nCount; ++n )
     {
         const beans::PropertyValue& rValue = pValues[ n ];
-#if OSL_DEBUG_LEVEL > 1
-        g_warning("Set prop '%s'", OUStringToOString(rValue.Name, RTL_TEXTENCODING_UTF8).getStr());
-#endif
+        SAL_INFO("ucb.ucp.gio", "Set prop '" << rValue.Name << "'");
         if ( rValue.Name == "ContentType" ||
              rValue.Name == "MediaType" ||
              rValue.Name == "IsDocument" ||
@@ -703,7 +695,7 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
             if (!( rValue.Value >>= aNewTitle ))
             {
                 aRet[ n ] <<= beans::IllegalTypeException
-                    ( OUString("Property value has wrong type!"),
+                    ( "Property value has wrong type!",
                       static_cast< cppu::OWeakObject * >( this ) );
                 continue;
             }
@@ -711,7 +703,7 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
             if ( aNewTitle.getLength() <= 0 )
             {
                 aRet[ n ] <<= lang::IllegalArgumentException
-                    ( OUString("Empty title not allowed!"),
+                    ( "Empty title not allowed!",
                       static_cast< cppu::OWeakObject * >( this ), -1 );
                 continue;
 
@@ -723,14 +715,12 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
 
             if (!newName || !oldName || strcmp(newName, oldName))
             {
-#if OSL_DEBUG_LEVEL > 1
-                g_warning ("Set new name to '%s'", newName);
-#endif
+                SAL_INFO("ucb.ucp.gio", "Set new name to '" << newName << "'");
 
                 aEvent.PropertyName = "Title";
                 if (oldName)
-                    aEvent.OldValue = uno::makeAny(OUString(oldName, strlen(oldName), RTL_TEXTENCODING_UTF8));
-                aEvent.NewValue = uno::makeAny(aNewTitle);
+                    aEvent.OldValue <<= OUString(oldName, strlen(oldName), RTL_TEXTENCODING_UTF8);
+                aEvent.NewValue <<= aNewTitle;
                 aChanges.getArray()[ nChanged ] = aEvent;
                 nTitlePos = nChanged++;
 
@@ -739,7 +729,7 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
         }
         else
         {
-            SAL_WARN("ucb.ucp.gio", "Unknown property " << rValue.Name << "\n");
+            SAL_WARN("ucb.ucp.gio", "Unknown property " << rValue.Name);
             aRet[ n ] <<= getReadOnlyException( static_cast< cppu::OWeakObject * >(this) );
             //TODO
         }
@@ -753,7 +743,7 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
             if ((bOk = doSetFileInfo(pNewInfo)))
             {
                 for (sal_Int32 i = 0; i < nChanged; ++i)
-                    aRet[ i ] <<= getBadArgExcept();
+                    aRet[ i ] = getBadArgExcept();
             }
         }
 
@@ -769,7 +759,7 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
                 if (!exchangeIdentity( xNewId ) )
                 {
                     aRet[ nTitlePos ] <<= uno::Exception
-                        ( OUString("Exchange failed!"),
+                        ( "Exchange failed!",
                           static_cast< cppu::OWeakObject * >( this ) );
                 }
             }
@@ -815,8 +805,8 @@ bool Content::doSetFileInfo(GFileInfo *pNewInfo)
 
 const int TRANSFER_BUFFER_SIZE = 65536;
 
-void Content::copyData( uno::Reference< io::XInputStream > xIn,
-    uno::Reference< io::XOutputStream > xOut )
+void Content::copyData( const uno::Reference< io::XInputStream >& xIn,
+    const uno::Reference< io::XOutputStream >& xOut )
 {
     uno::Sequence< sal_Int8 > theData( TRANSFER_BUFFER_SIZE );
 
@@ -828,8 +818,7 @@ void Content::copyData( uno::Reference< io::XInputStream > xIn,
     xOut->closeOutput();
 }
 
-bool Content::feedSink( uno::Reference< uno::XInterface > xSink,
-    const uno::Reference< ucb::XCommandEnvironment >& /*xEnv*/ )
+bool Content::feedSink( const uno::Reference< uno::XInterface >& xSink )
 {
     if ( !xSink.is() )
         return false;
@@ -860,7 +849,6 @@ bool Content::feedSink( uno::Reference< uno::XInterface > xSink,
 
 uno::Any Content::open(const ucb::OpenCommandArgument2 & rOpenCommand,
     const uno::Reference< ucb::XCommandEnvironment > & xEnv )
-    throw( uno::Exception )
 {
     bool bIsFolder = isFolder(xEnv);
 
@@ -905,15 +893,12 @@ uno::Any Content::open(const ucb::OpenCommandArgument2 & rOpenCommand,
                     xEnv );
         }
 
-        if ( !feedSink( rOpenCommand.Sink, xEnv ) )
+        if ( !feedSink( rOpenCommand.Sink ) )
         {
             // Note: rOpenCommand.Sink may contain an XStream
             //       implementation. Support for this type of
             //       sink is optional...
-#ifdef DEBUG
-            g_warning ("Failed to load data from '%s'",
-                OUStringToOString(m_xIdentifier->getContentIdentifier(), RTL_TEXTENCODING_UTF8).getStr());
-#endif
+            SAL_WARN("ucb.ucp.gio", "Failed to load data from '" << m_xIdentifier->getContentIdentifier() << "'");
 
             ucbhelper::cancelCommandExecution(
                 uno::makeAny (ucb::UnsupportedDataSinkException
@@ -923,7 +908,7 @@ uno::Any Content::open(const ucb::OpenCommandArgument2 & rOpenCommand,
         }
     }
     else
-        g_warning ("Open falling through ...");
+        SAL_INFO("ucb.ucp.gio", "Open falling through ...");
     return aRet;
 }
 
@@ -931,11 +916,8 @@ uno::Any SAL_CALL Content::execute(
         const ucb::Command& aCommand,
         sal_Int32 /*CommandId*/,
         const uno::Reference< ucb::XCommandEnvironment >& xEnv )
-    throw( uno::Exception,
-           ucb::CommandAbortedException,
-           uno::RuntimeException, std::exception )
 {
-    SAL_INFO("ucb.ucp.gio", "Content::execute " << aCommand.Name << "\n");
+    SAL_INFO("ucb.ucp.gio", "Content::execute " << aCommand.Name);
     uno::Any aRet;
 
     if ( aCommand.Name == "getPropertyValues" )
@@ -1006,7 +988,7 @@ uno::Any SAL_CALL Content::execute(
     }
     else
     {
-        SAL_WARN("ucb.ucp.gio", "Unknown command " << aCommand.Name << "\n");
+        SAL_WARN("ucb.ucp.gio", "Unknown command " << aCommand.Name);
 
         ucbhelper::cancelCommandExecution
             ( uno::makeAny( ucb::UnsupportedCommandException
@@ -1019,7 +1001,6 @@ uno::Any SAL_CALL Content::execute(
 }
 
 void Content::destroy( bool bDeletePhysical )
-    throw( uno::Exception, std::exception )
 {
     uno::Reference< ucb::XContent > xThis = this;
 
@@ -1040,7 +1021,6 @@ void Content::destroy( bool bDeletePhysical )
 
 void Content::insert(const uno::Reference< io::XInputStream > &xInputStream,
     bool bReplaceExisting, const uno::Reference< ucb::XCommandEnvironment > &xEnv )
-        throw( uno::Exception )
 {
     GError *pError = nullptr;
     GFileInfo *pInfo = getGFileInfo(xEnv);
@@ -1049,9 +1029,7 @@ void Content::insert(const uno::Reference< io::XInputStream > &xInputStream,
          g_file_info_has_attribute(pInfo, G_FILE_ATTRIBUTE_STANDARD_TYPE) &&
          g_file_info_get_file_type(pInfo) == G_FILE_TYPE_DIRECTORY )
     {
-#if OSL_DEBUG_LEVEL > 1
-        g_warning ("Make directory");
-#endif
+        SAL_INFO("ucb.ucp.gio", "Make directory");
         if( !g_file_make_directory( getGFile(), nullptr, &pError))
             ucbhelper::cancelCommandExecution(mapGIOError(pError), xEnv);
         return;
@@ -1091,7 +1069,6 @@ const GFileCopyFlags DEFAULT_COPYDATA_FLAGS =
     static_cast<GFileCopyFlags>(G_FILE_COPY_OVERWRITE|G_FILE_COPY_TARGET_DEFAULT_PERMS);
 
 void Content::transfer( const ucb::TransferInfo& aTransferInfo, const uno::Reference< ucb::XCommandEnvironment >& xEnv )
-    throw( uno::Exception, std::exception )
 {
     OUString sDest = m_xIdentifier->getContentIdentifier();
     if (!sDest.endsWith("/")) {
@@ -1119,7 +1096,6 @@ void Content::transfer( const ucb::TransferInfo& aTransferInfo, const uno::Refer
 
 uno::Sequence< ucb::ContentInfo > Content::queryCreatableContentsInfo(
     const uno::Reference< ucb::XCommandEnvironment >& xEnv)
-            throw( uno::RuntimeException )
 {
     if ( isFolder( xEnv ) )
     {
@@ -1128,7 +1104,7 @@ uno::Sequence< ucb::ContentInfo > Content::queryCreatableContentsInfo(
         // Minimum set of props we really need
         uno::Sequence< beans::Property > props( 1 );
         props[0] = beans::Property(
-            OUString("Title"),
+            "Title",
             -1,
             cppu::UnoType<OUString>::get(),
             beans::PropertyAttribute::MAYBEVOID | beans::PropertyAttribute::BOUND );
@@ -1153,14 +1129,12 @@ uno::Sequence< ucb::ContentInfo > Content::queryCreatableContentsInfo(
 }
 
 uno::Sequence< ucb::ContentInfo > SAL_CALL Content::queryCreatableContentsInfo()
-            throw( uno::RuntimeException, std::exception )
 {
     return queryCreatableContentsInfo( uno::Reference< ucb::XCommandEnvironment >() );
 }
 
 uno::Reference< ucb::XContent >
     SAL_CALL Content::createNewContent( const ucb::ContentInfo& Info )
-        throw( uno::RuntimeException, std::exception )
 {
     bool create_document;
     const char *name;
@@ -1171,17 +1145,11 @@ uno::Reference< ucb::XContent >
         create_document = false;
     else
     {
-#ifdef DEBUG
-        g_warning( "Failed to create new content '%s'", OUStringToOString(Info.Type,
-            RTL_TEXTENCODING_UTF8).getStr() );
-#endif
+        SAL_WARN("ucb.ucp.gio", "Failed to create new content '" << Info.Type << "'");
         return uno::Reference< ucb::XContent >();
     }
 
-#if OSL_DEBUG_LEVEL > 1
-    g_warning( "createNewContent (%d)", (int) create_document );
-#endif
-
+    SAL_INFO("ucb.ucp.gio", "createNewContent (" << create_document << ")");
     OUString aURL = m_xIdentifier->getContentIdentifier();
 
     if ( ( aURL.lastIndexOf( '/' ) + 1 ) != aURL.getLength() )
@@ -1202,11 +1170,10 @@ uno::Reference< ucb::XContent >
 }
 
 uno::Sequence< uno::Type > SAL_CALL Content::getTypes()
-    throw( uno::RuntimeException, std::exception )
 {
     if ( isFolder( uno::Reference< ucb::XCommandEnvironment >() ) )
     {
-        static cppu::OTypeCollection aFolderCollection
+        static cppu::OTypeCollection s_aFolderCollection
             (CPPU_TYPE_REF( lang::XTypeProvider ),
              CPPU_TYPE_REF( lang::XServiceInfo ),
              CPPU_TYPE_REF( lang::XComponent ),
@@ -1218,11 +1185,11 @@ uno::Sequence< uno::Type > SAL_CALL Content::getTypes()
              CPPU_TYPE_REF( beans::XPropertySetInfoChangeNotifier ),
              CPPU_TYPE_REF( container::XChild ),
              CPPU_TYPE_REF( ucb::XContentCreator ) );
-        return aFolderCollection.getTypes();
+        return s_aFolderCollection.getTypes();
     }
     else
     {
-        static cppu::OTypeCollection aFileCollection
+        static cppu::OTypeCollection s_aFileCollection
             (CPPU_TYPE_REF( lang::XTypeProvider ),
              CPPU_TYPE_REF( lang::XServiceInfo ),
              CPPU_TYPE_REF( lang::XComponent ),
@@ -1234,7 +1201,7 @@ uno::Sequence< uno::Type > SAL_CALL Content::getTypes()
              CPPU_TYPE_REF( beans::XPropertySetInfoChangeNotifier ),
              CPPU_TYPE_REF( container::XChild ) );
 
-        return aFileCollection.getTypes();
+        return s_aFileCollection.getTypes();
     }
 }
 
@@ -1243,45 +1210,45 @@ uno::Sequence< beans::Property > Content::getProperties(
 {
     static const beans::Property aGenericProperties[] =
     {
-        beans::Property( OUString(  "IsDocument"  ),
+        beans::Property( "IsDocument",
             -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "IsFolder"  ),
+        beans::Property( "IsFolder",
             -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "Title"  ),
+        beans::Property( "Title",
             -1, cppu::UnoType<OUString>::get(),
             beans::PropertyAttribute::BOUND ),
-        beans::Property( OUString(  "IsReadOnly"  ),
+        beans::Property( "IsReadOnly",
             -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "DateCreated"  ),
+        beans::Property( "DateCreated",
             -1, cppu::UnoType<util::DateTime>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "DateModified"  ),
+        beans::Property( "DateModified",
             -1, cppu::UnoType<util::DateTime>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "Size"  ),
+        beans::Property( "Size",
             -1, cppu::UnoType<sal_Int64>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "IsVolume"  ),
+        beans::Property( "IsVolume",
             1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "IsCompactDisc"  ),
+        beans::Property( "IsCompactDisc",
             -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "IsRemoveable"  ),
+        beans::Property( "IsRemoveable",
             -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "IsHidden"  ),
+        beans::Property( "IsHidden",
             -1, cppu::UnoType<bool>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY ),
-        beans::Property( OUString(  "CreatableContentsInfo"  ),
+        beans::Property( "CreatableContentsInfo",
             -1, cppu::UnoType<uno::Sequence< ucb::ContentInfo >>::get(),
             beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY )
     };
 
-    const int nProps = sizeof (aGenericProperties) / sizeof (aGenericProperties[0]);
+    const int nProps = SAL_N_ELEMENTS(aGenericProperties);
     return uno::Sequence< beans::Property > ( aGenericProperties, nProps );
 }
 
@@ -1291,39 +1258,39 @@ uno::Sequence< ucb::CommandInfo > Content::getCommands( const uno::Reference< uc
     {
         // Required commands
         ucb::CommandInfo
-        ( OUString(  "getCommandInfo"  ),
+        ( "getCommandInfo",
           -1, cppu::UnoType<void>::get() ),
         ucb::CommandInfo
-        ( OUString(  "getPropertySetInfo"  ),
+        ( "getPropertySetInfo",
           -1, cppu::UnoType<void>::get() ),
         ucb::CommandInfo
-        ( OUString(  "getPropertyValues"  ),
+        ( "getPropertyValues",
           -1, cppu::UnoType<uno::Sequence< beans::Property >>::get() ),
         ucb::CommandInfo
-        ( OUString(  "setPropertyValues"  ),
+        ( "setPropertyValues",
           -1, cppu::UnoType<uno::Sequence< beans::PropertyValue >>::get() ),
 
         // Optional standard commands
         ucb::CommandInfo
-        ( OUString(  "delete"  ),
+        ( "delete",
           -1, cppu::UnoType<bool>::get() ),
         ucb::CommandInfo
-        ( OUString(  "insert"  ),
+        ( "insert",
           -1, cppu::UnoType<ucb::InsertCommandArgument>::get() ),
         ucb::CommandInfo
-        ( OUString(  "open"  ),
+        ( "open",
           -1, cppu::UnoType<ucb::OpenCommandArgument2>::get() ),
 
         // Folder Only, omitted if not a folder
         ucb::CommandInfo
-        ( OUString(  "transfer"  ),
+        ( "transfer",
           -1, cppu::UnoType<ucb::TransferInfo>::get() ),
         ucb::CommandInfo
-        ( OUString(  "createNewContent"  ),
+        ( "createNewContent",
           -1, cppu::UnoType<ucb::ContentInfo>::get() )
     };
 
-    const int nProps = sizeof (aCommandInfoTable) / sizeof (aCommandInfoTable[0]);
+    const int nProps = SAL_N_ELEMENTS(aCommandInfoTable);
     return uno::Sequence< ucb::CommandInfo >(aCommandInfoTable, isFolder(xEnv) ? nProps : nProps - 2);
 }
 
@@ -1339,19 +1306,18 @@ void SAL_CALL Content::release() throw()
     ContentImplHelper::release();
 }
 
-uno::Any SAL_CALL Content::queryInterface( const uno::Type & rType ) throw ( uno::RuntimeException, std::exception )
+uno::Any SAL_CALL Content::queryInterface( const uno::Type & rType )
 {
     uno::Any aRet = cppu::queryInterface( rType, static_cast< ucb::XContentCreator * >( this ) );
     return aRet.hasValue() ? aRet : ContentImplHelper::queryInterface(rType);
 }
 
-OUString SAL_CALL Content::getImplementationName() throw( uno::RuntimeException, std::exception )
+OUString SAL_CALL Content::getImplementationName()
 {
        return OUString("com.sun.star.comp.GIOContent");
 }
 
 uno::Sequence< OUString > SAL_CALL Content::getSupportedServiceNames()
-       throw( uno::RuntimeException, std::exception )
 {
        uno::Sequence<OUString> aSNS { "com.sun.star.ucb.GIOContent" };
        return aSNS;
