@@ -32,6 +32,7 @@
 
  *************************************************************************/
 
+#include <memory>
 #include <set>
 #include <com/sun/star/beans/Property.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
@@ -52,6 +53,7 @@
 #include "webdavprovider.hxx"
 #include "DAVSession.hxx"
 #include "ContentProperties.hxx"
+#include "PropfindCache.hxx"
 
 using namespace com::sun::star;
 using namespace webdav_ucp;
@@ -68,7 +70,7 @@ bool ContentProvider::getProperty(
         osl::MutexGuard aGuard( m_aMutex );
         if ( !m_pProps )
         {
-            m_pProps = new PropertyMap;
+            m_pProps.reset( new PropertyMap );
 
 
             // Fill map of known properties...
@@ -77,7 +79,7 @@ bool ContentProvider::getProperty(
             // Mandatory UCB properties.
             m_pProps->insert(
                 beans::Property(
-                    OUString( "ContentType" ),
+                    "ContentType",
                     -1,
                     cppu::UnoType<OUString>::get(),
                     beans::PropertyAttribute::BOUND
@@ -85,7 +87,7 @@ bool ContentProvider::getProperty(
 
             m_pProps->insert(
                 beans::Property(
-                    OUString( "IsDocument" ),
+                    "IsDocument",
                     -1,
                     cppu::UnoType<bool>::get(),
                     beans::PropertyAttribute::BOUND
@@ -93,7 +95,7 @@ bool ContentProvider::getProperty(
 
             m_pProps->insert(
                 beans::Property(
-                    OUString( "IsFolder" ),
+                    "IsFolder",
                     -1,
                     cppu::UnoType<bool>::get(),
                     beans::PropertyAttribute::BOUND
@@ -101,7 +103,7 @@ bool ContentProvider::getProperty(
 
             m_pProps->insert(
                 beans::Property(
-                    OUString( "Title" ),
+                    "Title",
                     -1,
                     cppu::UnoType<OUString>::get(),
                     beans::PropertyAttribute::BOUND ) );
@@ -110,7 +112,7 @@ bool ContentProvider::getProperty(
 
             m_pProps->insert(
                 beans::Property(
-                    OUString( "DateCreated" ),
+                    "DateCreated",
                     -1,
                     cppu::UnoType<util::DateTime>::get(),
                     beans::PropertyAttribute::BOUND
@@ -118,7 +120,7 @@ bool ContentProvider::getProperty(
 
             m_pProps->insert(
                 beans::Property(
-                    OUString( "DateModified" ),
+                    "DateModified",
                     -1,
                     cppu::UnoType<util::DateTime>::get(),
                     beans::PropertyAttribute::BOUND
@@ -126,7 +128,7 @@ bool ContentProvider::getProperty(
 
             m_pProps->insert(
                 beans::Property(
-                    OUString( "MediaType" ),
+                    "MediaType",
                     -1,
                     cppu::UnoType<OUString>::get(),
                     beans::PropertyAttribute::BOUND
@@ -134,7 +136,7 @@ bool ContentProvider::getProperty(
 
             m_pProps->insert(
                 beans::Property(
-                    OUString( "Size" ),
+                    "Size",
                     -1,
                     cppu::UnoType<sal_Int64>::get(),
                     beans::PropertyAttribute::BOUND
@@ -142,7 +144,7 @@ bool ContentProvider::getProperty(
 
             m_pProps->insert(
                 beans::Property(
-                    OUString( "BaseURI" ),
+                    "BaseURI",
                     -1,
                     cppu::UnoType<OUString>::get(),
                     beans::PropertyAttribute::BOUND
@@ -150,8 +152,7 @@ bool ContentProvider::getProperty(
 
             m_pProps->insert(
                 beans::Property(
-                    OUString(
-                        "CreatableContentsInfo" ),
+                    "CreatableContentsInfo",
                     -1,
                     cppu::UnoType<
                         uno::Sequence< ucb::ContentInfo >>::get(),
@@ -281,6 +282,14 @@ bool ContentProvider::getProperty(
 }
 
 
+static PropertyNamesCache aStaticPropertyNamesCache;
+
+// static
+void Content::removeCachedPropertyNames( const OUString & rURL )
+{
+    aStaticPropertyNamesCache.removeCachedPropertyNames( rURL );
+}
+
 // Content implementation.
 
 
@@ -312,18 +321,41 @@ uno::Sequence< beans::Property > Content::getProperties(
     if ( !bTransient )
     {
         // Obtain all properties supported for this resource from server.
-        try
+        DAVOptions aDAVOptions;
+        getResourceOptions( xEnv, aDAVOptions, xResAccess );
+        // only Class 1 is needed for PROPFIND
+        if ( aDAVOptions.isClass1() )
         {
-            std::vector< DAVResourceInfo > props;
-            xResAccess->PROPFIND( DAVZERO, props, xEnv );
+            try
+            {
+                std::vector< DAVResourceInfo > props;
+                OUString aTheURL( xResAccess->getURL() );
+                PropertyNames aPropsNames( aTheURL );
 
-            // Note: vector always contains exactly one resource info, because
-            //       we used a depth of DAVZERO for PROPFIND.
-            aPropSet.insert( (*props.begin()).properties.begin(),
-                             (*props.begin()).properties.end() );
-        }
-        catch ( DAVException const & )
-        {
+                if( !aStaticPropertyNamesCache.getCachedPropertyNames( aTheURL, aPropsNames ) )
+                {
+
+                    xResAccess->PROPFIND( DAVZERO, props, xEnv );
+                    aPropsNames.setPropertiesNames( props );
+
+                    aStaticPropertyNamesCache.addCachePropertyNames( aPropsNames );
+                }
+                else
+                {
+                    props = aPropsNames.getPropertiesNames();
+                }
+
+                // Note: vector should contain exactly one resource info, because
+                //       we used a depth of DAVZERO for PROPFIND.
+                if (props.size() == 1)
+                {
+                    aPropSet.insert( (*props.begin()).properties.begin(),
+                                     (*props.begin()).properties.end() );
+                }
+            }
+            catch ( DAVException const & )
+            {
+            }
         }
     }
 
@@ -515,22 +547,22 @@ uno::Sequence< ucb::CommandInfo > Content::getCommands(
 
     aCmdInfo[ 0 ] =
             ucb::CommandInfo(
-                OUString( "getCommandInfo" ),
+                "getCommandInfo",
                 -1,
                 cppu::UnoType<void>::get() );
     aCmdInfo[ 1 ] =
             ucb::CommandInfo(
-                OUString( "getPropertySetInfo" ),
+                "getPropertySetInfo",
                 -1,
                 cppu::UnoType<void>::get() );
     aCmdInfo[ 2 ] =
             ucb::CommandInfo(
-                OUString( "getPropertyValues" ),
+                "getPropertyValues",
                 -1,
                 cppu::UnoType<uno::Sequence< beans::Property >>::get() );
     aCmdInfo[ 3 ] =
             ucb::CommandInfo(
-                OUString( "setPropertyValues" ),
+                "setPropertyValues",
                 -1,
                 cppu::UnoType<uno::Sequence< beans::PropertyValue >>::get() );
 
@@ -540,17 +572,17 @@ uno::Sequence< ucb::CommandInfo > Content::getCommands(
 
     aCmdInfo[ 4 ] =
             ucb::CommandInfo(
-                OUString( "delete" ),
+                "delete",
                 -1,
                 cppu::UnoType<bool>::get() );
     aCmdInfo[ 5 ] =
             ucb::CommandInfo(
-                OUString( "insert" ),
+                "insert",
                 -1,
                 cppu::UnoType<ucb::InsertCommandArgument>::get() );
     aCmdInfo[ 6 ] =
             ucb::CommandInfo(
-                OUString( "open" ),
+                "open",
                 -1,
                 cppu::UnoType<ucb::OpenCommandArgument2>::get() );
 
@@ -560,17 +592,17 @@ uno::Sequence< ucb::CommandInfo > Content::getCommands(
 
     aCmdInfo[ 7 ] =
             ucb::CommandInfo(
-                OUString( "post" ),
+                "post",
                 -1,
                 cppu::UnoType<ucb::PostCommandArgument2>::get() );
     aCmdInfo[ 8 ] =
             ucb::CommandInfo(
-                OUString( "addProperty" ),
+                "addProperty",
                 -1,
                 cppu::UnoType<ucb::PropertyCommandArgument>::get() );
     aCmdInfo[ 9 ] =
             ucb::CommandInfo(
-                OUString( "removeProperty" ),
+                "removeProperty",
                 -1,
                 cppu::UnoType<rtl::OUString>::get() );
 
@@ -603,14 +635,13 @@ uno::Sequence< ucb::CommandInfo > Content::getCommands(
 
         aCmdInfo[ nPos ] =
             ucb::CommandInfo(
-                OUString( "transfer" ),
+                "transfer",
                 -1,
                 cppu::UnoType<ucb::TransferInfo>::get() );
         nPos++;
         aCmdInfo[ nPos ] =
             ucb::CommandInfo(
-                OUString(
-                    "createNewContent" ),
+                "createNewContent",
                 -1,
                 cppu::UnoType<ucb::ContentInfo>::get() );
         nPos++;
@@ -624,13 +655,13 @@ uno::Sequence< ucb::CommandInfo > Content::getCommands(
     {
         aCmdInfo[ nPos ] =
             ucb::CommandInfo(
-                OUString( "lock" ),
+                "lock",
                 -1,
                 cppu::UnoType<void>::get() );
         nPos++;
         aCmdInfo[ nPos ] =
             ucb::CommandInfo(
-                OUString( "unlock" ),
+                "unlock",
                 -1,
                 cppu::UnoType<void>::get() );
         nPos++;
