@@ -17,89 +17,47 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
 
-/**************************************************************************
-                                TODO
- **************************************************************************
-
- *************************************************************************/
-
-#include <boost/unordered_map.hpp>
+#include <com/sun/star/beans/IllegalTypeException.hpp>
+#include <com/sun/star/beans/PropertyExistException.hpp>
 #include <com/sun/star/beans/XPropertyAccess.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/container/XNamed.hpp>
 #include <com/sun/star/ucb/Store.hpp>
-#include <com/sun/star/ucb/XPropertySetRegistryFactory.hpp>
 #include <com/sun/star/ucb/XPropertySetRegistry.hpp>
-
-#include "osl/diagnose.h"
-#include "osl/mutex.hxx"
-#include "cppuhelper/weakref.hxx"
+#include <com/sun/star/ucb/XPropertySetRegistryFactory.hpp>
+#include <cppuhelper/supportsservice.hxx>
+#include <ucbhelper/contenthelper.hxx>
 #include <ucbhelper/contentidentifier.hxx>
 #include <ucbhelper/providerhelper.hxx>
-#include <ucbhelper/contenthelper.hxx>
+
+#include <osl/diagnose.h>
+#include <osl/mutex.hxx>
+#include <cppuhelper/weakref.hxx>
+
+#include <unordered_map>
 
 using namespace com::sun::star;
 
 namespace ucbhelper_impl
 {
 
-//=========================================================================
-//
-// Contents.
-//
-//=========================================================================
-
-struct equalString
-{
-    bool operator()(
-        const OUString& rKey11, const OUString& rKey22 ) const
-      {
-          return !!( rKey11 == rKey22 );
-      }
-};
-
-struct hashString
-{
-    size_t operator()( const OUString & rName ) const
-    {
-        return rName.hashCode();
-    }
-};
-
-typedef boost::unordered_map
+typedef std::unordered_map
 <
     OUString,
-    uno::WeakReference< ucb::XContent >,
-    hashString,
-    equalString
+    uno::WeakReference< ucb::XContent >
 >
 Contents;
 
-//=========================================================================
-//
-// struct ContentProviderImplHelper_Impl.
-//
-//=========================================================================
-
 struct ContentProviderImplHelper_Impl
 {
-    uno::Reference< com::sun::star::ucb::XPropertySetRegistry >
-        m_xPropertySetRegistry;
-    Contents
-        m_aContents;
+    uno::Reference< css::ucb::XPropertySetRegistry >  m_xPropertySetRegistry;
+    Contents                                          m_aContents;
 };
 
 } // namespace ucbhelper_impl
 
-//=========================================================================
-//=========================================================================
-//
-// ContentProviderImplHelper Implementation.
-//
-//=========================================================================
-//=========================================================================
-
 namespace ucbhelper {
 
 ContentProviderImplHelper::ContentProviderImplHelper(
@@ -109,68 +67,50 @@ ContentProviderImplHelper::ContentProviderImplHelper(
 {
 }
 
-//=========================================================================
 // virtual
 ContentProviderImplHelper::~ContentProviderImplHelper()
 {
-    delete m_pImpl;
 }
 
-//=========================================================================
-//
-// XInterface methods.
-//
-//=========================================================================
+// XInterface
+void SAL_CALL ContentProviderImplHelper::acquire()
+    throw()
+{
+    OWeakObject::acquire();
+}
 
-XINTERFACE_IMPL_3( ContentProviderImplHelper,
-                   lang::XTypeProvider,
-                   lang::XServiceInfo,
-                   com::sun::star::ucb::XContentProvider );
+void SAL_CALL ContentProviderImplHelper::release()
+    throw()
+{
+    OWeakObject::release();
+}
 
-//=========================================================================
-//
-// XTypeProvider methods.
-//
-//=========================================================================
+css::uno::Any SAL_CALL ContentProviderImplHelper::queryInterface( const css::uno::Type & rType )
+{
+    css::uno::Any aRet = cppu::queryInterface( rType,
+                                               static_cast< lang::XTypeProvider* >(this),
+                                               static_cast< lang::XServiceInfo* >(this),
+                                               static_cast< css::ucb::XContentProvider* >(this)
+                                               );
+    return aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType );
+}
 
 XTYPEPROVIDER_IMPL_3( ContentProviderImplHelper,
                          lang::XTypeProvider,
                          lang::XServiceInfo,
-                         com::sun::star::ucb::XContentProvider );
-
-//=========================================================================
-//
-// XServiceInfo methods.
-//
-//=========================================================================
+                         css::ucb::XContentProvider );
 
 // virtual
 sal_Bool SAL_CALL ContentProviderImplHelper::supportsService(
                                             const OUString& ServiceName )
-    throw( uno::RuntimeException )
 {
-    uno::Sequence< OUString > aSNL = getSupportedServiceNames();
-    const OUString* pArray = aSNL.getConstArray();
-    for ( sal_Int32 i = 0; i < aSNL.getLength(); i++ )
-    {
-        if ( pArray[ i ] == ServiceName )
-            return sal_True;
-    }
-
-    return sal_False;
+    return cppu::supportsService(this, ServiceName);
 }
 
-//=========================================================================
-//
-// XContentProvider methods.
-//
-//=========================================================================
-
 // virtual
 sal_Int32 SAL_CALL ContentProviderImplHelper::compareContentIds(
-        const uno::Reference< com::sun::star::ucb::XContentIdentifier >& Id1,
-        const uno::Reference< com::sun::star::ucb::XContentIdentifier >& Id2 )
-    throw( uno::RuntimeException )
+        const uno::Reference< css::ucb::XContentIdentifier >& Id1,
+        const uno::Reference< css::ucb::XContentIdentifier >& Id2 )
 {
     // Simply do a string compare.
 
@@ -180,12 +120,6 @@ sal_Int32 SAL_CALL ContentProviderImplHelper::compareContentIds(
     return aURL1.compareTo( aURL2 );
 }
 
-//=========================================================================
-//
-// Non-interface methods
-//
-//=========================================================================
-
 void ContentProviderImplHelper::cleanupRegisteredContents()
 {
     osl::MutexGuard aGuard( m_aMutex );
@@ -208,8 +142,6 @@ void ContentProviderImplHelper::cleanupRegisteredContents()
     }
 }
 
-//=========================================================================
-
 void ContentProviderImplHelper::removeContent( ContentImplHelper* pContent )
 {
     osl::MutexGuard aGuard( m_aMutex );
@@ -225,16 +157,13 @@ void ContentProviderImplHelper::removeContent( ContentImplHelper* pContent )
         m_pImpl->m_aContents.erase( it );
 }
 
-//=========================================================================
 rtl::Reference< ContentImplHelper >
 ContentProviderImplHelper::queryExistingContent(
-    const uno::Reference< com::sun::star::ucb::XContentIdentifier >&
-        Identifier )
+    const uno::Reference< css::ucb::XContentIdentifier >& Identifier )
 {
     return queryExistingContent( Identifier->getContentIdentifier() );
 }
 
-//=========================================================================
 rtl::Reference< ContentImplHelper >
 ContentProviderImplHelper::queryExistingContent( const OUString& rURL )
 {
@@ -258,7 +187,6 @@ ContentProviderImplHelper::queryExistingContent( const OUString& rURL )
     return rtl::Reference< ContentImplHelper >();
 }
 
-//=========================================================================
 void ContentProviderImplHelper::queryExistingContents(
         ContentRefList& rContents )
 {
@@ -276,15 +204,13 @@ void ContentProviderImplHelper::queryExistingContents(
         uno::Reference< ucb::XContent > xContent( (*it).second );
         if ( xContent.is() )
         {
-            rContents.push_back(
-                rtl::Reference< ContentImplHelper >(
-                    static_cast< ContentImplHelper * >( xContent.get() ) ) );
+            rContents.emplace_back(
+                    static_cast< ContentImplHelper * >( xContent.get() ) );
         }
         ++it;
     }
 }
 
-//=========================================================================
 void ContentProviderImplHelper::registerNewContent(
     const uno::Reference< ucb::XContent > & xContent )
 {
@@ -303,8 +229,7 @@ void ContentProviderImplHelper::registerNewContent(
     }
 }
 
-//=========================================================================
-uno::Reference< com::sun::star::ucb::XPropertySetRegistry >
+uno::Reference< css::ucb::XPropertySetRegistry >
 ContentProviderImplHelper::getAdditionalPropertySetRegistry()
 {
     // Get propertyset registry.
@@ -313,8 +238,8 @@ ContentProviderImplHelper::getAdditionalPropertySetRegistry()
 
     if ( !m_pImpl->m_xPropertySetRegistry.is() )
     {
-        uno::Reference< com::sun::star::ucb::XPropertySetRegistryFactory >
-            xRegFac = com::sun::star::ucb::Store::create( m_xContext );
+        uno::Reference< css::ucb::XPropertySetRegistryFactory >
+            xRegFac = css::ucb::Store::create( m_xContext );
 
         // Open/create a registry.
         m_pImpl->m_xPropertySetRegistry
@@ -328,11 +253,9 @@ ContentProviderImplHelper::getAdditionalPropertySetRegistry()
     return m_pImpl->m_xPropertySetRegistry;
 }
 
-
-//=========================================================================
-uno::Reference< com::sun::star::ucb::XPersistentPropertySet >
+uno::Reference< css::ucb::XPersistentPropertySet >
 ContentProviderImplHelper::getAdditionalPropertySet(
-    const OUString& rKey, sal_Bool bCreate )
+    const OUString& rKey, bool bCreate )
 {
     // Get propertyset registry.
     getAdditionalPropertySetRegistry();
@@ -340,22 +263,20 @@ ContentProviderImplHelper::getAdditionalPropertySet(
     if ( m_pImpl->m_xPropertySetRegistry.is() )
     {
         // Open/create persistent property set.
-        return uno::Reference< com::sun::star::ucb::XPersistentPropertySet >(
-            m_pImpl->m_xPropertySetRegistry->openPropertySet(
-                rKey, bCreate ) );
+        return m_pImpl->m_xPropertySetRegistry->openPropertySet(
+                rKey, bCreate );
     }
 
-    return uno::Reference< com::sun::star::ucb::XPersistentPropertySet >();
+    return uno::Reference< css::ucb::XPersistentPropertySet >();
 }
 
-//=========================================================================
-sal_Bool ContentProviderImplHelper::renameAdditionalPropertySet(
+bool ContentProviderImplHelper::renameAdditionalPropertySet(
     const OUString& rOldKey,
     const OUString& rNewKey,
-    sal_Bool bRecursive )
+    bool bRecursive )
 {
     if ( rOldKey == rNewKey )
-        return sal_True;
+        return true;
 
     osl::MutexGuard aGuard( m_aMutex );
 
@@ -379,7 +300,7 @@ sal_Bool ContentProviderImplHelper::renameAdditionalPropertySet(
                     OUString aOldKeyWithoutSlash;
                     if ( !aOldKeyWithSlash.endsWith("/") )
                     {
-                        aOldKeyWithSlash += OUString( '/' );
+                        aOldKeyWithSlash += "/";
                         aOldKeyWithoutSlash = rOldKey;
                     }
                     else if ( !rOldKey.isEmpty() )
@@ -390,32 +311,30 @@ sal_Bool ContentProviderImplHelper::renameAdditionalPropertySet(
                     for ( sal_Int32 n = 0; n < nCount; ++n )
                     {
                         const OUString& rKey = pKeys[ n ];
-                        if ( rKey.compareTo(
-                                 aOldKeyWithSlash,
-                                 aOldKeyWithSlash.getLength() ) == 0
-                             || rKey.equals( aOldKeyWithoutSlash ) )
+                        if ( rKey.startsWith( aOldKeyWithSlash )
+                             || rKey == aOldKeyWithoutSlash )
                         {
                             OUString aNewKey
                                 = rKey.replaceAt(
                                     0, rOldKey.getLength(), rNewKey );
                             if ( !renameAdditionalPropertySet(
-                                    rKey, aNewKey, sal_False ) )
-                                return sal_False;
+                                    rKey, aNewKey, false ) )
+                                return false;
                         }
                     }
                 }
             }
             else
-                return sal_False;
+                return false;
         }
         else
-            return sal_False;
+            return false;
     }
     else
     {
         // Get old property set, if exists.
-        uno::Reference< com::sun::star::ucb::XPersistentPropertySet > xOldSet
-            = getAdditionalPropertySet( rOldKey, sal_False );
+        uno::Reference< css::ucb::XPersistentPropertySet > xOldSet
+            = getAdditionalPropertySet( rOldKey, false );
         if ( xOldSet.is() )
         {
             // Rename property set.
@@ -427,20 +346,19 @@ sal_Bool ContentProviderImplHelper::renameAdditionalPropertySet(
                 xNamed->setName( rNewKey );
             }
             else
-                return sal_False;
+                return false;
         }
     }
-    return sal_True;
+    return true;
 }
 
-//=========================================================================
-sal_Bool ContentProviderImplHelper::copyAdditionalPropertySet(
+bool ContentProviderImplHelper::copyAdditionalPropertySet(
     const OUString& rSourceKey,
     const OUString& rTargetKey,
-    sal_Bool bRecursive )
+    bool bRecursive )
 {
     if ( rSourceKey == rTargetKey )
-        return sal_True;
+        return true;
 
     osl::MutexGuard aGuard( m_aMutex );
 
@@ -464,7 +382,7 @@ sal_Bool ContentProviderImplHelper::copyAdditionalPropertySet(
                     OUString aSrcKeyWithoutSlash;
                     if ( !aSrcKeyWithSlash.endsWith("/") )
                     {
-                        aSrcKeyWithSlash += OUString( '/' );
+                        aSrcKeyWithSlash += "/";
                         aSrcKeyWithoutSlash = rSourceKey;
                     }
                     else if ( !rSourceKey.isEmpty() )
@@ -475,44 +393,42 @@ sal_Bool ContentProviderImplHelper::copyAdditionalPropertySet(
                     for ( sal_Int32 n = 0; n < nCount; ++n )
                     {
                         const OUString& rKey = pKeys[ n ];
-                        if ( rKey.compareTo(
-                                 aSrcKeyWithSlash,
-                                 aSrcKeyWithSlash.getLength() ) == 0
-                             || rKey.equals( aSrcKeyWithoutSlash ) )
+                        if ( rKey.startsWith(aSrcKeyWithSlash )
+                             || rKey == aSrcKeyWithoutSlash )
                         {
                             OUString aNewKey
                                 = rKey.replaceAt(
                                     0, rSourceKey.getLength(), rTargetKey );
                             if ( !copyAdditionalPropertySet(
-                                    rKey, aNewKey, sal_False ) )
-                                return sal_False;
+                                    rKey, aNewKey, false ) )
+                                return false;
                         }
                     }
                 }
             }
             else
-                return sal_False;
+                return false;
         }
         else
-            return sal_False;
+            return false;
     }
     else
     {
         // Get old property set, if exists.
-        uno::Reference< com::sun::star::ucb::XPersistentPropertySet >
-            xOldPropSet = getAdditionalPropertySet( rSourceKey, sal_False );
+        uno::Reference< css::ucb::XPersistentPropertySet >
+            xOldPropSet = getAdditionalPropertySet( rSourceKey, false );
         if ( !xOldPropSet.is() )
-            return sal_False;
+            return false;
 
         uno::Reference< beans::XPropertySetInfo > xPropSetInfo
             = xOldPropSet->getPropertySetInfo();
         if ( !xPropSetInfo.is() )
-            return sal_False;
+            return false;
 
         uno::Reference< beans::XPropertyAccess > xOldPropAccess(
             xOldPropSet, uno::UNO_QUERY );
         if ( !xOldPropAccess.is() )
-            return sal_False;
+            return false;
 
         // Obtain all values from old set.
         uno::Sequence< beans::PropertyValue > aValues
@@ -525,21 +441,21 @@ sal_Bool ContentProviderImplHelper::copyAdditionalPropertySet(
         if ( nCount )
         {
             // Fail, if property set with new key already exists.
-            uno::Reference< com::sun::star::ucb::XPersistentPropertySet >
+            uno::Reference< css::ucb::XPersistentPropertySet >
                 xNewPropSet
-                    = getAdditionalPropertySet( rTargetKey, sal_False );
+                    = getAdditionalPropertySet( rTargetKey, false );
             if ( xNewPropSet.is() )
-                return sal_False;
+                return false;
 
             // Create new, empty set.
-            xNewPropSet = getAdditionalPropertySet( rTargetKey, sal_True );
+            xNewPropSet = getAdditionalPropertySet( rTargetKey, true );
             if ( !xNewPropSet.is() )
-                return sal_False;
+                return false;
 
             uno::Reference< beans::XPropertyContainer > xNewPropContainer(
                 xNewPropSet, uno::UNO_QUERY );
             if ( !xNewPropContainer.is() )
-                return sal_False;
+                return false;
 
             for ( sal_Int32 n = 0; n < nCount; ++n )
             {
@@ -572,12 +488,11 @@ sal_Bool ContentProviderImplHelper::copyAdditionalPropertySet(
             }
         }
     }
-    return sal_True;
+    return true;
 }
 
-//=========================================================================
-sal_Bool ContentProviderImplHelper::removeAdditionalPropertySet(
-    const OUString& rKey, sal_Bool bRecursive )
+bool ContentProviderImplHelper::removeAdditionalPropertySet(
+    const OUString& rKey, bool bRecursive )
 {
     osl::MutexGuard aGuard( m_aMutex );
 
@@ -601,7 +516,7 @@ sal_Bool ContentProviderImplHelper::removeAdditionalPropertySet(
                     OUString aKeyWithoutSlash;
                     if ( !aKeyWithSlash.endsWith("/") )
                     {
-                        aKeyWithSlash += OUString( '/' );
+                        aKeyWithSlash += "/";
                         aKeyWithoutSlash = rKey;
                     }
                     else if ( !rKey.isEmpty() )
@@ -612,23 +527,21 @@ sal_Bool ContentProviderImplHelper::removeAdditionalPropertySet(
                     for ( sal_Int32 n = 0; n < nCount; ++n )
                     {
                         const OUString& rCurrKey = pKeys[ n ];
-                        if ( rCurrKey.compareTo(
-                                 aKeyWithSlash,
-                                 aKeyWithSlash.getLength() ) == 0
-                             || rCurrKey.equals( aKeyWithoutSlash ) )
+                        if ( rCurrKey.startsWith(aKeyWithSlash )
+                             || rCurrKey == aKeyWithoutSlash )
                         {
                             if ( !removeAdditionalPropertySet(
-                                     rCurrKey, sal_False ) )
-                                return sal_False;
+                                     rCurrKey, false ) )
+                                return false;
                         }
                     }
                 }
             }
             else
-                return sal_False;
+                return false;
         }
         else
-            return sal_False;
+            return false;
     }
     else
     {
@@ -638,9 +551,9 @@ sal_Bool ContentProviderImplHelper::removeAdditionalPropertySet(
         if ( m_pImpl->m_xPropertySetRegistry.is() )
             m_pImpl->m_xPropertySetRegistry->removePropertySet( rKey );
         else
-            return sal_False;
+            return false;
     }
-    return sal_True;
+    return true;
 }
 
 } // namespace ucbhelper
