@@ -24,7 +24,7 @@
 
  *************************************************************************/
 
-#include "osl/diagnose.h"
+#include <osl/diagnose.h>
 #include <com/sun/star/beans/Property.hpp>
 #include <com/sun/star/beans/XPropertySetInfo.hpp>
 #include <com/sun/star/io/XInputStream.hpp>
@@ -56,16 +56,13 @@ struct ResultSetMetaData_Impl
     osl::Mutex                                      m_aMutex;
     std::vector< ::ucbhelper::ResultSetColumnData > m_aColumnData;
     bool                                        m_bObtainedTypes;
-    bool                                        m_bGlobalReadOnlyValue;
 
     explicit ResultSetMetaData_Impl( sal_Int32 nSize )
-    : m_aColumnData( nSize ), m_bObtainedTypes( false ),
-      m_bGlobalReadOnlyValue( true ) {}
+    : m_aColumnData( nSize ), m_bObtainedTypes( false ) {}
 
     explicit ResultSetMetaData_Impl(
         const std::vector< ::ucbhelper::ResultSetColumnData >& rColumnData )
-    : m_aColumnData( rColumnData ), m_bObtainedTypes( false ),
-      m_bGlobalReadOnlyValue( false ) {}
+    : m_aColumnData( rColumnData ), m_bObtainedTypes( false ) {}
 };
 
 }
@@ -75,21 +72,15 @@ using namespace ucbhelper_impl;
 namespace ucbhelper {
 
 
-
-
 // ResultSetMetaData Implementation.
 
 
-
-
 ResultSetMetaData::ResultSetMetaData(
                         const Reference< XComponentContext >& rxContext,
-                        const Sequence< Property >& rProps,
-                        bool bReadOnly )
+                        const Sequence< Property >& rProps )
 : m_pImpl( new ResultSetMetaData_Impl( rProps.getLength() ) ),
   m_xContext( rxContext ),
-  m_aProps( rProps ),
-  m_bReadOnly( bReadOnly )
+  m_aProps( rProps )
 {
 }
 
@@ -100,8 +91,7 @@ ResultSetMetaData::ResultSetMetaData(
                         const std::vector< ResultSetColumnData >& rColumnData )
 : m_pImpl( new ResultSetMetaData_Impl( rColumnData ) ),
   m_xContext( rxContext ),
-  m_aProps( rProps ),
-  m_bReadOnly( true )
+  m_aProps( rProps )
 {
     OSL_ENSURE( rColumnData.size() == sal_uInt32( rProps.getLength() ),
                 "ResultSetMetaData ctor - different array sizes!" );
@@ -114,7 +104,6 @@ ResultSetMetaData::~ResultSetMetaData()
 }
 
 
-
 // XInterface methods.
 
 void SAL_CALL ResultSetMetaData::acquire()
@@ -130,11 +119,10 @@ void SAL_CALL ResultSetMetaData::release()
 }
 
 css::uno::Any SAL_CALL ResultSetMetaData::queryInterface( const css::uno::Type & rType )
-    throw( css::uno::RuntimeException, std::exception )
 {
     css::uno::Any aRet = cppu::queryInterface( rType,
-                                               (static_cast< XTypeProvider* >(this)),
-                                               (static_cast< XResultSetMetaData* >(this))
+                                               static_cast< XTypeProvider* >(this),
+                                               static_cast< XResultSetMetaData* >(this)
                                                );
     return aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType );
 }
@@ -142,117 +130,72 @@ css::uno::Any SAL_CALL ResultSetMetaData::queryInterface( const css::uno::Type &
 // XTypeProvider methods.
 
 
-
 XTYPEPROVIDER_IMPL_2( ResultSetMetaData,
                       XTypeProvider,
                       XResultSetMetaData );
 
 
-
 // XResultSetMetaData methods.
 
 
-
 // virtual
 sal_Int32 SAL_CALL ResultSetMetaData::getColumnCount()
-    throw( SQLException, RuntimeException, std::exception )
 {
     return m_aProps.getLength();
 }
 
 
 // virtual
-sal_Bool SAL_CALL ResultSetMetaData::isAutoIncrement( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Bool SAL_CALL ResultSetMetaData::isAutoIncrement( sal_Int32 /*column*/ )
 {
     /*
         Checks whether column is automatically numbered, which makes it
         read-only.
      */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return sal_False;
-
-    return m_pImpl->m_aColumnData[ column - 1 ].isAutoIncrement;
+    return false;
 }
 
 
 // virtual
 sal_Bool SAL_CALL ResultSetMetaData::isCaseSensitive( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
 {
     if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return sal_False;
+        return false;
 
     return m_pImpl->m_aColumnData[ column - 1 ].isCaseSensitive;
 }
 
 
 // virtual
-sal_Bool SAL_CALL ResultSetMetaData::isSearchable( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Bool SAL_CALL ResultSetMetaData::isSearchable( sal_Int32 /*column*/ )
 {
-    /*
-        Checks whether the value stored in column can be used in a
-        WHERE clause.
-     */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return sal_False;
-
-    return m_pImpl->m_aColumnData[ column - 1 ].isSearchable;
+    return false;
 }
 
 
 // virtual
-sal_Bool SAL_CALL ResultSetMetaData::isCurrency( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Bool SAL_CALL ResultSetMetaData::isCurrency( sal_Int32 /*column*/ )
 {
-    /*
-        Checks whether column is a cash value.
-     */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return sal_False;
-
-    return m_pImpl->m_aColumnData[ column - 1 ].isCurrency;
+    return false;
 }
 
 
 // virtual
-sal_Int32 SAL_CALL ResultSetMetaData::isNullable( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Int32 SAL_CALL ResultSetMetaData::isNullable( sal_Int32 /*column*/ )
 {
-    /*
-        Checks whether a NULL can be stored in column.
-        Possible values: see com/sun/star/sdbc/ColumnValue.idl
-     */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return ColumnValue::NULLABLE;
-
-    return m_pImpl->m_aColumnData[ column - 1 ].isNullable;
+    return ColumnValue::NULLABLE;
 }
 
 
 // virtual
-sal_Bool SAL_CALL ResultSetMetaData::isSigned( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Bool SAL_CALL ResultSetMetaData::isSigned( sal_Int32 /*column*/ )
 {
-    /*
-        Checks whether the value stored in column is a signed number.
-     */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return sal_False;
-
-    return m_pImpl->m_aColumnData[ column - 1 ].isSigned;
+    return false;
 }
 
 
 // virtual
 sal_Int32 SAL_CALL ResultSetMetaData::getColumnDisplaySize( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
 {
     /*
         Gets the normal maximum width in characters for column.
@@ -267,7 +210,6 @@ sal_Int32 SAL_CALL ResultSetMetaData::getColumnDisplaySize( sal_Int32 column )
 
 // virtual
 OUString SAL_CALL ResultSetMetaData::getColumnLabel( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
 {
     /*
         Gets the suggested column title for column, to be used in print-
@@ -277,17 +219,12 @@ OUString SAL_CALL ResultSetMetaData::getColumnLabel( sal_Int32 column )
     if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
         return OUString();
 
-    OUString aLabel = m_pImpl->m_aColumnData[ column - 1 ].columnLabel;
-    if ( !aLabel.isEmpty() )
-        return aLabel;
-
     return m_aProps.getConstArray()[ column - 1 ].Name;
 }
 
 
 // virtual
 OUString SAL_CALL ResultSetMetaData::getColumnName( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
 {
     /*
         Gets the name of column.
@@ -301,8 +238,7 @@ OUString SAL_CALL ResultSetMetaData::getColumnName( sal_Int32 column )
 
 
 // virtual
-OUString SAL_CALL ResultSetMetaData::getSchemaName( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+OUString SAL_CALL ResultSetMetaData::getSchemaName( sal_Int32 /*column*/ )
 {
     /*
         Gets the schema name for the table from which column of this
@@ -310,52 +246,26 @@ OUString SAL_CALL ResultSetMetaData::getSchemaName( sal_Int32 column )
         Because this feature is not widely supported, the return value
         for many DBMSs will be an empty string.
      */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return OUString();
-
-    return m_pImpl->m_aColumnData[ column - 1 ].schemaName;
+    return OUString();
 }
 
 
 // virtual
-sal_Int32 SAL_CALL ResultSetMetaData::getPrecision( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Int32 SAL_CALL ResultSetMetaData::getPrecision( sal_Int32 /*column*/ )
 {
-    /*
-        For number types, getprecision gets the number of decimal digits
-        in column.
-        For character types, it gets the maximum length in characters for
-        column.
-        For binary types, it gets the maximum length in bytes for column.
-     */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return -1;
-
-    return m_pImpl->m_aColumnData[ column - 1 ].precision;
+    return -1;
 }
 
 
 // virtual
-sal_Int32 SAL_CALL ResultSetMetaData::getScale( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Int32 SAL_CALL ResultSetMetaData::getScale( sal_Int32 /*column*/ )
 {
-    /*
-        Gets the number of digits to the right of the decimal point for
-        values in column.
-     */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return 0;
-
-    return m_pImpl->m_aColumnData[ column - 1 ].scale;
+    return 0;
 }
 
 
 // virtual
-OUString SAL_CALL ResultSetMetaData::getTableName( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+OUString SAL_CALL ResultSetMetaData::getTableName( sal_Int32 /*column*/ )
 {
     /*
         Gets the name of the table from which column of this result set
@@ -363,17 +273,12 @@ OUString SAL_CALL ResultSetMetaData::getTableName( sal_Int32 column )
         Because this feature is not widely supported, the return value
         for many DBMSs will be an empty string.
      */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return OUString();
-
-    return m_pImpl->m_aColumnData[ column - 1 ].tableName;
+    return OUString();
 }
 
 
 // virtual
-OUString SAL_CALL ResultSetMetaData::getCatalogName( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+OUString SAL_CALL ResultSetMetaData::getCatalogName( sal_Int32 /*column*/ )
 {
     /*
         Gets the catalog name for the table from which column of this
@@ -381,17 +286,12 @@ OUString SAL_CALL ResultSetMetaData::getCatalogName( sal_Int32 column )
         Because this feature is not widely supported, the return value
         for many DBMSs will be an empty string.
      */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return OUString();
-
-    return m_pImpl->m_aColumnData[ column - 1 ].catalogName;
+    return OUString();
 }
 
 
 // virtual
 sal_Int32 SAL_CALL ResultSetMetaData::getColumnType( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
 {
     /*
         Gets the JDBC type for the value stored in column. ... The STRUCT
@@ -498,8 +398,7 @@ sal_Int32 SAL_CALL ResultSetMetaData::getColumnType( sal_Int32 column )
 
 
 // virtual
-OUString SAL_CALL ResultSetMetaData::getColumnTypeName( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+OUString SAL_CALL ResultSetMetaData::getColumnTypeName( sal_Int32 /*column*/ )
 {
     /*
         Gets the type name used by this particular data source for the
@@ -507,72 +406,40 @@ OUString SAL_CALL ResultSetMetaData::getColumnTypeName( sal_Int32 column )
         stored in column is STRUCT, DISTINCT or JAVA_OBJECT, this method
         returns a fully-qualified SQL type name.
      */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return OUString();
-
-    return m_pImpl->m_aColumnData[ column - 1 ].columnTypeName;
+    return OUString();
 }
 
 
 // virtual
-sal_Bool SAL_CALL ResultSetMetaData::isReadOnly( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Bool SAL_CALL ResultSetMetaData::isReadOnly( sal_Int32 /*column*/ )
 {
-    if ( m_pImpl->m_bGlobalReadOnlyValue )
-        return m_bReadOnly;
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return sal_True;
-
-    // autoincrement==true => readonly
-    return m_pImpl->m_aColumnData[ column - 1 ].isAutoIncrement ||
-           m_pImpl->m_aColumnData[ column - 1 ].isReadOnly;
+    return true;
 }
 
 
 // virtual
-sal_Bool SAL_CALL ResultSetMetaData::isWritable( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Bool SAL_CALL ResultSetMetaData::isWritable( sal_Int32 /*column*/ )
 {
-    if ( m_pImpl->m_bGlobalReadOnlyValue )
-        return !m_bReadOnly;
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return sal_False;
-
-    return m_pImpl->m_aColumnData[ column - 1 ].isWritable;
+    return false;
 }
 
 
 // virtual
-sal_Bool SAL_CALL ResultSetMetaData::isDefinitelyWritable( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+sal_Bool SAL_CALL ResultSetMetaData::isDefinitelyWritable( sal_Int32 /*column*/ )
 {
-    if ( m_pImpl->m_bGlobalReadOnlyValue )
-        return !m_bReadOnly;
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return sal_False;
-
-    return m_pImpl->m_aColumnData[ column - 1 ].isDefinitelyWritable;
+    return false;
 }
 
 
 // virtual
-OUString SAL_CALL ResultSetMetaData::getColumnServiceName( sal_Int32 column )
-    throw( SQLException, RuntimeException, std::exception )
+OUString SAL_CALL ResultSetMetaData::getColumnServiceName( sal_Int32 /*column*/ )
 {
     /*
           Returns the fully-qualified name of the service whose instances
          are manufactured if XResultSet::getObject is called to retrieve
         a value from the column.
      */
-
-    if ( ( column < 1 ) || ( column > m_aProps.getLength() ) )
-        return OUString();
-
-    return m_pImpl->m_aColumnData[ column - 1 ].columnServiceName;
+    return OUString();
 }
 
 } // namespace ucbhelper
