@@ -17,30 +17,29 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
-#include "codemaker/commoncpp.hxx"
-#include "codemaker/global.hxx"
+#include <codemaker/commoncpp.hxx>
+#include <codemaker/global.hxx>
 
 #include "skeletoncommon.hxx"
 #include "skeletoncpp.hxx"
 
 #include <iostream>
 
-using namespace ::rtl;
 using namespace ::codemaker::cpp;
 
 namespace skeletonmaker { namespace cpp {
 
 void generateIncludes(std::ostream & o,
          const std::set< OUString >& interfaces,
-         OUString propertyhelper, bool serviceobject,
-         bool supportxcomponent)
+         const OUString & propertyhelper, const bool serviceobject,
+         const bool supportxcomponent)
 {
     o << "#include \"sal/config.h\"\n";
     if (serviceobject) {
         o << "#include \"cppuhelper/factory.hxx\"\n"
-          << "#include \"cppuhelper/implementationentry.hxx\"\n";
+             "#include \"cppuhelper/implementationentry.hxx\"\n";
     } else {
         o << "#include \"com/sun/star/uno/XComponentContext.hpp\"\n";
     }
@@ -52,7 +51,7 @@ void generateIncludes(std::ostream & o,
     }
 
     if (propertyhelper.getLength() > 1) {
-        if (propertyhelper.equals("_"))
+        if (propertyhelper == "_")
             o << "#include \"cppuhelper/rpopshlp.hxx\"\n";
         else
             o << "#include \"cppuhelper/propertysetmixin.hxx\"\n";
@@ -62,7 +61,7 @@ void generateIncludes(std::ostream & o,
     while (iter != interfaces.end())
     {
         o << "#include \""
-          << ((*iter).replace('.', '/').getStr())
+          << (*iter).replace('.', '/')
           << ".hpp\"\n";
         ++iter;
     }
@@ -89,7 +88,7 @@ short generateNamespace(std::ostream & o,
             o << "namespace comp_" << implname << " {\n\n";
             count=1;
         } else {
-            nm = OString();
+            nm.clear();
         }
     } else {
         sal_Int32 nPos=0;
@@ -147,12 +146,12 @@ void generateCompHelperDefinition(std::ostream & o,
     short nbrackets = generateNamespace(o, implname, true, nm);
 
     o << "::rtl::OUString SAL_CALL _getImplementationName() {\n"
-      << "    return ::rtl::OUString(\n"
-      << "        \"" << implname << "\");\n}\n\n";
+         "    return ::rtl::OUString(\n"
+         "        \"" << implname << "\");\n}\n\n";
 
     o << "css::uno::Sequence< ::rtl::OUString > SAL_CALL "
         "_getSupportedServiceNames()\n{\n    css::uno::Sequence< "
-      << "::rtl::OUString >" << " s(" << services.size() << ");\n";
+        "::rtl::OUString > s(" << services.size() << ");\n";
 
     std::set< OUString >::const_iterator iter = services.begin();
     short i=0;
@@ -165,9 +164,9 @@ void generateCompHelperDefinition(std::ostream & o,
     o << "    return s;\n}\n\n";
 
     o << "css::uno::Reference< css::uno::XInterface > SAL_CALL _create("
-      << "\n    const css::uno::Reference< css::uno::XComponentContext > & "
-      << "context)\n        SAL_THROW((css::uno::Exception))\n{\n"
-      << "    return static_cast< ::cppu::OWeakObject * >(new "
+         "\n    const css::uno::Reference< css::uno::XComponentContext > & "
+         "context)\n{\n"
+         "    return static_cast< ::cppu::OWeakObject * >(new "
       << classname <<  "(context));\n}\n\n";
 
     // close namepsace
@@ -180,21 +179,21 @@ void generateCompHelperDefinition(std::ostream & o,
 void generateCompFunctions(std::ostream & o, const OString & nmspace)
 {
     o << "static ::cppu::ImplementationEntry const entries[] = {\n"
-      << "    { &" << nmspace << "::_create,\n      &"
+         "    { &" << nmspace << "::_create,\n      &"
       << nmspace << "::_getImplementationName,\n      &"
       << nmspace << "::_getSupportedServiceNames,\n"
-      << "      &::cppu::createSingleComponentFactory, 0, 0 },\n"
-      << "    { 0, 0, 0, 0, 0, 0 }\n};\n\n";
+         "      &::cppu::createSingleComponentFactory, 0, 0 },\n"
+         "    { 0, 0, 0, 0, 0, 0 }\n};\n\n";
 
     o << "extern \"C\" SAL_DLLPUBLIC_EXPORT void * SAL_CALL component_getFactory(\n"
-      << "    const char * implName, void * serviceManager, void * registryKey)\n{\n"
-      << "    return ::cppu::component_getFactoryHelper(\n"
-      << "        implName, serviceManager, registryKey, entries);\n}\n\n";
+         "    const char * implName, void * serviceManager, void * registryKey)\n{\n"
+         "    return ::cppu::component_getFactoryHelper(\n"
+         "        implName, serviceManager, registryKey, entries);\n}\n\n";
 
     o << "extern \"C\" sal_Bool SAL_CALL component_writeInfo(\n"
-      << "    void * serviceManager, void * registryKey)\n{\n"
-      << "    return ::cppu::component_writeInfoHelper("
-      << "serviceManager, registryKey, entries);\n}\n";
+         "    void * serviceManager, void * registryKey)\n{\n"
+         "    return ::cppu::component_writeInfoHelper("
+         "serviceManager, registryKey, entries);\n}\n";
 }
 
 void generateXPropertySetBodies(std::ostream& o,
@@ -508,7 +507,7 @@ void generateAddinConstructorAndHelper(std::ostream& o,
 {
     o << classname << "::" << classname
       << "(css::uno::Reference< css::uno::XComponentContext > const & context) :\n"
-      << "    m_xContext(context),    m_locale()\n{\n";
+         "    m_xContext(context),    m_locale()\n{\n";
 
     if (options.backwardcompatible) {
         o << "     try {\n";
@@ -539,8 +538,7 @@ void generateAddinConstructorAndHelper(std::ostream& o,
             "        css::uno::Reference< css::uno::XInterface > xIface =\n"
             "            xProvider->createInstanceWithArguments(sReadOnlyView, "
             "aArguments);\n\n"
-            "         m_xHAccess = css::uno::Reference<\n            "
-            "css::container::XHierarchicalNameAccess >(xIface, css::uno::UNO_QUERY);"
+            "         m_xHAccess.set(xIface, css::uno::UNO_QUERY);"
             "\n\n";
 
         o << "        // extend arguments to create a view for all locales to get "
@@ -552,8 +550,7 @@ void generateAddinConstructorAndHelper(std::ostream& o,
             "        // create view for all locales\n"
             "        xIface = xProvider->createInstanceWithArguments(sReadOnlyView, "
             "aArguments);\n\n"
-            "        m_xCompAccess = css::uno::Reference<\n            "
-            "css::container::XHierarchicalNameAccess >(xIface, css::uno::UNO_QUERY);\n";
+            "        m_xCompAccess.set(xIface, css::uno::UNO_QUERY);\n";
 
         o << "    }\n    catch ( css::uno::Exception & ) {\n    }\n}\n\n";
 
@@ -587,8 +584,8 @@ void generateMemberInitialization(std::ostream& o,
              i != members.end(); ++i)
         {
             sal_Int32 rank;
-            if ((manager->decompose(i->type, true, 0, &rank, 0, 0)
-                 <= codemaker::UnoType::SORT_CHAR)
+            if ((manager->decompose(i->type, true, nullptr, &rank, nullptr, nullptr)
+                 <= codemaker::UnoType::Sort::Char)
                 && rank == 0)
             {
                 o << ",\n    m_" << i->name << "(";
@@ -608,7 +605,7 @@ void generateMemberDeclaration(std::ostream& o,
          i != members.end(); ++i)
     {
         o << "    ";
-        printType(o, options, manager, i->type, 1, false);
+        printType(o, options, manager, i->type, 1);
         o << " m_" << i->name << ";\n";
     }
 }
@@ -631,7 +628,7 @@ OString generateClassDefinition(std::ostream& o,
             parentname.append("::cppu::WeakComponentImplHelper");
             parentname.append(static_cast<sal_Int32>(interfaces.size()));
             o << "    private ::cppu::BaseMutex,\n"
-              << "    public ::cppu::WeakComponentImplHelper"
+                 "    public ::cppu::WeakComponentImplHelper"
               << interfaces.size() << "<";
         } else {
             parentname.append("::cppu::WeakImplHelper");
@@ -657,8 +654,8 @@ OString generateClassDefinition(std::ostream& o,
     }
 
     o << "\n{\npublic:\n"
-      << "    explicit " << classname << "("
-      << "css::uno::Reference< css::uno::XComponentContext > const & context);\n\n";
+         "    explicit " << classname << "("
+         "css::uno::Reference< css::uno::XComponentContext > const & context);\n\n";
 
     // generate component/service helper functions
 //     o << "    // component and service helper functions:\n"
@@ -669,7 +666,7 @@ OString generateClassDefinition(std::ostream& o,
 //       << "\n        css::uno::Reference< css::uno::XComponentContext > const & "
 //       << "context);\n\n";
 
-    // overload queryInterface
+    // override queryInterface
     if (propertyhelper.getLength() > 1) {
         o << "    // css::uno::XInterface:\n"
             "    virtual css::uno::Any SAL_CALL queryInterface("
@@ -706,9 +703,9 @@ OString generateClassDefinition(std::ostream& o,
     }
 
     o << "private:\n    " << classname << "(const " << classname << " &); // not defined\n"
-      << "    " << classname << "& operator=(const " << classname << " &); // not defined\n\n"
-      << "    // destructor is private and will be called indirectly by the release call"
-      << "    virtual ~" << classname << "() {}\n\n";
+         "    " << classname << "& operator=(const " << classname << " &); // not defined\n\n"
+         "    // destructor is private and will be called indirectly by the release call"
+         "    virtual ~" << classname << "() {}\n\n";
 
     if (options.componenttype == 2) {
         o << "    typedef boost::unordered_map< ::sal_Int32, rtl::OUString, "
@@ -721,7 +718,7 @@ OString generateClassDefinition(std::ostream& o,
     }
 
     if (supportxcomponent) {
-        o << "    // overload WeakComponentImplHelperBase::disposing()\n"
+        o << "    // override WeakComponentImplHelperBase::disposing()\n"
             "    // This function is called upon disposing the component,\n"
             "    // if your component needs special work when it becomes\n"
             "    // disposed, do it here.\n"
@@ -761,7 +758,7 @@ OString generateClassDefinition(std::ostream& o,
 //             printType(o, options, manager, iter->second.first.replace('.','/'),
 //                       1, false);
 //             o << " m_" << iter->first << ";\n";
-//             iter++;
+//             ++iter;
 //         }
 //     }
 //     if (!attributes.empty())
@@ -773,7 +770,7 @@ OString generateClassDefinition(std::ostream& o,
 //             printType(o, options, manager, iter->second.first.replace('.','/'),
 //                       1, false);
 //             o << " m_" << iter->first << ";\n";
-//             iter++;
+//             ++iter;
 //         }
 //     }
 
@@ -801,7 +798,7 @@ OString generateClassDefinition(std::ostream& o,
         if (propertyhelper.getLength() > 1) {
             o << "    ::cppu::PropertySetMixin< "
               << scopedCppName(u2b(propertyhelper)) << " >(\n"
-              << "        context, static_cast< Implements >(\n            ";
+                 "        context, static_cast< Implements >(\n            ";
             OStringBuffer buffer(128);
             if (propinterfaces.find("com/sun/star/beans/XPropertySet")
                 != propinterfaces.end()) {
@@ -836,7 +833,7 @@ OString generateClassDefinition(std::ostream& o,
 //     generateServiceHelper(o, options.implname, classname, services);
 
     if (supportxcomponent) {
-        o << "// overload WeakComponentImplHelperBase::disposing()\n"
+        o << "// override WeakComponentImplHelperBase::disposing()\n"
             "// This function is called upon disposing the component,\n"
             "// if your component needs special work when it becomes\n"
             "// disposed, do it here.\n"
@@ -851,22 +848,22 @@ void generateXServiceInfoBodies(std::ostream& o,
                                 OString const & comphelpernamespace)
 {
     o << "// com.sun.star.uno.XServiceInfo:\n"
-      << "::rtl::OUString SAL_CALL " << classname << "getImplementationName() "
-      << "throw (css::uno::RuntimeException)\n{\n    "
-      << "return " << comphelpernamespace << "::_getImplementationName();\n}\n\n";
+         "::rtl::OUString SAL_CALL " << classname << "getImplementationName() "
+         "throw (css::uno::RuntimeException)\n{\n    "
+         "return " << comphelpernamespace << "::_getImplementationName();\n}\n\n";
 
-    o << "::sal_Bool SAL_CALL " << classname
+    o << "sal_Bool SAL_CALL " << classname
       << "supportsService(::rtl::OUString const & "
-      << "serviceName) throw (css::uno::RuntimeException)\n{\n    "
-      << "css::uno::Sequence< ::rtl::OUString > serviceNames = "
+         "serviceName) throw (css::uno::RuntimeException)\n{\n    "
+         "css::uno::Sequence< ::rtl::OUString > serviceNames = "
       << comphelpernamespace << "::_getSupportedServiceNames();\n    "
-      << "for (::sal_Int32 i = 0; i < serviceNames.getLength(); ++i) {\n    "
-      << "    if (serviceNames[i] == serviceName)\n            return sal_True;\n"
-      << "    }\n    return sal_False;\n}\n\n";
+         "for (::sal_Int32 i = 0; i < serviceNames.getLength(); ++i) {\n    "
+         "    if (serviceNames[i] == serviceName)\n            return sal_True;\n"
+         "    }\n    return sal_False;\n}\n\n";
 
     o << "css::uno::Sequence< ::rtl::OUString > SAL_CALL " << classname
       << "getSupportedServiceNames() throw (css::uno::RuntimeException)\n{\n    "
-      << "return " << comphelpernamespace
+         "return " << comphelpernamespace
       << "::_getSupportedServiceNames();\n}\n\n";
 }
 
@@ -883,7 +880,7 @@ void generateMethodBodies(std::ostream& o,
     std::set< OUString >::const_iterator iter = interfaces.begin();
     codemaker::GeneratedTypeSet generated;
     while (iter != interfaces.end()) {
-        if ( (*iter).equals("com.sun.star.lang.XServiceInfo") ) {
+        if ( *iter == "com.sun.star.lang.XServiceInfo" ) {
             generateXServiceInfoBodies(o, name, comphelpernamespace);
             generated.add(u2b(*iter));
         } else {
@@ -931,11 +928,11 @@ void generateQueryInterface(std::ostream& o,
     } else {
         o << "::queryInterface(type));\n";
         o << "    return a.hasValue() ? a\n        : (";
-        if (propertyhelper.equals("_")) {
+        if (propertyhelper == "_") {
             o << "::cppu::OPropertySetHelper::queryInterface(type));\n";
         } else {
             o << "::cppu::PropertySetMixin<\n            ";
-            printType(o, options, manager, propertyhelper, 0, false);
+            printType(o, options, manager, propertyhelper, 0);
             o << " >::queryInterface(\n               type));\n";
         }
     }
@@ -996,7 +993,7 @@ void generateSkeleton(ProgramOptions const & options,
 
     OString compFileName;
     OString tmpFileName;
-    std::ostream* pofs = NULL;
+    std::ostream* pofs = nullptr;
     bool standardout = getOutputStream(options, ".cxx",
                                        &pofs, compFileName, tmpFileName);
 
@@ -1057,16 +1054,16 @@ void generateSkeleton(ProgramOptions const & options,
             *pofs << (nm > 0 ? "// closing namespace\n\n" : "\n");
         }
 
-        if ( !standardout && pofs && ((std::ofstream*)pofs)->is_open()) {
-            ((std::ofstream*)pofs)->close();
+        if ( !standardout && pofs && static_cast<std::ofstream*>(pofs)->is_open()) {
+            static_cast<std::ofstream*>(pofs)->close();
             delete pofs;
-            OSL_VERIFY(makeValidTypeFile(compFileName, tmpFileName, sal_False));
+            OSL_VERIFY(makeValidTypeFile(compFileName, tmpFileName, false));
         }
     } catch (CannotDumpException & e) {
         std::cerr << "ERROR: " << e.getMessage() << "\n";
         if ( !standardout ) {
-            if (pofs && ((std::ofstream*)pofs)->is_open()) {
-                ((std::ofstream*)pofs)->close();
+            if (pofs && static_cast<std::ofstream*>(pofs)->is_open()) {
+                static_cast<std::ofstream*>(pofs)->close();
                 delete pofs;
             }
             // remove existing type file if something goes wrong to ensure
@@ -1110,12 +1107,12 @@ void generateCalcAddin(ProgramOptions const & options,
     // get the one and only add-in service for later use
     std::set< OUString >::const_iterator iter2 = services.begin();
     sAddinService = *iter2;
-    if (sAddinService.equals("com.sun.star.sheet.AddIn")) {
+    if (sAddinService == "com.sun.star.sheet.AddIn") {
         sAddinService = *(++iter2);
     }
 
     // if backwardcompatible==true the AddIn service needs to be added to the
-    // suported service list, the necessary intefaces are mapped to the add-in
+    // supported service list, the necessary intefaces are mapped to the add-in
     // configuration. Since OO.org 2.0.4 this is obsolete and the add-in is
     // take form the configuration from Calc directly, this simplifies the
     // add-in code
@@ -1157,7 +1154,7 @@ void generateCalcAddin(ProgramOptions const & options,
 
     OString compFileName;
     OString tmpFileName;
-    std::ostream* pofs = NULL;
+    std::ostream* pofs = nullptr;
     bool standardout = getOutputStream(options, ".cxx",
                                        &pofs, compFileName, tmpFileName);
 
@@ -1220,16 +1217,16 @@ void generateCalcAddin(ProgramOptions const & options,
 
         generateCompFunctions(*pofs, nmspace);
 
-        if ( !standardout && pofs && ((std::ofstream*)pofs)->is_open()) {
-            ((std::ofstream*)pofs)->close();
+        if ( !standardout && pofs && static_cast<std::ofstream*>(pofs)->is_open()) {
+            static_cast<std::ofstream*>(pofs)->close();
             delete pofs;
-            OSL_VERIFY(makeValidTypeFile(compFileName, tmpFileName, sal_False));
+            OSL_VERIFY(makeValidTypeFile(compFileName, tmpFileName, false));
         }
     } catch (CannotDumpException & e) {
         std::cerr << "ERROR: " << e.getMessage() << "\n";
         if ( !standardout ) {
-            if (pofs && ((std::ofstream*)pofs)->is_open()) {
-                ((std::ofstream*)pofs)->close();
+            if (pofs && static_cast<std::ofstream*>(pofs)->is_open()) {
+                static_cast<std::ofstream*>(pofs)->close();
                 delete pofs;
             }
             // remove existing type file if something goes wrong to ensure
